/********************************************************************************
** Form generated from reading UI file 'chatmonitorsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHATMONITORSETTINGSPAGE_H
#define UI_CHATMONITORSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "bufferview.h"

QT_BEGIN_NAMESPACE

class Ui_ChatMonitorSettingsPage
{
public:
    QVBoxLayout *verticalLayout_4;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    QComboBox *operationMode;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_3;
    QLabel *labelAvailableBuffers;
    BufferView *availableBuffers;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer;
    QPushButton *deactivateBuffer;
    QPushButton *activateBuffer;
    QSpacerItem *verticalSpacer_2;
    QVBoxLayout *verticalLayout_2;
    QLabel *labelActiveBuffers;
    BufferView *activeBuffers;
    QCheckBox *showHighlights;
    QCheckBox *showOwnMessages;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *alwaysOwn;
    QHBoxLayout *horizontalLayout_5;
    QCheckBox *showBacklog;
    QPushButton *showBacklogUnavailableDetails;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *includeRead;

    void setupUi(QWidget *ChatMonitorSettingsPage)
    {
        if (ChatMonitorSettingsPage->objectName().isEmpty())
            ChatMonitorSettingsPage->setObjectName(QString::fromUtf8("ChatMonitorSettingsPage"));
        ChatMonitorSettingsPage->resize(553, 444);
        verticalLayout_4 = new QVBoxLayout(ChatMonitorSettingsPage);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label = new QLabel(ChatMonitorSettingsPage);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout_2->addWidget(label);

        operationMode = new QComboBox(ChatMonitorSettingsPage);
        operationMode->setObjectName(QString::fromUtf8("operationMode"));

        horizontalLayout_2->addWidget(operationMode);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout_4->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        labelAvailableBuffers = new QLabel(ChatMonitorSettingsPage);
        labelAvailableBuffers->setObjectName(QString::fromUtf8("labelAvailableBuffers"));

        verticalLayout_3->addWidget(labelAvailableBuffers);

        availableBuffers = new BufferView(ChatMonitorSettingsPage);
        availableBuffers->setObjectName(QString::fromUtf8("availableBuffers"));

        verticalLayout_3->addWidget(availableBuffers);


        horizontalLayout->addLayout(verticalLayout_3);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        deactivateBuffer = new QPushButton(ChatMonitorSettingsPage);
        deactivateBuffer->setObjectName(QString::fromUtf8("deactivateBuffer"));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/go-previous.png"), QSize(), QIcon::Normal, QIcon::Off);
        deactivateBuffer->setIcon(icon);

        verticalLayout->addWidget(deactivateBuffer);

        activateBuffer = new QPushButton(ChatMonitorSettingsPage);
        activateBuffer->setObjectName(QString::fromUtf8("activateBuffer"));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/go-next.png"), QSize(), QIcon::Normal, QIcon::Off);
        activateBuffer->setIcon(icon1);

        verticalLayout->addWidget(activateBuffer);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        horizontalLayout->addLayout(verticalLayout);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        labelActiveBuffers = new QLabel(ChatMonitorSettingsPage);
        labelActiveBuffers->setObjectName(QString::fromUtf8("labelActiveBuffers"));

        verticalLayout_2->addWidget(labelActiveBuffers);

        activeBuffers = new BufferView(ChatMonitorSettingsPage);
        activeBuffers->setObjectName(QString::fromUtf8("activeBuffers"));

        verticalLayout_2->addWidget(activeBuffers);


        horizontalLayout->addLayout(verticalLayout_2);


        verticalLayout_4->addLayout(horizontalLayout);

        showHighlights = new QCheckBox(ChatMonitorSettingsPage);
        showHighlights->setObjectName(QString::fromUtf8("showHighlights"));

        verticalLayout_4->addWidget(showHighlights);

        showOwnMessages = new QCheckBox(ChatMonitorSettingsPage);
        showOwnMessages->setObjectName(QString::fromUtf8("showOwnMessages"));

        verticalLayout_4->addWidget(showOwnMessages);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        horizontalSpacer_3 = new QSpacerItem(20, 16, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);

        alwaysOwn = new QCheckBox(ChatMonitorSettingsPage);
        alwaysOwn->setObjectName(QString::fromUtf8("alwaysOwn"));

        horizontalLayout_4->addWidget(alwaysOwn);


        verticalLayout_4->addLayout(horizontalLayout_4);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        showBacklog = new QCheckBox(ChatMonitorSettingsPage);
        showBacklog->setObjectName(QString::fromUtf8("showBacklog"));

        horizontalLayout_5->addWidget(showBacklog);

        showBacklogUnavailableDetails = new QPushButton(ChatMonitorSettingsPage);
        showBacklogUnavailableDetails->setObjectName(QString::fromUtf8("showBacklogUnavailableDetails"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(showBacklogUnavailableDetails->sizePolicy().hasHeightForWidth());
        showBacklogUnavailableDetails->setSizePolicy(sizePolicy);

        horizontalLayout_5->addWidget(showBacklogUnavailableDetails);


        verticalLayout_4->addLayout(horizontalLayout_5);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        horizontalSpacer_2 = new QSpacerItem(20, 16, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);

        includeRead = new QCheckBox(ChatMonitorSettingsPage);
        includeRead->setObjectName(QString::fromUtf8("includeRead"));

        horizontalLayout_3->addWidget(includeRead);


        verticalLayout_4->addLayout(horizontalLayout_3);

        QWidget::setTabOrder(operationMode, availableBuffers);
        QWidget::setTabOrder(availableBuffers, deactivateBuffer);
        QWidget::setTabOrder(deactivateBuffer, activateBuffer);
        QWidget::setTabOrder(activateBuffer, activeBuffers);
        QWidget::setTabOrder(activeBuffers, showHighlights);
        QWidget::setTabOrder(showHighlights, showOwnMessages);
        QWidget::setTabOrder(showOwnMessages, alwaysOwn);
        QWidget::setTabOrder(alwaysOwn, showBacklog);
        QWidget::setTabOrder(showBacklog, showBacklogUnavailableDetails);
        QWidget::setTabOrder(showBacklogUnavailableDetails, includeRead);

        retranslateUi(ChatMonitorSettingsPage);
        QObject::connect(showOwnMessages, SIGNAL(toggled(bool)), alwaysOwn, SLOT(setEnabled(bool)));
        QObject::connect(showBacklog, SIGNAL(toggled(bool)), includeRead, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(ChatMonitorSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *ChatMonitorSettingsPage)
    {
        ChatMonitorSettingsPage->setWindowTitle(QCoreApplication::translate("ChatMonitorSettingsPage", "Form", nullptr));
        label->setText(QCoreApplication::translate("ChatMonitorSettingsPage", "Operation Mode:", nullptr));
#if QT_CONFIG(tooltip)
        operationMode->setToolTip(QCoreApplication::translate("ChatMonitorSettingsPage", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'DejaVu Sans'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">Operation modes:</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-weight:600;\"><span style=\" font-weight:400; text-decoration: underline;\">Opt-In:</span> <span style=\" font-weight:400;\">Only buffers on the right side are shown in chatmonitor</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" text-decoration: underline;\">Opt-Out:</span"
                        "> Buffers on the right side will be ignored in chatmonitor</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        labelAvailableBuffers->setText(QCoreApplication::translate("ChatMonitorSettingsPage", "Available:", nullptr));
#if QT_CONFIG(tooltip)
        deactivateBuffer->setToolTip(QCoreApplication::translate("ChatMonitorSettingsPage", "Move selected buffers to the left", nullptr));
#endif // QT_CONFIG(tooltip)
        deactivateBuffer->setText(QString());
#if QT_CONFIG(tooltip)
        activateBuffer->setToolTip(QCoreApplication::translate("ChatMonitorSettingsPage", "Move selected buffers to the right", nullptr));
#endif // QT_CONFIG(tooltip)
        activateBuffer->setText(QString());
        labelActiveBuffers->setText(QCoreApplication::translate("ChatMonitorSettingsPage", "Show:", nullptr));
#if QT_CONFIG(tooltip)
        showHighlights->setToolTip(QCoreApplication::translate("ChatMonitorSettingsPage", "Show highlights in chatmonitor even if the originating buffer is ignored", nullptr));
#endif // QT_CONFIG(tooltip)
        showHighlights->setText(QCoreApplication::translate("ChatMonitorSettingsPage", "Always show highlighted messages", nullptr));
        showOwnMessages->setText(QCoreApplication::translate("ChatMonitorSettingsPage", "Show own messages", nullptr));
#if QT_CONFIG(tooltip)
        alwaysOwn->setToolTip(QCoreApplication::translate("ChatMonitorSettingsPage", "Show own messages in chatmonitor even if the originating buffer is ignored", nullptr));
#endif // QT_CONFIG(tooltip)
        alwaysOwn->setText(QCoreApplication::translate("ChatMonitorSettingsPage", "Include ignored buffers", nullptr));
#if QT_CONFIG(tooltip)
        showBacklog->setToolTip(QCoreApplication::translate("ChatMonitorSettingsPage", "Display messages from backlog on reconnect", nullptr));
#endif // QT_CONFIG(tooltip)
        showBacklog->setText(QCoreApplication::translate("ChatMonitorSettingsPage", "Show messages from backlog", nullptr));
        showBacklogUnavailableDetails->setText(QCoreApplication::translate("ChatMonitorSettingsPage", "Details...", nullptr));
#if QT_CONFIG(tooltip)
        includeRead->setToolTip(QCoreApplication::translate("ChatMonitorSettingsPage", "Include read messages from backlog on reconnect", nullptr));
#endif // QT_CONFIG(tooltip)
        includeRead->setText(QCoreApplication::translate("ChatMonitorSettingsPage", "Include read messages", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ChatMonitorSettingsPage: public Ui_ChatMonitorSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CHATMONITORSETTINGSPAGE_H
