/********************************************************************************
** Form generated from reading UI file 'receivefiledlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RECEIVEFILEDLG_H
#define UI_RECEIVEFILEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ReceiveFileDlg
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *infoText;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ReceiveFileDlg)
    {
        if (ReceiveFileDlg->objectName().isEmpty())
            ReceiveFileDlg->setObjectName(QString::fromUtf8("ReceiveFileDlg"));
        ReceiveFileDlg->resize(354, 97);
        verticalLayout = new QVBoxLayout(ReceiveFileDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        infoText = new QLabel(ReceiveFileDlg);
        infoText->setObjectName(QString::fromUtf8("infoText"));
        infoText->setText(QString::fromUtf8("Someone is trying to send you a file."));
        infoText->setWordWrap(true);

        verticalLayout->addWidget(infoText);

        buttonBox = new QDialogButtonBox(ReceiveFileDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Discard|QDialogButtonBox::Ignore|QDialogButtonBox::Save);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(ReceiveFileDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), ReceiveFileDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), ReceiveFileDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(ReceiveFileDlg);
    } // setupUi

    void retranslateUi(QDialog *ReceiveFileDlg)
    {
        ReceiveFileDlg->setWindowTitle(QCoreApplication::translate("ReceiveFileDlg", "Incoming File Transfer", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ReceiveFileDlg: public Ui_ReceiveFileDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_RECEIVEFILEDLG_H
