/****************************************************************************
** Meta object code from reading C++ file 'eventmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/eventmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'eventmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventManager_t {
    QByteArrayData data[74];
    char stringdata0[985];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventManager_t qt_meta_stringdata_EventManager = {
    {
QT_MOC_LITERAL(0, 0, 12), // "EventManager"
QT_MOC_LITERAL(1, 13, 14), // "registerObject"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 6), // "object"
QT_MOC_LITERAL(4, 36, 8), // "Priority"
QT_MOC_LITERAL(5, 45, 8), // "priority"
QT_MOC_LITERAL(6, 54, 12), // "methodPrefix"
QT_MOC_LITERAL(7, 67, 12), // "filterPrefix"
QT_MOC_LITERAL(8, 80, 20), // "registerEventHandler"
QT_MOC_LITERAL(9, 101, 9), // "EventType"
QT_MOC_LITERAL(10, 111, 5), // "event"
QT_MOC_LITERAL(11, 117, 11), // "const char*"
QT_MOC_LITERAL(12, 129, 4), // "slot"
QT_MOC_LITERAL(13, 134, 8), // "isFilter"
QT_MOC_LITERAL(14, 143, 16), // "QList<EventType>"
QT_MOC_LITERAL(15, 160, 6), // "events"
QT_MOC_LITERAL(16, 167, 19), // "registerEventFilter"
QT_MOC_LITERAL(17, 187, 9), // "postEvent"
QT_MOC_LITERAL(18, 197, 6), // "Event*"
QT_MOC_LITERAL(19, 204, 9), // "EventFlag"
QT_MOC_LITERAL(20, 214, 4), // "Self"
QT_MOC_LITERAL(21, 219, 4), // "Fake"
QT_MOC_LITERAL(22, 224, 8), // "Netsplit"
QT_MOC_LITERAL(23, 233, 7), // "Backlog"
QT_MOC_LITERAL(24, 241, 6), // "Silent"
QT_MOC_LITERAL(25, 248, 7), // "Stopped"
QT_MOC_LITERAL(26, 256, 10), // "EventFlags"
QT_MOC_LITERAL(27, 267, 7), // "Invalid"
QT_MOC_LITERAL(28, 275, 12), // "GenericEvent"
QT_MOC_LITERAL(29, 288, 14), // "EventGroupMask"
QT_MOC_LITERAL(30, 303, 12), // "NetworkEvent"
QT_MOC_LITERAL(31, 316, 17), // "NetworkConnecting"
QT_MOC_LITERAL(32, 334, 19), // "NetworkInitializing"
QT_MOC_LITERAL(33, 354, 18), // "NetworkInitialized"
QT_MOC_LITERAL(34, 373, 19), // "NetworkReconnecting"
QT_MOC_LITERAL(35, 393, 20), // "NetworkDisconnecting"
QT_MOC_LITERAL(36, 414, 19), // "NetworkDisconnected"
QT_MOC_LITERAL(37, 434, 16), // "NetworkSplitJoin"
QT_MOC_LITERAL(38, 451, 16), // "NetworkSplitQuit"
QT_MOC_LITERAL(39, 468, 15), // "NetworkIncoming"
QT_MOC_LITERAL(40, 484, 14), // "IrcServerEvent"
QT_MOC_LITERAL(41, 499, 17), // "IrcServerIncoming"
QT_MOC_LITERAL(42, 517, 19), // "IrcServerParseError"
QT_MOC_LITERAL(43, 537, 8), // "IrcEvent"
QT_MOC_LITERAL(44, 546, 20), // "IrcEventAuthenticate"
QT_MOC_LITERAL(45, 567, 15), // "IrcEventAccount"
QT_MOC_LITERAL(46, 583, 12), // "IrcEventAway"
QT_MOC_LITERAL(47, 596, 11), // "IrcEventCap"
QT_MOC_LITERAL(48, 608, 15), // "IrcEventChghost"
QT_MOC_LITERAL(49, 624, 14), // "IrcEventInvite"
QT_MOC_LITERAL(50, 639, 12), // "IrcEventJoin"
QT_MOC_LITERAL(51, 652, 12), // "IrcEventKick"
QT_MOC_LITERAL(52, 665, 12), // "IrcEventMode"
QT_MOC_LITERAL(53, 678, 12), // "IrcEventNick"
QT_MOC_LITERAL(54, 691, 14), // "IrcEventNotice"
QT_MOC_LITERAL(55, 706, 12), // "IrcEventPart"
QT_MOC_LITERAL(56, 719, 12), // "IrcEventPing"
QT_MOC_LITERAL(57, 732, 12), // "IrcEventPong"
QT_MOC_LITERAL(58, 745, 15), // "IrcEventPrivmsg"
QT_MOC_LITERAL(59, 761, 12), // "IrcEventQuit"
QT_MOC_LITERAL(60, 774, 14), // "IrcEventTagmsg"
QT_MOC_LITERAL(61, 789, 13), // "IrcEventTopic"
QT_MOC_LITERAL(62, 803, 13), // "IrcEventError"
QT_MOC_LITERAL(63, 817, 15), // "IrcEventSetname"
QT_MOC_LITERAL(64, 833, 15), // "IrcEventWallops"
QT_MOC_LITERAL(65, 849, 18), // "IrcEventRawPrivmsg"
QT_MOC_LITERAL(66, 868, 17), // "IrcEventRawNotice"
QT_MOC_LITERAL(67, 886, 15), // "IrcEventUnknown"
QT_MOC_LITERAL(68, 902, 15), // "IrcEventNumeric"
QT_MOC_LITERAL(69, 918, 19), // "IrcEventNumericMask"
QT_MOC_LITERAL(70, 938, 12), // "MessageEvent"
QT_MOC_LITERAL(71, 951, 9), // "CtcpEvent"
QT_MOC_LITERAL(72, 961, 14), // "CtcpEventFlush"
QT_MOC_LITERAL(73, 976, 8) // "KeyEvent"

    },
    "EventManager\0registerObject\0\0object\0"
    "Priority\0priority\0methodPrefix\0"
    "filterPrefix\0registerEventHandler\0"
    "EventType\0event\0const char*\0slot\0"
    "isFilter\0QList<EventType>\0events\0"
    "registerEventFilter\0postEvent\0Event*\0"
    "EventFlag\0Self\0Fake\0Netsplit\0Backlog\0"
    "Silent\0Stopped\0EventFlags\0Invalid\0"
    "GenericEvent\0EventGroupMask\0NetworkEvent\0"
    "NetworkConnecting\0NetworkInitializing\0"
    "NetworkInitialized\0NetworkReconnecting\0"
    "NetworkDisconnecting\0NetworkDisconnected\0"
    "NetworkSplitJoin\0NetworkSplitQuit\0"
    "NetworkIncoming\0IrcServerEvent\0"
    "IrcServerIncoming\0IrcServerParseError\0"
    "IrcEvent\0IrcEventAuthenticate\0"
    "IrcEventAccount\0IrcEventAway\0IrcEventCap\0"
    "IrcEventChghost\0IrcEventInvite\0"
    "IrcEventJoin\0IrcEventKick\0IrcEventMode\0"
    "IrcEventNick\0IrcEventNotice\0IrcEventPart\0"
    "IrcEventPing\0IrcEventPong\0IrcEventPrivmsg\0"
    "IrcEventQuit\0IrcEventTagmsg\0IrcEventTopic\0"
    "IrcEventError\0IrcEventSetname\0"
    "IrcEventWallops\0IrcEventRawPrivmsg\0"
    "IrcEventRawNotice\0IrcEventUnknown\0"
    "IrcEventNumeric\0IrcEventNumericMask\0"
    "MessageEvent\0CtcpEvent\0CtcpEventFlush\0"
    "KeyEvent"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       3,  174, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    4,   79,    2, 0x0a /* Public */,
       1,    3,   88,    2, 0x2a /* Public | MethodCloned */,
       1,    2,   95,    2, 0x2a /* Public | MethodCloned */,
       1,    1,  100,    2, 0x2a /* Public | MethodCloned */,
       8,    5,  103,    2, 0x0a /* Public */,
       8,    4,  114,    2, 0x2a /* Public | MethodCloned */,
       8,    3,  123,    2, 0x2a /* Public | MethodCloned */,
       8,    5,  130,    2, 0x0a /* Public */,
       8,    4,  141,    2, 0x2a /* Public | MethodCloned */,
       8,    3,  150,    2, 0x2a /* Public | MethodCloned */,
      16,    3,  157,    2, 0x0a /* Public */,
      16,    3,  164,    2, 0x0a /* Public */,
      17,    1,  171,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QObjectStar, 0x80000000 | 4, QMetaType::QString, QMetaType::QString,    3,    5,    6,    7,
    QMetaType::Void, QMetaType::QObjectStar, 0x80000000 | 4, QMetaType::QString,    3,    5,    6,
    QMetaType::Void, QMetaType::QObjectStar, 0x80000000 | 4,    3,    5,
    QMetaType::Void, QMetaType::QObjectStar,    3,
    QMetaType::Void, 0x80000000 | 9, QMetaType::QObjectStar, 0x80000000 | 11, 0x80000000 | 4, QMetaType::Bool,   10,    3,   12,    5,   13,
    QMetaType::Void, 0x80000000 | 9, QMetaType::QObjectStar, 0x80000000 | 11, 0x80000000 | 4,   10,    3,   12,    5,
    QMetaType::Void, 0x80000000 | 9, QMetaType::QObjectStar, 0x80000000 | 11,   10,    3,   12,
    QMetaType::Void, 0x80000000 | 14, QMetaType::QObjectStar, 0x80000000 | 11, 0x80000000 | 4, QMetaType::Bool,   15,    3,   12,    5,   13,
    QMetaType::Void, 0x80000000 | 14, QMetaType::QObjectStar, 0x80000000 | 11, 0x80000000 | 4,   15,    3,   12,    5,
    QMetaType::Void, 0x80000000 | 14, QMetaType::QObjectStar, 0x80000000 | 11,   15,    3,   12,
    QMetaType::Void, 0x80000000 | 9, QMetaType::QObjectStar, 0x80000000 | 11,   10,    3,   12,
    QMetaType::Void, 0x80000000 | 14, QMetaType::QObjectStar, 0x80000000 | 11,   15,    3,   12,
    QMetaType::Void, 0x80000000 | 18,   10,

 // enums: name, alias, flags, count, data
      19,   19, 0x1,    6,  189,
      26,   19, 0x1,    6,  201,
       9,    9, 0x0,   47,  213,

 // enum data: key, value
      20, uint(EventManager::Self),
      21, uint(EventManager::Fake),
      22, uint(EventManager::Netsplit),
      23, uint(EventManager::Backlog),
      24, uint(EventManager::Silent),
      25, uint(EventManager::Stopped),
      20, uint(EventManager::Self),
      21, uint(EventManager::Fake),
      22, uint(EventManager::Netsplit),
      23, uint(EventManager::Backlog),
      24, uint(EventManager::Silent),
      25, uint(EventManager::Stopped),
      27, uint(EventManager::Invalid),
      28, uint(EventManager::GenericEvent),
      29, uint(EventManager::EventGroupMask),
      30, uint(EventManager::NetworkEvent),
      31, uint(EventManager::NetworkConnecting),
      32, uint(EventManager::NetworkInitializing),
      33, uint(EventManager::NetworkInitialized),
      34, uint(EventManager::NetworkReconnecting),
      35, uint(EventManager::NetworkDisconnecting),
      36, uint(EventManager::NetworkDisconnected),
      37, uint(EventManager::NetworkSplitJoin),
      38, uint(EventManager::NetworkSplitQuit),
      39, uint(EventManager::NetworkIncoming),
      40, uint(EventManager::IrcServerEvent),
      41, uint(EventManager::IrcServerIncoming),
      42, uint(EventManager::IrcServerParseError),
      43, uint(EventManager::IrcEvent),
      44, uint(EventManager::IrcEventAuthenticate),
      45, uint(EventManager::IrcEventAccount),
      46, uint(EventManager::IrcEventAway),
      47, uint(EventManager::IrcEventCap),
      48, uint(EventManager::IrcEventChghost),
      49, uint(EventManager::IrcEventInvite),
      50, uint(EventManager::IrcEventJoin),
      51, uint(EventManager::IrcEventKick),
      52, uint(EventManager::IrcEventMode),
      53, uint(EventManager::IrcEventNick),
      54, uint(EventManager::IrcEventNotice),
      55, uint(EventManager::IrcEventPart),
      56, uint(EventManager::IrcEventPing),
      57, uint(EventManager::IrcEventPong),
      58, uint(EventManager::IrcEventPrivmsg),
      59, uint(EventManager::IrcEventQuit),
      60, uint(EventManager::IrcEventTagmsg),
      61, uint(EventManager::IrcEventTopic),
      62, uint(EventManager::IrcEventError),
      63, uint(EventManager::IrcEventSetname),
      64, uint(EventManager::IrcEventWallops),
      65, uint(EventManager::IrcEventRawPrivmsg),
      66, uint(EventManager::IrcEventRawNotice),
      67, uint(EventManager::IrcEventUnknown),
      68, uint(EventManager::IrcEventNumeric),
      69, uint(EventManager::IrcEventNumericMask),
      70, uint(EventManager::MessageEvent),
      71, uint(EventManager::CtcpEvent),
      72, uint(EventManager::CtcpEventFlush),
      73, uint(EventManager::KeyEvent),

       0        // eod
};

void EventManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<EventManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->registerObject((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< Priority(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 1: _t->registerObject((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< Priority(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 2: _t->registerObject((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< Priority(*)>(_a[2]))); break;
        case 3: _t->registerObject((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        case 4: _t->registerEventHandler((*reinterpret_cast< EventType(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2])),(*reinterpret_cast< const char*(*)>(_a[3])),(*reinterpret_cast< Priority(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        case 5: _t->registerEventHandler((*reinterpret_cast< EventType(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2])),(*reinterpret_cast< const char*(*)>(_a[3])),(*reinterpret_cast< Priority(*)>(_a[4]))); break;
        case 6: _t->registerEventHandler((*reinterpret_cast< EventType(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2])),(*reinterpret_cast< const char*(*)>(_a[3]))); break;
        case 7: _t->registerEventHandler((*reinterpret_cast< QList<EventType>(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2])),(*reinterpret_cast< const char*(*)>(_a[3])),(*reinterpret_cast< Priority(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        case 8: _t->registerEventHandler((*reinterpret_cast< QList<EventType>(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2])),(*reinterpret_cast< const char*(*)>(_a[3])),(*reinterpret_cast< Priority(*)>(_a[4]))); break;
        case 9: _t->registerEventHandler((*reinterpret_cast< QList<EventType>(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2])),(*reinterpret_cast< const char*(*)>(_a[3]))); break;
        case 10: _t->registerEventFilter((*reinterpret_cast< EventType(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2])),(*reinterpret_cast< const char*(*)>(_a[3]))); break;
        case 11: _t->registerEventFilter((*reinterpret_cast< QList<EventType>(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2])),(*reinterpret_cast< const char*(*)>(_a[3]))); break;
        case 12: _t->postEvent((*reinterpret_cast< Event*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject EventManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_EventManager.data,
    qt_meta_data_EventManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *EventManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int EventManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
