/********************************************************************************
** Form generated from reading UI file 'dccsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DCCSETTINGSPAGE_H
#define UI_DCCSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DccSettingsPage
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *dccEnabled;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QComboBox *portSelectionMode;
    QHBoxLayout *horizontalLayout;
    QSpinBox *minPort;
    QLabel *portsToLabel;
    QSpinBox *maxPort;
    QLabel *label;
    QLineEdit *outgoingIp;
    QComboBox *ipDetectionMode;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_4;
    QSpinBox *sendTimeout;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_5;
    QSpinBox *chunkSize;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *usePassiveDcc;
    QCheckBox *useFastSend;
    QGroupBox *enableFileTransfers;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_6;
    QLineEdit *downloadPath;
    QToolButton *browseButton;
    QCheckBox *createSenderDirectory;
    QCheckBox *prefixFilenames;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *DccSettingsPage)
    {
        if (DccSettingsPage->objectName().isEmpty())
            DccSettingsPage->setObjectName(QString::fromUtf8("DccSettingsPage"));
        DccSettingsPage->resize(736, 559);
        verticalLayout_3 = new QVBoxLayout(DccSettingsPage);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        dccEnabled = new QGroupBox(DccSettingsPage);
        dccEnabled->setObjectName(QString::fromUtf8("dccEnabled"));
        dccEnabled->setCheckable(true);
        dccEnabled->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        dccEnabled->setProperty("defaultValue", QVariant(false));
        verticalLayout = new QVBoxLayout(dccEnabled);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_2 = new QLabel(dccEnabled);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        portSelectionMode = new QComboBox(dccEnabled);
        portSelectionMode->addItem(QString());
        portSelectionMode->addItem(QString());
        portSelectionMode->setObjectName(QString::fromUtf8("portSelectionMode"));
        portSelectionMode->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        portSelectionMode->setProperty("defaultValue", QVariant(0));

        gridLayout->addWidget(portSelectionMode, 1, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        minPort = new QSpinBox(dccEnabled);
        minPort->setObjectName(QString::fromUtf8("minPort"));
        minPort->setMinimum(1024);
        minPort->setMaximum(65535);
        minPort->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        minPort->setProperty("defaultValue", QVariant(1024));

        horizontalLayout->addWidget(minPort);

        portsToLabel = new QLabel(dccEnabled);
        portsToLabel->setObjectName(QString::fromUtf8("portsToLabel"));

        horizontalLayout->addWidget(portsToLabel);

        maxPort = new QSpinBox(dccEnabled);
        maxPort->setObjectName(QString::fromUtf8("maxPort"));
        maxPort->setMinimum(1024);
        maxPort->setMaximum(65535);
        maxPort->setValue(65535);
        maxPort->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        maxPort->setProperty("defaultValue", QVariant(32767));

        horizontalLayout->addWidget(maxPort);


        gridLayout->addLayout(horizontalLayout, 1, 2, 1, 1);

        label = new QLabel(dccEnabled);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        outgoingIp = new QLineEdit(dccEnabled);
        outgoingIp->setObjectName(QString::fromUtf8("outgoingIp"));
        outgoingIp->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        outgoingIp->setProperty("defaultValue", QVariant(QString::fromUtf8("localhost")));

        gridLayout->addWidget(outgoingIp, 0, 2, 1, 1);

        ipDetectionMode = new QComboBox(dccEnabled);
        ipDetectionMode->addItem(QString());
        ipDetectionMode->addItem(QString());
        ipDetectionMode->setObjectName(QString::fromUtf8("ipDetectionMode"));
        ipDetectionMode->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        ipDetectionMode->setProperty("defaultValue", QVariant(0));

        gridLayout->addWidget(ipDetectionMode, 0, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 3, 1, 1);


        verticalLayout->addLayout(gridLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_4 = new QLabel(dccEnabled);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        horizontalLayout_2->addWidget(label_4);

        sendTimeout = new QSpinBox(dccEnabled);
        sendTimeout->setObjectName(QString::fromUtf8("sendTimeout"));
        sendTimeout->setMinimum(10);
        sendTimeout->setMaximum(3600);
        sendTimeout->setSingleStep(10);
        sendTimeout->setValue(180);
        sendTimeout->setProperty("defaultValue", QVariant(180));

        horizontalLayout_2->addWidget(sendTimeout);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label_5 = new QLabel(dccEnabled);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        horizontalLayout_3->addWidget(label_5);

        chunkSize = new QSpinBox(dccEnabled);
        chunkSize->setObjectName(QString::fromUtf8("chunkSize"));
        chunkSize->setMinimum(1);
        chunkSize->setMaximum(1024);
        chunkSize->setSingleStep(16);
        chunkSize->setValue(16);
        chunkSize->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        chunkSize->setProperty("defaultValue", QVariant(16));

        horizontalLayout_3->addWidget(chunkSize);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout_3);

        usePassiveDcc = new QCheckBox(dccEnabled);
        usePassiveDcc->setObjectName(QString::fromUtf8("usePassiveDcc"));
        usePassiveDcc->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        usePassiveDcc->setProperty("defaultValue", QVariant(false));

        verticalLayout->addWidget(usePassiveDcc);

        useFastSend = new QCheckBox(dccEnabled);
        useFastSend->setObjectName(QString::fromUtf8("useFastSend"));
        useFastSend->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        useFastSend->setProperty("defaultValue", QVariant(false));

        verticalLayout->addWidget(useFastSend);


        verticalLayout_3->addWidget(dccEnabled);

        enableFileTransfers = new QGroupBox(DccSettingsPage);
        enableFileTransfers->setObjectName(QString::fromUtf8("enableFileTransfers"));
        enableFileTransfers->setEnabled(false);
        verticalLayout_2 = new QVBoxLayout(enableFileTransfers);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        label_6 = new QLabel(enableFileTransfers);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        horizontalLayout_4->addWidget(label_6);

        downloadPath = new QLineEdit(enableFileTransfers);
        downloadPath->setObjectName(QString::fromUtf8("downloadPath"));

        horizontalLayout_4->addWidget(downloadPath);

        browseButton = new QToolButton(enableFileTransfers);
        browseButton->setObjectName(QString::fromUtf8("browseButton"));

        horizontalLayout_4->addWidget(browseButton);


        verticalLayout_2->addLayout(horizontalLayout_4);

        createSenderDirectory = new QCheckBox(enableFileTransfers);
        createSenderDirectory->setObjectName(QString::fromUtf8("createSenderDirectory"));

        verticalLayout_2->addWidget(createSenderDirectory);

        prefixFilenames = new QCheckBox(enableFileTransfers);
        prefixFilenames->setObjectName(QString::fromUtf8("prefixFilenames"));

        verticalLayout_2->addWidget(prefixFilenames);


        verticalLayout_3->addWidget(enableFileTransfers);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        QWidget::setTabOrder(ipDetectionMode, outgoingIp);
        QWidget::setTabOrder(outgoingIp, portSelectionMode);
        QWidget::setTabOrder(portSelectionMode, minPort);
        QWidget::setTabOrder(minPort, maxPort);
        QWidget::setTabOrder(maxPort, sendTimeout);
        QWidget::setTabOrder(sendTimeout, chunkSize);
        QWidget::setTabOrder(chunkSize, usePassiveDcc);
        QWidget::setTabOrder(usePassiveDcc, useFastSend);
        QWidget::setTabOrder(useFastSend, downloadPath);
        QWidget::setTabOrder(downloadPath, browseButton);
        QWidget::setTabOrder(browseButton, createSenderDirectory);
        QWidget::setTabOrder(createSenderDirectory, prefixFilenames);
        QWidget::setTabOrder(prefixFilenames, dccEnabled);

        retranslateUi(DccSettingsPage);

        QMetaObject::connectSlotsByName(DccSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *DccSettingsPage)
    {
        DccSettingsPage->setWindowTitle(QCoreApplication::translate("DccSettingsPage", "Form", nullptr));
        dccEnabled->setTitle(QCoreApplication::translate("DccSettingsPage", "Enable DCC", nullptr));
        label_2->setText(QCoreApplication::translate("DccSettingsPage", "Ports:", nullptr));
        portSelectionMode->setItemText(0, QCoreApplication::translate("DccSettingsPage", "Automatic", nullptr));
        portSelectionMode->setItemText(1, QCoreApplication::translate("DccSettingsPage", "Manual", nullptr));

        portsToLabel->setText(QCoreApplication::translate("DccSettingsPage", "to", nullptr));
        label->setText(QCoreApplication::translate("DccSettingsPage", "Outgoing IP:", nullptr));
        ipDetectionMode->setItemText(0, QCoreApplication::translate("DccSettingsPage", "Automatic", nullptr));
        ipDetectionMode->setItemText(1, QCoreApplication::translate("DccSettingsPage", "Manual", nullptr));

        label_4->setText(QCoreApplication::translate("DccSettingsPage", "DCC send timeout:", nullptr));
        sendTimeout->setSuffix(QCoreApplication::translate("DccSettingsPage", " seconds", nullptr));
        sendTimeout->setProperty("settingsKey", QVariant(QString()));
        label_5->setText(QCoreApplication::translate("DccSettingsPage", "Chunk size:", nullptr));
        chunkSize->setSuffix(QCoreApplication::translate("DccSettingsPage", " KiB", nullptr));
        chunkSize->setPrefix(QString());
        usePassiveDcc->setText(QCoreApplication::translate("DccSettingsPage", "Use passive/reverse DCC", nullptr));
        useFastSend->setText(QCoreApplication::translate("DccSettingsPage", "Use fast sending (might not work with all peers)", nullptr));
        enableFileTransfers->setTitle(QCoreApplication::translate("DccSettingsPage", "File transfers", nullptr));
        label_6->setText(QCoreApplication::translate("DccSettingsPage", "Default download folder:", nullptr));
        browseButton->setText(QCoreApplication::translate("DccSettingsPage", "...", nullptr));
        createSenderDirectory->setText(QCoreApplication::translate("DccSettingsPage", "Create folder per sender", nullptr));
        prefixFilenames->setText(QCoreApplication::translate("DccSettingsPage", "Prefix filenames with sender", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DccSettingsPage: public Ui_DccSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DCCSETTINGSPAGE_H
