/****************************************************************************
** Meta object code from reading C++ file 'statusnotifieritem.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/statusnotifieritem.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statusnotifieritem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_StatusNotifierItem_t {
    QByteArrayData data[34];
    char stringdata0[355];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_StatusNotifierItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_StatusNotifierItem_t qt_meta_stringdata_StatusNotifierItem = {
    {
QT_MOC_LITERAL(0, 0, 18), // "StatusNotifierItem"
QT_MOC_LITERAL(1, 19, 11), // "showMessage"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 5), // "title"
QT_MOC_LITERAL(4, 38, 7), // "message"
QT_MOC_LITERAL(5, 46, 11), // "MessageIcon"
QT_MOC_LITERAL(6, 58, 4), // "icon"
QT_MOC_LITERAL(7, 63, 9), // "msTimeout"
QT_MOC_LITERAL(8, 73, 14), // "notificationId"
QT_MOC_LITERAL(9, 88, 12), // "closeMessage"
QT_MOC_LITERAL(10, 101, 9), // "activated"
QT_MOC_LITERAL(11, 111, 3), // "pos"
QT_MOC_LITERAL(12, 115, 13), // "serviceChange"
QT_MOC_LITERAL(13, 129, 4), // "name"
QT_MOC_LITERAL(14, 134, 8), // "oldOwner"
QT_MOC_LITERAL(15, 143, 8), // "newOwner"
QT_MOC_LITERAL(16, 152, 23), // "checkForRegisteredHosts"
QT_MOC_LITERAL(17, 176, 11), // "onDBusError"
QT_MOC_LITERAL(18, 188, 10), // "QDBusError"
QT_MOC_LITERAL(19, 199, 5), // "error"
QT_MOC_LITERAL(20, 205, 18), // "notificationClosed"
QT_MOC_LITERAL(21, 224, 2), // "id"
QT_MOC_LITERAL(22, 227, 6), // "reason"
QT_MOC_LITERAL(23, 234, 19), // "notificationInvoked"
QT_MOC_LITERAL(24, 254, 6), // "action"
QT_MOC_LITERAL(25, 261, 12), // "refreshIcons"
QT_MOC_LITERAL(26, 274, 13), // "onModeChanged"
QT_MOC_LITERAL(27, 288, 4), // "Mode"
QT_MOC_LITERAL(28, 293, 4), // "mode"
QT_MOC_LITERAL(29, 298, 14), // "onStateChanged"
QT_MOC_LITERAL(30, 313, 5), // "State"
QT_MOC_LITERAL(31, 319, 5), // "state"
QT_MOC_LITERAL(32, 325, 19), // "onVisibilityChanged"
QT_MOC_LITERAL(33, 345, 9) // "isVisible"

    },
    "StatusNotifierItem\0showMessage\0\0title\0"
    "message\0MessageIcon\0icon\0msTimeout\0"
    "notificationId\0closeMessage\0activated\0"
    "pos\0serviceChange\0name\0oldOwner\0"
    "newOwner\0checkForRegisteredHosts\0"
    "onDBusError\0QDBusError\0error\0"
    "notificationClosed\0id\0reason\0"
    "notificationInvoked\0action\0refreshIcons\0"
    "onModeChanged\0Mode\0mode\0onStateChanged\0"
    "State\0state\0onVisibilityChanged\0"
    "isVisible"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_StatusNotifierItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    5,   89,    2, 0x0a /* Public */,
       1,    4,  100,    2, 0x2a /* Public | MethodCloned */,
       1,    3,  109,    2, 0x2a /* Public | MethodCloned */,
       1,    2,  116,    2, 0x2a /* Public | MethodCloned */,
       9,    1,  121,    2, 0x0a /* Public */,
      10,    1,  124,    2, 0x08 /* Private */,
      12,    3,  127,    2, 0x08 /* Private */,
      16,    0,  134,    2, 0x08 /* Private */,
      17,    1,  135,    2, 0x08 /* Private */,
      20,    2,  138,    2, 0x08 /* Private */,
      23,    2,  143,    2, 0x08 /* Private */,
      25,    0,  148,    2, 0x08 /* Private */,
      26,    1,  149,    2, 0x08 /* Private */,
      29,    1,  152,    2, 0x08 /* Private */,
      32,    1,  155,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 5, QMetaType::Int, QMetaType::UInt,    3,    4,    6,    7,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 5, QMetaType::Int,    3,    4,    6,    7,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 5,    3,    4,    6,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    3,    4,
    QMetaType::Void, QMetaType::UInt,    8,
    QMetaType::Void, QMetaType::QPoint,   11,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,   13,   14,   15,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt,   21,   22,
    QMetaType::Void, QMetaType::UInt, QMetaType::QString,   21,   24,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 27,   28,
    QMetaType::Void, 0x80000000 | 30,   31,
    QMetaType::Void, QMetaType::Bool,   33,

       0        // eod
};

void StatusNotifierItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<StatusNotifierItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->showMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< MessageIcon(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5]))); break;
        case 1: _t->showMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< MessageIcon(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 2: _t->showMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< MessageIcon(*)>(_a[3]))); break;
        case 3: _t->showMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->closeMessage((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 5: _t->activated((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 6: _t->serviceChange((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 7: _t->checkForRegisteredHosts(); break;
        case 8: _t->onDBusError((*reinterpret_cast< const QDBusError(*)>(_a[1]))); break;
        case 9: _t->notificationClosed((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 10: _t->notificationInvoked((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 11: _t->refreshIcons(); break;
        case 12: _t->onModeChanged((*reinterpret_cast< Mode(*)>(_a[1]))); break;
        case 13: _t->onStateChanged((*reinterpret_cast< State(*)>(_a[1]))); break;
        case 14: _t->onVisibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusError >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject StatusNotifierItem::staticMetaObject = { {
    QMetaObject::SuperData::link<LegacySystemTray::staticMetaObject>(),
    qt_meta_stringdata_StatusNotifierItem.data,
    qt_meta_data_StatusNotifierItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *StatusNotifierItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StatusNotifierItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_StatusNotifierItem.stringdata0))
        return static_cast<void*>(this);
    return LegacySystemTray::qt_metacast(_clname);
}

int StatusNotifierItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = LegacySystemTray::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
