/****************************************************************************
** Meta object code from reading C++ file 'mainwin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/mainwin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MainWin_t {
    QByteArrayData data[103];
    char stringdata0[1736];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainWin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainWin_t qt_meta_stringdata_MainWin = {
    {
QT_MOC_LITERAL(0, 0, 7), // "MainWin"
QT_MOC_LITERAL(1, 8, 13), // "connectToCore"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 8), // "connInfo"
QT_MOC_LITERAL(4, 32, 18), // "disconnectFromCore"
QT_MOC_LITERAL(5, 51, 20), // "showStatusBarMessage"
QT_MOC_LITERAL(6, 72, 7), // "message"
QT_MOC_LITERAL(7, 80, 17), // "hideCurrentBuffer"
QT_MOC_LITERAL(8, 98, 14), // "nextBufferView"
QT_MOC_LITERAL(9, 113, 18), // "previousBufferView"
QT_MOC_LITERAL(10, 132, 10), // "nextBuffer"
QT_MOC_LITERAL(11, 143, 14), // "previousBuffer"
QT_MOC_LITERAL(12, 158, 20), // "showMigrationWarning"
QT_MOC_LITERAL(13, 179, 4), // "show"
QT_MOC_LITERAL(14, 184, 15), // "onExitRequested"
QT_MOC_LITERAL(15, 200, 6), // "reason"
QT_MOC_LITERAL(16, 207, 15), // "connectedToCore"
QT_MOC_LITERAL(17, 223, 17), // "setConnectedState"
QT_MOC_LITERAL(18, 241, 20), // "disconnectedFromCore"
QT_MOC_LITERAL(19, 262, 20), // "setDisconnectedState"
QT_MOC_LITERAL(20, 283, 13), // "addBufferView"
QT_MOC_LITERAL(21, 297, 18), // "bufferViewConfigId"
QT_MOC_LITERAL(22, 316, 16), // "awayLogDestroyed"
QT_MOC_LITERAL(23, 333, 16), // "removeBufferView"
QT_MOC_LITERAL(24, 350, 20), // "currentBufferChanged"
QT_MOC_LITERAL(25, 371, 8), // "BufferId"
QT_MOC_LITERAL(26, 380, 16), // "messagesInserted"
QT_MOC_LITERAL(27, 397, 11), // "QModelIndex"
QT_MOC_LITERAL(28, 409, 6), // "parent"
QT_MOC_LITERAL(29, 416, 5), // "start"
QT_MOC_LITERAL(30, 422, 3), // "end"
QT_MOC_LITERAL(31, 426, 12), // "showAboutDlg"
QT_MOC_LITERAL(32, 439, 15), // "showChannelList"
QT_MOC_LITERAL(33, 455, 9), // "NetworkId"
QT_MOC_LITERAL(34, 465, 5), // "netId"
QT_MOC_LITERAL(35, 471, 14), // "channelFilters"
QT_MOC_LITERAL(36, 486, 15), // "listImmediately"
QT_MOC_LITERAL(37, 502, 17), // "showNetworkConfig"
QT_MOC_LITERAL(38, 520, 21), // "showCoreConnectionDlg"
QT_MOC_LITERAL(39, 542, 20), // "showCoreConfigWizard"
QT_MOC_LITERAL(40, 563, 15), // "showCoreInfoDlg"
QT_MOC_LITERAL(41, 579, 11), // "showAwayLog"
QT_MOC_LITERAL(42, 591, 15), // "showSettingsDlg"
QT_MOC_LITERAL(43, 607, 20), // "showNotificationsDlg"
QT_MOC_LITERAL(44, 628, 14), // "showIgnoreList"
QT_MOC_LITERAL(45, 643, 7), // "newRule"
QT_MOC_LITERAL(46, 651, 16), // "showShortcutsDlg"
QT_MOC_LITERAL(47, 668, 21), // "showPasswordChangeDlg"
QT_MOC_LITERAL(48, 690, 18), // "showNewTransferDlg"
QT_MOC_LITERAL(49, 709, 10), // "transferId"
QT_MOC_LITERAL(50, 720, 19), // "onFullScreenToggled"
QT_MOC_LITERAL(51, 740, 13), // "doAutoConnect"
QT_MOC_LITERAL(52, 754, 25), // "handleCoreConnectionError"
QT_MOC_LITERAL(53, 780, 8), // "errorMsg"
QT_MOC_LITERAL(54, 789, 26), // "userAuthenticationRequired"
QT_MOC_LITERAL(55, 816, 12), // "CoreAccount*"
QT_MOC_LITERAL(56, 829, 5), // "bool*"
QT_MOC_LITERAL(57, 835, 5), // "valid"
QT_MOC_LITERAL(58, 841, 12), // "errorMessage"
QT_MOC_LITERAL(59, 854, 19), // "handleNoSslInClient"
QT_MOC_LITERAL(60, 874, 8), // "accepted"
QT_MOC_LITERAL(61, 883, 17), // "handleNoSslInCore"
QT_MOC_LITERAL(62, 901, 15), // "handleSslErrors"
QT_MOC_LITERAL(63, 917, 17), // "const QSslSocket*"
QT_MOC_LITERAL(64, 935, 6), // "socket"
QT_MOC_LITERAL(65, 942, 11), // "permanently"
QT_MOC_LITERAL(66, 954, 28), // "onConfigureNetworksTriggered"
QT_MOC_LITERAL(67, 983, 25), // "onConfigureViewsTriggered"
QT_MOC_LITERAL(68, 1009, 19), // "onLockLayoutToggled"
QT_MOC_LITERAL(69, 1029, 4), // "lock"
QT_MOC_LITERAL(70, 1034, 27), // "onFormatApplyColorTriggered"
QT_MOC_LITERAL(71, 1062, 31), // "onFormatApplyColorFillTriggered"
QT_MOC_LITERAL(72, 1094, 21), // "onFormatBoldTriggered"
QT_MOC_LITERAL(73, 1116, 23), // "onFormatItalicTriggered"
QT_MOC_LITERAL(74, 1140, 26), // "onFormatUnderlineTriggered"
QT_MOC_LITERAL(75, 1167, 30), // "onFormatStrikethroughTriggered"
QT_MOC_LITERAL(76, 1198, 22), // "onFormatClearTriggered"
QT_MOC_LITERAL(77, 1221, 24), // "onJumpHotBufferTriggered"
QT_MOC_LITERAL(78, 1246, 23), // "onBufferSearchTriggered"
QT_MOC_LITERAL(79, 1270, 28), // "onDebugNetworkModelTriggered"
QT_MOC_LITERAL(80, 1299, 33), // "onDebugBufferViewOverlayTrigg..."
QT_MOC_LITERAL(81, 1333, 28), // "onDebugMessageModelTriggered"
QT_MOC_LITERAL(82, 1362, 23), // "onDebugHotListTriggered"
QT_MOC_LITERAL(83, 1386, 19), // "onDebugLogTriggered"
QT_MOC_LITERAL(84, 1406, 27), // "onShowResourceTreeTriggered"
QT_MOC_LITERAL(85, 1434, 11), // "bindJumpKey"
QT_MOC_LITERAL(86, 1446, 9), // "onJumpKey"
QT_MOC_LITERAL(87, 1456, 20), // "clientNetworkCreated"
QT_MOC_LITERAL(88, 1477, 20), // "clientNetworkRemoved"
QT_MOC_LITERAL(89, 1498, 20), // "clientNetworkUpdated"
QT_MOC_LITERAL(90, 1519, 26), // "connectOrDisconnectFromNet"
QT_MOC_LITERAL(91, 1546, 17), // "saveMenuBarStatus"
QT_MOC_LITERAL(92, 1564, 7), // "enabled"
QT_MOC_LITERAL(93, 1572, 19), // "saveStatusBarStatus"
QT_MOC_LITERAL(94, 1592, 21), // "saveMainToolBarStatus"
QT_MOC_LITERAL(95, 1614, 10), // "loadLayout"
QT_MOC_LITERAL(96, 1625, 10), // "saveLayout"
QT_MOC_LITERAL(97, 1636, 17), // "bufferViewToggled"
QT_MOC_LITERAL(98, 1654, 27), // "bufferViewVisibilityChanged"
QT_MOC_LITERAL(99, 1682, 7), // "visible"
QT_MOC_LITERAL(100, 1690, 22), // "changeActiveBufferView"
QT_MOC_LITERAL(101, 1713, 9), // "backwards"
QT_MOC_LITERAL(102, 1723, 12) // "bufferViewId"

    },
    "MainWin\0connectToCore\0\0connInfo\0"
    "disconnectFromCore\0showStatusBarMessage\0"
    "message\0hideCurrentBuffer\0nextBufferView\0"
    "previousBufferView\0nextBuffer\0"
    "previousBuffer\0showMigrationWarning\0"
    "show\0onExitRequested\0reason\0connectedToCore\0"
    "setConnectedState\0disconnectedFromCore\0"
    "setDisconnectedState\0addBufferView\0"
    "bufferViewConfigId\0awayLogDestroyed\0"
    "removeBufferView\0currentBufferChanged\0"
    "BufferId\0messagesInserted\0QModelIndex\0"
    "parent\0start\0end\0showAboutDlg\0"
    "showChannelList\0NetworkId\0netId\0"
    "channelFilters\0listImmediately\0"
    "showNetworkConfig\0showCoreConnectionDlg\0"
    "showCoreConfigWizard\0showCoreInfoDlg\0"
    "showAwayLog\0showSettingsDlg\0"
    "showNotificationsDlg\0showIgnoreList\0"
    "newRule\0showShortcutsDlg\0showPasswordChangeDlg\0"
    "showNewTransferDlg\0transferId\0"
    "onFullScreenToggled\0doAutoConnect\0"
    "handleCoreConnectionError\0errorMsg\0"
    "userAuthenticationRequired\0CoreAccount*\0"
    "bool*\0valid\0errorMessage\0handleNoSslInClient\0"
    "accepted\0handleNoSslInCore\0handleSslErrors\0"
    "const QSslSocket*\0socket\0permanently\0"
    "onConfigureNetworksTriggered\0"
    "onConfigureViewsTriggered\0onLockLayoutToggled\0"
    "lock\0onFormatApplyColorTriggered\0"
    "onFormatApplyColorFillTriggered\0"
    "onFormatBoldTriggered\0onFormatItalicTriggered\0"
    "onFormatUnderlineTriggered\0"
    "onFormatStrikethroughTriggered\0"
    "onFormatClearTriggered\0onJumpHotBufferTriggered\0"
    "onBufferSearchTriggered\0"
    "onDebugNetworkModelTriggered\0"
    "onDebugBufferViewOverlayTriggered\0"
    "onDebugMessageModelTriggered\0"
    "onDebugHotListTriggered\0onDebugLogTriggered\0"
    "onShowResourceTreeTriggered\0bindJumpKey\0"
    "onJumpKey\0clientNetworkCreated\0"
    "clientNetworkRemoved\0clientNetworkUpdated\0"
    "connectOrDisconnectFromNet\0saveMenuBarStatus\0"
    "enabled\0saveStatusBarStatus\0"
    "saveMainToolBarStatus\0loadLayout\0"
    "saveLayout\0bufferViewToggled\0"
    "bufferViewVisibilityChanged\0visible\0"
    "changeActiveBufferView\0backwards\0"
    "bufferViewId"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainWin[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      77,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  399,    2, 0x06 /* Public */,
       4,    0,  402,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,  403,    2, 0x0a /* Public */,
       7,    0,  406,    2, 0x0a /* Public */,
       8,    0,  407,    2, 0x0a /* Public */,
       9,    0,  408,    2, 0x0a /* Public */,
      10,    0,  409,    2, 0x0a /* Public */,
      11,    0,  410,    2, 0x0a /* Public */,
      12,    1,  411,    2, 0x0a /* Public */,
      14,    1,  414,    2, 0x0a /* Public */,
      16,    0,  417,    2, 0x09 /* Protected */,
      17,    0,  418,    2, 0x09 /* Protected */,
      18,    0,  419,    2, 0x09 /* Protected */,
      19,    0,  420,    2, 0x09 /* Protected */,
      20,    1,  421,    2, 0x08 /* Private */,
      22,    0,  424,    2, 0x08 /* Private */,
      23,    1,  425,    2, 0x08 /* Private */,
      24,    1,  428,    2, 0x08 /* Private */,
      26,    3,  431,    2, 0x08 /* Private */,
      31,    0,  438,    2, 0x08 /* Private */,
      32,    3,  439,    2, 0x08 /* Private */,
      32,    2,  446,    2, 0x28 /* Private | MethodCloned */,
      32,    1,  451,    2, 0x28 /* Private | MethodCloned */,
      32,    0,  454,    2, 0x28 /* Private | MethodCloned */,
      37,    1,  455,    2, 0x08 /* Private */,
      37,    0,  458,    2, 0x28 /* Private | MethodCloned */,
      38,    0,  459,    2, 0x08 /* Private */,
      39,    2,  460,    2, 0x08 /* Private */,
      40,    0,  465,    2, 0x08 /* Private */,
      41,    0,  466,    2, 0x08 /* Private */,
      42,    0,  467,    2, 0x08 /* Private */,
      43,    0,  468,    2, 0x08 /* Private */,
      44,    1,  469,    2, 0x08 /* Private */,
      44,    0,  472,    2, 0x28 /* Private | MethodCloned */,
      46,    0,  473,    2, 0x08 /* Private */,
      47,    0,  474,    2, 0x08 /* Private */,
      48,    1,  475,    2, 0x08 /* Private */,
      50,    0,  478,    2, 0x08 /* Private */,
      51,    0,  479,    2, 0x08 /* Private */,
      52,    1,  480,    2, 0x08 /* Private */,
      54,    3,  483,    2, 0x08 /* Private */,
      59,    1,  490,    2, 0x08 /* Private */,
      61,    1,  493,    2, 0x08 /* Private */,
      62,    3,  496,    2, 0x08 /* Private */,
      66,    0,  503,    2, 0x08 /* Private */,
      67,    0,  504,    2, 0x08 /* Private */,
      68,    1,  505,    2, 0x08 /* Private */,
      70,    0,  508,    2, 0x08 /* Private */,
      71,    0,  509,    2, 0x08 /* Private */,
      72,    0,  510,    2, 0x08 /* Private */,
      73,    0,  511,    2, 0x08 /* Private */,
      74,    0,  512,    2, 0x08 /* Private */,
      75,    0,  513,    2, 0x08 /* Private */,
      76,    0,  514,    2, 0x08 /* Private */,
      77,    0,  515,    2, 0x08 /* Private */,
      78,    0,  516,    2, 0x08 /* Private */,
      79,    0,  517,    2, 0x08 /* Private */,
      80,    0,  518,    2, 0x08 /* Private */,
      81,    0,  519,    2, 0x08 /* Private */,
      82,    0,  520,    2, 0x08 /* Private */,
      83,    0,  521,    2, 0x08 /* Private */,
      84,    0,  522,    2, 0x08 /* Private */,
      85,    0,  523,    2, 0x08 /* Private */,
      86,    0,  524,    2, 0x08 /* Private */,
      87,    1,  525,    2, 0x08 /* Private */,
      88,    1,  528,    2, 0x08 /* Private */,
      89,    0,  531,    2, 0x08 /* Private */,
      90,    0,  532,    2, 0x08 /* Private */,
      91,    1,  533,    2, 0x08 /* Private */,
      93,    1,  536,    2, 0x08 /* Private */,
      94,    1,  539,    2, 0x08 /* Private */,
      95,    0,  542,    2, 0x08 /* Private */,
      96,    0,  543,    2, 0x08 /* Private */,
      97,    1,  544,    2, 0x08 /* Private */,
      98,    1,  547,    2, 0x08 /* Private */,
     100,    1,  550,    2, 0x08 /* Private */,
     100,    1,  553,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QVariantMap,    3,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void, 0x80000000 | 27, QMetaType::Int, QMetaType::Int,   28,   29,   30,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 33, QMetaType::QString, QMetaType::Bool,   34,   35,   36,
    QMetaType::Void, 0x80000000 | 33, QMetaType::QString,   34,   35,
    QMetaType::Void, 0x80000000 | 33,   34,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 33,   34,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QVariantList, QMetaType::QVariantList,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   45,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUuid,   49,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   53,
    QMetaType::Void, 0x80000000 | 55, 0x80000000 | 56, QMetaType::QString,    2,   57,   58,
    QMetaType::Void, 0x80000000 | 56,   60,
    QMetaType::Void, 0x80000000 | 56,   60,
    QMetaType::Void, 0x80000000 | 63, 0x80000000 | 56, 0x80000000 | 56,   64,   60,   65,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   69,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 33,    2,
    QMetaType::Void, 0x80000000 | 33,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   92,
    QMetaType::Void, QMetaType::Bool,   92,
    QMetaType::Void, QMetaType::Bool,   92,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   92,
    QMetaType::Void, QMetaType::Bool,   99,
    QMetaType::Void, QMetaType::Bool,  101,
    QMetaType::Void, QMetaType::Int,  102,

       0        // eod
};

void MainWin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MainWin *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->connectToCore((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 1: _t->disconnectFromCore(); break;
        case 2: _t->showStatusBarMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->hideCurrentBuffer(); break;
        case 4: _t->nextBufferView(); break;
        case 5: _t->previousBufferView(); break;
        case 6: _t->nextBuffer(); break;
        case 7: _t->previousBuffer(); break;
        case 8: _t->showMigrationWarning((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->onExitRequested((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->connectedToCore(); break;
        case 11: _t->setConnectedState(); break;
        case 12: _t->disconnectedFromCore(); break;
        case 13: _t->setDisconnectedState(); break;
        case 14: _t->addBufferView((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->awayLogDestroyed(); break;
        case 16: _t->removeBufferView((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->currentBufferChanged((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 18: _t->messagesInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 19: _t->showAboutDlg(); break;
        case 20: _t->showChannelList((*reinterpret_cast< NetworkId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 21: _t->showChannelList((*reinterpret_cast< NetworkId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 22: _t->showChannelList((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 23: _t->showChannelList(); break;
        case 24: _t->showNetworkConfig((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 25: _t->showNetworkConfig(); break;
        case 26: _t->showCoreConnectionDlg(); break;
        case 27: _t->showCoreConfigWizard((*reinterpret_cast< const QVariantList(*)>(_a[1])),(*reinterpret_cast< const QVariantList(*)>(_a[2]))); break;
        case 28: _t->showCoreInfoDlg(); break;
        case 29: _t->showAwayLog(); break;
        case 30: _t->showSettingsDlg(); break;
        case 31: _t->showNotificationsDlg(); break;
        case 32: _t->showIgnoreList((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 33: _t->showIgnoreList(); break;
        case 34: _t->showShortcutsDlg(); break;
        case 35: _t->showPasswordChangeDlg(); break;
        case 36: _t->showNewTransferDlg((*reinterpret_cast< const QUuid(*)>(_a[1]))); break;
        case 37: _t->onFullScreenToggled(); break;
        case 38: _t->doAutoConnect(); break;
        case 39: _t->handleCoreConnectionError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 40: _t->userAuthenticationRequired((*reinterpret_cast< CoreAccount*(*)>(_a[1])),(*reinterpret_cast< bool*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 41: _t->handleNoSslInClient((*reinterpret_cast< bool*(*)>(_a[1]))); break;
        case 42: _t->handleNoSslInCore((*reinterpret_cast< bool*(*)>(_a[1]))); break;
        case 43: _t->handleSslErrors((*reinterpret_cast< const QSslSocket*(*)>(_a[1])),(*reinterpret_cast< bool*(*)>(_a[2])),(*reinterpret_cast< bool*(*)>(_a[3]))); break;
        case 44: _t->onConfigureNetworksTriggered(); break;
        case 45: _t->onConfigureViewsTriggered(); break;
        case 46: _t->onLockLayoutToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 47: _t->onFormatApplyColorTriggered(); break;
        case 48: _t->onFormatApplyColorFillTriggered(); break;
        case 49: _t->onFormatBoldTriggered(); break;
        case 50: _t->onFormatItalicTriggered(); break;
        case 51: _t->onFormatUnderlineTriggered(); break;
        case 52: _t->onFormatStrikethroughTriggered(); break;
        case 53: _t->onFormatClearTriggered(); break;
        case 54: _t->onJumpHotBufferTriggered(); break;
        case 55: _t->onBufferSearchTriggered(); break;
        case 56: _t->onDebugNetworkModelTriggered(); break;
        case 57: _t->onDebugBufferViewOverlayTriggered(); break;
        case 58: _t->onDebugMessageModelTriggered(); break;
        case 59: _t->onDebugHotListTriggered(); break;
        case 60: _t->onDebugLogTriggered(); break;
        case 61: _t->onShowResourceTreeTriggered(); break;
        case 62: _t->bindJumpKey(); break;
        case 63: _t->onJumpKey(); break;
        case 64: _t->clientNetworkCreated((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 65: _t->clientNetworkRemoved((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 66: _t->clientNetworkUpdated(); break;
        case 67: _t->connectOrDisconnectFromNet(); break;
        case 68: _t->saveMenuBarStatus((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 69: _t->saveStatusBarStatus((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 70: _t->saveMainToolBarStatus((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 71: _t->loadLayout(); break;
        case 72: _t->saveLayout(); break;
        case 73: _t->bufferViewToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 74: _t->bufferViewVisibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 75: _t->changeActiveBufferView((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 76: _t->changeActiveBufferView((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 64:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 65:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MainWin::*)(const QVariantMap & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWin::connectToCore)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (MainWin::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWin::disconnectFromCore)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MainWin::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_MainWin.data,
    qt_meta_data_MainWin,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MainWin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MainWin.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 77)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 77;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 77)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 77;
    }
    return _id;
}

// SIGNAL 0
void MainWin::connectToCore(const QVariantMap & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void MainWin::disconnectFromCore()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
