/********************************************************************************
** Form generated from reading UI file 'coreconfigwizardsyncpage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CORECONFIGWIZARDSYNCPAGE_H
#define UI_CORECONFIGWIZARDSYNCPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CoreConfigWizardSyncPage
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *user;
    QLabel *label_2;
    QLabel *backend;
    QLabel *label_3;
    QLabel *authenticator;
    QSpacerItem *spacerItem;
    QLabel *status;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *CoreConfigWizardSyncPage)
    {
        if (CoreConfigWizardSyncPage->objectName().isEmpty())
            CoreConfigWizardSyncPage->setObjectName(QString::fromUtf8("CoreConfigWizardSyncPage"));
        CoreConfigWizardSyncPage->resize(400, 252);
        vboxLayout = new QVBoxLayout(CoreConfigWizardSyncPage);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        groupBox = new QGroupBox(CoreConfigWizardSyncPage);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        vboxLayout1 = new QVBoxLayout(groupBox);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(groupBox);
        label->setObjectName(QString::fromUtf8("label"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        label->setFont(font);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        user = new QLabel(groupBox);
        user->setObjectName(QString::fromUtf8("user"));
        user->setText(QString::fromUtf8("foo"));

        gridLayout->addWidget(user, 0, 1, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setFont(font);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        backend = new QLabel(groupBox);
        backend->setObjectName(QString::fromUtf8("backend"));
        backend->setText(QString::fromUtf8("bar"));

        gridLayout->addWidget(backend, 1, 1, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setFont(font);

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        authenticator = new QLabel(groupBox);
        authenticator->setObjectName(QString::fromUtf8("authenticator"));
        authenticator->setText(QString::fromUtf8("bar"));

        gridLayout->addWidget(authenticator, 2, 1, 1, 1);


        hboxLayout->addLayout(gridLayout);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout1->addLayout(hboxLayout);


        vboxLayout->addWidget(groupBox);

        status = new QLabel(CoreConfigWizardSyncPage);
        status->setObjectName(QString::fromUtf8("status"));
        status->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        status->setWordWrap(true);

        vboxLayout->addWidget(status);

        spacerItem1 = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(CoreConfigWizardSyncPage);

        QMetaObject::connectSlotsByName(CoreConfigWizardSyncPage);
    } // setupUi

    void retranslateUi(QWidget *CoreConfigWizardSyncPage)
    {
        CoreConfigWizardSyncPage->setWindowTitle(QCoreApplication::translate("CoreConfigWizardSyncPage", "Form", nullptr));
        groupBox->setTitle(QCoreApplication::translate("CoreConfigWizardSyncPage", "Your Choices", nullptr));
        label->setText(QCoreApplication::translate("CoreConfigWizardSyncPage", "Admin User:", nullptr));
        label_2->setText(QCoreApplication::translate("CoreConfigWizardSyncPage", "Storage Backend:", nullptr));
        label_3->setText(QCoreApplication::translate("CoreConfigWizardSyncPage", "Authentication Backend:", nullptr));
        status->setText(QCoreApplication::translate("CoreConfigWizardSyncPage", "Please wait while your settings are being transmitted to the core...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CoreConfigWizardSyncPage: public Ui_CoreConfigWizardSyncPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CORECONFIGWIZARDSYNCPAGE_H
