/********************************************************************************
** Form generated from reading UI file 'buffervieweditdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BUFFERVIEWEDITDLG_H
#define UI_BUFFERVIEWEDITDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_BufferViewEditDlg
{
public:
    QVBoxLayout *vboxLayout;
    QVBoxLayout *vboxLayout1;
    QLabel *label;
    QLineEdit *bufferViewEdit;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *BufferViewEditDlg)
    {
        if (BufferViewEditDlg->objectName().isEmpty())
            BufferViewEditDlg->setObjectName(QString::fromUtf8("BufferViewEditDlg"));
        BufferViewEditDlg->resize(282, 131);
        vboxLayout = new QVBoxLayout(BufferViewEditDlg);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        label = new QLabel(BufferViewEditDlg);
        label->setObjectName(QString::fromUtf8("label"));

        vboxLayout1->addWidget(label);

        bufferViewEdit = new QLineEdit(BufferViewEditDlg);
        bufferViewEdit->setObjectName(QString::fromUtf8("bufferViewEdit"));

        vboxLayout1->addWidget(bufferViewEdit);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(BufferViewEditDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout1->addWidget(buttonBox);


        vboxLayout->addLayout(vboxLayout1);


        retranslateUi(BufferViewEditDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), BufferViewEditDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), BufferViewEditDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(BufferViewEditDlg);
    } // setupUi

    void retranslateUi(QDialog *BufferViewEditDlg)
    {
        BufferViewEditDlg->setWindowTitle(QCoreApplication::translate("BufferViewEditDlg", "Dialog", nullptr));
        label->setText(QCoreApplication::translate("BufferViewEditDlg", "Please enter a name for the chat list:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BufferViewEditDlg: public Ui_BufferViewEditDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BUFFERVIEWEDITDLG_H
