/********************************************************************************
** Form generated from reading UI file 'chatviewcolorsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHATVIEWCOLORSETTINGSPAGE_H
#define UI_CHATVIEWCOLORSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "colorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ChatViewColorSettingsPage
{
public:
    QVBoxLayout *verticalLayout_2;
    QCheckBox *allowMircColors;
    QGroupBox *useCustomColors;
    QGridLayout *gridLayout;
    QLabel *label_10;
    ColorButton *actionMsgColor;
    QLabel *label_5;
    ColorButton *timestampColor;
    QLabel *label_3;
    ColorButton *channelMsgColor;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_7;
    ColorButton *highlightColor;
    QLabel *label_6;
    ColorButton *commandMsgColor;
    QLabel *label_12;
    QLabel *label_4;
    ColorButton *serverMsgColor;
    QLabel *label_11;
    ColorButton *markerLineColor;
    QLabel *label;
    ColorButton *errorMsgColor;
    QLabel *label_8;
    ColorButton *backgroundColor;
    ColorButton *highlightBackgroundColor;
    QSpacerItem *horizontalSpacer_4;
    QGroupBox *useSenderColors;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout_3;
    ColorButton *senderColor00;
    ColorButton *senderColor01;
    ColorButton *senderColor02;
    ColorButton *senderColor03;
    ColorButton *senderColor04;
    ColorButton *senderColor05;
    ColorButton *senderColor06;
    ColorButton *senderColor07;
    ColorButton *senderColor08;
    ColorButton *senderColor09;
    ColorButton *senderColor10;
    ColorButton *senderColor11;
    ColorButton *senderColor12;
    ColorButton *senderColor13;
    ColorButton *senderColor14;
    ColorButton *senderColor15;
    QSpacerItem *horizontalSpacer_5;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_9;
    ColorButton *senderColorSelf;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *useSenderActionColors;
    QCheckBox *useNicknameGeneralColors;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ChatViewColorSettingsPage)
    {
        if (ChatViewColorSettingsPage->objectName().isEmpty())
            ChatViewColorSettingsPage->setObjectName(QString::fromUtf8("ChatViewColorSettingsPage"));
        ChatViewColorSettingsPage->resize(486, 456);
        verticalLayout_2 = new QVBoxLayout(ChatViewColorSettingsPage);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        allowMircColors = new QCheckBox(ChatViewColorSettingsPage);
        allowMircColors->setObjectName(QString::fromUtf8("allowMircColors"));
        allowMircColors->setChecked(true);
        allowMircColors->setProperty("defaultValue", QVariant(true));
        allowMircColors->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/AllowMircColors")));

        verticalLayout_2->addWidget(allowMircColors);

        useCustomColors = new QGroupBox(ChatViewColorSettingsPage);
        useCustomColors->setObjectName(QString::fromUtf8("useCustomColors"));
        useCustomColors->setCheckable(true);
        useCustomColors->setChecked(false);
        useCustomColors->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/UseChatViewColors")));
        useCustomColors->setProperty("defaultValue", QVariant(false));
        gridLayout = new QGridLayout(useCustomColors);
        gridLayout->setSpacing(12);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_10 = new QLabel(useCustomColors);
        label_10->setObjectName(QString::fromUtf8("label_10"));

        gridLayout->addWidget(label_10, 0, 0, 1, 1);

        actionMsgColor = new ColorButton(useCustomColors);
        actionMsgColor->setObjectName(QString::fromUtf8("actionMsgColor"));
        actionMsgColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/ActionMsg")));
        actionMsgColor->setProperty("defaultValue", QVariant(QColor(0, 0, 255)));

        gridLayout->addWidget(actionMsgColor, 0, 1, 1, 1);

        label_5 = new QLabel(useCustomColors);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout->addWidget(label_5, 0, 3, 1, 1);

        timestampColor = new ColorButton(useCustomColors);
        timestampColor->setObjectName(QString::fromUtf8("timestampColor"));
        timestampColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Timestamp")));
        timestampColor->setProperty("defaultValue", QVariant(QColor(112, 124, 112)));

        gridLayout->addWidget(timestampColor, 0, 4, 1, 1);

        label_3 = new QLabel(useCustomColors);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        channelMsgColor = new ColorButton(useCustomColors);
        channelMsgColor->setObjectName(QString::fromUtf8("channelMsgColor"));
        channelMsgColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/ChannelMsg")));
        channelMsgColor->setProperty("defaultValue", QVariant(QColor(60, 60, 60)));

        gridLayout->addWidget(channelMsgColor, 1, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(124, 20, QSizePolicy::Preferred, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 1, 2, 1, 1);

        label_7 = new QLabel(useCustomColors);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout->addWidget(label_7, 1, 3, 1, 1);

        highlightColor = new ColorButton(useCustomColors);
        highlightColor->setObjectName(QString::fromUtf8("highlightColor"));
        highlightColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Highlight")));
        highlightColor->setProperty("defaultValue", QVariant(QColor(0, 0, 0)));

        gridLayout->addWidget(highlightColor, 1, 4, 1, 1);

        label_6 = new QLabel(useCustomColors);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout->addWidget(label_6, 2, 0, 1, 1);

        commandMsgColor = new ColorButton(useCustomColors);
        commandMsgColor->setObjectName(QString::fromUtf8("commandMsgColor"));
        commandMsgColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/CommandMsg")));
        commandMsgColor->setProperty("defaultValue", QVariant(QColor(112, 112, 112)));

        gridLayout->addWidget(commandMsgColor, 2, 1, 1, 1);

        label_12 = new QLabel(useCustomColors);
        label_12->setObjectName(QString::fromUtf8("label_12"));

        gridLayout->addWidget(label_12, 2, 3, 1, 1);

        label_4 = new QLabel(useCustomColors);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout->addWidget(label_4, 3, 0, 1, 1);

        serverMsgColor = new ColorButton(useCustomColors);
        serverMsgColor->setObjectName(QString::fromUtf8("serverMsgColor"));
        serverMsgColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/ServerMsg")));
        serverMsgColor->setProperty("defaultValue", QVariant(QColor(145, 100, 9)));

        gridLayout->addWidget(serverMsgColor, 3, 1, 1, 1);

        label_11 = new QLabel(useCustomColors);
        label_11->setObjectName(QString::fromUtf8("label_11"));

        gridLayout->addWidget(label_11, 3, 3, 1, 1);

        markerLineColor = new ColorButton(useCustomColors);
        markerLineColor->setObjectName(QString::fromUtf8("markerLineColor"));
        markerLineColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/MarkerLine")));
        markerLineColor->setProperty("defaultValue", QVariant(QColor(255, 0, 0)));

        gridLayout->addWidget(markerLineColor, 3, 4, 1, 1);

        label = new QLabel(useCustomColors);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 4, 0, 1, 1);

        errorMsgColor = new ColorButton(useCustomColors);
        errorMsgColor->setObjectName(QString::fromUtf8("errorMsgColor"));
        errorMsgColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/ErrorMsg")));
        errorMsgColor->setProperty("defaultValue", QVariant(QColor(179, 14, 14)));

        gridLayout->addWidget(errorMsgColor, 4, 1, 1, 1);

        label_8 = new QLabel(useCustomColors);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        gridLayout->addWidget(label_8, 4, 3, 1, 1);

        backgroundColor = new ColorButton(useCustomColors);
        backgroundColor->setObjectName(QString::fromUtf8("backgroundColor"));
        backgroundColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/ChatViewBackground")));
        backgroundColor->setProperty("defaultValue", QVariant(QColor(255, 255, 255)));

        gridLayout->addWidget(backgroundColor, 4, 4, 1, 1);

        highlightBackgroundColor = new ColorButton(useCustomColors);
        highlightBackgroundColor->setObjectName(QString::fromUtf8("highlightBackgroundColor"));
        highlightBackgroundColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/HighlightBackground")));
        highlightBackgroundColor->setProperty("defaultValue", QVariant(QColor(255, 128, 0)));

        gridLayout->addWidget(highlightBackgroundColor, 2, 4, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 0, 5, 1, 1);


        verticalLayout_2->addWidget(useCustomColors);

        useSenderColors = new QGroupBox(ChatViewColorSettingsPage);
        useSenderColors->setObjectName(QString::fromUtf8("useSenderColors"));
        useSenderColors->setCheckable(true);
        useSenderColors->setChecked(true);
        useSenderColors->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/UseSenderColors")));
        useSenderColors->setProperty("defaultValue", QVariant(true));
        verticalLayout = new QVBoxLayout(useSenderColors);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        gridLayout_3->setHorizontalSpacing(30);
        gridLayout_3->setVerticalSpacing(12);
        senderColor00 = new ColorButton(useSenderColors);
        senderColor00->setObjectName(QString::fromUtf8("senderColor00"));
        senderColor00->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender00")));
        senderColor00->setProperty("defaultValue", QVariant(QColor(204, 0, 0)));

        gridLayout_3->addWidget(senderColor00, 0, 0, 1, 1);

        senderColor01 = new ColorButton(useSenderColors);
        senderColor01->setObjectName(QString::fromUtf8("senderColor01"));
        senderColor01->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender01")));
        senderColor01->setProperty("defaultValue", QVariant(QColor(0, 108, 173)));

        gridLayout_3->addWidget(senderColor01, 0, 1, 1, 1);

        senderColor02 = new ColorButton(useSenderColors);
        senderColor02->setObjectName(QString::fromUtf8("senderColor02"));
        senderColor02->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender02")));
        senderColor02->setProperty("defaultValue", QVariant(QColor(77, 153, 0)));

        gridLayout_3->addWidget(senderColor02, 0, 2, 1, 1);

        senderColor03 = new ColorButton(useSenderColors);
        senderColor03->setObjectName(QString::fromUtf8("senderColor03"));
        senderColor03->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender03")));
        senderColor03->setProperty("defaultValue", QVariant(QColor(102, 0, 204)));

        gridLayout_3->addWidget(senderColor03, 0, 3, 1, 1);

        senderColor04 = new ColorButton(useSenderColors);
        senderColor04->setObjectName(QString::fromUtf8("senderColor04"));
        senderColor04->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender04")));
        senderColor04->setProperty("defaultValue", QVariant(QColor(166, 125, 0)));

        gridLayout_3->addWidget(senderColor04, 0, 4, 1, 1);

        senderColor05 = new ColorButton(useSenderColors);
        senderColor05->setObjectName(QString::fromUtf8("senderColor05"));
        senderColor05->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender05")));
        senderColor05->setProperty("defaultValue", QVariant(QColor(0, 153, 39)));

        gridLayout_3->addWidget(senderColor05, 0, 5, 1, 1);

        senderColor06 = new ColorButton(useSenderColors);
        senderColor06->setObjectName(QString::fromUtf8("senderColor06"));
        senderColor06->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender06")));
        senderColor06->setProperty("defaultValue", QVariant(QColor(0, 48, 192)));

        gridLayout_3->addWidget(senderColor06, 0, 6, 1, 1);

        senderColor07 = new ColorButton(useSenderColors);
        senderColor07->setObjectName(QString::fromUtf8("senderColor07"));
        senderColor07->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender07")));
        senderColor07->setProperty("defaultValue", QVariant(QColor(204, 0, 154)));

        gridLayout_3->addWidget(senderColor07, 0, 7, 1, 1);

        senderColor08 = new ColorButton(useSenderColors);
        senderColor08->setObjectName(QString::fromUtf8("senderColor08"));
        senderColor08->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender08")));
        senderColor08->setProperty("defaultValue", QVariant(QColor(185, 70, 0)));

        gridLayout_3->addWidget(senderColor08, 1, 0, 1, 1);

        senderColor09 = new ColorButton(useSenderColors);
        senderColor09->setObjectName(QString::fromUtf8("senderColor09"));
        senderColor09->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender09")));
        senderColor09->setProperty("defaultValue", QVariant(QColor(134, 153, 0)));

        gridLayout_3->addWidget(senderColor09, 1, 1, 1, 1);

        senderColor10 = new ColorButton(useSenderColors);
        senderColor10->setObjectName(QString::fromUtf8("senderColor10"));
        senderColor10->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender10")));
        senderColor10->setProperty("defaultValue", QVariant(QColor(20, 153, 0)));

        gridLayout_3->addWidget(senderColor10, 1, 2, 1, 1);

        senderColor11 = new ColorButton(useSenderColors);
        senderColor11->setObjectName(QString::fromUtf8("senderColor11"));
        senderColor11->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender11")));
        senderColor11->setProperty("defaultValue", QVariant(QColor(0, 153, 96)));

        gridLayout_3->addWidget(senderColor11, 1, 3, 1, 1);

        senderColor12 = new ColorButton(useSenderColors);
        senderColor12->setObjectName(QString::fromUtf8("senderColor12"));
        senderColor12->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender12")));
        senderColor12->setProperty("defaultValue", QVariant(QColor(0, 108, 173)));

        gridLayout_3->addWidget(senderColor12, 1, 4, 1, 1);

        senderColor13 = new ColorButton(useSenderColors);
        senderColor13->setObjectName(QString::fromUtf8("senderColor13"));
        senderColor13->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender13")));
        senderColor13->setProperty("defaultValue", QVariant(QColor(0, 153, 204)));

        gridLayout_3->addWidget(senderColor13, 1, 5, 1, 1);

        senderColor14 = new ColorButton(useSenderColors);
        senderColor14->setObjectName(QString::fromUtf8("senderColor14"));
        senderColor14->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender14")));
        senderColor14->setProperty("defaultValue", QVariant(QColor(179, 0, 204)));

        gridLayout_3->addWidget(senderColor14, 1, 6, 1, 1);

        senderColor15 = new ColorButton(useSenderColors);
        senderColor15->setObjectName(QString::fromUtf8("senderColor15"));
        senderColor15->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/Sender15")));
        senderColor15->setProperty("defaultValue", QVariant(QColor(204, 0, 77)));

        gridLayout_3->addWidget(senderColor15, 1, 7, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_5, 0, 8, 1, 1);


        verticalLayout->addLayout(gridLayout_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_9 = new QLabel(useSenderColors);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        horizontalLayout_2->addWidget(label_9);

        senderColorSelf = new ColorButton(useSenderColors);
        senderColorSelf->setObjectName(QString::fromUtf8("senderColorSelf"));
        senderColorSelf->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/SenderSelf")));
        senderColorSelf->setProperty("defaultValue", QVariant(QColor(0, 0, 0)));

        horizontalLayout_2->addWidget(senderColorSelf);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout_2);

        useSenderActionColors = new QCheckBox(useSenderColors);
        useSenderActionColors->setObjectName(QString::fromUtf8("useSenderActionColors"));
        useSenderActionColors->setChecked(true);
        useSenderActionColors->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/UseSenderActionColors")));
        useSenderActionColors->setProperty("defaultValue", QVariant(true));

        verticalLayout->addWidget(useSenderActionColors);

        useNicknameGeneralColors = new QCheckBox(useSenderColors);
        useNicknameGeneralColors->setObjectName(QString::fromUtf8("useNicknameGeneralColors"));
        useNicknameGeneralColors->setChecked(true);
        useNicknameGeneralColors->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Colors/UseNickGeneralColors")));
        useNicknameGeneralColors->setProperty("defaultValue", QVariant(true));

        verticalLayout->addWidget(useNicknameGeneralColors);


        verticalLayout_2->addWidget(useSenderColors);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        QWidget::setTabOrder(allowMircColors, useCustomColors);
        QWidget::setTabOrder(useCustomColors, actionMsgColor);
        QWidget::setTabOrder(actionMsgColor, channelMsgColor);
        QWidget::setTabOrder(channelMsgColor, commandMsgColor);
        QWidget::setTabOrder(commandMsgColor, serverMsgColor);
        QWidget::setTabOrder(serverMsgColor, errorMsgColor);
        QWidget::setTabOrder(errorMsgColor, timestampColor);
        QWidget::setTabOrder(timestampColor, highlightColor);
        QWidget::setTabOrder(highlightColor, highlightBackgroundColor);
        QWidget::setTabOrder(highlightBackgroundColor, markerLineColor);
        QWidget::setTabOrder(markerLineColor, backgroundColor);
        QWidget::setTabOrder(backgroundColor, useSenderColors);
        QWidget::setTabOrder(useSenderColors, senderColor00);
        QWidget::setTabOrder(senderColor00, senderColor01);
        QWidget::setTabOrder(senderColor01, senderColor02);
        QWidget::setTabOrder(senderColor02, senderColor03);
        QWidget::setTabOrder(senderColor03, senderColor04);
        QWidget::setTabOrder(senderColor04, senderColor05);
        QWidget::setTabOrder(senderColor05, senderColor06);
        QWidget::setTabOrder(senderColor06, senderColor07);
        QWidget::setTabOrder(senderColor07, senderColor08);
        QWidget::setTabOrder(senderColor08, senderColor09);
        QWidget::setTabOrder(senderColor09, senderColor10);
        QWidget::setTabOrder(senderColor10, senderColor11);
        QWidget::setTabOrder(senderColor11, senderColor12);
        QWidget::setTabOrder(senderColor12, senderColor13);
        QWidget::setTabOrder(senderColor13, senderColor14);
        QWidget::setTabOrder(senderColor14, senderColor15);
        QWidget::setTabOrder(senderColor15, senderColorSelf);
        QWidget::setTabOrder(senderColorSelf, useSenderActionColors);

        retranslateUi(ChatViewColorSettingsPage);

        QMetaObject::connectSlotsByName(ChatViewColorSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *ChatViewColorSettingsPage)
    {
        ChatViewColorSettingsPage->setWindowTitle(QCoreApplication::translate("ChatViewColorSettingsPage", "Form", nullptr));
#if QT_CONFIG(tooltip)
        allowMircColors->setToolTip(QCoreApplication::translate("ChatViewColorSettingsPage", "Show colored text in the chat window", nullptr));
#endif // QT_CONFIG(tooltip)
        allowMircColors->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Allow colored text (mIRC color codes)", nullptr));
        useCustomColors->setTitle(QCoreApplication::translate("ChatViewColorSettingsPage", "Custom Colors", nullptr));
        label_10->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Action:", nullptr));
        actionMsgColor->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        label_5->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Timestamp:", nullptr));
        timestampColor->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        label_3->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Channel message:", nullptr));
        channelMsgColor->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        label_7->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Highlight foreground:", nullptr));
        highlightColor->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        label_6->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Command message:", nullptr));
        commandMsgColor->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        label_12->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Highlight background:", nullptr));
        label_4->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Server message:", nullptr));
        serverMsgColor->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        label_11->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Marker line:", nullptr));
        markerLineColor->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        label->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Error message:", nullptr));
        errorMsgColor->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        label_8->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Background:", nullptr));
        backgroundColor->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        highlightBackgroundColor->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
#if QT_CONFIG(tooltip)
        useSenderColors->setToolTip(QCoreApplication::translate("ChatViewColorSettingsPage", "Color senders in chat based on nicknames", nullptr));
#endif // QT_CONFIG(tooltip)
        useSenderColors->setTitle(QCoreApplication::translate("ChatViewColorSettingsPage", "Use Sender Coloring", nullptr));
        senderColor00->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor01->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor02->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor03->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor04->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor05->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor06->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor07->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor08->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor09->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor10->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor11->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor12->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor13->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor14->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        senderColor15->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
        label_9->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Own messages:", nullptr));
        senderColorSelf->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "...", nullptr));
#if QT_CONFIG(tooltip)
        useSenderActionColors->setToolTip(QCoreApplication::translate("ChatViewColorSettingsPage", "Color sender nicknames in action messages, e.g.<br/>-*- <span style=\" font-style:italic;\">Nick</span> does an action", nullptr));
#endif // QT_CONFIG(tooltip)
        useSenderActionColors->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Color senders in action messages", nullptr));
#if QT_CONFIG(tooltip)
        useNicknameGeneralColors->setToolTip(QCoreApplication::translate("ChatViewColorSettingsPage", "Color nicknames in joins, parts, quits, and other messages, e.g.<br/>--> <span style=\" font-style:italic;\">Nick</span> joined #quassel", nullptr));
#endif // QT_CONFIG(tooltip)
        useNicknameGeneralColors->setText(QCoreApplication::translate("ChatViewColorSettingsPage", "Color nicknames in other messages", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ChatViewColorSettingsPage: public Ui_ChatViewColorSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CHATVIEWCOLORSETTINGSPAGE_H
