/****************************************************************************
** Meta object code from reading C++ file 'nicklistwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/nicklistwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'nicklistwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_NickListWidget_t {
    QByteArrayData data[15];
    char stringdata0[165];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NickListWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NickListWidget_t qt_meta_stringdata_NickListWidget = {
    {
QT_MOC_LITERAL(0, 0, 14), // "NickListWidget"
QT_MOC_LITERAL(1, 15, 20), // "nickSelectionChanged"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 15), // "QModelIndexList"
QT_MOC_LITERAL(4, 53, 10), // "showWidget"
QT_MOC_LITERAL(5, 64, 7), // "visible"
QT_MOC_LITERAL(6, 72, 10), // "setVisible"
QT_MOC_LITERAL(7, 83, 14), // "currentChanged"
QT_MOC_LITERAL(8, 98, 11), // "QModelIndex"
QT_MOC_LITERAL(9, 110, 7), // "current"
QT_MOC_LITERAL(10, 118, 8), // "previous"
QT_MOC_LITERAL(11, 127, 20), // "rowsAboutToBeRemoved"
QT_MOC_LITERAL(12, 148, 6), // "parent"
QT_MOC_LITERAL(13, 155, 5), // "start"
QT_MOC_LITERAL(14, 161, 3) // "end"

    },
    "NickListWidget\0nickSelectionChanged\0"
    "\0QModelIndexList\0showWidget\0visible\0"
    "setVisible\0currentChanged\0QModelIndex\0"
    "current\0previous\0rowsAboutToBeRemoved\0"
    "parent\0start\0end"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NickListWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   42,    2, 0x0a /* Public */,
       6,    1,   45,    2, 0x0a /* Public */,
       7,    2,   48,    2, 0x09 /* Protected */,
      11,    3,   53,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, 0x80000000 | 8, 0x80000000 | 8,    9,   10,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int, QMetaType::Int,   12,   13,   14,

       0        // eod
};

void NickListWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<NickListWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->nickSelectionChanged((*reinterpret_cast< const QModelIndexList(*)>(_a[1]))); break;
        case 1: _t->showWidget((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->setVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->currentChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 4: _t->rowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QModelIndexList >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (NickListWidget::*)(const QModelIndexList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NickListWidget::nickSelectionChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject NickListWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractItemView::staticMetaObject>(),
    qt_meta_stringdata_NickListWidget.data,
    qt_meta_data_NickListWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *NickListWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NickListWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NickListWidget.stringdata0))
        return static_cast<void*>(this);
    return AbstractItemView::qt_metacast(_clname);
}

int NickListWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractItemView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void NickListWidget::nickSelectionChanged(const QModelIndexList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_NickListDock_t {
    QByteArrayData data[1];
    char stringdata0[13];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NickListDock_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NickListDock_t qt_meta_stringdata_NickListDock = {
    {
QT_MOC_LITERAL(0, 0, 12) // "NickListDock"

    },
    "NickListDock"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NickListDock[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void NickListDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject NickListDock::staticMetaObject = { {
    QMetaObject::SuperData::link<QDockWidget::staticMetaObject>(),
    qt_meta_stringdata_NickListDock.data,
    qt_meta_data_NickListDock,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *NickListDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NickListDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NickListDock.stringdata0))
        return static_cast<void*>(this);
    return QDockWidget::qt_metacast(_clname);
}

int NickListDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDockWidget::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
