/****************************************************************************
** Meta object code from reading C++ file 'core.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/core.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QPointer>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'core.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Core_t {
    QByteArrayData data[53];
    char stringdata0[683];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Core_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Core_t qt_meta_stringdata_Core = {
    {
QT_MOC_LITERAL(0, 0, 4), // "Core"
QT_MOC_LITERAL(1, 5, 17), // "bufferInfoUpdated"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 6), // "UserId"
QT_MOC_LITERAL(4, 31, 4), // "user"
QT_MOC_LITERAL(5, 36, 10), // "BufferInfo"
QT_MOC_LITERAL(6, 47, 4), // "info"
QT_MOC_LITERAL(7, 52, 20), // "sessionStateReceived"
QT_MOC_LITERAL(8, 73, 22), // "Protocol::SessionState"
QT_MOC_LITERAL(9, 96, 12), // "sessionState"
QT_MOC_LITERAL(10, 109, 19), // "dbUpgradeInProgress"
QT_MOC_LITERAL(11, 129, 10), // "inProgress"
QT_MOC_LITERAL(12, 140, 13), // "exitRequested"
QT_MOC_LITERAL(13, 154, 8), // "exitCode"
QT_MOC_LITERAL(14, 163, 6), // "reason"
QT_MOC_LITERAL(15, 170, 16), // "shutdownComplete"
QT_MOC_LITERAL(16, 187, 9), // "initAsync"
QT_MOC_LITERAL(17, 197, 11), // "syncStorage"
QT_MOC_LITERAL(18, 209, 11), // "reloadCerts"
QT_MOC_LITERAL(19, 221, 13), // "cacheSysIdent"
QT_MOC_LITERAL(20, 235, 9), // "setupCore"
QT_MOC_LITERAL(21, 245, 9), // "adminUser"
QT_MOC_LITERAL(22, 255, 13), // "adminPassword"
QT_MOC_LITERAL(23, 269, 7), // "backend"
QT_MOC_LITERAL(24, 277, 9), // "setupData"
QT_MOC_LITERAL(25, 287, 13), // "authenticator"
QT_MOC_LITERAL(26, 301, 12), // "authSetupMap"
QT_MOC_LITERAL(27, 314, 19), // "connectInternalPeer"
QT_MOC_LITERAL(28, 334, 22), // "QPointer<InternalPeer>"
QT_MOC_LITERAL(29, 357, 4), // "peer"
QT_MOC_LITERAL(30, 362, 14), // "startListening"
QT_MOC_LITERAL(31, 377, 13), // "stopListening"
QT_MOC_LITERAL(32, 391, 3), // "msg"
QT_MOC_LITERAL(33, 395, 18), // "incomingConnection"
QT_MOC_LITERAL(34, 414, 18), // "clientDisconnected"
QT_MOC_LITERAL(35, 433, 11), // "initStorage"
QT_MOC_LITERAL(36, 445, 8), // "settings"
QT_MOC_LITERAL(37, 454, 19), // "QProcessEnvironment"
QT_MOC_LITERAL(38, 474, 11), // "environment"
QT_MOC_LITERAL(39, 486, 19), // "loadFromEnvironment"
QT_MOC_LITERAL(40, 506, 5), // "setup"
QT_MOC_LITERAL(41, 512, 17), // "initAuthenticator"
QT_MOC_LITERAL(42, 530, 11), // "socketError"
QT_MOC_LITERAL(43, 542, 28), // "QAbstractSocket::SocketError"
QT_MOC_LITERAL(44, 571, 3), // "err"
QT_MOC_LITERAL(45, 575, 11), // "errorString"
QT_MOC_LITERAL(46, 587, 18), // "setupClientSession"
QT_MOC_LITERAL(47, 606, 11), // "RemotePeer*"
QT_MOC_LITERAL(48, 618, 14), // "changeUserPass"
QT_MOC_LITERAL(49, 633, 8), // "username"
QT_MOC_LITERAL(50, 642, 17), // "onSessionShutdown"
QT_MOC_LITERAL(51, 660, 14), // "SessionThread*"
QT_MOC_LITERAL(52, 675, 7) // "session"

    },
    "Core\0bufferInfoUpdated\0\0UserId\0user\0"
    "BufferInfo\0info\0sessionStateReceived\0"
    "Protocol::SessionState\0sessionState\0"
    "dbUpgradeInProgress\0inProgress\0"
    "exitRequested\0exitCode\0reason\0"
    "shutdownComplete\0initAsync\0syncStorage\0"
    "reloadCerts\0cacheSysIdent\0setupCore\0"
    "adminUser\0adminPassword\0backend\0"
    "setupData\0authenticator\0authSetupMap\0"
    "connectInternalPeer\0QPointer<InternalPeer>\0"
    "peer\0startListening\0stopListening\0msg\0"
    "incomingConnection\0clientDisconnected\0"
    "initStorage\0settings\0QProcessEnvironment\0"
    "environment\0loadFromEnvironment\0setup\0"
    "initAuthenticator\0socketError\0"
    "QAbstractSocket::SocketError\0err\0"
    "errorString\0setupClientSession\0"
    "RemotePeer*\0changeUserPass\0username\0"
    "onSessionShutdown\0SessionThread*\0"
    "session"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Core[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      24,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  134,    2, 0x06 /* Public */,
       7,    1,  139,    2, 0x06 /* Public */,
      10,    1,  142,    2, 0x06 /* Public */,
      12,    2,  145,    2, 0x06 /* Public */,
      15,    0,  150,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    0,  151,    2, 0x0a /* Public */,
      17,    0,  152,    2, 0x0a /* Public */,
      18,    0,  153,    2, 0x0a /* Public */,
      19,    0,  154,    2, 0x0a /* Public */,
      20,    6,  155,    2, 0x0a /* Public */,
      27,    1,  168,    2, 0x0a /* Public */,
      30,    0,  171,    2, 0x08 /* Private */,
      31,    1,  172,    2, 0x08 /* Private */,
      31,    0,  175,    2, 0x28 /* Private | MethodCloned */,
      33,    0,  176,    2, 0x08 /* Private */,
      34,    0,  177,    2, 0x08 /* Private */,
      35,    5,  178,    2, 0x08 /* Private */,
      35,    4,  189,    2, 0x28 /* Private | MethodCloned */,
      41,    5,  198,    2, 0x08 /* Private */,
      41,    4,  209,    2, 0x28 /* Private | MethodCloned */,
      42,    2,  218,    2, 0x08 /* Private */,
      46,    2,  223,    2, 0x08 /* Private */,
      48,    1,  228,    2, 0x08 /* Private */,
      50,    1,  231,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   13,   14,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QVariantMap, QMetaType::QString, QMetaType::QVariantMap,   21,   22,   23,   24,   25,   26,
    QMetaType::Void, 0x80000000 | 28,   29,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::QString,   32,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::QString, QMetaType::QVariantMap, 0x80000000 | 37, QMetaType::Bool, QMetaType::Bool,   23,   36,   38,   39,   40,
    QMetaType::Bool, QMetaType::QString, QMetaType::QVariantMap, 0x80000000 | 37, QMetaType::Bool,   23,   36,   38,   39,
    QMetaType::Bool, QMetaType::QString, QMetaType::QVariantMap, 0x80000000 | 37, QMetaType::Bool, QMetaType::Bool,   23,   36,   38,   39,   40,
    QMetaType::Bool, QMetaType::QString, QMetaType::QVariantMap, 0x80000000 | 37, QMetaType::Bool,   23,   36,   38,   39,
    QMetaType::Void, 0x80000000 | 43, QMetaType::QString,   44,   45,
    QMetaType::Void, 0x80000000 | 47, 0x80000000 | 3,    2,    2,
    QMetaType::Bool, QMetaType::QString,   49,
    QMetaType::Void, 0x80000000 | 51,   52,

       0        // eod
};

void Core::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Core *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->bufferInfoUpdated((*reinterpret_cast< UserId(*)>(_a[1])),(*reinterpret_cast< const BufferInfo(*)>(_a[2]))); break;
        case 1: _t->sessionStateReceived((*reinterpret_cast< const Protocol::SessionState(*)>(_a[1]))); break;
        case 2: _t->dbUpgradeInProgress((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->exitRequested((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->shutdownComplete(); break;
        case 5: _t->initAsync(); break;
        case 6: _t->syncStorage(); break;
        case 7: { bool _r = _t->reloadCerts();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->cacheSysIdent(); break;
        case 9: { QString _r = _t->setupCore((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QVariantMap(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QVariantMap(*)>(_a[6])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->connectInternalPeer((*reinterpret_cast< QPointer<InternalPeer>(*)>(_a[1]))); break;
        case 11: { bool _r = _t->startListening();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->stopListening((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->stopListening(); break;
        case 14: _t->incomingConnection(); break;
        case 15: _t->clientDisconnected(); break;
        case 16: { bool _r = _t->initStorage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])),(*reinterpret_cast< const QProcessEnvironment(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->initStorage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])),(*reinterpret_cast< const QProcessEnvironment(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->initAuthenticator((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])),(*reinterpret_cast< const QProcessEnvironment(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->initAuthenticator((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])),(*reinterpret_cast< const QProcessEnvironment(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->socketError((*reinterpret_cast< QAbstractSocket::SocketError(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 21: _t->setupClientSession((*reinterpret_cast< RemotePeer*(*)>(_a[1])),(*reinterpret_cast< UserId(*)>(_a[2]))); break;
        case 22: { bool _r = _t->changeUserPass((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->onSessionShutdown((*reinterpret_cast< SessionThread*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UserId >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UserId >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SessionThread* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Core::*)(UserId , const BufferInfo & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Core::bufferInfoUpdated)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Core::*)(const Protocol::SessionState & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Core::sessionStateReceived)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Core::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Core::dbUpgradeInProgress)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Core::*)(int , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Core::exitRequested)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Core::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Core::shutdownComplete)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Core::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Core.data,
    qt_meta_data_Core,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Core::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Core::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Core.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Singleton<Core>"))
        return static_cast< Singleton<Core>*>(this);
    return QObject::qt_metacast(_clname);
}

int Core::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void Core::bufferInfoUpdated(UserId _t1, const BufferInfo & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Core::sessionStateReceived(const Protocol::SessionState & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Core::dbUpgradeInProgress(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Core::exitRequested(int _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Core::shutdownComplete()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
