/****************************************************************************
** Meta object code from reading C++ file 'corebuffersyncer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/corebuffersyncer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'corebuffersyncer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreBufferSyncer_t {
    QByteArrayData data[29];
    char stringdata0[414];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreBufferSyncer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreBufferSyncer_t qt_meta_stringdata_CoreBufferSyncer = {
    {
QT_MOC_LITERAL(0, 0, 16), // "CoreBufferSyncer"
QT_MOC_LITERAL(1, 17, 21), // "requestSetLastSeenMsg"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 8), // "BufferId"
QT_MOC_LITERAL(4, 49, 6), // "buffer"
QT_MOC_LITERAL(5, 56, 5), // "MsgId"
QT_MOC_LITERAL(6, 62, 5), // "msgId"
QT_MOC_LITERAL(7, 68, 20), // "requestSetMarkerLine"
QT_MOC_LITERAL(8, 89, 19), // "requestRemoveBuffer"
QT_MOC_LITERAL(9, 109, 12), // "removeBuffer"
QT_MOC_LITERAL(10, 122, 8), // "bufferId"
QT_MOC_LITERAL(11, 131, 17), // "addBufferActivity"
QT_MOC_LITERAL(12, 149, 7), // "Message"
QT_MOC_LITERAL(13, 157, 7), // "message"
QT_MOC_LITERAL(14, 165, 16), // "addCoreHighlight"
QT_MOC_LITERAL(15, 182, 17), // "setBufferActivity"
QT_MOC_LITERAL(16, 200, 8), // "activity"
QT_MOC_LITERAL(17, 209, 17), // "setHighlightCount"
QT_MOC_LITERAL(18, 227, 14), // "highlightCount"
QT_MOC_LITERAL(19, 242, 19), // "requestRenameBuffer"
QT_MOC_LITERAL(20, 262, 7), // "newName"
QT_MOC_LITERAL(21, 270, 12), // "renameBuffer"
QT_MOC_LITERAL(22, 283, 30), // "requestMergeBuffersPermanently"
QT_MOC_LITERAL(23, 314, 7), // "buffer1"
QT_MOC_LITERAL(24, 322, 7), // "buffer2"
QT_MOC_LITERAL(25, 330, 23), // "mergeBuffersPermanently"
QT_MOC_LITERAL(26, 354, 21), // "requestPurgeBufferIds"
QT_MOC_LITERAL(27, 376, 23), // "requestMarkBufferAsRead"
QT_MOC_LITERAL(28, 400, 13) // "storeDirtyIds"

    },
    "CoreBufferSyncer\0requestSetLastSeenMsg\0"
    "\0BufferId\0buffer\0MsgId\0msgId\0"
    "requestSetMarkerLine\0requestRemoveBuffer\0"
    "removeBuffer\0bufferId\0addBufferActivity\0"
    "Message\0message\0addCoreHighlight\0"
    "setBufferActivity\0activity\0setHighlightCount\0"
    "highlightCount\0requestRenameBuffer\0"
    "newName\0renameBuffer\0"
    "requestMergeBuffersPermanently\0buffer1\0"
    "buffer2\0mergeBuffersPermanently\0"
    "requestPurgeBufferIds\0requestMarkBufferAsRead\0"
    "storeDirtyIds"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreBufferSyncer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   89,    2, 0x0a /* Public */,
       7,    2,   94,    2, 0x0a /* Public */,
       8,    1,   99,    2, 0x0a /* Public */,
       9,    1,  102,    2, 0x0a /* Public */,
      11,    1,  105,    2, 0x0a /* Public */,
      14,    1,  108,    2, 0x0a /* Public */,
      15,    2,  111,    2, 0x0a /* Public */,
      17,    2,  116,    2, 0x0a /* Public */,
      19,    2,  121,    2, 0x0a /* Public */,
      21,    2,  126,    2, 0x0a /* Public */,
      22,    2,  131,    2, 0x0a /* Public */,
      25,    2,  136,    2, 0x0a /* Public */,
      26,    0,  141,    2, 0x0a /* Public */,
      27,    1,  142,    2, 0x0a /* Public */,
      28,    0,  145,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,   16,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,   18,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   20,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   20,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,   23,   24,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,   23,   24,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

       0        // eod
};

void CoreBufferSyncer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreBufferSyncer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->requestSetLastSeenMsg((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const MsgId(*)>(_a[2]))); break;
        case 1: _t->requestSetMarkerLine((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const MsgId(*)>(_a[2]))); break;
        case 2: _t->requestRemoveBuffer((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 3: _t->removeBuffer((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 4: _t->addBufferActivity((*reinterpret_cast< const Message(*)>(_a[1]))); break;
        case 5: _t->addCoreHighlight((*reinterpret_cast< const Message(*)>(_a[1]))); break;
        case 6: _t->setBufferActivity((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->setHighlightCount((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 8: _t->requestRenameBuffer((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 9: _t->renameBuffer((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 10: _t->requestMergeBuffersPermanently((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< BufferId(*)>(_a[2]))); break;
        case 11: _t->mergeBuffersPermanently((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< BufferId(*)>(_a[2]))); break;
        case 12: _t->requestPurgeBufferIds(); break;
        case 13: _t->requestMarkBufferAsRead((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 14: _t->storeDirtyIds(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Message >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Message >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreBufferSyncer::staticMetaObject = { {
    QMetaObject::SuperData::link<BufferSyncer::staticMetaObject>(),
    qt_meta_stringdata_CoreBufferSyncer.data,
    qt_meta_data_CoreBufferSyncer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreBufferSyncer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreBufferSyncer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreBufferSyncer.stringdata0))
        return static_cast<void*>(this);
    return BufferSyncer::qt_metacast(_clname);
}

int CoreBufferSyncer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BufferSyncer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
