/****************************************************************************
** Meta object code from reading C++ file 'abstractsqlstorage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/abstractsqlstorage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractsqlstorage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_AbstractSqlStorage_t {
    QByteArrayData data[10];
    char stringdata0[118];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AbstractSqlStorage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AbstractSqlStorage_t qt_meta_stringdata_AbstractSqlStorage = {
    {
QT_MOC_LITERAL(0, 0, 18), // "AbstractSqlStorage"
QT_MOC_LITERAL(1, 19, 4), // "init"
QT_MOC_LITERAL(2, 24, 5), // "State"
QT_MOC_LITERAL(3, 30, 0), // ""
QT_MOC_LITERAL(4, 31, 8), // "settings"
QT_MOC_LITERAL(5, 40, 19), // "QProcessEnvironment"
QT_MOC_LITERAL(6, 60, 11), // "environment"
QT_MOC_LITERAL(7, 72, 19), // "loadFromEnvironment"
QT_MOC_LITERAL(8, 92, 5), // "setup"
QT_MOC_LITERAL(9, 98, 19) // "connectionDestroyed"

    },
    "AbstractSqlStorage\0init\0State\0\0settings\0"
    "QProcessEnvironment\0environment\0"
    "loadFromEnvironment\0setup\0connectionDestroyed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AbstractSqlStorage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    3,   59,    3, 0x0a /* Public */,
       1,    2,   66,    3, 0x2a /* Public | MethodCloned */,
       1,    1,   71,    3, 0x2a /* Public | MethodCloned */,
       1,    0,   74,    3, 0x2a /* Public | MethodCloned */,
       8,    3,   75,    3, 0x0a /* Public */,
       8,    2,   82,    3, 0x2a /* Public | MethodCloned */,
       8,    1,   87,    3, 0x2a /* Public | MethodCloned */,
       8,    0,   90,    3, 0x2a /* Public | MethodCloned */,
       9,    0,   91,    3, 0x08 /* Private */,

 // slots: parameters
    0x80000000 | 2, QMetaType::QVariantMap, 0x80000000 | 5, QMetaType::Bool,    4,    6,    7,
    0x80000000 | 2, QMetaType::QVariantMap, 0x80000000 | 5,    4,    6,
    0x80000000 | 2, QMetaType::QVariantMap,    4,
    0x80000000 | 2,
    QMetaType::Bool, QMetaType::QVariantMap, 0x80000000 | 5, QMetaType::Bool,    4,    6,    7,
    QMetaType::Bool, QMetaType::QVariantMap, 0x80000000 | 5,    4,    6,
    QMetaType::Bool, QMetaType::QVariantMap,    4,
    QMetaType::Bool,
    QMetaType::Void,

       0        // eod
};

void AbstractSqlStorage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AbstractSqlStorage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { State _r = _t->init((*reinterpret_cast< const QVariantMap(*)>(_a[1])),(*reinterpret_cast< const QProcessEnvironment(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< State*>(_a[0]) = std::move(_r); }  break;
        case 1: { State _r = _t->init((*reinterpret_cast< const QVariantMap(*)>(_a[1])),(*reinterpret_cast< const QProcessEnvironment(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< State*>(_a[0]) = std::move(_r); }  break;
        case 2: { State _r = _t->init((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< State*>(_a[0]) = std::move(_r); }  break;
        case 3: { State _r = _t->init();
            if (_a[0]) *reinterpret_cast< State*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->setup((*reinterpret_cast< const QVariantMap(*)>(_a[1])),(*reinterpret_cast< const QProcessEnvironment(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->setup((*reinterpret_cast< const QVariantMap(*)>(_a[1])),(*reinterpret_cast< const QProcessEnvironment(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->setup((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->setup();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->connectionDestroyed(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject AbstractSqlStorage::staticMetaObject = { {
    QMetaObject::SuperData::link<Storage::staticMetaObject>(),
    qt_meta_stringdata_AbstractSqlStorage.data,
    qt_meta_data_AbstractSqlStorage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *AbstractSqlStorage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractSqlStorage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AbstractSqlStorage.stringdata0))
        return static_cast<void*>(this);
    return Storage::qt_metacast(_clname);
}

int AbstractSqlStorage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Storage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}
struct qt_meta_stringdata_AbstractSqlStorage__Connection_t {
    QByteArrayData data[1];
    char stringdata0[31];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AbstractSqlStorage__Connection_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AbstractSqlStorage__Connection_t qt_meta_stringdata_AbstractSqlStorage__Connection = {
    {
QT_MOC_LITERAL(0, 0, 30) // "AbstractSqlStorage::Connection"

    },
    "AbstractSqlStorage::Connection"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AbstractSqlStorage__Connection[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void AbstractSqlStorage::Connection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject AbstractSqlStorage::Connection::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_AbstractSqlStorage__Connection.data,
    qt_meta_data_AbstractSqlStorage__Connection,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *AbstractSqlStorage::Connection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractSqlStorage::Connection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AbstractSqlStorage__Connection.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractSqlStorage::Connection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
