/****************************************************************************
** Meta object code from reading C++ file 'dockmanagernotificationbackend.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/dockmanagernotificationbackend.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dockmanagernotificationbackend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DockManagerNotificationBackend_t {
    QByteArrayData data[10];
    char stringdata0[121];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DockManagerNotificationBackend_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DockManagerNotificationBackend_t qt_meta_stringdata_DockManagerNotificationBackend = {
    {
QT_MOC_LITERAL(0, 0, 30), // "DockManagerNotificationBackend"
QT_MOC_LITERAL(1, 31, 14), // "enabledChanged"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 14), // "updateProgress"
QT_MOC_LITERAL(4, 62, 8), // "progress"
QT_MOC_LITERAL(5, 71, 4), // "done"
QT_MOC_LITERAL(6, 76, 5), // "total"
QT_MOC_LITERAL(7, 82, 9), // "itemAdded"
QT_MOC_LITERAL(8, 92, 15), // "QDBusObjectPath"
QT_MOC_LITERAL(9, 108, 12) // "synchronized"

    },
    "DockManagerNotificationBackend\0"
    "enabledChanged\0\0updateProgress\0progress\0"
    "done\0total\0itemAdded\0QDBusObjectPath\0"
    "synchronized"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DockManagerNotificationBackend[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x08 /* Private */,
       3,    1,   42,    2, 0x08 /* Private */,
       3,    2,   45,    2, 0x08 /* Private */,
       7,    1,   50,    2, 0x08 /* Private */,
       9,    0,   53,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    5,    6,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void,

       0        // eod
};

void DockManagerNotificationBackend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DockManagerNotificationBackend *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->enabledChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 1: _t->updateProgress((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->updateProgress((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->itemAdded((*reinterpret_cast< QDBusObjectPath(*)>(_a[1]))); break;
        case 4: _t->synchronized(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DockManagerNotificationBackend::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractNotificationBackend::staticMetaObject>(),
    qt_meta_stringdata_DockManagerNotificationBackend.data,
    qt_meta_data_DockManagerNotificationBackend,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DockManagerNotificationBackend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DockManagerNotificationBackend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DockManagerNotificationBackend.stringdata0))
        return static_cast<void*>(this);
    return AbstractNotificationBackend::qt_metacast(_clname);
}

int DockManagerNotificationBackend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractNotificationBackend::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
struct qt_meta_stringdata_DockManagerNotificationBackend__ConfigWidget_t {
    QByteArrayData data[3];
    char stringdata0[60];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DockManagerNotificationBackend__ConfigWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DockManagerNotificationBackend__ConfigWidget_t qt_meta_stringdata_DockManagerNotificationBackend__ConfigWidget = {
    {
QT_MOC_LITERAL(0, 0, 44), // "DockManagerNotificationBacken..."
QT_MOC_LITERAL(1, 45, 13), // "widgetChanged"
QT_MOC_LITERAL(2, 59, 0) // ""

    },
    "DockManagerNotificationBackend::ConfigWidget\0"
    "widgetChanged\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DockManagerNotificationBackend__ConfigWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void DockManagerNotificationBackend::ConfigWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ConfigWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->widgetChanged(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject DockManagerNotificationBackend::ConfigWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingsPage::staticMetaObject>(),
    qt_meta_stringdata_DockManagerNotificationBackend__ConfigWidget.data,
    qt_meta_data_DockManagerNotificationBackend__ConfigWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DockManagerNotificationBackend::ConfigWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DockManagerNotificationBackend::ConfigWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DockManagerNotificationBackend__ConfigWidget.stringdata0))
        return static_cast<void*>(this);
    return SettingsPage::qt_metacast(_clname);
}

int DockManagerNotificationBackend::ConfigWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingsPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
