/****************************************************************************
** Meta object code from reading C++ file 'highlightsettingspage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/settingspages/highlightsettingspage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'highlightsettingspage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_HighlightSettingsPage_t {
    QByteArrayData data[19];
    char stringdata0[203];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_HighlightSettingsPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_HighlightSettingsPage_t qt_meta_stringdata_HighlightSettingsPage = {
    {
QT_MOC_LITERAL(0, 0, 21), // "HighlightSettingsPage"
QT_MOC_LITERAL(1, 22, 4), // "save"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 4), // "load"
QT_MOC_LITERAL(4, 33, 8), // "defaults"
QT_MOC_LITERAL(5, 42, 16), // "widgetHasChanged"
QT_MOC_LITERAL(6, 59, 9), // "addNewRow"
QT_MOC_LITERAL(7, 69, 4), // "name"
QT_MOC_LITERAL(8, 74, 5), // "regex"
QT_MOC_LITERAL(9, 80, 2), // "cs"
QT_MOC_LITERAL(10, 83, 6), // "enable"
QT_MOC_LITERAL(11, 90, 8), // "chanName"
QT_MOC_LITERAL(12, 99, 4), // "self"
QT_MOC_LITERAL(13, 104, 18), // "removeSelectedRows"
QT_MOC_LITERAL(14, 123, 9), // "selectRow"
QT_MOC_LITERAL(15, 133, 17), // "QTableWidgetItem*"
QT_MOC_LITERAL(16, 151, 4), // "item"
QT_MOC_LITERAL(17, 156, 12), // "tableChanged"
QT_MOC_LITERAL(18, 169, 33) // "on_localHighlightsDetails_cli..."

    },
    "HighlightSettingsPage\0save\0\0load\0"
    "defaults\0widgetHasChanged\0addNewRow\0"
    "name\0regex\0cs\0enable\0chanName\0self\0"
    "removeSelectedRows\0selectRow\0"
    "QTableWidgetItem*\0item\0tableChanged\0"
    "on_localHighlightsDetails_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_HighlightSettingsPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   89,    2, 0x0a /* Public */,
       3,    0,   90,    2, 0x0a /* Public */,
       4,    0,   91,    2, 0x0a /* Public */,
       5,    0,   92,    2, 0x08 /* Private */,
       6,    6,   93,    2, 0x08 /* Private */,
       6,    5,  106,    2, 0x28 /* Private | MethodCloned */,
       6,    4,  117,    2, 0x28 /* Private | MethodCloned */,
       6,    3,  126,    2, 0x28 /* Private | MethodCloned */,
       6,    2,  133,    2, 0x28 /* Private | MethodCloned */,
       6,    1,  138,    2, 0x28 /* Private | MethodCloned */,
       6,    0,  141,    2, 0x28 /* Private | MethodCloned */,
      13,    0,  142,    2, 0x08 /* Private */,
      14,    1,  143,    2, 0x08 /* Private */,
      17,    1,  146,    2, 0x08 /* Private */,
      18,    0,  149,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool, QMetaType::QString, QMetaType::Bool,    7,    8,    9,   10,   11,   12,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool, QMetaType::QString,    7,    8,    9,   10,   11,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool,    7,    8,    9,   10,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,    7,    8,    9,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    7,    8,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void,

       0        // eod
};

void HighlightSettingsPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<HighlightSettingsPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->save(); break;
        case 1: _t->load(); break;
        case 2: _t->defaults(); break;
        case 3: _t->widgetHasChanged(); break;
        case 4: _t->addNewRow((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< QString(*)>(_a[5])),(*reinterpret_cast< bool(*)>(_a[6]))); break;
        case 5: _t->addNewRow((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< QString(*)>(_a[5]))); break;
        case 6: _t->addNewRow((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 7: _t->addNewRow((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 8: _t->addNewRow((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 9: _t->addNewRow((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 10: _t->addNewRow(); break;
        case 11: _t->removeSelectedRows(); break;
        case 12: _t->selectRow((*reinterpret_cast< QTableWidgetItem*(*)>(_a[1]))); break;
        case 13: _t->tableChanged((*reinterpret_cast< QTableWidgetItem*(*)>(_a[1]))); break;
        case 14: _t->on_localHighlightsDetails_clicked(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject HighlightSettingsPage::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingsPage::staticMetaObject>(),
    qt_meta_stringdata_HighlightSettingsPage.data,
    qt_meta_data_HighlightSettingsPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *HighlightSettingsPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HighlightSettingsPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_HighlightSettingsPage.stringdata0))
        return static_cast<void*>(this);
    return SettingsPage::qt_metacast(_clname);
}

int HighlightSettingsPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingsPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
