/********************************************************************************
** Form generated from reading UI file 'identityeditwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IDENTITYEDITWIDGET_H
#define UI_IDENTITYEDITWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_IdentityEditWidget
{
public:
    QVBoxLayout *verticalLayout_13;
    QTabWidget *tabWidget;
    QWidget *generalTab;
    QVBoxLayout *vboxLayout;
    QHBoxLayout *_2;
    QLabel *label;
    QLineEdit *realName;
    QGroupBox *groupBox;
    QHBoxLayout *_3;
    QListWidget *nicknameList;
    QVBoxLayout *_4;
    QPushButton *addNick;
    QPushButton *deleteNick;
    QPushButton *renameNick;
    QHBoxLayout *_5;
    QSpacerItem *spacerItem;
    QToolButton *nickUp;
    QToolButton *nickDown;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;
    QWidget *awayTab;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QGridLayout *_6;
    QLineEdit *awayNick;
    QLineEdit *awayReason;
    QLabel *awayNickLabel;
    QLabel *awayReasonLabel;
    QGroupBox *detachAwayEnabled;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label_13;
    QLineEdit *detachAwayReason;
    QGroupBox *autoAwayEnabled;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *_7;
    QLabel *autoAwayLabel_1;
    QSpinBox *autoAwayTime;
    QLabel *autoAwayLabel_2;
    QSpacerItem *spacerItem3;
    QGridLayout *_8;
    QCheckBox *autoAwayReasonEnabled;
    QLineEdit *autoAwayReason;
    QSpacerItem *spacerItem4;
    QWidget *advancedTab;
    QVBoxLayout *verticalLayout_12;
    QHBoxLayout *_9;
    QLabel *label_2;
    QLineEdit *ident;
    QGroupBox *groupBox_3;
    QVBoxLayout *_10;
    QGridLayout *_11;
    QLabel *label_3;
    QLineEdit *partReason;
    QLineEdit *kickReason;
    QLabel *label_5;
    QLineEdit *quitReason;
    QLabel *label_4;
    QStackedWidget *keyAndCertSettings;
    QWidget *pageNoSsl;
    QVBoxLayout *verticalLayout_8;
    QGroupBox *groupBox_6;
    QVBoxLayout *verticalLayout_9;
    QLabel *label_8;
    QWidget *pageUnsecure;
    QVBoxLayout *verticalLayout_7;
    QGroupBox *groupBox_5;
    QVBoxLayout *verticalLayout_6;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QPushButton *continueUnsecured;
    QSpacerItem *horizontalSpacer_3;
    QWidget *pageEditSsl;
    QVBoxLayout *verticalLayout_11;
    QGroupBox *sslKeyGroupBox;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_6;
    QLabel *keyTypeLabel;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *clearOrLoadKeyButton;
    QGroupBox *sslCertGroupBox;
    QHBoxLayout *horizontalLayout_6;
    QVBoxLayout *verticalLayout_10;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_9;
    QLabel *certOrgLabel;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_10;
    QLabel *certCNameLabel;
    QSpacerItem *horizontalSpacer_5;
    QVBoxLayout *verticalLayout_14;
    QPushButton *clearOrLoadCertButton;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *IdentityEditWidget)
    {
        if (IdentityEditWidget->objectName().isEmpty())
            IdentityEditWidget->setObjectName(QString::fromUtf8("IdentityEditWidget"));
        IdentityEditWidget->resize(393, 422);
        verticalLayout_13 = new QVBoxLayout(IdentityEditWidget);
        verticalLayout_13->setSpacing(0);
        verticalLayout_13->setContentsMargins(0, 0, 0, 0);
        verticalLayout_13->setObjectName(QString::fromUtf8("verticalLayout_13"));
        tabWidget = new QTabWidget(IdentityEditWidget);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        generalTab = new QWidget();
        generalTab->setObjectName(QString::fromUtf8("generalTab"));
        vboxLayout = new QVBoxLayout(generalTab);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        _2 = new QHBoxLayout();
        _2->setObjectName(QString::fromUtf8("_2"));
        label = new QLabel(generalTab);
        label->setObjectName(QString::fromUtf8("label"));

        _2->addWidget(label);

        realName = new QLineEdit(generalTab);
        realName->setObjectName(QString::fromUtf8("realName"));

        _2->addWidget(realName);


        vboxLayout->addLayout(_2);

        groupBox = new QGroupBox(generalTab);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        _3 = new QHBoxLayout(groupBox);
        _3->setObjectName(QString::fromUtf8("_3"));
        nicknameList = new QListWidget(groupBox);
        nicknameList->setObjectName(QString::fromUtf8("nicknameList"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(nicknameList->sizePolicy().hasHeightForWidth());
        nicknameList->setSizePolicy(sizePolicy);
        nicknameList->setProperty("showDropIndicator", QVariant(true));
        nicknameList->setDragEnabled(false);
        nicknameList->setDragDropMode(QAbstractItemView::NoDragDrop);
        nicknameList->setSelectionBehavior(QAbstractItemView::SelectRows);

        _3->addWidget(nicknameList);

        _4 = new QVBoxLayout();
        _4->setObjectName(QString::fromUtf8("_4"));
        addNick = new QPushButton(groupBox);
        addNick->setObjectName(QString::fromUtf8("addNick"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(addNick->sizePolicy().hasHeightForWidth());
        addNick->setSizePolicy(sizePolicy1);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/list-add.png"), QSize(), QIcon::Normal, QIcon::Off);
        addNick->setIcon(icon);
        addNick->setIconSize(QSize(16, 16));

        _4->addWidget(addNick);

        deleteNick = new QPushButton(groupBox);
        deleteNick->setObjectName(QString::fromUtf8("deleteNick"));
        sizePolicy1.setHeightForWidth(deleteNick->sizePolicy().hasHeightForWidth());
        deleteNick->setSizePolicy(sizePolicy1);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/edit-delete.png"), QSize(), QIcon::Normal, QIcon::Off);
        deleteNick->setIcon(icon1);

        _4->addWidget(deleteNick);

        renameNick = new QPushButton(groupBox);
        renameNick->setObjectName(QString::fromUtf8("renameNick"));
        sizePolicy1.setHeightForWidth(renameNick->sizePolicy().hasHeightForWidth());
        renameNick->setSizePolicy(sizePolicy1);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/edit-rename.png"), QSize(), QIcon::Normal, QIcon::Off);
        renameNick->setIcon(icon2);

        _4->addWidget(renameNick);

        _5 = new QHBoxLayout();
        _5->setObjectName(QString::fromUtf8("_5"));
        spacerItem = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _5->addItem(spacerItem);

        nickUp = new QToolButton(groupBox);
        nickUp->setObjectName(QString::fromUtf8("nickUp"));
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/go-up.png"), QSize(), QIcon::Normal, QIcon::Off);
        nickUp->setIcon(icon3);

        _5->addWidget(nickUp);

        nickDown = new QToolButton(groupBox);
        nickDown->setObjectName(QString::fromUtf8("nickDown"));
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/go-down.png"), QSize(), QIcon::Normal, QIcon::Off);
        nickDown->setIcon(icon4);

        _5->addWidget(nickDown);

        spacerItem1 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _5->addItem(spacerItem1);


        _4->addLayout(_5);

        spacerItem2 = new QSpacerItem(124, 76, QSizePolicy::Minimum, QSizePolicy::Expanding);

        _4->addItem(spacerItem2);


        _3->addLayout(_4);


        vboxLayout->addWidget(groupBox);

        tabWidget->addTab(generalTab, QString());
        awayTab = new QWidget();
        awayTab->setObjectName(QString::fromUtf8("awayTab"));
        verticalLayout_4 = new QVBoxLayout(awayTab);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        groupBox_2 = new QGroupBox(awayTab);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        _6 = new QGridLayout();
        _6->setObjectName(QString::fromUtf8("_6"));
        awayNick = new QLineEdit(groupBox_2);
        awayNick->setObjectName(QString::fromUtf8("awayNick"));
        awayNick->setEnabled(false);

        _6->addWidget(awayNick, 0, 1, 1, 1);

        awayReason = new QLineEdit(groupBox_2);
        awayReason->setObjectName(QString::fromUtf8("awayReason"));
        awayReason->setEnabled(true);

        _6->addWidget(awayReason, 1, 1, 1, 1);

        awayNickLabel = new QLabel(groupBox_2);
        awayNickLabel->setObjectName(QString::fromUtf8("awayNickLabel"));

        _6->addWidget(awayNickLabel, 0, 0, 1, 1);

        awayReasonLabel = new QLabel(groupBox_2);
        awayReasonLabel->setObjectName(QString::fromUtf8("awayReasonLabel"));

        _6->addWidget(awayReasonLabel, 1, 0, 1, 1);


        verticalLayout_3->addLayout(_6);


        verticalLayout_4->addWidget(groupBox_2);

        detachAwayEnabled = new QGroupBox(awayTab);
        detachAwayEnabled->setObjectName(QString::fromUtf8("detachAwayEnabled"));
        detachAwayEnabled->setCheckable(true);
        detachAwayEnabled->setChecked(true);
        verticalLayout = new QVBoxLayout(detachAwayEnabled);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label_13 = new QLabel(detachAwayEnabled);
        label_13->setObjectName(QString::fromUtf8("label_13"));

        horizontalLayout->addWidget(label_13);

        detachAwayReason = new QLineEdit(detachAwayEnabled);
        detachAwayReason->setObjectName(QString::fromUtf8("detachAwayReason"));

        horizontalLayout->addWidget(detachAwayReason);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_4->addWidget(detachAwayEnabled);

        autoAwayEnabled = new QGroupBox(awayTab);
        autoAwayEnabled->setObjectName(QString::fromUtf8("autoAwayEnabled"));
        autoAwayEnabled->setEnabled(false);
        autoAwayEnabled->setCheckable(true);
        autoAwayEnabled->setChecked(false);
        verticalLayout_2 = new QVBoxLayout(autoAwayEnabled);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        _7 = new QHBoxLayout();
        _7->setObjectName(QString::fromUtf8("_7"));
        autoAwayLabel_1 = new QLabel(autoAwayEnabled);
        autoAwayLabel_1->setObjectName(QString::fromUtf8("autoAwayLabel_1"));

        _7->addWidget(autoAwayLabel_1);

        autoAwayTime = new QSpinBox(autoAwayEnabled);
        autoAwayTime->setObjectName(QString::fromUtf8("autoAwayTime"));

        _7->addWidget(autoAwayTime);

        autoAwayLabel_2 = new QLabel(autoAwayEnabled);
        autoAwayLabel_2->setObjectName(QString::fromUtf8("autoAwayLabel_2"));

        _7->addWidget(autoAwayLabel_2);

        spacerItem3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _7->addItem(spacerItem3);


        verticalLayout_2->addLayout(_7);

        _8 = new QGridLayout();
        _8->setObjectName(QString::fromUtf8("_8"));
        autoAwayReasonEnabled = new QCheckBox(autoAwayEnabled);
        autoAwayReasonEnabled->setObjectName(QString::fromUtf8("autoAwayReasonEnabled"));

        _8->addWidget(autoAwayReasonEnabled, 0, 0, 1, 1);

        autoAwayReason = new QLineEdit(autoAwayEnabled);
        autoAwayReason->setObjectName(QString::fromUtf8("autoAwayReason"));
        autoAwayReason->setEnabled(false);

        _8->addWidget(autoAwayReason, 0, 1, 1, 1);


        verticalLayout_2->addLayout(_8);


        verticalLayout_4->addWidget(autoAwayEnabled);

        spacerItem4 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(spacerItem4);

        tabWidget->addTab(awayTab, QString());
        advancedTab = new QWidget();
        advancedTab->setObjectName(QString::fromUtf8("advancedTab"));
        verticalLayout_12 = new QVBoxLayout(advancedTab);
        verticalLayout_12->setObjectName(QString::fromUtf8("verticalLayout_12"));
        _9 = new QHBoxLayout();
        _9->setObjectName(QString::fromUtf8("_9"));
        label_2 = new QLabel(advancedTab);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        _9->addWidget(label_2);

        ident = new QLineEdit(advancedTab);
        ident->setObjectName(QString::fromUtf8("ident"));

        _9->addWidget(ident);


        verticalLayout_12->addLayout(_9);

        groupBox_3 = new QGroupBox(advancedTab);
        groupBox_3->setObjectName(QString::fromUtf8("groupBox_3"));
        _10 = new QVBoxLayout(groupBox_3);
        _10->setObjectName(QString::fromUtf8("_10"));
        _11 = new QGridLayout();
        _11->setObjectName(QString::fromUtf8("_11"));
        label_3 = new QLabel(groupBox_3);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        _11->addWidget(label_3, 1, 0, 1, 1);

        partReason = new QLineEdit(groupBox_3);
        partReason->setObjectName(QString::fromUtf8("partReason"));

        _11->addWidget(partReason, 1, 1, 1, 1);

        kickReason = new QLineEdit(groupBox_3);
        kickReason->setObjectName(QString::fromUtf8("kickReason"));

        _11->addWidget(kickReason, 0, 1, 1, 1);

        label_5 = new QLabel(groupBox_3);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        _11->addWidget(label_5, 2, 0, 1, 1);

        quitReason = new QLineEdit(groupBox_3);
        quitReason->setObjectName(QString::fromUtf8("quitReason"));

        _11->addWidget(quitReason, 2, 1, 1, 1);

        label_4 = new QLabel(groupBox_3);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        _11->addWidget(label_4, 0, 0, 1, 1);


        _10->addLayout(_11);


        verticalLayout_12->addWidget(groupBox_3);

        keyAndCertSettings = new QStackedWidget(advancedTab);
        keyAndCertSettings->setObjectName(QString::fromUtf8("keyAndCertSettings"));
        keyAndCertSettings->setStyleSheet(QString::fromUtf8(""));
        keyAndCertSettings->setLineWidth(0);
        pageNoSsl = new QWidget();
        pageNoSsl->setObjectName(QString::fromUtf8("pageNoSsl"));
        verticalLayout_8 = new QVBoxLayout(pageNoSsl);
        verticalLayout_8->setContentsMargins(0, 0, 0, 0);
        verticalLayout_8->setObjectName(QString::fromUtf8("verticalLayout_8"));
        groupBox_6 = new QGroupBox(pageNoSsl);
        groupBox_6->setObjectName(QString::fromUtf8("groupBox_6"));
        verticalLayout_9 = new QVBoxLayout(groupBox_6);
        verticalLayout_9->setObjectName(QString::fromUtf8("verticalLayout_9"));
        label_8 = new QLabel(groupBox_6);
        label_8->setObjectName(QString::fromUtf8("label_8"));
        label_8->setAlignment(Qt::AlignCenter);
        label_8->setWordWrap(true);

        verticalLayout_9->addWidget(label_8);


        verticalLayout_8->addWidget(groupBox_6);

        keyAndCertSettings->addWidget(pageNoSsl);
        pageUnsecure = new QWidget();
        pageUnsecure->setObjectName(QString::fromUtf8("pageUnsecure"));
        verticalLayout_7 = new QVBoxLayout(pageUnsecure);
        verticalLayout_7->setContentsMargins(0, 0, 0, 0);
        verticalLayout_7->setObjectName(QString::fromUtf8("verticalLayout_7"));
        groupBox_5 = new QGroupBox(pageUnsecure);
        groupBox_5->setObjectName(QString::fromUtf8("groupBox_5"));
        verticalLayout_6 = new QVBoxLayout(groupBox_5);
        verticalLayout_6->setObjectName(QString::fromUtf8("verticalLayout_6"));
        label_7 = new QLabel(groupBox_5);
        label_7->setObjectName(QString::fromUtf8("label_7"));
        label_7->setAlignment(Qt::AlignCenter);
        label_7->setWordWrap(true);

        verticalLayout_6->addWidget(label_7);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        continueUnsecured = new QPushButton(groupBox_5);
        continueUnsecured->setObjectName(QString::fromUtf8("continueUnsecured"));

        horizontalLayout_2->addWidget(continueUnsecured);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        verticalLayout_6->addLayout(horizontalLayout_2);


        verticalLayout_7->addWidget(groupBox_5);

        keyAndCertSettings->addWidget(pageUnsecure);
        pageEditSsl = new QWidget();
        pageEditSsl->setObjectName(QString::fromUtf8("pageEditSsl"));
        verticalLayout_11 = new QVBoxLayout(pageEditSsl);
        verticalLayout_11->setSpacing(0);
        verticalLayout_11->setContentsMargins(0, 0, 0, 0);
        verticalLayout_11->setObjectName(QString::fromUtf8("verticalLayout_11"));
        sslKeyGroupBox = new QGroupBox(pageEditSsl);
        sslKeyGroupBox->setObjectName(QString::fromUtf8("sslKeyGroupBox"));
        sslKeyGroupBox->setStyleSheet(QString::fromUtf8(""));
        sslKeyGroupBox->setCheckable(false);
        sslKeyGroupBox->setChecked(false);
        verticalLayout_5 = new QVBoxLayout(sslKeyGroupBox);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label_6 = new QLabel(sslKeyGroupBox);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        horizontalLayout_3->addWidget(label_6);

        keyTypeLabel = new QLabel(sslKeyGroupBox);
        keyTypeLabel->setObjectName(QString::fromUtf8("keyTypeLabel"));

        horizontalLayout_3->addWidget(keyTypeLabel);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);

        clearOrLoadKeyButton = new QPushButton(sslKeyGroupBox);
        clearOrLoadKeyButton->setObjectName(QString::fromUtf8("clearOrLoadKeyButton"));

        horizontalLayout_3->addWidget(clearOrLoadKeyButton);


        verticalLayout_5->addLayout(horizontalLayout_3);


        verticalLayout_11->addWidget(sslKeyGroupBox);

        sslCertGroupBox = new QGroupBox(pageEditSsl);
        sslCertGroupBox->setObjectName(QString::fromUtf8("sslCertGroupBox"));
        horizontalLayout_6 = new QHBoxLayout(sslCertGroupBox);
        horizontalLayout_6->setSpacing(0);
        horizontalLayout_6->setObjectName(QString::fromUtf8("horizontalLayout_6"));
        verticalLayout_10 = new QVBoxLayout();
        verticalLayout_10->setSpacing(0);
        verticalLayout_10->setObjectName(QString::fromUtf8("verticalLayout_10"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(8);
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        label_9 = new QLabel(sslCertGroupBox);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        horizontalLayout_4->addWidget(label_9);

        certOrgLabel = new QLabel(sslCertGroupBox);
        certOrgLabel->setObjectName(QString::fromUtf8("certOrgLabel"));

        horizontalLayout_4->addWidget(certOrgLabel);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);


        verticalLayout_10->addLayout(horizontalLayout_4);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setSpacing(8);
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        label_10 = new QLabel(sslCertGroupBox);
        label_10->setObjectName(QString::fromUtf8("label_10"));

        horizontalLayout_5->addWidget(label_10);

        certCNameLabel = new QLabel(sslCertGroupBox);
        certCNameLabel->setObjectName(QString::fromUtf8("certCNameLabel"));

        horizontalLayout_5->addWidget(certCNameLabel);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_5);


        verticalLayout_10->addLayout(horizontalLayout_5);


        horizontalLayout_6->addLayout(verticalLayout_10);

        verticalLayout_14 = new QVBoxLayout();
        verticalLayout_14->setObjectName(QString::fromUtf8("verticalLayout_14"));
        clearOrLoadCertButton = new QPushButton(sslCertGroupBox);
        clearOrLoadCertButton->setObjectName(QString::fromUtf8("clearOrLoadCertButton"));

        verticalLayout_14->addWidget(clearOrLoadCertButton);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_14->addItem(verticalSpacer_2);


        horizontalLayout_6->addLayout(verticalLayout_14);


        verticalLayout_11->addWidget(sslCertGroupBox);

        keyAndCertSettings->addWidget(pageEditSsl);

        verticalLayout_12->addWidget(keyAndCertSettings);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_12->addItem(verticalSpacer);

        tabWidget->addTab(advancedTab, QString());

        verticalLayout_13->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, realName);
        QWidget::setTabOrder(realName, nicknameList);
        QWidget::setTabOrder(nicknameList, addNick);
        QWidget::setTabOrder(addNick, deleteNick);
        QWidget::setTabOrder(deleteNick, renameNick);
        QWidget::setTabOrder(renameNick, nickUp);
        QWidget::setTabOrder(nickUp, nickDown);
        QWidget::setTabOrder(nickDown, awayNick);
        QWidget::setTabOrder(awayNick, awayReason);
        QWidget::setTabOrder(awayReason, detachAwayEnabled);
        QWidget::setTabOrder(detachAwayEnabled, detachAwayReason);
        QWidget::setTabOrder(detachAwayReason, autoAwayEnabled);
        QWidget::setTabOrder(autoAwayEnabled, autoAwayTime);
        QWidget::setTabOrder(autoAwayTime, autoAwayReasonEnabled);
        QWidget::setTabOrder(autoAwayReasonEnabled, autoAwayReason);
        QWidget::setTabOrder(autoAwayReason, ident);
        QWidget::setTabOrder(ident, kickReason);
        QWidget::setTabOrder(kickReason, partReason);
        QWidget::setTabOrder(partReason, quitReason);
        QWidget::setTabOrder(quitReason, continueUnsecured);
        QWidget::setTabOrder(continueUnsecured, clearOrLoadKeyButton);
        QWidget::setTabOrder(clearOrLoadKeyButton, clearOrLoadCertButton);

        retranslateUi(IdentityEditWidget);

        tabWidget->setCurrentIndex(0);
        keyAndCertSettings->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(IdentityEditWidget);
    } // setupUi

    void retranslateUi(QWidget *IdentityEditWidget)
    {
        IdentityEditWidget->setWindowTitle(QString());
        label->setText(QCoreApplication::translate("IdentityEditWidget", "Real Name:", nullptr));
#if QT_CONFIG(whatsthis)
        realName->setWhatsThis(QCoreApplication::translate("IdentityEditWidget", "The \"Real Name\" is shown in /whois.", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox->setTitle(QCoreApplication::translate("IdentityEditWidget", "Nicknames", nullptr));
#if QT_CONFIG(tooltip)
        addNick->setToolTip(QCoreApplication::translate("IdentityEditWidget", "Add Nickname", nullptr));
#endif // QT_CONFIG(tooltip)
        addNick->setText(QCoreApplication::translate("IdentityEditWidget", "&Add...", nullptr));
#if QT_CONFIG(tooltip)
        deleteNick->setToolTip(QCoreApplication::translate("IdentityEditWidget", "Remove Nickname", nullptr));
#endif // QT_CONFIG(tooltip)
        deleteNick->setText(QCoreApplication::translate("IdentityEditWidget", "Remove", nullptr));
#if QT_CONFIG(tooltip)
        renameNick->setToolTip(QCoreApplication::translate("IdentityEditWidget", "Rename Identity", nullptr));
#endif // QT_CONFIG(tooltip)
        renameNick->setText(QCoreApplication::translate("IdentityEditWidget", "Re&name...", nullptr));
#if QT_CONFIG(tooltip)
        nickUp->setToolTip(QCoreApplication::translate("IdentityEditWidget", "Move upwards in list", nullptr));
#endif // QT_CONFIG(tooltip)
        nickUp->setText(QCoreApplication::translate("IdentityEditWidget", "...", nullptr));
#if QT_CONFIG(tooltip)
        nickDown->setToolTip(QCoreApplication::translate("IdentityEditWidget", "Move downwards in list", nullptr));
#endif // QT_CONFIG(tooltip)
        nickDown->setText(QCoreApplication::translate("IdentityEditWidget", "...", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(generalTab), QCoreApplication::translate("IdentityEditWidget", "General", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("IdentityEditWidget", "Default Away Settings", nullptr));
#if QT_CONFIG(tooltip)
        awayNick->setToolTip(QCoreApplication::translate("IdentityEditWidget", "Nick to be used when being away", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        awayReason->setToolTip(QCoreApplication::translate("IdentityEditWidget", "Default away reason", nullptr));
#endif // QT_CONFIG(tooltip)
        awayNickLabel->setText(QCoreApplication::translate("IdentityEditWidget", "Away Nick:", nullptr));
        awayReasonLabel->setText(QCoreApplication::translate("IdentityEditWidget", "Away Reason:", nullptr));
#if QT_CONFIG(tooltip)
        detachAwayEnabled->setToolTip(QCoreApplication::translate("IdentityEditWidget", "Set away when all clients have detached from the core", nullptr));
#endif // QT_CONFIG(tooltip)
        detachAwayEnabled->setTitle(QCoreApplication::translate("IdentityEditWidget", "Away On Detach", nullptr));
        label_13->setText(QCoreApplication::translate("IdentityEditWidget", "Away Reason:", nullptr));
#if QT_CONFIG(tooltip)
        autoAwayEnabled->setToolTip(QCoreApplication::translate("IdentityEditWidget", "Not implemented yet", nullptr));
#endif // QT_CONFIG(tooltip)
        autoAwayEnabled->setTitle(QCoreApplication::translate("IdentityEditWidget", "Away On Idle", nullptr));
        autoAwayLabel_1->setText(QCoreApplication::translate("IdentityEditWidget", "Set away after", nullptr));
        autoAwayLabel_2->setText(QCoreApplication::translate("IdentityEditWidget", "minutes of being idle", nullptr));
        autoAwayReasonEnabled->setText(QCoreApplication::translate("IdentityEditWidget", "Away Reason:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(awayTab), QCoreApplication::translate("IdentityEditWidget", "A&way", nullptr));
        label_2->setText(QCoreApplication::translate("IdentityEditWidget", "Ident:", nullptr));
#if QT_CONFIG(whatsthis)
        ident->setWhatsThis(QCoreApplication::translate("IdentityEditWidget", "The \"ident\" is part of your hostmask and, together with your host, uniquely identifies you within the IRC network.", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox_3->setTitle(QCoreApplication::translate("IdentityEditWidget", "Messages", nullptr));
        label_3->setText(QCoreApplication::translate("IdentityEditWidget", "Part Reason:", nullptr));
        label_5->setText(QCoreApplication::translate("IdentityEditWidget", "Quit Reason:", nullptr));
        label_4->setText(QCoreApplication::translate("IdentityEditWidget", "Kick Reason:", nullptr));
        groupBox_6->setTitle(QString());
        label_8->setText(QCoreApplication::translate("IdentityEditWidget", "You need an SSL Capable Client to edit your Cores SSL Key and Certificate", nullptr));
        groupBox_5->setTitle(QString());
        label_7->setText(QCoreApplication::translate("IdentityEditWidget", "Warning: you are not connected with a secured connection to the Quassel Core!\n"
"Proceeding will cause an unencrypted transfer of your SSL Key and SSL Certificate!", nullptr));
        continueUnsecured->setText(QCoreApplication::translate("IdentityEditWidget", "Continue", nullptr));
        sslKeyGroupBox->setTitle(QCoreApplication::translate("IdentityEditWidget", "Use SSL Key", nullptr));
        label_6->setText(QCoreApplication::translate("IdentityEditWidget", "Key Type:", nullptr));
        keyTypeLabel->setText(QCoreApplication::translate("IdentityEditWidget", "No Key loaded", nullptr));
        clearOrLoadKeyButton->setText(QCoreApplication::translate("IdentityEditWidget", "Load", nullptr));
        sslCertGroupBox->setTitle(QCoreApplication::translate("IdentityEditWidget", "Use SSL Certificate", nullptr));
        label_9->setText(QCoreApplication::translate("IdentityEditWidget", "Organisation:", nullptr));
        certOrgLabel->setText(QCoreApplication::translate("IdentityEditWidget", "No Certificate loaded", nullptr));
        label_10->setText(QCoreApplication::translate("IdentityEditWidget", "CommonName:", nullptr));
        certCNameLabel->setText(QCoreApplication::translate("IdentityEditWidget", "No Certificate loaded", nullptr));
        clearOrLoadCertButton->setText(QCoreApplication::translate("IdentityEditWidget", "Load", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(advancedTab), QCoreApplication::translate("IdentityEditWidget", "Advanced", nullptr));
    } // retranslateUi

};

namespace Ui {
    class IdentityEditWidget: public Ui_IdentityEditWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_IDENTITYEDITWIDGET_H
