/********************************************************************************
** Form generated from reading UI file 'networkadddlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NETWORKADDDLG_H
#define UI_NETWORKADDDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_NetworkAddDlg
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *usePreset;
    QComboBox *presetList;
    QSpacerItem *horizontalSpacer;
    QRadioButton *useManual;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_3;
    QLineEdit *networkName;
    QLabel *label;
    QLineEdit *serverAddress;
    QLabel *label_2;
    QSpinBox *port;
    QLabel *label_4;
    QLineEdit *serverPassword;
    QCheckBox *useSSL;
    QCheckBox *sslVerify;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *NetworkAddDlg)
    {
        if (NetworkAddDlg->objectName().isEmpty())
            NetworkAddDlg->setObjectName(QString::fromUtf8("NetworkAddDlg"));
        NetworkAddDlg->resize(421, 307);
        verticalLayout_2 = new QVBoxLayout(NetworkAddDlg);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        usePreset = new QRadioButton(NetworkAddDlg);
        usePreset->setObjectName(QString::fromUtf8("usePreset"));
        usePreset->setChecked(true);

        horizontalLayout_2->addWidget(usePreset);

        presetList = new QComboBox(NetworkAddDlg);
        presetList->setObjectName(QString::fromUtf8("presetList"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(presetList->sizePolicy().hasHeightForWidth());
        presetList->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(presetList);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout_2);

        useManual = new QRadioButton(NetworkAddDlg);
        useManual->setObjectName(QString::fromUtf8("useManual"));

        verticalLayout_2->addWidget(useManual);

        groupBox = new QGroupBox(NetworkAddDlg);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        groupBox->setEnabled(false);
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_3 = new QLabel(groupBox);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        networkName = new QLineEdit(groupBox);
        networkName->setObjectName(QString::fromUtf8("networkName"));

        gridLayout->addWidget(networkName, 0, 1, 1, 3);

        label = new QLabel(groupBox);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 1, 0, 1, 1);

        serverAddress = new QLineEdit(groupBox);
        serverAddress->setObjectName(QString::fromUtf8("serverAddress"));

        gridLayout->addWidget(serverAddress, 1, 1, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 1, 2, 1, 1);

        port = new QSpinBox(groupBox);
        port->setObjectName(QString::fromUtf8("port"));
        port->setMinimum(0);
        port->setMaximum(65535);
        port->setValue(6667);

        gridLayout->addWidget(port, 1, 3, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        serverPassword = new QLineEdit(groupBox);
        serverPassword->setObjectName(QString::fromUtf8("serverPassword"));
        serverPassword->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(serverPassword, 2, 1, 1, 3);


        verticalLayout->addLayout(gridLayout);

        useSSL = new QCheckBox(groupBox);
        useSSL->setObjectName(QString::fromUtf8("useSSL"));

        verticalLayout->addWidget(useSSL);

        sslVerify = new QCheckBox(groupBox);
        sslVerify->setObjectName(QString::fromUtf8("sslVerify"));
        sslVerify->setEnabled(false);
        sslVerify->setChecked(true);

        verticalLayout->addWidget(sslVerify);


        verticalLayout_2->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 31, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(NetworkAddDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);

        QWidget::setTabOrder(usePreset, presetList);
        QWidget::setTabOrder(presetList, useManual);
        QWidget::setTabOrder(useManual, networkName);
        QWidget::setTabOrder(networkName, serverAddress);
        QWidget::setTabOrder(serverAddress, port);
        QWidget::setTabOrder(port, serverPassword);
        QWidget::setTabOrder(serverPassword, useSSL);
        QWidget::setTabOrder(useSSL, sslVerify);
        QWidget::setTabOrder(sslVerify, buttonBox);

        retranslateUi(NetworkAddDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), NetworkAddDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), NetworkAddDlg, SLOT(reject()));
        QObject::connect(usePreset, SIGNAL(toggled(bool)), presetList, SLOT(setEnabled(bool)));
        QObject::connect(useManual, SIGNAL(toggled(bool)), groupBox, SLOT(setEnabled(bool)));
        QObject::connect(useManual, SIGNAL(clicked()), networkName, SLOT(setFocus()));

        QMetaObject::connectSlotsByName(NetworkAddDlg);
    } // setupUi

    void retranslateUi(QDialog *NetworkAddDlg)
    {
        NetworkAddDlg->setWindowTitle(QCoreApplication::translate("NetworkAddDlg", "Add Network", nullptr));
        usePreset->setText(QCoreApplication::translate("NetworkAddDlg", "Use preset:", nullptr));
        useManual->setText(QCoreApplication::translate("NetworkAddDlg", "Manually specify network settings", nullptr));
        groupBox->setTitle(QCoreApplication::translate("NetworkAddDlg", "Manual Settings", nullptr));
        label_3->setText(QCoreApplication::translate("NetworkAddDlg", "Network name:", nullptr));
        label->setText(QCoreApplication::translate("NetworkAddDlg", "Server address:", nullptr));
        label_2->setText(QCoreApplication::translate("NetworkAddDlg", "Port:", nullptr));
        label_4->setText(QCoreApplication::translate("NetworkAddDlg", "Server password:", nullptr));
#if QT_CONFIG(tooltip)
        useSSL->setToolTip(QCoreApplication::translate("NetworkAddDlg", "Try to use an encrypted connection (e.g. SSL/TLS)", nullptr));
#endif // QT_CONFIG(tooltip)
        useSSL->setText(QCoreApplication::translate("NetworkAddDlg", "Use encrypted connection", nullptr));
#if QT_CONFIG(tooltip)
        sslVerify->setToolTip(QCoreApplication::translate("NetworkAddDlg", "<p>Verify the encrypted connection provides a valid certificate, increasing security.<br/>Uncheck if the IRC server uses a self-signed or invalid certificate.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        sslVerify->setText(QCoreApplication::translate("NetworkAddDlg", "Verify connection security", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NetworkAddDlg: public Ui_NetworkAddDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NETWORKADDDLG_H
