/********************************************************************************
** Form generated from reading UI file 'inputwidgetsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INPUTWIDGETSETTINGSPAGE_H
#define UI_INPUTWIDGETSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "fontselector.h"

QT_BEGIN_NAMESPACE

class Ui_InputWidgetSettingsPage
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QCheckBox *customFont;
    FontSelector *inputLineFont;
    QCheckBox *enablePerBufferHistory;
    QCheckBox *showNickSelector;
    QCheckBox *showStyleButtons;
    QCheckBox *enableEmacsMode;
    QCheckBox *enableLineWrapMode;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    QSpinBox *maxNumLines;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *enableScrollBars;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *completionSuffixDesc;
    QLineEdit *completionSuffix;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *addSpaceMidSentence;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *InputWidgetSettingsPage)
    {
        if (InputWidgetSettingsPage->objectName().isEmpty())
            InputWidgetSettingsPage->setObjectName(QString::fromUtf8("InputWidgetSettingsPage"));
        InputWidgetSettingsPage->resize(512, 514);
        verticalLayout_2 = new QVBoxLayout(InputWidgetSettingsPage);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        customFont = new QCheckBox(InputWidgetSettingsPage);
        customFont->setObjectName(QString::fromUtf8("customFont"));
        customFont->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Fonts/UseCustomInputWidgetFont")));
        customFont->setProperty("defaultValue", QVariant(false));

        horizontalLayout->addWidget(customFont);

        inputLineFont = new FontSelector(InputWidgetSettingsPage);
        inputLineFont->setObjectName(QString::fromUtf8("inputLineFont"));
        inputLineFont->setEnabled(false);
        inputLineFont->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Fonts/InputWidget")));
        QFont font;
        inputLineFont->setProperty("defaultValue", QVariant(font));

        horizontalLayout->addWidget(inputLineFont);


        verticalLayout_2->addLayout(horizontalLayout);

        enablePerBufferHistory = new QCheckBox(InputWidgetSettingsPage);
        enablePerBufferHistory->setObjectName(QString::fromUtf8("enablePerBufferHistory"));
        enablePerBufferHistory->setChecked(false);
        enablePerBufferHistory->setProperty("settingsKey", QVariant(QString::fromUtf8("EnablePerChatHistory")));
        enablePerBufferHistory->setProperty("defaultValue", QVariant(true));

        verticalLayout_2->addWidget(enablePerBufferHistory);

        showNickSelector = new QCheckBox(InputWidgetSettingsPage);
        showNickSelector->setObjectName(QString::fromUtf8("showNickSelector"));
        showNickSelector->setChecked(true);
        showNickSelector->setProperty("settingsKey", QVariant(QString::fromUtf8("ShowNickSelector")));
        showNickSelector->setProperty("defaultValue", QVariant(true));

        verticalLayout_2->addWidget(showNickSelector);

        showStyleButtons = new QCheckBox(InputWidgetSettingsPage);
        showStyleButtons->setObjectName(QString::fromUtf8("showStyleButtons"));
        showStyleButtons->setChecked(true);
        showStyleButtons->setProperty("settingsKey", QVariant(QString::fromUtf8("ShowStyleButtons")));
        showStyleButtons->setProperty("defaultValue", QVariant(true));

        verticalLayout_2->addWidget(showStyleButtons);

        enableEmacsMode = new QCheckBox(InputWidgetSettingsPage);
        enableEmacsMode->setObjectName(QString::fromUtf8("enableEmacsMode"));
        enableEmacsMode->setProperty("settingsKey", QVariant(QString::fromUtf8("EnableEmacsMode")));
        enableEmacsMode->setProperty("defaultValue", QVariant(false));

        verticalLayout_2->addWidget(enableEmacsMode);

        enableLineWrapMode = new QCheckBox(InputWidgetSettingsPage);
        enableLineWrapMode->setObjectName(QString::fromUtf8("enableLineWrapMode"));
        enableLineWrapMode->setProperty("settingsKey", QVariant(QString::fromUtf8("EnableLineWrap")));
        enableLineWrapMode->setProperty("defaultValue", QVariant(true));

        verticalLayout_2->addWidget(enableLineWrapMode);

        groupBox = new QGroupBox(InputWidgetSettingsPage);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        groupBox->setCheckable(true);
        groupBox->setProperty("settingsKey", QVariant(QString::fromUtf8("EnableMultiLine")));
        groupBox->setProperty("defaultValue", QVariant(true));
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label = new QLabel(groupBox);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout_2->addWidget(label);

        maxNumLines = new QSpinBox(groupBox);
        maxNumLines->setObjectName(QString::fromUtf8("maxNumLines"));
        maxNumLines->setMinimum(1);
        maxNumLines->setMaximum(19);
        maxNumLines->setValue(5);
        maxNumLines->setProperty("settingsKey", QVariant(QString::fromUtf8("MaxNumLines")));
        maxNumLines->setProperty("defaultValue", QVariant(5));

        horizontalLayout_2->addWidget(maxNumLines);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout_2->addWidget(label_2);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_2);

        enableScrollBars = new QCheckBox(groupBox);
        enableScrollBars->setObjectName(QString::fromUtf8("enableScrollBars"));
        enableScrollBars->setChecked(true);
        enableScrollBars->setProperty("settingsKey", QVariant(QString::fromUtf8("EnableScrollBars")));
        enableScrollBars->setProperty("defaultValue", QVariant(true));

        verticalLayout->addWidget(enableScrollBars);


        verticalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(InputWidgetSettingsPage);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        completionSuffixDesc = new QLabel(groupBox_2);
        completionSuffixDesc->setObjectName(QString::fromUtf8("completionSuffixDesc"));

        horizontalLayout_3->addWidget(completionSuffixDesc);

        completionSuffix = new QLineEdit(groupBox_2);
        completionSuffix->setObjectName(QString::fromUtf8("completionSuffix"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(completionSuffix->sizePolicy().hasHeightForWidth());
        completionSuffix->setSizePolicy(sizePolicy);
        completionSuffix->setProperty("settingsKey", QVariant(QString::fromUtf8("/TabCompletion/CompletionSuffix")));

        horizontalLayout_3->addWidget(completionSuffix);

        horizontalSpacer = new QSpacerItem(157, 27, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);


        verticalLayout_3->addLayout(horizontalLayout_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        addSpaceMidSentence = new QCheckBox(groupBox_2);
        addSpaceMidSentence->setObjectName(QString::fromUtf8("addSpaceMidSentence"));
        addSpaceMidSentence->setChecked(false);
        addSpaceMidSentence->setProperty("settingsKey", QVariant(QString::fromUtf8("/TabCompletion/AddSpaceMidSentence")));
        addSpaceMidSentence->setProperty("defaultValue", QVariant(false));

        horizontalLayout_4->addWidget(addSpaceMidSentence);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);


        verticalLayout_3->addLayout(horizontalLayout_4);


        verticalLayout_2->addWidget(groupBox_2);

        verticalSpacer = new QSpacerItem(20, 233, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        QWidget::setTabOrder(customFont, showNickSelector);
        QWidget::setTabOrder(showNickSelector, groupBox);
        QWidget::setTabOrder(groupBox, maxNumLines);
        QWidget::setTabOrder(maxNumLines, enableScrollBars);
        QWidget::setTabOrder(enableScrollBars, completionSuffix);

        retranslateUi(InputWidgetSettingsPage);
        QObject::connect(customFont, SIGNAL(toggled(bool)), inputLineFont, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(InputWidgetSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *InputWidgetSettingsPage)
    {
        InputWidgetSettingsPage->setWindowTitle(QCoreApplication::translate("InputWidgetSettingsPage", "Form", nullptr));
        customFont->setText(QCoreApplication::translate("InputWidgetSettingsPage", "Custom font:", nullptr));
        enablePerBufferHistory->setText(QCoreApplication::translate("InputWidgetSettingsPage", "Enable per chat history", nullptr));
        showNickSelector->setText(QCoreApplication::translate("InputWidgetSettingsPage", "Show nick selector", nullptr));
        showStyleButtons->setText(QCoreApplication::translate("InputWidgetSettingsPage", "Show style buttons", nullptr));
#if QT_CONFIG(tooltip)
        enableEmacsMode->setToolTip(QCoreApplication::translate("InputWidgetSettingsPage", "Enables (limited) Emacs key bindings in the input field.", nullptr));
#endif // QT_CONFIG(tooltip)
        enableEmacsMode->setText(QCoreApplication::translate("InputWidgetSettingsPage", "Emacs key bindings", nullptr));
#if QT_CONFIG(tooltip)
        enableLineWrapMode->setToolTip(QCoreApplication::translate("InputWidgetSettingsPage", "Enables line wrapping for input.", nullptr));
#endif // QT_CONFIG(tooltip)
        enableLineWrapMode->setText(QCoreApplication::translate("InputWidgetSettingsPage", "Line wrapping", nullptr));
        groupBox->setTitle(QCoreApplication::translate("InputWidgetSettingsPage", "&Multi-Line Editing", nullptr));
        label->setText(QCoreApplication::translate("InputWidgetSettingsPage", "Show at most", nullptr));
        label_2->setText(QCoreApplication::translate("InputWidgetSettingsPage", "lines", nullptr));
        enableScrollBars->setText(QCoreApplication::translate("InputWidgetSettingsPage", "Enable scrollbars", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("InputWidgetSettingsPage", "Tab Completion", nullptr));
        completionSuffixDesc->setText(QCoreApplication::translate("InputWidgetSettingsPage", "Completion suffix:", nullptr));
        completionSuffix->setProperty("defaultValue", QVariant(QCoreApplication::translate("InputWidgetSettingsPage", ": ", nullptr)));
        addSpaceMidSentence->setText(QCoreApplication::translate("InputWidgetSettingsPage", "Add space after nick when completing mid-sentence", nullptr));
    } // retranslateUi

};

namespace Ui {
    class InputWidgetSettingsPage: public Ui_InputWidgetSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INPUTWIDGETSETTINGSPAGE_H
