/****************************************************************************
** Meta object code from reading C++ file 'bufferviewmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/bufferviewmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bufferviewmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BufferViewManager_t {
    QByteArrayData data[17];
    char stringdata0[314];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferViewManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferViewManager_t qt_meta_stringdata_BufferViewManager = {
    {
QT_MOC_LITERAL(0, 0, 17), // "BufferViewManager"
QT_MOC_LITERAL(1, 18, 21), // "bufferViewConfigAdded"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 18), // "bufferViewConfigId"
QT_MOC_LITERAL(4, 60, 23), // "bufferViewConfigDeleted"
QT_MOC_LITERAL(5, 84, 17), // "initBufferViewIds"
QT_MOC_LITERAL(6, 102, 20), // "initSetBufferViewIds"
QT_MOC_LITERAL(7, 123, 13), // "bufferViewIds"
QT_MOC_LITERAL(8, 137, 19), // "addBufferViewConfig"
QT_MOC_LITERAL(9, 157, 22), // "deleteBufferViewConfig"
QT_MOC_LITERAL(10, 180, 23), // "requestCreateBufferView"
QT_MOC_LITERAL(11, 204, 10), // "properties"
QT_MOC_LITERAL(12, 215, 24), // "requestCreateBufferViews"
QT_MOC_LITERAL(13, 240, 23), // "requestDeleteBufferView"
QT_MOC_LITERAL(14, 264, 12), // "bufferViewId"
QT_MOC_LITERAL(15, 277, 24), // "requestDeleteBufferViews"
QT_MOC_LITERAL(16, 302, 11) // "bufferViews"

    },
    "BufferViewManager\0bufferViewConfigAdded\0"
    "\0bufferViewConfigId\0bufferViewConfigDeleted\0"
    "initBufferViewIds\0initSetBufferViewIds\0"
    "bufferViewIds\0addBufferViewConfig\0"
    "deleteBufferViewConfig\0requestCreateBufferView\0"
    "properties\0requestCreateBufferViews\0"
    "requestDeleteBufferView\0bufferViewId\0"
    "requestDeleteBufferViews\0bufferViews"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferViewManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       4,    1,   67,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   70,    2, 0x0a /* Public */,
       6,    1,   71,    2, 0x0a /* Public */,
       8,    1,   74,    2, 0x0a /* Public */,
       9,    1,   77,    2, 0x0a /* Public */,
      10,    1,   80,    2, 0x0a /* Public */,
      12,    1,   83,    2, 0x0a /* Public */,
      13,    1,   86,    2, 0x0a /* Public */,
      15,    1,   89,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,

 // slots: parameters
    QMetaType::QVariantList,
    QMetaType::Void, QMetaType::QVariantList,    7,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::QVariantMap,   11,
    QMetaType::Void, QMetaType::QVariantList,   11,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::QVariantList,   16,

       0        // eod
};

void BufferViewManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferViewManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->bufferViewConfigAdded((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->bufferViewConfigDeleted((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: { QVariantList _r = _t->initBufferViewIds();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->initSetBufferViewIds((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 4: _t->addBufferViewConfig((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->deleteBufferViewConfig((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->requestCreateBufferView((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 7: _t->requestCreateBufferViews((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 8: _t->requestDeleteBufferView((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->requestDeleteBufferViews((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BufferViewManager::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferViewManager::bufferViewConfigAdded)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (BufferViewManager::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferViewManager::bufferViewConfigDeleted)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BufferViewManager::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_BufferViewManager.data,
    qt_meta_data_BufferViewManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferViewManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferViewManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferViewManager.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int BufferViewManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void BufferViewManager::bufferViewConfigAdded(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void BufferViewManager::bufferViewConfigDeleted(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
