/****************************************************************************
** Meta object code from reading C++ file 'flatproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/uisupport/flatproxymodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'flatproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_FlatProxyModel_t {
    QByteArrayData data[22];
    char stringdata0[344];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FlatProxyModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FlatProxyModel_t qt_meta_stringdata_FlatProxyModel = {
    {
QT_MOC_LITERAL(0, 0, 14), // "FlatProxyModel"
QT_MOC_LITERAL(1, 15, 8), // "linkTest"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 16), // "completenessTest"
QT_MOC_LITERAL(4, 42, 27), // "on_columnsAboutToBeInserted"
QT_MOC_LITERAL(5, 70, 11), // "QModelIndex"
QT_MOC_LITERAL(6, 82, 6), // "parent"
QT_MOC_LITERAL(7, 89, 5), // "start"
QT_MOC_LITERAL(8, 95, 3), // "end"
QT_MOC_LITERAL(9, 99, 26), // "on_columnsAboutToBeRemoved"
QT_MOC_LITERAL(10, 126, 18), // "on_columnsInserted"
QT_MOC_LITERAL(11, 145, 17), // "on_columnsRemoved"
QT_MOC_LITERAL(12, 163, 14), // "on_dataChanged"
QT_MOC_LITERAL(13, 178, 7), // "topLeft"
QT_MOC_LITERAL(14, 186, 11), // "bottomRight"
QT_MOC_LITERAL(15, 198, 25), // "on_layoutAboutToBeChanged"
QT_MOC_LITERAL(16, 224, 16), // "on_layoutChanged"
QT_MOC_LITERAL(17, 241, 22), // "on_modelAboutToBeReset"
QT_MOC_LITERAL(18, 264, 24), // "on_rowsAboutToBeInserted"
QT_MOC_LITERAL(19, 289, 23), // "on_rowsAboutToBeRemoved"
QT_MOC_LITERAL(20, 313, 15), // "on_rowsInserted"
QT_MOC_LITERAL(21, 329, 14) // "on_rowsRemoved"

    },
    "FlatProxyModel\0linkTest\0\0completenessTest\0"
    "on_columnsAboutToBeInserted\0QModelIndex\0"
    "parent\0start\0end\0on_columnsAboutToBeRemoved\0"
    "on_columnsInserted\0on_columnsRemoved\0"
    "on_dataChanged\0topLeft\0bottomRight\0"
    "on_layoutAboutToBeChanged\0on_layoutChanged\0"
    "on_modelAboutToBeReset\0on_rowsAboutToBeInserted\0"
    "on_rowsAboutToBeRemoved\0on_rowsInserted\0"
    "on_rowsRemoved"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FlatProxyModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   84,    2, 0x0a /* Public */,
       3,    0,   85,    2, 0x0a /* Public */,
       4,    3,   86,    2, 0x08 /* Private */,
       9,    3,   93,    2, 0x08 /* Private */,
      10,    3,  100,    2, 0x08 /* Private */,
      11,    3,  107,    2, 0x08 /* Private */,
      12,    2,  114,    2, 0x08 /* Private */,
      15,    0,  119,    2, 0x08 /* Private */,
      16,    0,  120,    2, 0x08 /* Private */,
      17,    0,  121,    2, 0x08 /* Private */,
      18,    3,  122,    2, 0x08 /* Private */,
      19,    3,  129,    2, 0x08 /* Private */,
      20,    3,  136,    2, 0x08 /* Private */,
      21,    3,  143,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    6,    7,    8,
    QMetaType::Void, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    6,    7,    8,
    QMetaType::Void, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    6,    7,    8,
    QMetaType::Void, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    6,    7,    8,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 5,   13,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    6,    7,    8,
    QMetaType::Void, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    6,    7,    8,
    QMetaType::Void, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    6,    7,    8,
    QMetaType::Void, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    6,    7,    8,

       0        // eod
};

void FlatProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FlatProxyModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->linkTest(); break;
        case 1: _t->completenessTest(); break;
        case 2: _t->on_columnsAboutToBeInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 3: _t->on_columnsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 4: _t->on_columnsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 5: _t->on_columnsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 6: _t->on_dataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 7: _t->on_layoutAboutToBeChanged(); break;
        case 8: _t->on_layoutChanged(); break;
        case 9: _t->on_modelAboutToBeReset(); break;
        case 10: _t->on_rowsAboutToBeInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 11: _t->on_rowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 12: _t->on_rowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 13: _t->on_rowsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject FlatProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractProxyModel::staticMetaObject>(),
    qt_meta_stringdata_FlatProxyModel.data,
    qt_meta_data_FlatProxyModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *FlatProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FlatProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FlatProxyModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractProxyModel::qt_metacast(_clname);
}

int FlatProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
