/****************************************************************************
** Meta object code from reading C++ file 'networkconfig.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/networkconfig.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'networkconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_NetworkConfig_t {
    QByteArrayData data[34];
    char stringdata0[587];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NetworkConfig_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NetworkConfig_t qt_meta_stringdata_NetworkConfig = {
    {
QT_MOC_LITERAL(0, 0, 13), // "NetworkConfig"
QT_MOC_LITERAL(1, 14, 21), // "pingTimeoutEnabledSet"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 15), // "pingIntervalSet"
QT_MOC_LITERAL(4, 53, 17), // "autoWhoEnabledSet"
QT_MOC_LITERAL(5, 71, 18), // "autoWhoIntervalSet"
QT_MOC_LITERAL(6, 90, 15), // "autoWhoDelaySet"
QT_MOC_LITERAL(7, 106, 15), // "standardCtcpSet"
QT_MOC_LITERAL(8, 122, 18), // "pingTimeoutEnabled"
QT_MOC_LITERAL(9, 141, 21), // "setPingTimeoutEnabled"
QT_MOC_LITERAL(10, 163, 28), // "requestSetPingTimeoutEnabled"
QT_MOC_LITERAL(11, 192, 1), // "b"
QT_MOC_LITERAL(12, 194, 12), // "pingInterval"
QT_MOC_LITERAL(13, 207, 15), // "setPingInterval"
QT_MOC_LITERAL(14, 223, 22), // "requestSetPingInterval"
QT_MOC_LITERAL(15, 246, 1), // "i"
QT_MOC_LITERAL(16, 248, 12), // "maxPingCount"
QT_MOC_LITERAL(17, 261, 15), // "setMaxPingCount"
QT_MOC_LITERAL(18, 277, 22), // "requestSetMaxPingCount"
QT_MOC_LITERAL(19, 300, 14), // "autoWhoEnabled"
QT_MOC_LITERAL(20, 315, 17), // "setAutoWhoEnabled"
QT_MOC_LITERAL(21, 333, 24), // "requestSetAutoWhoEnabled"
QT_MOC_LITERAL(22, 358, 15), // "autoWhoInterval"
QT_MOC_LITERAL(23, 374, 18), // "setAutoWhoInterval"
QT_MOC_LITERAL(24, 393, 25), // "requestSetAutoWhoInterval"
QT_MOC_LITERAL(25, 419, 16), // "autoWhoNickLimit"
QT_MOC_LITERAL(26, 436, 19), // "setAutoWhoNickLimit"
QT_MOC_LITERAL(27, 456, 26), // "requestSetAutoWhoNickLimit"
QT_MOC_LITERAL(28, 483, 12), // "autoWhoDelay"
QT_MOC_LITERAL(29, 496, 15), // "setAutoWhoDelay"
QT_MOC_LITERAL(30, 512, 22), // "requestSetAutoWhoDelay"
QT_MOC_LITERAL(31, 535, 12), // "standardCtcp"
QT_MOC_LITERAL(32, 548, 15), // "setStandardCtcp"
QT_MOC_LITERAL(33, 564, 22) // "requestSetStandardCtcp"

    },
    "NetworkConfig\0pingTimeoutEnabledSet\0"
    "\0pingIntervalSet\0autoWhoEnabledSet\0"
    "autoWhoIntervalSet\0autoWhoDelaySet\0"
    "standardCtcpSet\0pingTimeoutEnabled\0"
    "setPingTimeoutEnabled\0"
    "requestSetPingTimeoutEnabled\0b\0"
    "pingInterval\0setPingInterval\0"
    "requestSetPingInterval\0i\0maxPingCount\0"
    "setMaxPingCount\0requestSetMaxPingCount\0"
    "autoWhoEnabled\0setAutoWhoEnabled\0"
    "requestSetAutoWhoEnabled\0autoWhoInterval\0"
    "setAutoWhoInterval\0requestSetAutoWhoInterval\0"
    "autoWhoNickLimit\0setAutoWhoNickLimit\0"
    "requestSetAutoWhoNickLimit\0autoWhoDelay\0"
    "setAutoWhoDelay\0requestSetAutoWhoDelay\0"
    "standardCtcp\0setStandardCtcp\0"
    "requestSetStandardCtcp"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NetworkConfig[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      30,   14, // methods
       8,  238, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  164,    2, 0x06 /* Public */,
       3,    1,  167,    2, 0x06 /* Public */,
       4,    1,  170,    2, 0x06 /* Public */,
       5,    1,  173,    2, 0x06 /* Public */,
       6,    1,  176,    2, 0x06 /* Public */,
       7,    1,  179,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,  182,    2, 0x0a /* Public */,
       9,    1,  183,    2, 0x0a /* Public */,
      10,    1,  186,    2, 0x0a /* Public */,
      12,    0,  189,    2, 0x0a /* Public */,
      13,    1,  190,    2, 0x0a /* Public */,
      14,    1,  193,    2, 0x0a /* Public */,
      16,    0,  196,    2, 0x0a /* Public */,
      17,    1,  197,    2, 0x0a /* Public */,
      18,    1,  200,    2, 0x0a /* Public */,
      19,    0,  203,    2, 0x0a /* Public */,
      20,    1,  204,    2, 0x0a /* Public */,
      21,    1,  207,    2, 0x0a /* Public */,
      22,    0,  210,    2, 0x0a /* Public */,
      23,    1,  211,    2, 0x0a /* Public */,
      24,    1,  214,    2, 0x0a /* Public */,
      25,    0,  217,    2, 0x0a /* Public */,
      26,    1,  218,    2, 0x0a /* Public */,
      27,    1,  221,    2, 0x0a /* Public */,
      28,    0,  224,    2, 0x0a /* Public */,
      29,    1,  225,    2, 0x0a /* Public */,
      30,    1,  228,    2, 0x0a /* Public */,
      31,    0,  231,    2, 0x0a /* Public */,
      32,    1,  232,    2, 0x0a /* Public */,
      33,    1,  235,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   11,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   11,

 // properties: name, type, flags
       8, QMetaType::Bool, 0x00095103,
      12, QMetaType::Int, 0x00095103,
      16, QMetaType::Int, 0x00095103,
      19, QMetaType::Bool, 0x00095103,
      22, QMetaType::Int, 0x00095103,
      25, QMetaType::Int, 0x00095103,
      28, QMetaType::Int, 0x00095103,
      31, QMetaType::Bool, 0x00095103,

       0        // eod
};

void NetworkConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<NetworkConfig *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->pingTimeoutEnabledSet((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->pingIntervalSet((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->autoWhoEnabledSet((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->autoWhoIntervalSet((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->autoWhoDelaySet((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->standardCtcpSet((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: { bool _r = _t->pingTimeoutEnabled();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->setPingTimeoutEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->requestSetPingTimeoutEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: { int _r = _t->pingInterval();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setPingInterval((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->requestSetPingInterval((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: { int _r = _t->maxPingCount();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->setMaxPingCount((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->requestSetMaxPingCount((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: { bool _r = _t->autoWhoEnabled();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->setAutoWhoEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->requestSetAutoWhoEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: { int _r = _t->autoWhoInterval();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->setAutoWhoInterval((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->requestSetAutoWhoInterval((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: { int _r = _t->autoWhoNickLimit();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->setAutoWhoNickLimit((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->requestSetAutoWhoNickLimit((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: { int _r = _t->autoWhoDelay();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->setAutoWhoDelay((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 26: _t->requestSetAutoWhoDelay((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 27: { bool _r = _t->standardCtcp();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->setStandardCtcp((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 29: _t->requestSetStandardCtcp((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (NetworkConfig::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkConfig::pingTimeoutEnabledSet)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (NetworkConfig::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkConfig::pingIntervalSet)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (NetworkConfig::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkConfig::autoWhoEnabledSet)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (NetworkConfig::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkConfig::autoWhoIntervalSet)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (NetworkConfig::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkConfig::autoWhoDelaySet)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (NetworkConfig::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkConfig::standardCtcpSet)) {
                *result = 5;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<NetworkConfig *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->pingTimeoutEnabled(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->pingInterval(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->maxPingCount(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->autoWhoEnabled(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->autoWhoInterval(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->autoWhoNickLimit(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->autoWhoDelay(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->standardCtcp(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<NetworkConfig *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPingTimeoutEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setPingInterval(*reinterpret_cast< int*>(_v)); break;
        case 2: _t->setMaxPingCount(*reinterpret_cast< int*>(_v)); break;
        case 3: _t->setAutoWhoEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setAutoWhoInterval(*reinterpret_cast< int*>(_v)); break;
        case 5: _t->setAutoWhoNickLimit(*reinterpret_cast< int*>(_v)); break;
        case 6: _t->setAutoWhoDelay(*reinterpret_cast< int*>(_v)); break;
        case 7: _t->setStandardCtcp(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject NetworkConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_NetworkConfig.data,
    qt_meta_data_NetworkConfig,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *NetworkConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetworkConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NetworkConfig.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int NetworkConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 30;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void NetworkConfig::pingTimeoutEnabledSet(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void NetworkConfig::pingIntervalSet(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void NetworkConfig::autoWhoEnabledSet(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void NetworkConfig::autoWhoIntervalSet(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void NetworkConfig::autoWhoDelaySet(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void NetworkConfig::standardCtcpSet(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
