/********************************************************************************
** Form generated from reading UI file 'coreconnectauthdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CORECONNECTAUTHDLG_H
#define UI_CORECONNECTAUTHDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_CoreConnectAuthDlg
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QGridLayout *gridLayout;
    QLineEdit *user;
    QLabel *label_3;
    QLineEdit *password;
    QLabel *label_2;
    QCheckBox *rememberPasswd;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CoreConnectAuthDlg)
    {
        if (CoreConnectAuthDlg->objectName().isEmpty())
            CoreConnectAuthDlg->setObjectName(QString::fromUtf8("CoreConnectAuthDlg"));
        CoreConnectAuthDlg->resize(395, 183);
        verticalLayout = new QVBoxLayout(CoreConnectAuthDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        label = new QLabel(CoreConnectAuthDlg);
        label->setObjectName(QString::fromUtf8("label"));
        label->setWordWrap(false);

        verticalLayout->addWidget(label);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        user = new QLineEdit(CoreConnectAuthDlg);
        user->setObjectName(QString::fromUtf8("user"));

        gridLayout->addWidget(user, 0, 1, 1, 1);

        label_3 = new QLabel(CoreConnectAuthDlg);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        password = new QLineEdit(CoreConnectAuthDlg);
        password->setObjectName(QString::fromUtf8("password"));
        password->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(password, 1, 1, 1, 1);

        label_2 = new QLabel(CoreConnectAuthDlg);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 0, 0, 1, 1);


        verticalLayout->addLayout(gridLayout);

        rememberPasswd = new QCheckBox(CoreConnectAuthDlg);
        rememberPasswd->setObjectName(QString::fromUtf8("rememberPasswd"));

        verticalLayout->addWidget(rememberPasswd);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(CoreConnectAuthDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(user, password);
        QWidget::setTabOrder(password, rememberPasswd);
        QWidget::setTabOrder(rememberPasswd, buttonBox);

        retranslateUi(CoreConnectAuthDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), CoreConnectAuthDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), CoreConnectAuthDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(CoreConnectAuthDlg);
    } // setupUi

    void retranslateUi(QDialog *CoreConnectAuthDlg)
    {
        CoreConnectAuthDlg->setWindowTitle(QCoreApplication::translate("CoreConnectAuthDlg", "Authentication Required", nullptr));
        label->setText(QCoreApplication::translate("CoreConnectAuthDlg", "Please enter your account data:", nullptr));
        label_3->setText(QCoreApplication::translate("CoreConnectAuthDlg", "Password:", nullptr));
        label_2->setText(QCoreApplication::translate("CoreConnectAuthDlg", "Username:", nullptr));
        rememberPasswd->setText(QCoreApplication::translate("CoreConnectAuthDlg", "Remember password", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CoreConnectAuthDlg: public Ui_CoreConnectAuthDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CORECONNECTAUTHDLG_H
