/****************************************************************************
** Meta object code from reading C++ file 'corenetwork.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/corenetwork.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'corenetwork.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreNetwork_t {
    QByteArrayData data[131];
    char stringdata0[1781];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreNetwork_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreNetwork_t qt_meta_stringdata_CoreNetwork = {
    {
QT_MOC_LITERAL(0, 0, 11), // "CoreNetwork"
QT_MOC_LITERAL(1, 12, 16), // "recvRawServerMsg"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 16), // "displayStatusMsg"
QT_MOC_LITERAL(4, 47, 10), // "displayMsg"
QT_MOC_LITERAL(5, 58, 10), // "RawMessage"
QT_MOC_LITERAL(6, 69, 3), // "msg"
QT_MOC_LITERAL(7, 73, 12), // "disconnected"
QT_MOC_LITERAL(8, 86, 9), // "NetworkId"
QT_MOC_LITERAL(9, 96, 9), // "networkId"
QT_MOC_LITERAL(10, 106, 15), // "connectionError"
QT_MOC_LITERAL(11, 122, 8), // "errorMsg"
QT_MOC_LITERAL(12, 131, 13), // "quitRequested"
QT_MOC_LITERAL(13, 145, 9), // "sslErrors"
QT_MOC_LITERAL(14, 155, 9), // "errorData"
QT_MOC_LITERAL(15, 165, 8), // "newEvent"
QT_MOC_LITERAL(16, 174, 6), // "Event*"
QT_MOC_LITERAL(17, 181, 5), // "event"
QT_MOC_LITERAL(18, 187, 17), // "socketInitialized"
QT_MOC_LITERAL(19, 205, 19), // "const CoreIdentity*"
QT_MOC_LITERAL(20, 225, 8), // "identity"
QT_MOC_LITERAL(21, 234, 12), // "QHostAddress"
QT_MOC_LITERAL(22, 247, 12), // "localAddress"
QT_MOC_LITERAL(23, 260, 9), // "localPort"
QT_MOC_LITERAL(24, 270, 11), // "peerAddress"
QT_MOC_LITERAL(25, 282, 8), // "peerPort"
QT_MOC_LITERAL(26, 291, 8), // "socketId"
QT_MOC_LITERAL(27, 300, 18), // "socketDisconnected"
QT_MOC_LITERAL(28, 319, 9), // "setMyNick"
QT_MOC_LITERAL(29, 329, 6), // "mynick"
QT_MOC_LITERAL(30, 336, 14), // "requestConnect"
QT_MOC_LITERAL(31, 351, 17), // "requestDisconnect"
QT_MOC_LITERAL(32, 369, 21), // "requestSetNetworkInfo"
QT_MOC_LITERAL(33, 391, 11), // "NetworkInfo"
QT_MOC_LITERAL(34, 403, 4), // "info"
QT_MOC_LITERAL(35, 408, 19), // "setUseAutoReconnect"
QT_MOC_LITERAL(36, 428, 24), // "setAutoReconnectInterval"
QT_MOC_LITERAL(37, 453, 23), // "setAutoReconnectRetries"
QT_MOC_LITERAL(38, 477, 15), // "setPingInterval"
QT_MOC_LITERAL(39, 493, 8), // "interval"
QT_MOC_LITERAL(40, 502, 21), // "setPongTimestampValid"
QT_MOC_LITERAL(41, 524, 14), // "validTimestamp"
QT_MOC_LITERAL(42, 539, 8), // "shutdown"
QT_MOC_LITERAL(43, 548, 12), // "connectToIrc"
QT_MOC_LITERAL(44, 561, 12), // "reconnecting"
QT_MOC_LITERAL(45, 574, 17), // "disconnectFromIrc"
QT_MOC_LITERAL(46, 592, 9), // "requested"
QT_MOC_LITERAL(47, 602, 6), // "reason"
QT_MOC_LITERAL(48, 609, 13), // "withReconnect"
QT_MOC_LITERAL(49, 623, 15), // "forceDisconnect"
QT_MOC_LITERAL(50, 639, 5), // "msecs"
QT_MOC_LITERAL(51, 645, 9), // "userInput"
QT_MOC_LITERAL(52, 655, 10), // "BufferInfo"
QT_MOC_LITERAL(53, 666, 10), // "bufferInfo"
QT_MOC_LITERAL(54, 677, 10), // "putRawLine"
QT_MOC_LITERAL(55, 688, 5), // "input"
QT_MOC_LITERAL(56, 694, 7), // "prepend"
QT_MOC_LITERAL(57, 702, 6), // "putCmd"
QT_MOC_LITERAL(58, 709, 3), // "cmd"
QT_MOC_LITERAL(59, 713, 6), // "params"
QT_MOC_LITERAL(60, 720, 6), // "prefix"
QT_MOC_LITERAL(61, 727, 24), // "QHash<IrcTagKey,QString>"
QT_MOC_LITERAL(62, 752, 4), // "tags"
QT_MOC_LITERAL(63, 757, 25), // "QList<QList<QByteArray> >"
QT_MOC_LITERAL(64, 783, 10), // "prependAll"
QT_MOC_LITERAL(65, 794, 16), // "setChannelJoined"
QT_MOC_LITERAL(66, 811, 7), // "channel"
QT_MOC_LITERAL(67, 819, 16), // "setChannelParted"
QT_MOC_LITERAL(68, 836, 13), // "addChannelKey"
QT_MOC_LITERAL(69, 850, 3), // "key"
QT_MOC_LITERAL(70, 854, 16), // "removeChannelKey"
QT_MOC_LITERAL(71, 871, 6), // "cipher"
QT_MOC_LITERAL(72, 878, 7), // "Cipher*"
QT_MOC_LITERAL(73, 886, 9), // "recipient"
QT_MOC_LITERAL(74, 896, 9), // "cipherKey"
QT_MOC_LITERAL(75, 906, 12), // "setCipherKey"
QT_MOC_LITERAL(76, 919, 13), // "cipherUsesCBC"
QT_MOC_LITERAL(77, 933, 6), // "target"
QT_MOC_LITERAL(78, 940, 18), // "updateRateLimiting"
QT_MOC_LITERAL(79, 959, 14), // "forceUnlimited"
QT_MOC_LITERAL(80, 974, 16), // "resetTokenBucket"
QT_MOC_LITERAL(81, 991, 14), // "serverCapAdded"
QT_MOC_LITERAL(82, 1006, 10), // "capability"
QT_MOC_LITERAL(83, 1017, 21), // "serverCapAcknowledged"
QT_MOC_LITERAL(84, 1039, 16), // "serverCapRemoved"
QT_MOC_LITERAL(85, 1056, 11), // "sendNextCap"
QT_MOC_LITERAL(86, 1068, 17), // "setAutoWhoEnabled"
QT_MOC_LITERAL(87, 1086, 7), // "enabled"
QT_MOC_LITERAL(88, 1094, 18), // "setAutoWhoInterval"
QT_MOC_LITERAL(89, 1113, 15), // "setAutoWhoDelay"
QT_MOC_LITERAL(90, 1129, 5), // "delay"
QT_MOC_LITERAL(91, 1135, 19), // "queueAutoWhoOneshot"
QT_MOC_LITERAL(92, 1155, 4), // "name"
QT_MOC_LITERAL(93, 1160, 14), // "setAutoWhoDone"
QT_MOC_LITERAL(94, 1175, 17), // "updateIssuedModes"
QT_MOC_LITERAL(95, 1193, 14), // "requestedModes"
QT_MOC_LITERAL(96, 1208, 21), // "updatePersistentModes"
QT_MOC_LITERAL(97, 1230, 8), // "addModes"
QT_MOC_LITERAL(98, 1239, 11), // "removeModes"
QT_MOC_LITERAL(99, 1251, 20), // "resetPersistentModes"
QT_MOC_LITERAL(100, 1272, 10), // "usedServer"
QT_MOC_LITERAL(101, 1283, 6), // "Server"
QT_MOC_LITERAL(102, 1290, 16), // "resetPingTimeout"
QT_MOC_LITERAL(103, 1307, 21), // "resetPongReplyPending"
QT_MOC_LITERAL(104, 1329, 12), // "onDisplayMsg"
QT_MOC_LITERAL(105, 1342, 22), // "NetworkInternalMessage"
QT_MOC_LITERAL(106, 1365, 15), // "onSocketHasData"
QT_MOC_LITERAL(107, 1381, 13), // "onSocketError"
QT_MOC_LITERAL(108, 1395, 28), // "QAbstractSocket::SocketError"
QT_MOC_LITERAL(109, 1424, 19), // "onSocketInitialized"
QT_MOC_LITERAL(110, 1444, 20), // "onSocketCloseTimeout"
QT_MOC_LITERAL(111, 1465, 20), // "onSocketDisconnected"
QT_MOC_LITERAL(112, 1486, 20), // "onSocketStateChanged"
QT_MOC_LITERAL(113, 1507, 28), // "QAbstractSocket::SocketState"
QT_MOC_LITERAL(114, 1536, 18), // "networkInitialized"
QT_MOC_LITERAL(115, 1555, 11), // "sendPerform"
QT_MOC_LITERAL(116, 1567, 16), // "restoreUserModes"
QT_MOC_LITERAL(117, 1584, 15), // "doAutoReconnect"
QT_MOC_LITERAL(118, 1600, 8), // "sendPing"
QT_MOC_LITERAL(119, 1609, 17), // "enablePingTimeout"
QT_MOC_LITERAL(120, 1627, 6), // "enable"
QT_MOC_LITERAL(121, 1634, 18), // "disablePingTimeout"
QT_MOC_LITERAL(122, 1653, 11), // "sendAutoWho"
QT_MOC_LITERAL(123, 1665, 17), // "startAutoWhoCycle"
QT_MOC_LITERAL(124, 1683, 11), // "onSslErrors"
QT_MOC_LITERAL(125, 1695, 16), // "QList<QSslError>"
QT_MOC_LITERAL(126, 1712, 6), // "errors"
QT_MOC_LITERAL(127, 1719, 16), // "checkTokenBucket"
QT_MOC_LITERAL(128, 1736, 25), // "fillBucketAndProcessQueue"
QT_MOC_LITERAL(129, 1762, 13), // "writeToSocket"
QT_MOC_LITERAL(130, 1776, 4) // "data"

    },
    "CoreNetwork\0recvRawServerMsg\0\0"
    "displayStatusMsg\0displayMsg\0RawMessage\0"
    "msg\0disconnected\0NetworkId\0networkId\0"
    "connectionError\0errorMsg\0quitRequested\0"
    "sslErrors\0errorData\0newEvent\0Event*\0"
    "event\0socketInitialized\0const CoreIdentity*\0"
    "identity\0QHostAddress\0localAddress\0"
    "localPort\0peerAddress\0peerPort\0socketId\0"
    "socketDisconnected\0setMyNick\0mynick\0"
    "requestConnect\0requestDisconnect\0"
    "requestSetNetworkInfo\0NetworkInfo\0"
    "info\0setUseAutoReconnect\0"
    "setAutoReconnectInterval\0"
    "setAutoReconnectRetries\0setPingInterval\0"
    "interval\0setPongTimestampValid\0"
    "validTimestamp\0shutdown\0connectToIrc\0"
    "reconnecting\0disconnectFromIrc\0requested\0"
    "reason\0withReconnect\0forceDisconnect\0"
    "msecs\0userInput\0BufferInfo\0bufferInfo\0"
    "putRawLine\0input\0prepend\0putCmd\0cmd\0"
    "params\0prefix\0QHash<IrcTagKey,QString>\0"
    "tags\0QList<QList<QByteArray> >\0"
    "prependAll\0setChannelJoined\0channel\0"
    "setChannelParted\0addChannelKey\0key\0"
    "removeChannelKey\0cipher\0Cipher*\0"
    "recipient\0cipherKey\0setCipherKey\0"
    "cipherUsesCBC\0target\0updateRateLimiting\0"
    "forceUnlimited\0resetTokenBucket\0"
    "serverCapAdded\0capability\0"
    "serverCapAcknowledged\0serverCapRemoved\0"
    "sendNextCap\0setAutoWhoEnabled\0enabled\0"
    "setAutoWhoInterval\0setAutoWhoDelay\0"
    "delay\0queueAutoWhoOneshot\0name\0"
    "setAutoWhoDone\0updateIssuedModes\0"
    "requestedModes\0updatePersistentModes\0"
    "addModes\0removeModes\0resetPersistentModes\0"
    "usedServer\0Server\0resetPingTimeout\0"
    "resetPongReplyPending\0onDisplayMsg\0"
    "NetworkInternalMessage\0onSocketHasData\0"
    "onSocketError\0QAbstractSocket::SocketError\0"
    "onSocketInitialized\0onSocketCloseTimeout\0"
    "onSocketDisconnected\0onSocketStateChanged\0"
    "QAbstractSocket::SocketState\0"
    "networkInitialized\0sendPerform\0"
    "restoreUserModes\0doAutoReconnect\0"
    "sendPing\0enablePingTimeout\0enable\0"
    "disablePingTimeout\0sendAutoWho\0"
    "startAutoWhoCycle\0onSslErrors\0"
    "QList<QSslError>\0errors\0checkTokenBucket\0"
    "fillBucketAndProcessQueue\0writeToSocket\0"
    "data"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreNetwork[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      86,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  444,    2, 0x06 /* Public */,
       3,    1,  447,    2, 0x06 /* Public */,
       4,    1,  450,    2, 0x06 /* Public */,
       7,    1,  453,    2, 0x06 /* Public */,
      10,    1,  456,    2, 0x06 /* Public */,
      12,    1,  459,    2, 0x06 /* Public */,
      13,    1,  462,    2, 0x06 /* Public */,
      15,    1,  465,    2, 0x06 /* Public */,
      18,    6,  468,    2, 0x06 /* Public */,
      27,    6,  481,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      28,    1,  494,    2, 0x0a /* Public */,
      30,    0,  497,    2, 0x0a /* Public */,
      31,    0,  498,    2, 0x0a /* Public */,
      32,    1,  499,    2, 0x0a /* Public */,
      35,    1,  502,    2, 0x0a /* Public */,
      36,    1,  505,    2, 0x0a /* Public */,
      37,    1,  508,    2, 0x0a /* Public */,
      38,    1,  511,    2, 0x0a /* Public */,
      40,    1,  514,    2, 0x0a /* Public */,
      42,    0,  517,    2, 0x0a /* Public */,
      43,    1,  518,    2, 0x0a /* Public */,
      43,    0,  521,    2, 0x2a /* Public | MethodCloned */,
      45,    3,  522,    2, 0x0a /* Public */,
      45,    2,  529,    2, 0x2a /* Public | MethodCloned */,
      45,    1,  534,    2, 0x2a /* Public | MethodCloned */,
      45,    0,  537,    2, 0x2a /* Public | MethodCloned */,
      49,    1,  538,    2, 0x0a /* Public */,
      49,    0,  541,    2, 0x2a /* Public | MethodCloned */,
      51,    2,  542,    2, 0x0a /* Public */,
      54,    2,  547,    2, 0x0a /* Public */,
      54,    1,  552,    2, 0x2a /* Public | MethodCloned */,
      57,    5,  555,    2, 0x0a /* Public */,
      57,    4,  566,    2, 0x2a /* Public | MethodCloned */,
      57,    3,  575,    2, 0x2a /* Public | MethodCloned */,
      57,    2,  582,    2, 0x2a /* Public | MethodCloned */,
      57,    5,  587,    2, 0x0a /* Public */,
      57,    4,  598,    2, 0x2a /* Public | MethodCloned */,
      57,    3,  607,    2, 0x2a /* Public | MethodCloned */,
      57,    2,  614,    2, 0x2a /* Public | MethodCloned */,
      65,    1,  619,    2, 0x0a /* Public */,
      67,    1,  622,    2, 0x0a /* Public */,
      68,    2,  625,    2, 0x0a /* Public */,
      70,    1,  630,    2, 0x0a /* Public */,
      71,    1,  633,    2, 0x0a /* Public */,
      74,    1,  636,    2, 0x0a /* Public */,
      75,    2,  639,    2, 0x0a /* Public */,
      76,    1,  644,    2, 0x0a /* Public */,
      78,    1,  647,    2, 0x0a /* Public */,
      78,    0,  650,    2, 0x2a /* Public | MethodCloned */,
      80,    0,  651,    2, 0x0a /* Public */,
      81,    1,  652,    2, 0x0a /* Public */,
      83,    1,  655,    2, 0x0a /* Public */,
      84,    1,  658,    2, 0x0a /* Public */,
      85,    0,  661,    2, 0x0a /* Public */,
      86,    1,  662,    2, 0x0a /* Public */,
      88,    1,  665,    2, 0x0a /* Public */,
      89,    1,  668,    2, 0x0a /* Public */,
      91,    1,  671,    2, 0x0a /* Public */,
      93,    1,  674,    2, 0x0a /* Public */,
      94,    1,  677,    2, 0x0a /* Public */,
      96,    2,  680,    2, 0x0a /* Public */,
      99,    0,  685,    2, 0x0a /* Public */,
     100,    0,  686,    2, 0x0a /* Public */,
     102,    0,  687,    2, 0x0a /* Public */,
     103,    0,  688,    2, 0x0a /* Public */,
     104,    1,  689,    2, 0x0a /* Public */,
     106,    0,  692,    2, 0x08 /* Private */,
     107,    1,  693,    2, 0x08 /* Private */,
     109,    0,  696,    2, 0x08 /* Private */,
     110,    0,  697,    2, 0x08 /* Private */,
     111,    0,  698,    2, 0x08 /* Private */,
     112,    1,  699,    2, 0x08 /* Private */,
     114,    0,  702,    2, 0x08 /* Private */,
     115,    0,  703,    2, 0x08 /* Private */,
     116,    0,  704,    2, 0x08 /* Private */,
     117,    0,  705,    2, 0x08 /* Private */,
     118,    0,  706,    2, 0x08 /* Private */,
     119,    1,  707,    2, 0x08 /* Private */,
     119,    0,  710,    2, 0x28 /* Private | MethodCloned */,
     121,    0,  711,    2, 0x08 /* Private */,
     122,    0,  712,    2, 0x08 /* Private */,
     123,    0,  713,    2, 0x08 /* Private */,
     124,    1,  714,    2, 0x08 /* Private */,
     127,    0,  717,    2, 0x08 /* Private */,
     128,    0,  718,    2, 0x08 /* Private */,
     129,    1,  719,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::QVariant,   14,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, 0x80000000 | 19, 0x80000000 | 21, QMetaType::UShort, 0x80000000 | 21, QMetaType::UShort, QMetaType::LongLong,   20,   22,   23,   24,   25,   26,
    QMetaType::Void, 0x80000000 | 19, 0x80000000 | 21, QMetaType::UShort, 0x80000000 | 21, QMetaType::UShort, QMetaType::LongLong,   20,   22,   23,   24,   25,   26,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,   29,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 33,   34,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::UInt,    2,
    QMetaType::Void, QMetaType::UShort,    2,
    QMetaType::Void, QMetaType::Int,   39,
    QMetaType::Void, QMetaType::Bool,   41,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   44,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::QString, QMetaType::Bool,   46,   47,   48,
    QMetaType::Void, QMetaType::Bool, QMetaType::QString,   46,   47,
    QMetaType::Void, QMetaType::Bool,   46,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::Int,   50,
    QMetaType::Bool,
    QMetaType::Void, 0x80000000 | 52, QMetaType::QString,   53,    6,
    QMetaType::Void, QMetaType::QByteArray, QMetaType::Bool,   55,   56,
    QMetaType::Void, QMetaType::QByteArray,   55,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArrayList, QMetaType::QByteArray, 0x80000000 | 61, QMetaType::Bool,   58,   59,   60,   62,   56,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArrayList, QMetaType::QByteArray, 0x80000000 | 61,   58,   59,   60,   62,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArrayList, QMetaType::QByteArray,   58,   59,   60,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArrayList,   58,   59,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 63, QMetaType::QByteArray, 0x80000000 | 61, QMetaType::Bool,   58,   59,   60,   62,   64,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 63, QMetaType::QByteArray, 0x80000000 | 61,   58,   59,   60,   62,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 63, QMetaType::QByteArray,   58,   59,   60,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 63,   58,   59,
    QMetaType::Void, QMetaType::QString,   66,
    QMetaType::Void, QMetaType::QString,   66,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   66,   69,
    QMetaType::Void, QMetaType::QString,   66,
    0x80000000 | 72, QMetaType::QString,   73,
    QMetaType::QByteArray, QMetaType::QString,   73,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArray,   73,   69,
    QMetaType::Bool, QMetaType::QString,   77,
    QMetaType::Void, QMetaType::Bool,   79,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   82,
    QMetaType::Void, QMetaType::QString,   82,
    QMetaType::Void, QMetaType::QString,   82,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   87,
    QMetaType::Void, QMetaType::Int,   39,
    QMetaType::Void, QMetaType::Int,   90,
    QMetaType::Void, QMetaType::QString,   92,
    QMetaType::Bool, QMetaType::QString,   92,
    QMetaType::Void, QMetaType::QString,   95,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   97,   98,
    QMetaType::Void,
    0x80000000 | 101,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 105,    6,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 108,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 113,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,  120,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 125,  126,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QByteArray,  130,

       0        // eod
};

void CoreNetwork::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreNetwork *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->recvRawServerMsg((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->displayStatusMsg((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->displayMsg((*reinterpret_cast< const RawMessage(*)>(_a[1]))); break;
        case 3: _t->disconnected((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 4: _t->connectionError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->quitRequested((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 6: _t->sslErrors((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 7: _t->newEvent((*reinterpret_cast< Event*(*)>(_a[1]))); break;
        case 8: _t->socketInitialized((*reinterpret_cast< const CoreIdentity*(*)>(_a[1])),(*reinterpret_cast< const QHostAddress(*)>(_a[2])),(*reinterpret_cast< quint16(*)>(_a[3])),(*reinterpret_cast< const QHostAddress(*)>(_a[4])),(*reinterpret_cast< quint16(*)>(_a[5])),(*reinterpret_cast< qint64(*)>(_a[6]))); break;
        case 9: _t->socketDisconnected((*reinterpret_cast< const CoreIdentity*(*)>(_a[1])),(*reinterpret_cast< const QHostAddress(*)>(_a[2])),(*reinterpret_cast< quint16(*)>(_a[3])),(*reinterpret_cast< const QHostAddress(*)>(_a[4])),(*reinterpret_cast< quint16(*)>(_a[5])),(*reinterpret_cast< qint64(*)>(_a[6]))); break;
        case 10: _t->setMyNick((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->requestConnect(); break;
        case 12: _t->requestDisconnect(); break;
        case 13: _t->requestSetNetworkInfo((*reinterpret_cast< const NetworkInfo(*)>(_a[1]))); break;
        case 14: _t->setUseAutoReconnect((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->setAutoReconnectInterval((*reinterpret_cast< quint32(*)>(_a[1]))); break;
        case 16: _t->setAutoReconnectRetries((*reinterpret_cast< quint16(*)>(_a[1]))); break;
        case 17: _t->setPingInterval((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->setPongTimestampValid((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: _t->shutdown(); break;
        case 20: _t->connectToIrc((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->connectToIrc(); break;
        case 22: _t->disconnectFromIrc((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 23: _t->disconnectFromIrc((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 24: _t->disconnectFromIrc((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->disconnectFromIrc(); break;
        case 26: { bool _r = _t->forceDisconnect((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->forceDisconnect();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->userInput((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 29: _t->putRawLine((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 30: _t->putRawLine((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 31: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QByteArray>(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3])),(*reinterpret_cast< const QHash<IrcTagKey,QString>(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        case 32: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QByteArray>(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3])),(*reinterpret_cast< const QHash<IrcTagKey,QString>(*)>(_a[4]))); break;
        case 33: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QByteArray>(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3]))); break;
        case 34: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QByteArray>(*)>(_a[2]))); break;
        case 35: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QList<QByteArray> >(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3])),(*reinterpret_cast< const QHash<IrcTagKey,QString>(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        case 36: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QList<QByteArray> >(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3])),(*reinterpret_cast< const QHash<IrcTagKey,QString>(*)>(_a[4]))); break;
        case 37: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QList<QByteArray> >(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3]))); break;
        case 38: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QList<QByteArray> >(*)>(_a[2]))); break;
        case 39: _t->setChannelJoined((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 40: _t->setChannelParted((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 41: _t->addChannelKey((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 42: _t->removeChannelKey((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 43: { Cipher* _r = _t->cipher((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< Cipher**>(_a[0]) = std::move(_r); }  break;
        case 44: { QByteArray _r = _t->cipherKey((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 45: _t->setCipherKey((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 46: { bool _r = _t->cipherUsesCBC((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 47: _t->updateRateLimiting((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 48: _t->updateRateLimiting(); break;
        case 49: _t->resetTokenBucket(); break;
        case 50: _t->serverCapAdded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 51: _t->serverCapAcknowledged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 52: _t->serverCapRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 53: _t->sendNextCap(); break;
        case 54: _t->setAutoWhoEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 55: _t->setAutoWhoInterval((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 56: _t->setAutoWhoDelay((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 57: _t->queueAutoWhoOneshot((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 58: { bool _r = _t->setAutoWhoDone((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 59: _t->updateIssuedModes((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 60: _t->updatePersistentModes((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 61: _t->resetPersistentModes(); break;
        case 62: { Server _r = _t->usedServer();
            if (_a[0]) *reinterpret_cast< Server*>(_a[0]) = std::move(_r); }  break;
        case 63: _t->resetPingTimeout(); break;
        case 64: _t->resetPongReplyPending(); break;
        case 65: _t->onDisplayMsg((*reinterpret_cast< const NetworkInternalMessage(*)>(_a[1]))); break;
        case 66: _t->onSocketHasData(); break;
        case 67: _t->onSocketError((*reinterpret_cast< QAbstractSocket::SocketError(*)>(_a[1]))); break;
        case 68: _t->onSocketInitialized(); break;
        case 69: _t->onSocketCloseTimeout(); break;
        case 70: _t->onSocketDisconnected(); break;
        case 71: _t->onSocketStateChanged((*reinterpret_cast< QAbstractSocket::SocketState(*)>(_a[1]))); break;
        case 72: _t->networkInitialized(); break;
        case 73: _t->sendPerform(); break;
        case 74: _t->restoreUserModes(); break;
        case 75: _t->doAutoReconnect(); break;
        case 76: _t->sendPing(); break;
        case 77: _t->enablePingTimeout((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 78: _t->enablePingTimeout(); break;
        case 79: _t->disablePingTimeout(); break;
        case 80: _t->sendAutoWho(); break;
        case 81: _t->startAutoWhoCycle(); break;
        case 82: _t->onSslErrors((*reinterpret_cast< const QList<QSslError>(*)>(_a[1]))); break;
        case 83: _t->checkTokenBucket(); break;
        case 84: _t->fillBucketAndProcessQueue(); break;
        case 85: _t->writeToSocket((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 3:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QHostAddress >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 3:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QHostAddress >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkInfo >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QList<QByteArray> > >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QList<QByteArray> > >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QList<QByteArray> > >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QList<QByteArray> > >(); break;
            }
            break;
        case 67:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
            }
            break;
        case 71:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketState >(); break;
            }
            break;
        case 82:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QSslError> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CoreNetwork::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreNetwork::recvRawServerMsg)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (CoreNetwork::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreNetwork::displayStatusMsg)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (CoreNetwork::*)(const RawMessage & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreNetwork::displayMsg)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (CoreNetwork::*)(NetworkId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreNetwork::disconnected)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (CoreNetwork::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreNetwork::connectionError)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (CoreNetwork::*)(NetworkId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreNetwork::quitRequested)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (CoreNetwork::*)(const QVariant & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreNetwork::sslErrors)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (CoreNetwork::*)(Event * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreNetwork::newEvent)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (CoreNetwork::*)(const CoreIdentity * , const QHostAddress & , quint16 , const QHostAddress & , quint16 , qint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreNetwork::socketInitialized)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (CoreNetwork::*)(const CoreIdentity * , const QHostAddress & , quint16 , const QHostAddress & , quint16 , qint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreNetwork::socketDisconnected)) {
                *result = 9;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreNetwork::staticMetaObject = { {
    QMetaObject::SuperData::link<Network::staticMetaObject>(),
    qt_meta_stringdata_CoreNetwork.data,
    qt_meta_data_CoreNetwork,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreNetwork::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreNetwork::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreNetwork.stringdata0))
        return static_cast<void*>(this);
    return Network::qt_metacast(_clname);
}

int CoreNetwork::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Network::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 86)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 86;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 86)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 86;
    }
    return _id;
}

// SIGNAL 0
void CoreNetwork::recvRawServerMsg(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void CoreNetwork::displayStatusMsg(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void CoreNetwork::displayMsg(const RawMessage & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void CoreNetwork::disconnected(NetworkId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void CoreNetwork::connectionError(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void CoreNetwork::quitRequested(NetworkId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void CoreNetwork::sslErrors(const QVariant & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void CoreNetwork::newEvent(Event * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void CoreNetwork::socketInitialized(const CoreIdentity * _t1, const QHostAddress & _t2, quint16 _t3, const QHostAddress & _t4, quint16 _t5, qint64 _t6)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t6))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void CoreNetwork::socketDisconnected(const CoreIdentity * _t1, const QHostAddress & _t2, quint16 _t3, const QHostAddress & _t4, quint16 _t5, qint64 _t6)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t6))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
