/****************************************************************************
** Meta object code from reading C++ file 'networkmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/client/networkmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'networkmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_NetworkItem_t {
    QByteArrayData data[23];
    char stringdata0[266];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NetworkItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NetworkItem_t qt_meta_stringdata_NetworkItem = {
    {
QT_MOC_LITERAL(0, 0, 11), // "NetworkItem"
QT_MOC_LITERAL(1, 12, 18), // "networkDataChanged"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 6), // "column"
QT_MOC_LITERAL(4, 39, 14), // "setNetworkName"
QT_MOC_LITERAL(5, 54, 11), // "networkName"
QT_MOC_LITERAL(6, 66, 16), // "setCurrentServer"
QT_MOC_LITERAL(7, 83, 10), // "serverName"
QT_MOC_LITERAL(8, 94, 13), // "attachNetwork"
QT_MOC_LITERAL(9, 108, 8), // "Network*"
QT_MOC_LITERAL(10, 117, 7), // "network"
QT_MOC_LITERAL(11, 125, 16), // "attachIrcChannel"
QT_MOC_LITERAL(12, 142, 11), // "IrcChannel*"
QT_MOC_LITERAL(13, 154, 7), // "channel"
QT_MOC_LITERAL(14, 162, 13), // "attachIrcUser"
QT_MOC_LITERAL(15, 176, 8), // "IrcUser*"
QT_MOC_LITERAL(16, 185, 7), // "ircUser"
QT_MOC_LITERAL(17, 193, 19), // "onBeginRemoveChilds"
QT_MOC_LITERAL(18, 213, 5), // "start"
QT_MOC_LITERAL(19, 219, 3), // "end"
QT_MOC_LITERAL(20, 223, 18), // "onNetworkDestroyed"
QT_MOC_LITERAL(21, 242, 13), // "currentServer"
QT_MOC_LITERAL(22, 256, 9) // "nickCount"

    },
    "NetworkItem\0networkDataChanged\0\0column\0"
    "setNetworkName\0networkName\0setCurrentServer\0"
    "serverName\0attachNetwork\0Network*\0"
    "network\0attachIrcChannel\0IrcChannel*\0"
    "channel\0attachIrcUser\0IrcUser*\0ircUser\0"
    "onBeginRemoveChilds\0start\0end\0"
    "onNetworkDestroyed\0currentServer\0"
    "nickCount"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NetworkItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       3,   84, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,
       1,    0,   62,    2, 0x26 /* Public | MethodCloned */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   63,    2, 0x0a /* Public */,
       6,    1,   66,    2, 0x0a /* Public */,
       8,    1,   69,    2, 0x0a /* Public */,
      11,    1,   72,    2, 0x0a /* Public */,
      14,    1,   75,    2, 0x0a /* Public */,
      17,    2,   78,    2, 0x08 /* Private */,
      20,    0,   83,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   18,   19,
    QMetaType::Void,

 // properties: name, type, flags
       5, QMetaType::QString, 0x00095001,
      21, QMetaType::QString, 0x00095001,
      22, QMetaType::Int, 0x00095001,

       0        // eod
};

void NetworkItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<NetworkItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->networkDataChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->networkDataChanged(); break;
        case 2: _t->setNetworkName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->setCurrentServer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->attachNetwork((*reinterpret_cast< Network*(*)>(_a[1]))); break;
        case 5: _t->attachIrcChannel((*reinterpret_cast< IrcChannel*(*)>(_a[1]))); break;
        case 6: _t->attachIrcUser((*reinterpret_cast< IrcUser*(*)>(_a[1]))); break;
        case 7: _t->onBeginRemoveChilds((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 8: _t->onNetworkDestroyed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Network* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IrcChannel* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IrcUser* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (NetworkItem::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkItem::networkDataChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<NetworkItem *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->networkName(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->currentServer(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->nickCount(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject NetworkItem::staticMetaObject = { {
    QMetaObject::SuperData::link<PropertyMapItem::staticMetaObject>(),
    qt_meta_stringdata_NetworkItem.data,
    qt_meta_data_NetworkItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *NetworkItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetworkItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NetworkItem.stringdata0))
        return static_cast<void*>(this);
    return PropertyMapItem::qt_metacast(_clname);
}

int NetworkItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PropertyMapItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 3;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void NetworkItem::networkDataChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_BufferItem_t {
    QByteArrayData data[7];
    char stringdata0[61];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferItem_t qt_meta_stringdata_BufferItem = {
    {
QT_MOC_LITERAL(0, 0, 10), // "BufferItem"
QT_MOC_LITERAL(1, 11, 8), // "setTopic"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 12), // "setEncrypted"
QT_MOC_LITERAL(4, 34, 10), // "bufferName"
QT_MOC_LITERAL(5, 45, 5), // "topic"
QT_MOC_LITERAL(6, 51, 9) // "nickCount"

    },
    "BufferItem\0setTopic\0\0setEncrypted\0"
    "bufferName\0topic\0nickCount"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       3,   30, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x0a /* Public */,
       3,    1,   27,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Bool,    2,

 // properties: name, type, flags
       4, QMetaType::QString, 0x00095103,
       5, QMetaType::QString, 0x00095001,
       6, QMetaType::Int, 0x00095001,

       0        // eod
};

void BufferItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setTopic((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->setEncrypted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<BufferItem *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->bufferName(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->topic(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->nickCount(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<BufferItem *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBufferName(*reinterpret_cast< QString*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject BufferItem::staticMetaObject = { {
    QMetaObject::SuperData::link<PropertyMapItem::staticMetaObject>(),
    qt_meta_stringdata_BufferItem.data,
    qt_meta_data_BufferItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferItem.stringdata0))
        return static_cast<void*>(this);
    return PropertyMapItem::qt_metacast(_clname);
}

int BufferItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PropertyMapItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 3;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 3;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
struct qt_meta_stringdata_StatusBufferItem_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_StatusBufferItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_StatusBufferItem_t qt_meta_stringdata_StatusBufferItem = {
    {
QT_MOC_LITERAL(0, 0, 16) // "StatusBufferItem"

    },
    "StatusBufferItem"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_StatusBufferItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void StatusBufferItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject StatusBufferItem::staticMetaObject = { {
    QMetaObject::SuperData::link<BufferItem::staticMetaObject>(),
    qt_meta_stringdata_StatusBufferItem.data,
    qt_meta_data_StatusBufferItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *StatusBufferItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StatusBufferItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_StatusBufferItem.stringdata0))
        return static_cast<void*>(this);
    return BufferItem::qt_metacast(_clname);
}

int StatusBufferItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BufferItem::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_QueryBufferItem_t {
    QByteArrayData data[6];
    char stringdata0[59];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QueryBufferItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QueryBufferItem_t qt_meta_stringdata_QueryBufferItem = {
    {
QT_MOC_LITERAL(0, 0, 15), // "QueryBufferItem"
QT_MOC_LITERAL(1, 16, 10), // "setIrcUser"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 8), // "IrcUser*"
QT_MOC_LITERAL(4, 37, 7), // "ircUser"
QT_MOC_LITERAL(5, 45, 13) // "removeIrcUser"

    },
    "QueryBufferItem\0setIrcUser\0\0IrcUser*\0"
    "ircUser\0removeIrcUser"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QueryBufferItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x0a /* Public */,
       5,    0,   27,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

       0        // eod
};

void QueryBufferItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QueryBufferItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setIrcUser((*reinterpret_cast< IrcUser*(*)>(_a[1]))); break;
        case 1: _t->removeIrcUser(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IrcUser* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QueryBufferItem::staticMetaObject = { {
    QMetaObject::SuperData::link<BufferItem::staticMetaObject>(),
    qt_meta_stringdata_QueryBufferItem.data,
    qt_meta_data_QueryBufferItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QueryBufferItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QueryBufferItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QueryBufferItem.stringdata0))
        return static_cast<void*>(this);
    return BufferItem::qt_metacast(_clname);
}

int QueryBufferItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BufferItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_ChannelBufferItem_t {
    QByteArrayData data[17];
    char stringdata0[230];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChannelBufferItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChannelBufferItem_t qt_meta_stringdata_ChannelBufferItem = {
    {
QT_MOC_LITERAL(0, 0, 17), // "ChannelBufferItem"
QT_MOC_LITERAL(1, 18, 4), // "join"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 15), // "QList<IrcUser*>"
QT_MOC_LITERAL(4, 40, 8), // "ircUsers"
QT_MOC_LITERAL(5, 49, 4), // "part"
QT_MOC_LITERAL(6, 54, 8), // "IrcUser*"
QT_MOC_LITERAL(7, 63, 7), // "ircUser"
QT_MOC_LITERAL(8, 71, 16), // "findCategoryItem"
QT_MOC_LITERAL(9, 88, 17), // "UserCategoryItem*"
QT_MOC_LITERAL(10, 106, 10), // "categoryId"
QT_MOC_LITERAL(11, 117, 17), // "addUserToCategory"
QT_MOC_LITERAL(12, 135, 18), // "addUsersToCategory"
QT_MOC_LITERAL(13, 154, 22), // "removeUserFromCategory"
QT_MOC_LITERAL(14, 177, 15), // "userModeChanged"
QT_MOC_LITERAL(15, 193, 16), // "ircChannelParted"
QT_MOC_LITERAL(16, 210, 19) // "ircChannelDestroyed"

    },
    "ChannelBufferItem\0join\0\0QList<IrcUser*>\0"
    "ircUsers\0part\0IrcUser*\0ircUser\0"
    "findCategoryItem\0UserCategoryItem*\0"
    "categoryId\0addUserToCategory\0"
    "addUsersToCategory\0removeUserFromCategory\0"
    "userModeChanged\0ircChannelParted\0"
    "ircChannelDestroyed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChannelBufferItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x0a /* Public */,
       5,    1,   62,    2, 0x0a /* Public */,
       8,    1,   65,    2, 0x0a /* Public */,
      11,    1,   68,    2, 0x0a /* Public */,
      12,    1,   71,    2, 0x0a /* Public */,
      13,    1,   74,    2, 0x0a /* Public */,
      14,    1,   77,    2, 0x0a /* Public */,
      15,    0,   80,    2, 0x08 /* Private */,
      16,    0,   81,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    0x80000000 | 9, QMetaType::Int,   10,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 3,    7,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ChannelBufferItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ChannelBufferItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->join((*reinterpret_cast< const QList<IrcUser*>(*)>(_a[1]))); break;
        case 1: _t->part((*reinterpret_cast< IrcUser*(*)>(_a[1]))); break;
        case 2: { UserCategoryItem* _r = _t->findCategoryItem((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< UserCategoryItem**>(_a[0]) = std::move(_r); }  break;
        case 3: _t->addUserToCategory((*reinterpret_cast< IrcUser*(*)>(_a[1]))); break;
        case 4: _t->addUsersToCategory((*reinterpret_cast< const QList<IrcUser*>(*)>(_a[1]))); break;
        case 5: _t->removeUserFromCategory((*reinterpret_cast< IrcUser*(*)>(_a[1]))); break;
        case 6: _t->userModeChanged((*reinterpret_cast< IrcUser*(*)>(_a[1]))); break;
        case 7: _t->ircChannelParted(); break;
        case 8: _t->ircChannelDestroyed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<IrcUser*> >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IrcUser* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IrcUser* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<IrcUser*> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IrcUser* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IrcUser* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ChannelBufferItem::staticMetaObject = { {
    QMetaObject::SuperData::link<BufferItem::staticMetaObject>(),
    qt_meta_stringdata_ChannelBufferItem.data,
    qt_meta_data_ChannelBufferItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ChannelBufferItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChannelBufferItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ChannelBufferItem.stringdata0))
        return static_cast<void*>(this);
    return BufferItem::qt_metacast(_clname);
}

int ChannelBufferItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BufferItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
struct qt_meta_stringdata_UserCategoryItem_t {
    QByteArrayData data[2];
    char stringdata0[30];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_UserCategoryItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_UserCategoryItem_t qt_meta_stringdata_UserCategoryItem = {
    {
QT_MOC_LITERAL(0, 0, 16), // "UserCategoryItem"
QT_MOC_LITERAL(1, 17, 12) // "categoryName"

    },
    "UserCategoryItem\0categoryName"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_UserCategoryItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       1,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::QString, 0x00095001,

       0        // eod
};

void UserCategoryItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<UserCategoryItem *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->categoryName(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject UserCategoryItem::staticMetaObject = { {
    QMetaObject::SuperData::link<PropertyMapItem::staticMetaObject>(),
    qt_meta_stringdata_UserCategoryItem.data,
    qt_meta_data_UserCategoryItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *UserCategoryItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UserCategoryItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_UserCategoryItem.stringdata0))
        return static_cast<void*>(this);
    return PropertyMapItem::qt_metacast(_clname);
}

int UserCategoryItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PropertyMapItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    
#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
struct qt_meta_stringdata_IrcUserItem_t {
    QByteArrayData data[4];
    char stringdata0[36];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_IrcUserItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_IrcUserItem_t qt_meta_stringdata_IrcUserItem = {
    {
QT_MOC_LITERAL(0, 0, 11), // "IrcUserItem"
QT_MOC_LITERAL(1, 12, 13), // "ircUserQuited"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 8) // "nickName"

    },
    "IrcUserItem\0ircUserQuited\0\0nickName"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_IrcUserItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       1,   20, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,

 // properties: name, type, flags
       3, QMetaType::QString, 0x00095001,

       0        // eod
};

void IrcUserItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<IrcUserItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->ircUserQuited(); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<IrcUserItem *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->nickName(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject IrcUserItem::staticMetaObject = { {
    QMetaObject::SuperData::link<PropertyMapItem::staticMetaObject>(),
    qt_meta_stringdata_IrcUserItem.data,
    qt_meta_data_IrcUserItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *IrcUserItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IrcUserItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_IrcUserItem.stringdata0))
        return static_cast<void*>(this);
    return PropertyMapItem::qt_metacast(_clname);
}

int IrcUserItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PropertyMapItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
struct qt_meta_stringdata_NetworkModel_t {
    QByteArrayData data[37];
    char stringdata0[507];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NetworkModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NetworkModel_t qt_meta_stringdata_NetworkModel = {
    {
QT_MOC_LITERAL(0, 0, 12), // "NetworkModel"
QT_MOC_LITERAL(1, 13, 21), // "requestSetLastSeenMsg"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 8), // "BufferId"
QT_MOC_LITERAL(4, 45, 6), // "buffer"
QT_MOC_LITERAL(5, 52, 5), // "MsgId"
QT_MOC_LITERAL(6, 58, 3), // "msg"
QT_MOC_LITERAL(7, 62, 14), // "lastSeenMsgSet"
QT_MOC_LITERAL(8, 77, 13), // "markerLineSet"
QT_MOC_LITERAL(9, 91, 13), // "bufferUpdated"
QT_MOC_LITERAL(10, 105, 10), // "BufferInfo"
QT_MOC_LITERAL(11, 116, 10), // "bufferInfo"
QT_MOC_LITERAL(12, 127, 12), // "removeBuffer"
QT_MOC_LITERAL(13, 140, 8), // "bufferId"
QT_MOC_LITERAL(14, 149, 13), // "lastSeenMsgId"
QT_MOC_LITERAL(15, 163, 16), // "setLastSeenMsgId"
QT_MOC_LITERAL(16, 180, 5), // "msgId"
QT_MOC_LITERAL(17, 186, 18), // "setMarkerLineMsgId"
QT_MOC_LITERAL(18, 205, 17), // "setBufferActivity"
QT_MOC_LITERAL(19, 223, 25), // "BufferInfo::ActivityLevel"
QT_MOC_LITERAL(20, 249, 8), // "activity"
QT_MOC_LITERAL(21, 258, 19), // "clearBufferActivity"
QT_MOC_LITERAL(22, 278, 20), // "updateBufferActivity"
QT_MOC_LITERAL(23, 299, 8), // "Message&"
QT_MOC_LITERAL(24, 308, 14), // "networkRemoved"
QT_MOC_LITERAL(25, 323, 9), // "NetworkId"
QT_MOC_LITERAL(26, 333, 9), // "networkId"
QT_MOC_LITERAL(27, 343, 21), // "bufferActivityChanged"
QT_MOC_LITERAL(28, 365, 14), // "Message::Types"
QT_MOC_LITERAL(29, 380, 21), // "highlightCountChanged"
QT_MOC_LITERAL(30, 402, 22), // "checkForRemovedBuffers"
QT_MOC_LITERAL(31, 425, 11), // "QModelIndex"
QT_MOC_LITERAL(32, 437, 6), // "parent"
QT_MOC_LITERAL(33, 444, 5), // "start"
QT_MOC_LITERAL(34, 450, 3), // "end"
QT_MOC_LITERAL(35, 454, 18), // "checkForNewBuffers"
QT_MOC_LITERAL(36, 473, 33) // "messageRedirectionSettingsCha..."

    },
    "NetworkModel\0requestSetLastSeenMsg\0\0"
    "BufferId\0buffer\0MsgId\0msg\0lastSeenMsgSet\0"
    "markerLineSet\0bufferUpdated\0BufferInfo\0"
    "bufferInfo\0removeBuffer\0bufferId\0"
    "lastSeenMsgId\0setLastSeenMsgId\0msgId\0"
    "setMarkerLineMsgId\0setBufferActivity\0"
    "BufferInfo::ActivityLevel\0activity\0"
    "clearBufferActivity\0updateBufferActivity\0"
    "Message&\0networkRemoved\0NetworkId\0"
    "networkId\0bufferActivityChanged\0"
    "Message::Types\0highlightCountChanged\0"
    "checkForRemovedBuffers\0QModelIndex\0"
    "parent\0start\0end\0checkForNewBuffers\0"
    "messageRedirectionSettingsChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NetworkModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   99,    2, 0x06 /* Public */,
       7,    2,  104,    2, 0x06 /* Public */,
       8,    2,  109,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,  114,    2, 0x0a /* Public */,
      12,    1,  117,    2, 0x0a /* Public */,
      14,    1,  120,    2, 0x0a /* Public */,
      15,    2,  123,    2, 0x0a /* Public */,
      17,    2,  128,    2, 0x0a /* Public */,
      18,    2,  133,    2, 0x0a /* Public */,
      21,    1,  138,    2, 0x0a /* Public */,
      22,    1,  141,    2, 0x0a /* Public */,
      24,    1,  144,    2, 0x0a /* Public */,
      27,    2,  147,    2, 0x0a /* Public */,
      29,    2,  152,    2, 0x0a /* Public */,
      30,    3,  157,    2, 0x08 /* Private */,
      35,    3,  164,    2, 0x08 /* Private */,
      36,    0,  171,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 3,   13,
    0x80000000 | 5, 0x80000000 | 3,   13,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,   13,   16,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,   13,   16,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 19,   13,   20,
    QMetaType::Void, 0x80000000 | 3,   13,
    QMetaType::Void, 0x80000000 | 23,    6,
    QMetaType::Void, 0x80000000 | 25,   26,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 28,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    2,    2,
    QMetaType::Void, 0x80000000 | 31, QMetaType::Int, QMetaType::Int,   32,   33,   34,
    QMetaType::Void, 0x80000000 | 31, QMetaType::Int, QMetaType::Int,   32,   33,   34,
    QMetaType::Void,

       0        // eod
};

void NetworkModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<NetworkModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->requestSetLastSeenMsg((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2]))); break;
        case 1: _t->lastSeenMsgSet((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2]))); break;
        case 2: _t->markerLineSet((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2]))); break;
        case 3: _t->bufferUpdated((*reinterpret_cast< BufferInfo(*)>(_a[1]))); break;
        case 4: _t->removeBuffer((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 5: { MsgId _r = _t->lastSeenMsgId((*reinterpret_cast< const BufferId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< MsgId*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->setLastSeenMsgId((*reinterpret_cast< const BufferId(*)>(_a[1])),(*reinterpret_cast< const MsgId(*)>(_a[2]))); break;
        case 7: _t->setMarkerLineMsgId((*reinterpret_cast< const BufferId(*)>(_a[1])),(*reinterpret_cast< const MsgId(*)>(_a[2]))); break;
        case 8: _t->setBufferActivity((*reinterpret_cast< const BufferId(*)>(_a[1])),(*reinterpret_cast< BufferInfo::ActivityLevel(*)>(_a[2]))); break;
        case 9: _t->clearBufferActivity((*reinterpret_cast< const BufferId(*)>(_a[1]))); break;
        case 10: _t->updateBufferActivity((*reinterpret_cast< Message(*)>(_a[1]))); break;
        case 11: _t->networkRemoved((*reinterpret_cast< const NetworkId(*)>(_a[1]))); break;
        case 12: _t->bufferActivityChanged((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< Message::Types(*)>(_a[2]))); break;
        case 13: _t->highlightCountChanged((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 14: _t->checkForRemovedBuffers((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 15: _t->checkForNewBuffers((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 16: _t->messageRedirectionSettingsChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (NetworkModel::*)(BufferId , MsgId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkModel::requestSetLastSeenMsg)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (NetworkModel::*)(BufferId , MsgId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkModel::lastSeenMsgSet)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (NetworkModel::*)(BufferId , MsgId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NetworkModel::markerLineSet)) {
                *result = 2;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject NetworkModel::staticMetaObject = { {
    QMetaObject::SuperData::link<TreeModel::staticMetaObject>(),
    qt_meta_stringdata_NetworkModel.data,
    qt_meta_data_NetworkModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *NetworkModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetworkModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NetworkModel.stringdata0))
        return static_cast<void*>(this);
    return TreeModel::qt_metacast(_clname);
}

int NetworkModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TreeModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void NetworkModel::requestSetLastSeenMsg(BufferId _t1, MsgId _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void NetworkModel::lastSeenMsgSet(BufferId _t1, MsgId _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void NetworkModel::markerLineSet(BufferId _t1, MsgId _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
