/********************************************************************************
** Form generated from reading UI file 'bufferviewsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BUFFERVIEWSETTINGSPAGE_H
#define UI_BUFFERVIEWSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "settingspages/previewbufferview.h"

QT_BEGIN_NAMESPACE

class Ui_BufferViewSettingsPage
{
public:
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    QListWidget *bufferViewList;
    QPushButton *renameBufferView;
    QPushButton *addBufferView;
    QPushButton *deleteBufferView;
    QGroupBox *settingsGroupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hboxLayout1;
    QLabel *label;
    QComboBox *networkSelector;
    QCheckBox *onlyStatusBuffers;
    QCheckBox *onlyChannelBuffers;
    QCheckBox *onlyQueryBuffers;
    QCheckBox *hideInactiveBuffers;
    QCheckBox *hideInactiveNetworks;
    QCheckBox *addNewBuffersAutomatically;
    QCheckBox *sortAlphabetically;
    QCheckBox *showSearch;
    QLabel *label_3;
    QComboBox *minimumActivitySelector;
    QSpacerItem *spacerItem;
    QVBoxLayout *vboxLayout1;
    QLabel *label_2;
    PreviewBufferView *bufferViewPreview;

    void setupUi(QWidget *BufferViewSettingsPage)
    {
        if (BufferViewSettingsPage->objectName().isEmpty())
            BufferViewSettingsPage->setObjectName(QString::fromUtf8("BufferViewSettingsPage"));
        BufferViewSettingsPage->resize(672, 529);
        hboxLayout = new QHBoxLayout(BufferViewSettingsPage);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        bufferViewList = new QListWidget(BufferViewSettingsPage);
        bufferViewList->setObjectName(QString::fromUtf8("bufferViewList"));

        vboxLayout->addWidget(bufferViewList);

        renameBufferView = new QPushButton(BufferViewSettingsPage);
        renameBufferView->setObjectName(QString::fromUtf8("renameBufferView"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(renameBufferView->sizePolicy().hasHeightForWidth());
        renameBufferView->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/edit-rename.png"), QSize(), QIcon::Normal, QIcon::Off);
        renameBufferView->setIcon(icon);

        vboxLayout->addWidget(renameBufferView);

        addBufferView = new QPushButton(BufferViewSettingsPage);
        addBufferView->setObjectName(QString::fromUtf8("addBufferView"));
        sizePolicy.setHeightForWidth(addBufferView->sizePolicy().hasHeightForWidth());
        addBufferView->setSizePolicy(sizePolicy);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/list-add.png"), QSize(), QIcon::Normal, QIcon::Off);
        addBufferView->setIcon(icon1);
        addBufferView->setIconSize(QSize(16, 16));

        vboxLayout->addWidget(addBufferView);

        deleteBufferView = new QPushButton(BufferViewSettingsPage);
        deleteBufferView->setObjectName(QString::fromUtf8("deleteBufferView"));
        sizePolicy.setHeightForWidth(deleteBufferView->sizePolicy().hasHeightForWidth());
        deleteBufferView->setSizePolicy(sizePolicy);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/edit-delete.png"), QSize(), QIcon::Normal, QIcon::Off);
        deleteBufferView->setIcon(icon2);

        vboxLayout->addWidget(deleteBufferView);


        hboxLayout->addLayout(vboxLayout);

        settingsGroupBox = new QGroupBox(BufferViewSettingsPage);
        settingsGroupBox->setObjectName(QString::fromUtf8("settingsGroupBox"));
        verticalLayout = new QVBoxLayout(settingsGroupBox);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        label = new QLabel(settingsGroupBox);
        label->setObjectName(QString::fromUtf8("label"));

        hboxLayout1->addWidget(label);

        networkSelector = new QComboBox(settingsGroupBox);
        networkSelector->addItem(QString());
        networkSelector->setObjectName(QString::fromUtf8("networkSelector"));

        hboxLayout1->addWidget(networkSelector);


        verticalLayout->addLayout(hboxLayout1);

        onlyStatusBuffers = new QCheckBox(settingsGroupBox);
        onlyStatusBuffers->setObjectName(QString::fromUtf8("onlyStatusBuffers"));

        verticalLayout->addWidget(onlyStatusBuffers);

        onlyChannelBuffers = new QCheckBox(settingsGroupBox);
        onlyChannelBuffers->setObjectName(QString::fromUtf8("onlyChannelBuffers"));

        verticalLayout->addWidget(onlyChannelBuffers);

        onlyQueryBuffers = new QCheckBox(settingsGroupBox);
        onlyQueryBuffers->setObjectName(QString::fromUtf8("onlyQueryBuffers"));

        verticalLayout->addWidget(onlyQueryBuffers);

        hideInactiveBuffers = new QCheckBox(settingsGroupBox);
        hideInactiveBuffers->setObjectName(QString::fromUtf8("hideInactiveBuffers"));

        verticalLayout->addWidget(hideInactiveBuffers);

        hideInactiveNetworks = new QCheckBox(settingsGroupBox);
        hideInactiveNetworks->setObjectName(QString::fromUtf8("hideInactiveNetworks"));

        verticalLayout->addWidget(hideInactiveNetworks);

        addNewBuffersAutomatically = new QCheckBox(settingsGroupBox);
        addNewBuffersAutomatically->setObjectName(QString::fromUtf8("addNewBuffersAutomatically"));

        verticalLayout->addWidget(addNewBuffersAutomatically);

        sortAlphabetically = new QCheckBox(settingsGroupBox);
        sortAlphabetically->setObjectName(QString::fromUtf8("sortAlphabetically"));

        verticalLayout->addWidget(sortAlphabetically);

        showSearch = new QCheckBox(settingsGroupBox);
        showSearch->setObjectName(QString::fromUtf8("showSearch"));

        verticalLayout->addWidget(showSearch);

        label_3 = new QLabel(settingsGroupBox);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        verticalLayout->addWidget(label_3);

        minimumActivitySelector = new QComboBox(settingsGroupBox);
        minimumActivitySelector->addItem(QString());
        minimumActivitySelector->addItem(QString());
        minimumActivitySelector->addItem(QString());
        minimumActivitySelector->addItem(QString());
        minimumActivitySelector->setObjectName(QString::fromUtf8("minimumActivitySelector"));

        verticalLayout->addWidget(minimumActivitySelector);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem);


        hboxLayout->addWidget(settingsGroupBox);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        label_2 = new QLabel(BufferViewSettingsPage);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        vboxLayout1->addWidget(label_2);

        bufferViewPreview = new PreviewBufferView(BufferViewSettingsPage);
        bufferViewPreview->setObjectName(QString::fromUtf8("bufferViewPreview"));
        bufferViewPreview->setHeaderHidden(true);

        vboxLayout1->addWidget(bufferViewPreview);


        hboxLayout->addLayout(vboxLayout1);

        QWidget::setTabOrder(bufferViewList, renameBufferView);
        QWidget::setTabOrder(renameBufferView, addBufferView);
        QWidget::setTabOrder(addBufferView, deleteBufferView);
        QWidget::setTabOrder(deleteBufferView, networkSelector);
        QWidget::setTabOrder(networkSelector, onlyStatusBuffers);
        QWidget::setTabOrder(onlyStatusBuffers, onlyChannelBuffers);
        QWidget::setTabOrder(onlyChannelBuffers, onlyQueryBuffers);
        QWidget::setTabOrder(onlyQueryBuffers, hideInactiveBuffers);
        QWidget::setTabOrder(hideInactiveBuffers, addNewBuffersAutomatically);
        QWidget::setTabOrder(addNewBuffersAutomatically, sortAlphabetically);
        QWidget::setTabOrder(sortAlphabetically, minimumActivitySelector);
        QWidget::setTabOrder(minimumActivitySelector, bufferViewPreview);

        retranslateUi(BufferViewSettingsPage);

        QMetaObject::connectSlotsByName(BufferViewSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *BufferViewSettingsPage)
    {
        BufferViewSettingsPage->setWindowTitle(QCoreApplication::translate("BufferViewSettingsPage", "Form", nullptr));
        renameBufferView->setText(QCoreApplication::translate("BufferViewSettingsPage", "Re&name...", nullptr));
        addBufferView->setText(QCoreApplication::translate("BufferViewSettingsPage", "&Add...", nullptr));
        deleteBufferView->setText(QCoreApplication::translate("BufferViewSettingsPage", "De&lete", nullptr));
        settingsGroupBox->setTitle(QCoreApplication::translate("BufferViewSettingsPage", "Chat List Settings", nullptr));
        label->setText(QCoreApplication::translate("BufferViewSettingsPage", "Network:", nullptr));
        networkSelector->setItemText(0, QCoreApplication::translate("BufferViewSettingsPage", "All", nullptr));

#if QT_CONFIG(tooltip)
        onlyStatusBuffers->setToolTip(QCoreApplication::translate("BufferViewSettingsPage", "This option is not available when all Networks are visible.\n"
"In this mode no separate status buffer is displayed.", nullptr));
#endif // QT_CONFIG(tooltip)
        onlyStatusBuffers->setText(QCoreApplication::translate("BufferViewSettingsPage", "Show status window", nullptr));
        onlyChannelBuffers->setText(QCoreApplication::translate("BufferViewSettingsPage", "Show channels", nullptr));
        onlyQueryBuffers->setText(QCoreApplication::translate("BufferViewSettingsPage", "Show queries", nullptr));
        hideInactiveBuffers->setText(QCoreApplication::translate("BufferViewSettingsPage", "Hide inactive chats", nullptr));
        hideInactiveNetworks->setText(QCoreApplication::translate("BufferViewSettingsPage", "Hide inactive networks", nullptr));
        addNewBuffersAutomatically->setText(QCoreApplication::translate("BufferViewSettingsPage", "Add new chats automatically", nullptr));
        sortAlphabetically->setText(QCoreApplication::translate("BufferViewSettingsPage", "Sort alphabetically", nullptr));
        showSearch->setText(QCoreApplication::translate("BufferViewSettingsPage", "Show search", nullptr));
        label_3->setText(QCoreApplication::translate("BufferViewSettingsPage", "Minimum Activity:", nullptr));
        minimumActivitySelector->setItemText(0, QCoreApplication::translate("BufferViewSettingsPage", "No Activity", nullptr));
        minimumActivitySelector->setItemText(1, QCoreApplication::translate("BufferViewSettingsPage", "Other Activity", nullptr));
        minimumActivitySelector->setItemText(2, QCoreApplication::translate("BufferViewSettingsPage", "New Message", nullptr));
        minimumActivitySelector->setItemText(3, QCoreApplication::translate("BufferViewSettingsPage", "Highlight", nullptr));

        label_2->setText(QCoreApplication::translate("BufferViewSettingsPage", "Preview:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BufferViewSettingsPage: public Ui_BufferViewSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BUFFERVIEWSETTINGSPAGE_H
