/****************************************************************************
** Meta object code from reading C++ file 'remotepeer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/remotepeer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'remotepeer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RemotePeer_t {
    QByteArrayData data[26];
    char stringdata0[333];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RemotePeer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RemotePeer_t qt_meta_stringdata_RemotePeer = {
    {
QT_MOC_LITERAL(0, 0, 10), // "RemotePeer"
QT_MOC_LITERAL(1, 11, 16), // "transferProgress"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 7), // "current"
QT_MOC_LITERAL(4, 37, 3), // "max"
QT_MOC_LITERAL(5, 41, 11), // "socketError"
QT_MOC_LITERAL(6, 53, 28), // "QAbstractSocket::SocketError"
QT_MOC_LITERAL(7, 82, 5), // "error"
QT_MOC_LITERAL(8, 88, 11), // "errorString"
QT_MOC_LITERAL(9, 100, 13), // "statusMessage"
QT_MOC_LITERAL(10, 114, 3), // "msg"
QT_MOC_LITERAL(11, 118, 23), // "protocolVersionMismatch"
QT_MOC_LITERAL(12, 142, 6), // "actual"
QT_MOC_LITERAL(13, 149, 8), // "expected"
QT_MOC_LITERAL(14, 158, 5), // "close"
QT_MOC_LITERAL(15, 164, 6), // "reason"
QT_MOC_LITERAL(16, 171, 20), // "onSocketStateChanged"
QT_MOC_LITERAL(17, 192, 28), // "QAbstractSocket::SocketState"
QT_MOC_LITERAL(18, 221, 5), // "state"
QT_MOC_LITERAL(19, 227, 13), // "onSocketError"
QT_MOC_LITERAL(20, 241, 11), // "onReadyRead"
QT_MOC_LITERAL(21, 253, 18), // "onCompressionError"
QT_MOC_LITERAL(22, 272, 17), // "Compressor::Error"
QT_MOC_LITERAL(23, 290, 13), // "sendHeartBeat"
QT_MOC_LITERAL(24, 304, 23), // "changeHeartBeatInterval"
QT_MOC_LITERAL(25, 328, 4) // "secs"

    },
    "RemotePeer\0transferProgress\0\0current\0"
    "max\0socketError\0QAbstractSocket::SocketError\0"
    "error\0errorString\0statusMessage\0msg\0"
    "protocolVersionMismatch\0actual\0expected\0"
    "close\0reason\0onSocketStateChanged\0"
    "QAbstractSocket::SocketState\0state\0"
    "onSocketError\0onReadyRead\0onCompressionError\0"
    "Compressor::Error\0sendHeartBeat\0"
    "changeHeartBeatInterval\0secs"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RemotePeer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   74,    2, 0x06 /* Public */,
       5,    2,   79,    2, 0x06 /* Public */,
       9,    1,   84,    2, 0x06 /* Public */,
      11,    2,   87,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    1,   92,    2, 0x0a /* Public */,
      14,    0,   95,    2, 0x2a /* Public | MethodCloned */,
      16,    1,   96,    2, 0x09 /* Protected */,
      19,    1,   99,    2, 0x09 /* Protected */,
      20,    0,  102,    2, 0x08 /* Private */,
      21,    1,  103,    2, 0x08 /* Private */,
      23,    0,  106,    2, 0x08 /* Private */,
      24,    1,  107,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,    4,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString,    7,    8,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   12,   13,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 22,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   25,

       0        // eod
};

void RemotePeer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<RemotePeer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->transferProgress((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->socketError((*reinterpret_cast< QAbstractSocket::SocketError(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->statusMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->protocolVersionMismatch((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->close((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->close(); break;
        case 6: _t->onSocketStateChanged((*reinterpret_cast< QAbstractSocket::SocketState(*)>(_a[1]))); break;
        case 7: _t->onSocketError((*reinterpret_cast< QAbstractSocket::SocketError(*)>(_a[1]))); break;
        case 8: _t->onReadyRead(); break;
        case 9: _t->onCompressionError((*reinterpret_cast< Compressor::Error(*)>(_a[1]))); break;
        case 10: _t->sendHeartBeat(); break;
        case 11: _t->changeHeartBeatInterval((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketState >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (RemotePeer::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RemotePeer::transferProgress)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (RemotePeer::*)(QAbstractSocket::SocketError , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RemotePeer::socketError)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (RemotePeer::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RemotePeer::statusMessage)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (RemotePeer::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RemotePeer::protocolVersionMismatch)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject RemotePeer::staticMetaObject = { {
    QMetaObject::SuperData::link<Peer::staticMetaObject>(),
    qt_meta_stringdata_RemotePeer.data,
    qt_meta_data_RemotePeer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RemotePeer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RemotePeer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RemotePeer.stringdata0))
        return static_cast<void*>(this);
    return Peer::qt_metacast(_clname);
}

int RemotePeer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Peer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void RemotePeer::transferProgress(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void RemotePeer::socketError(QAbstractSocket::SocketError _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void RemotePeer::statusMessage(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void RemotePeer::protocolVersionMismatch(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
