/********************************************************************************
** Form generated from reading UI file 'sslinfodlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SSLINFODLG_H
#define UI_SSLINFODLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SslInfoDlg
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *hostname;
    QLabel *label_2;
    QLabel *address;
    QLabel *label_3;
    QLabel *encryption;
    QLabel *label_5;
    QLabel *protocol;
    QLabel *label_6;
    QComboBox *certificateChain;
    QTabWidget *tabWidget;
    QWidget *subjectTab;
    QGridLayout *gridLayout_2;
    QLabel *label_7;
    QLabel *subjectCommonName;
    QLabel *label_8;
    QLabel *subjectOrganization;
    QLabel *label_9;
    QLabel *subjectOrganizationalUnit;
    QLabel *label_10;
    QLabel *subjectCountry;
    QLabel *label_11;
    QLabel *subjectState;
    QSpacerItem *horizontalSpacer;
    QLabel *subjectCity;
    QLabel *label_12;
    QWidget *issuerTab;
    QGridLayout *gridLayout_3;
    QLabel *label_17;
    QLabel *issuerCommonName;
    QLabel *label_18;
    QLabel *issuerOrganization;
    QLabel *label_13;
    QLabel *issuerOrganizationalUnit;
    QLabel *label_15;
    QLabel *issuerCountry;
    QLabel *label_16;
    QLabel *issuerState;
    QSpacerItem *horizontalSpacer_3;
    QLabel *issuerCity;
    QLabel *label_14;
    QLabel *label_20;
    QLabel *validity;
    QLabel *label_22;
    QLabel *md5Digest;
    QLabel *label_23;
    QLabel *sha1Digest;
    QLabel *sha256Label;
    QLabel *sha256Digest;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_19;
    QLabel *trusted;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SslInfoDlg)
    {
        if (SslInfoDlg->objectName().isEmpty())
            SslInfoDlg->setObjectName(QString::fromUtf8("SslInfoDlg"));
        SslInfoDlg->resize(555, 449);
        verticalLayout = new QVBoxLayout(SslInfoDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(SslInfoDlg);
        label->setObjectName(QString::fromUtf8("label"));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        hostname = new QLabel(SslInfoDlg);
        hostname->setObjectName(QString::fromUtf8("hostname"));
        hostname->setText(QString::fromUtf8("n/a"));

        gridLayout->addWidget(hostname, 0, 1, 1, 1);

        label_2 = new QLabel(SslInfoDlg);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        address = new QLabel(SslInfoDlg);
        address->setObjectName(QString::fromUtf8("address"));
        address->setText(QString::fromUtf8("n/a"));

        gridLayout->addWidget(address, 1, 1, 1, 1);

        label_3 = new QLabel(SslInfoDlg);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        encryption = new QLabel(SslInfoDlg);
        encryption->setObjectName(QString::fromUtf8("encryption"));
        encryption->setText(QString::fromUtf8("n/a"));

        gridLayout->addWidget(encryption, 2, 1, 1, 1);

        label_5 = new QLabel(SslInfoDlg);
        label_5->setObjectName(QString::fromUtf8("label_5"));
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_5, 3, 0, 1, 1);

        protocol = new QLabel(SslInfoDlg);
        protocol->setObjectName(QString::fromUtf8("protocol"));
        protocol->setText(QString::fromUtf8("n/a"));

        gridLayout->addWidget(protocol, 3, 1, 1, 1);

        label_6 = new QLabel(SslInfoDlg);
        label_6->setObjectName(QString::fromUtf8("label_6"));
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_6, 4, 0, 1, 1);

        certificateChain = new QComboBox(SslInfoDlg);
        certificateChain->setObjectName(QString::fromUtf8("certificateChain"));
        QSizePolicy sizePolicy(QSizePolicy::Maximum, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(certificateChain->sizePolicy().hasHeightForWidth());
        certificateChain->setSizePolicy(sizePolicy);

        gridLayout->addWidget(certificateChain, 4, 1, 1, 1);

        tabWidget = new QTabWidget(SslInfoDlg);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy1);
        subjectTab = new QWidget();
        subjectTab->setObjectName(QString::fromUtf8("subjectTab"));
        gridLayout_2 = new QGridLayout(subjectTab);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        label_7 = new QLabel(subjectTab);
        label_7->setObjectName(QString::fromUtf8("label_7"));
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_7, 0, 0, 1, 1);

        subjectCommonName = new QLabel(subjectTab);
        subjectCommonName->setObjectName(QString::fromUtf8("subjectCommonName"));
        subjectCommonName->setText(QString::fromUtf8("Common Name"));

        gridLayout_2->addWidget(subjectCommonName, 0, 1, 1, 1);

        label_8 = new QLabel(subjectTab);
        label_8->setObjectName(QString::fromUtf8("label_8"));
        label_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_8, 1, 0, 1, 1);

        subjectOrganization = new QLabel(subjectTab);
        subjectOrganization->setObjectName(QString::fromUtf8("subjectOrganization"));
        subjectOrganization->setText(QString::fromUtf8("Organization"));

        gridLayout_2->addWidget(subjectOrganization, 1, 1, 1, 1);

        label_9 = new QLabel(subjectTab);
        label_9->setObjectName(QString::fromUtf8("label_9"));
        label_9->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_9, 2, 0, 1, 1);

        subjectOrganizationalUnit = new QLabel(subjectTab);
        subjectOrganizationalUnit->setObjectName(QString::fromUtf8("subjectOrganizationalUnit"));
        subjectOrganizationalUnit->setText(QString::fromUtf8("Organizational Unit"));

        gridLayout_2->addWidget(subjectOrganizationalUnit, 2, 1, 1, 1);

        label_10 = new QLabel(subjectTab);
        label_10->setObjectName(QString::fromUtf8("label_10"));
        label_10->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_10, 5, 0, 1, 1);

        subjectCountry = new QLabel(subjectTab);
        subjectCountry->setObjectName(QString::fromUtf8("subjectCountry"));
        subjectCountry->setText(QString::fromUtf8("Country"));

        gridLayout_2->addWidget(subjectCountry, 5, 1, 1, 1);

        label_11 = new QLabel(subjectTab);
        label_11->setObjectName(QString::fromUtf8("label_11"));
        label_11->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_11, 6, 0, 1, 1);

        subjectState = new QLabel(subjectTab);
        subjectState->setObjectName(QString::fromUtf8("subjectState"));
        subjectState->setText(QString::fromUtf8("State"));

        gridLayout_2->addWidget(subjectState, 6, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 5, 2, 1, 1);

        subjectCity = new QLabel(subjectTab);
        subjectCity->setObjectName(QString::fromUtf8("subjectCity"));
        subjectCity->setText(QString::fromUtf8("City"));

        gridLayout_2->addWidget(subjectCity, 4, 1, 1, 1);

        label_12 = new QLabel(subjectTab);
        label_12->setObjectName(QString::fromUtf8("label_12"));
        label_12->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_12, 4, 0, 1, 1);

        tabWidget->addTab(subjectTab, QString());
        issuerTab = new QWidget();
        issuerTab->setObjectName(QString::fromUtf8("issuerTab"));
        gridLayout_3 = new QGridLayout(issuerTab);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        label_17 = new QLabel(issuerTab);
        label_17->setObjectName(QString::fromUtf8("label_17"));
        label_17->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_17, 0, 0, 1, 1);

        issuerCommonName = new QLabel(issuerTab);
        issuerCommonName->setObjectName(QString::fromUtf8("issuerCommonName"));
        issuerCommonName->setText(QString::fromUtf8("Common Name"));

        gridLayout_3->addWidget(issuerCommonName, 0, 1, 1, 1);

        label_18 = new QLabel(issuerTab);
        label_18->setObjectName(QString::fromUtf8("label_18"));
        label_18->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_18, 1, 0, 1, 1);

        issuerOrganization = new QLabel(issuerTab);
        issuerOrganization->setObjectName(QString::fromUtf8("issuerOrganization"));
        issuerOrganization->setText(QString::fromUtf8("Organization"));

        gridLayout_3->addWidget(issuerOrganization, 1, 1, 1, 1);

        label_13 = new QLabel(issuerTab);
        label_13->setObjectName(QString::fromUtf8("label_13"));
        label_13->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_13, 2, 0, 1, 1);

        issuerOrganizationalUnit = new QLabel(issuerTab);
        issuerOrganizationalUnit->setObjectName(QString::fromUtf8("issuerOrganizationalUnit"));
        issuerOrganizationalUnit->setText(QString::fromUtf8("Organizational Unit"));

        gridLayout_3->addWidget(issuerOrganizationalUnit, 2, 1, 1, 1);

        label_15 = new QLabel(issuerTab);
        label_15->setObjectName(QString::fromUtf8("label_15"));
        label_15->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_15, 5, 0, 1, 1);

        issuerCountry = new QLabel(issuerTab);
        issuerCountry->setObjectName(QString::fromUtf8("issuerCountry"));
        issuerCountry->setText(QString::fromUtf8("Country"));

        gridLayout_3->addWidget(issuerCountry, 5, 1, 1, 1);

        label_16 = new QLabel(issuerTab);
        label_16->setObjectName(QString::fromUtf8("label_16"));
        label_16->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_16, 6, 0, 1, 1);

        issuerState = new QLabel(issuerTab);
        issuerState->setObjectName(QString::fromUtf8("issuerState"));
        issuerState->setText(QString::fromUtf8("State"));

        gridLayout_3->addWidget(issuerState, 6, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_3, 5, 2, 1, 1);

        issuerCity = new QLabel(issuerTab);
        issuerCity->setObjectName(QString::fromUtf8("issuerCity"));
        issuerCity->setText(QString::fromUtf8("City"));

        gridLayout_3->addWidget(issuerCity, 4, 1, 1, 1);

        label_14 = new QLabel(issuerTab);
        label_14->setObjectName(QString::fromUtf8("label_14"));
        label_14->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_14, 4, 0, 1, 1);

        tabWidget->addTab(issuerTab, QString());

        gridLayout->addWidget(tabWidget, 5, 0, 1, 4);

        label_20 = new QLabel(SslInfoDlg);
        label_20->setObjectName(QString::fromUtf8("label_20"));
        label_20->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_20, 7, 0, 1, 1);

        validity = new QLabel(SslInfoDlg);
        validity->setObjectName(QString::fromUtf8("validity"));
        validity->setText(QString::fromUtf8("n/a"));

        gridLayout->addWidget(validity, 7, 1, 1, 1);

        label_22 = new QLabel(SslInfoDlg);
        label_22->setObjectName(QString::fromUtf8("label_22"));
        label_22->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_22, 8, 0, 1, 1);

        md5Digest = new QLabel(SslInfoDlg);
        md5Digest->setObjectName(QString::fromUtf8("md5Digest"));
        md5Digest->setText(QString::fromUtf8("n/a"));

        gridLayout->addWidget(md5Digest, 8, 1, 1, 1);

        label_23 = new QLabel(SslInfoDlg);
        label_23->setObjectName(QString::fromUtf8("label_23"));
        label_23->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_23, 9, 0, 1, 1);

        sha1Digest = new QLabel(SslInfoDlg);
        sha1Digest->setObjectName(QString::fromUtf8("sha1Digest"));
        sha1Digest->setText(QString::fromUtf8("n/a"));

        gridLayout->addWidget(sha1Digest, 9, 1, 1, 1);

        sha256Label = new QLabel(SslInfoDlg);
        sha256Label->setObjectName(QString::fromUtf8("sha256Label"));
        sha256Label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(sha256Label, 10, 0, 1, 1);

        sha256Digest = new QLabel(SslInfoDlg);
        sha256Digest->setObjectName(QString::fromUtf8("sha256Digest"));
        sha256Digest->setText(QString::fromUtf8("n/a"));

        gridLayout->addWidget(sha256Digest, 10, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 4, 2, 1, 2);

        label_19 = new QLabel(SslInfoDlg);
        label_19->setObjectName(QString::fromUtf8("label_19"));
        label_19->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        gridLayout->addWidget(label_19, 11, 0, 1, 1);

        trusted = new QLabel(SslInfoDlg);
        trusted->setObjectName(QString::fromUtf8("trusted"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(trusted->sizePolicy().hasHeightForWidth());
        trusted->setSizePolicy(sizePolicy2);
        trusted->setText(QString::fromUtf8("n/a"));
        trusted->setWordWrap(false);

        gridLayout->addWidget(trusted, 11, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(SslInfoDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(certificateChain, tabWidget);
        QWidget::setTabOrder(tabWidget, buttonBox);

        retranslateUi(SslInfoDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), SslInfoDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), SslInfoDlg, SLOT(reject()));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SslInfoDlg);
    } // setupUi

    void retranslateUi(QDialog *SslInfoDlg)
    {
        SslInfoDlg->setWindowTitle(QCoreApplication::translate("SslInfoDlg", "Security Information", nullptr));
        label->setText(QCoreApplication::translate("SslInfoDlg", "<b>Hostname:</b>", nullptr));
        label_2->setText(QCoreApplication::translate("SslInfoDlg", "<b>IP address:</b>", nullptr));
        label_3->setText(QCoreApplication::translate("SslInfoDlg", "<b>Encryption:</b>", nullptr));
        label_5->setText(QCoreApplication::translate("SslInfoDlg", "<b>Protocol:</b>", nullptr));
        label_6->setText(QCoreApplication::translate("SslInfoDlg", "<b>Certificate chain:</b>", nullptr));
        label_7->setText(QCoreApplication::translate("SslInfoDlg", "<b>Common name:</b>", nullptr));
        label_8->setText(QCoreApplication::translate("SslInfoDlg", "<b>Organization:</b>", nullptr));
        label_9->setText(QCoreApplication::translate("SslInfoDlg", "<b>Organizational unit:</b>", nullptr));
        label_10->setText(QCoreApplication::translate("SslInfoDlg", "<b>Country:</b>", nullptr));
        label_11->setText(QCoreApplication::translate("SslInfoDlg", "<b>State or province:</b>", nullptr));
        label_12->setText(QCoreApplication::translate("SslInfoDlg", "<b>Locality:</b>", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(subjectTab), QCoreApplication::translate("SslInfoDlg", "Subject", nullptr));
        label_17->setText(QCoreApplication::translate("SslInfoDlg", "<b>Common name:</b>", nullptr));
        label_18->setText(QCoreApplication::translate("SslInfoDlg", "<b>Organization:</b>", nullptr));
        label_13->setText(QCoreApplication::translate("SslInfoDlg", "<b>Organizational unit:</b>", nullptr));
        label_15->setText(QCoreApplication::translate("SslInfoDlg", "<b>Country:</b>", nullptr));
        label_16->setText(QCoreApplication::translate("SslInfoDlg", "<b>State or province:</b>", nullptr));
        label_14->setText(QCoreApplication::translate("SslInfoDlg", "<b>Locality:</b>", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(issuerTab), QCoreApplication::translate("SslInfoDlg", "Issuer", nullptr));
        label_20->setText(QCoreApplication::translate("SslInfoDlg", "<b>Validity period:</b>", nullptr));
        label_22->setText(QCoreApplication::translate("SslInfoDlg", "<b>MD5 digest:</b>", nullptr));
        label_23->setText(QCoreApplication::translate("SslInfoDlg", "<b>SHA1 digest:</b>", nullptr));
        sha256Label->setText(QCoreApplication::translate("SslInfoDlg", "<b>SHA256 digest:</b>", nullptr));
        label_19->setText(QCoreApplication::translate("SslInfoDlg", "<b>Trusted:</b>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SslInfoDlg: public Ui_SslInfoDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SSLINFODLG_H
