/****************************************************************************
** Meta object code from reading C++ file 'toolbaractionprovider.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/uisupport/toolbaractionprovider.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'toolbaractionprovider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ToolBarActionProvider_t {
    QByteArrayData data[16];
    char stringdata0[231];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ToolBarActionProvider_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ToolBarActionProvider_t qt_meta_stringdata_ToolBarActionProvider = {
    {
QT_MOC_LITERAL(0, 0, 21), // "ToolBarActionProvider"
QT_MOC_LITERAL(1, 22, 20), // "disconnectedFromCore"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 22), // "onCurrentBufferChanged"
QT_MOC_LITERAL(4, 67, 11), // "QModelIndex"
QT_MOC_LITERAL(5, 79, 22), // "onNickSelectionChanged"
QT_MOC_LITERAL(6, 102, 15), // "QModelIndexList"
QT_MOC_LITERAL(7, 118, 14), // "networkCreated"
QT_MOC_LITERAL(8, 133, 9), // "NetworkId"
QT_MOC_LITERAL(9, 143, 2), // "id"
QT_MOC_LITERAL(10, 146, 14), // "networkRemoved"
QT_MOC_LITERAL(11, 161, 14), // "networkUpdated"
QT_MOC_LITERAL(12, 176, 14), // "const Network*"
QT_MOC_LITERAL(13, 191, 3), // "net"
QT_MOC_LITERAL(14, 195, 22), // "connectOrDisconnectNet"
QT_MOC_LITERAL(15, 218, 12) // "updateStates"

    },
    "ToolBarActionProvider\0disconnectedFromCore\0"
    "\0onCurrentBufferChanged\0QModelIndex\0"
    "onNickSelectionChanged\0QModelIndexList\0"
    "networkCreated\0NetworkId\0id\0networkRemoved\0"
    "networkUpdated\0const Network*\0net\0"
    "connectOrDisconnectNet\0updateStates"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ToolBarActionProvider[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x0a /* Public */,
       3,    1,   60,    2, 0x0a /* Public */,
       5,    1,   63,    2, 0x0a /* Public */,
       7,    1,   66,    2, 0x08 /* Private */,
      10,    1,   69,    2, 0x08 /* Private */,
      11,    1,   72,    2, 0x08 /* Private */,
      11,    0,   75,    2, 0x28 /* Private | MethodCloned */,
      14,    0,   76,    2, 0x08 /* Private */,
      15,    0,   77,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ToolBarActionProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ToolBarActionProvider *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->disconnectedFromCore(); break;
        case 1: _t->onCurrentBufferChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 2: _t->onNickSelectionChanged((*reinterpret_cast< const QModelIndexList(*)>(_a[1]))); break;
        case 3: _t->networkCreated((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 4: _t->networkRemoved((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 5: _t->networkUpdated((*reinterpret_cast< const Network*(*)>(_a[1]))); break;
        case 6: _t->networkUpdated(); break;
        case 7: _t->connectOrDisconnectNet(); break;
        case 8: _t->updateStates(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QModelIndexList >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ToolBarActionProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<NetworkModelController::staticMetaObject>(),
    qt_meta_stringdata_ToolBarActionProvider.data,
    qt_meta_data_ToolBarActionProvider,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ToolBarActionProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ToolBarActionProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ToolBarActionProvider.stringdata0))
        return static_cast<void*>(this);
    return NetworkModelController::qt_metacast(_clname);
}

int ToolBarActionProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetworkModelController::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
