/****************************************************************************
** Meta object code from reading C++ file 'bufferwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/bufferwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bufferwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BufferWidget_t {
    QByteArrayData data[23];
    char stringdata0[307];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferWidget_t qt_meta_stringdata_BufferWidget = {
    {
QT_MOC_LITERAL(0, 0, 12), // "BufferWidget"
QT_MOC_LITERAL(1, 13, 13), // "setMarkerLine"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 9), // "ChatView*"
QT_MOC_LITERAL(4, 38, 4), // "view"
QT_MOC_LITERAL(5, 43, 14), // "allowGoingBack"
QT_MOC_LITERAL(6, 58, 16), // "jumpToMarkerLine"
QT_MOC_LITERAL(7, 75, 14), // "requestBacklog"
QT_MOC_LITERAL(8, 90, 14), // "currentChanged"
QT_MOC_LITERAL(9, 105, 11), // "QModelIndex"
QT_MOC_LITERAL(10, 117, 7), // "current"
QT_MOC_LITERAL(11, 125, 8), // "previous"
QT_MOC_LITERAL(12, 134, 12), // "showChatView"
QT_MOC_LITERAL(13, 147, 8), // "BufferId"
QT_MOC_LITERAL(14, 156, 17), // "scrollToHighlight"
QT_MOC_LITERAL(15, 174, 14), // "QGraphicsItem*"
QT_MOC_LITERAL(16, 189, 13), // "highlightItem"
QT_MOC_LITERAL(17, 203, 6), // "zoomIn"
QT_MOC_LITERAL(18, 210, 7), // "zoomOut"
QT_MOC_LITERAL(19, 218, 12), // "zoomOriginal"
QT_MOC_LITERAL(20, 231, 17), // "setAutoMarkerLine"
QT_MOC_LITERAL(21, 249, 28), // "setAutoMarkerLineOnLostFocus"
QT_MOC_LITERAL(22, 278, 28) // "setEnsureBacklogOnBufferShow"

    },
    "BufferWidget\0setMarkerLine\0\0ChatView*\0"
    "view\0allowGoingBack\0jumpToMarkerLine\0"
    "requestBacklog\0currentChanged\0QModelIndex\0"
    "current\0previous\0showChatView\0BufferId\0"
    "scrollToHighlight\0QGraphicsItem*\0"
    "highlightItem\0zoomIn\0zoomOut\0zoomOriginal\0"
    "setAutoMarkerLine\0setAutoMarkerLineOnLostFocus\0"
    "setEnsureBacklogOnBufferShow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   89,    2, 0x0a /* Public */,
       1,    1,   94,    2, 0x2a /* Public | MethodCloned */,
       1,    0,   97,    2, 0x2a /* Public | MethodCloned */,
       6,    2,   98,    2, 0x0a /* Public */,
       6,    1,  103,    2, 0x2a /* Public | MethodCloned */,
       6,    0,  106,    2, 0x2a /* Public | MethodCloned */,
       8,    2,  107,    2, 0x09 /* Protected */,
      12,    1,  112,    2, 0x09 /* Protected */,
      14,    1,  115,    2, 0x08 /* Private */,
      17,    0,  118,    2, 0x08 /* Private */,
      18,    0,  119,    2, 0x08 /* Private */,
      19,    0,  120,    2, 0x08 /* Private */,
      20,    1,  121,    2, 0x08 /* Private */,
      21,    1,  124,    2, 0x08 /* Private */,
      22,    1,  127,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,    4,    5,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,    4,    7,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9, 0x80000000 | 9,   10,   11,
    QMetaType::Void, 0x80000000 | 13,    2,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,

       0        // eod
};

void BufferWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setMarkerLine((*reinterpret_cast< ChatView*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 1: _t->setMarkerLine((*reinterpret_cast< ChatView*(*)>(_a[1]))); break;
        case 2: _t->setMarkerLine(); break;
        case 3: _t->jumpToMarkerLine((*reinterpret_cast< ChatView*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 4: _t->jumpToMarkerLine((*reinterpret_cast< ChatView*(*)>(_a[1]))); break;
        case 5: _t->jumpToMarkerLine(); break;
        case 6: _t->currentChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 7: _t->showChatView((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 8: _t->scrollToHighlight((*reinterpret_cast< QGraphicsItem*(*)>(_a[1]))); break;
        case 9: _t->zoomIn(); break;
        case 10: _t->zoomOut(); break;
        case 11: _t->zoomOriginal(); break;
        case 12: _t->setAutoMarkerLine((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 13: _t->setAutoMarkerLineOnLostFocus((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 14: _t->setEnsureBacklogOnBufferShow((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BufferWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractBufferContainer::staticMetaObject>(),
    qt_meta_stringdata_BufferWidget.data,
    qt_meta_data_BufferWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferWidget.stringdata0))
        return static_cast<void*>(this);
    return AbstractBufferContainer::qt_metacast(_clname);
}

int BufferWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractBufferContainer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
