/********************************************************************************
** Form generated from reading UI file 'bufferwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BUFFERWIDGET_H
#define UI_BUFFERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <chatviewsearchbar.h>
#include "mainpage.h"

QT_BEGIN_NAMESPACE

class Ui_BufferWidget
{
public:
    QVBoxLayout *verticalLayout;
    QStackedWidget *stackedWidget;
    MainPage *page;
    ChatViewSearchBar *searchBar;

    void setupUi(QWidget *BufferWidget)
    {
        if (BufferWidget->objectName().isEmpty())
            BufferWidget->setObjectName(QString::fromUtf8("BufferWidget"));
        BufferWidget->resize(599, 478);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(5);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(BufferWidget->sizePolicy().hasHeightForWidth());
        BufferWidget->setSizePolicy(sizePolicy);
        BufferWidget->setMinimumSize(QSize(200, 100));
        BufferWidget->setContextMenuPolicy(Qt::DefaultContextMenu);
        verticalLayout = new QVBoxLayout(BufferWidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        stackedWidget = new QStackedWidget(BufferWidget);
        stackedWidget->setObjectName(QString::fromUtf8("stackedWidget"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(stackedWidget->sizePolicy().hasHeightForWidth());
        stackedWidget->setSizePolicy(sizePolicy1);
        page = new MainPage();
        page->setObjectName(QString::fromUtf8("page"));
        stackedWidget->addWidget(page);

        verticalLayout->addWidget(stackedWidget);

        searchBar = new ChatViewSearchBar(BufferWidget);
        searchBar->setObjectName(QString::fromUtf8("searchBar"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(searchBar->sizePolicy().hasHeightForWidth());
        searchBar->setSizePolicy(sizePolicy2);

        verticalLayout->addWidget(searchBar);


        retranslateUi(BufferWidget);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(BufferWidget);
    } // setupUi

    void retranslateUi(QWidget *BufferWidget)
    {
        BufferWidget->setWindowTitle(QString());
    } // retranslateUi

};

namespace Ui {
    class BufferWidget: public Ui_BufferWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BUFFERWIDGET_H
