/****************************************************************************
** Meta object code from reading C++ file 'chatmonitorfilter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/chatmonitorfilter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'chatmonitorfilter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ChatMonitorFilter_t {
    QByteArrayData data[17];
    char stringdata0[330];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChatMonitorFilter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChatMonitorFilter_t qt_meta_stringdata_ChatMonitorFilter = {
    {
QT_MOC_LITERAL(0, 0, 17), // "ChatMonitorFilter"
QT_MOC_LITERAL(1, 18, 12), // "addShowField"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 5), // "field"
QT_MOC_LITERAL(4, 38, 15), // "removeShowField"
QT_MOC_LITERAL(5, 54, 18), // "setShowOwnMessages"
QT_MOC_LITERAL(6, 73, 4), // "show"
QT_MOC_LITERAL(7, 78, 24), // "showFieldsSettingChanged"
QT_MOC_LITERAL(8, 103, 8), // "newValue"
QT_MOC_LITERAL(9, 112, 29), // "showOwnMessagesSettingChanged"
QT_MOC_LITERAL(10, 142, 23), // "alwaysOwnSettingChanged"
QT_MOC_LITERAL(11, 166, 28), // "showHighlightsSettingChanged"
QT_MOC_LITERAL(12, 195, 27), // "operationModeSettingChanged"
QT_MOC_LITERAL(13, 223, 21), // "buffersSettingChanged"
QT_MOC_LITERAL(14, 245, 25), // "showBacklogSettingChanged"
QT_MOC_LITERAL(15, 271, 25), // "includeReadSettingChanged"
QT_MOC_LITERAL(16, 297, 32) // "showSenderBracketsSettingChanged"

    },
    "ChatMonitorFilter\0addShowField\0\0field\0"
    "removeShowField\0setShowOwnMessages\0"
    "show\0showFieldsSettingChanged\0newValue\0"
    "showOwnMessagesSettingChanged\0"
    "alwaysOwnSettingChanged\0"
    "showHighlightsSettingChanged\0"
    "operationModeSettingChanged\0"
    "buffersSettingChanged\0showBacklogSettingChanged\0"
    "includeReadSettingChanged\0"
    "showSenderBracketsSettingChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChatMonitorFilter[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x0a /* Public */,
       4,    1,   77,    2, 0x0a /* Public */,
       5,    1,   80,    2, 0x0a /* Public */,
       7,    1,   83,    2, 0x08 /* Private */,
       9,    1,   86,    2, 0x08 /* Private */,
      10,    1,   89,    2, 0x08 /* Private */,
      11,    1,   92,    2, 0x08 /* Private */,
      12,    1,   95,    2, 0x08 /* Private */,
      13,    1,   98,    2, 0x08 /* Private */,
      14,    1,  101,    2, 0x08 /* Private */,
      15,    1,  104,    2, 0x08 /* Private */,
      16,    1,  107,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, QMetaType::QVariant,    8,
    QMetaType::Void, QMetaType::QVariant,    8,
    QMetaType::Void, QMetaType::QVariant,    8,
    QMetaType::Void, QMetaType::QVariant,    8,
    QMetaType::Void, QMetaType::QVariant,    8,
    QMetaType::Void, QMetaType::QVariant,    8,
    QMetaType::Void, QMetaType::QVariant,    8,
    QMetaType::Void, QMetaType::QVariant,    8,
    QMetaType::Void, QMetaType::QVariant,    8,

       0        // eod
};

void ChatMonitorFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ChatMonitorFilter *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->addShowField((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->removeShowField((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->setShowOwnMessages((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->showFieldsSettingChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 4: _t->showOwnMessagesSettingChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 5: _t->alwaysOwnSettingChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 6: _t->showHighlightsSettingChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 7: _t->operationModeSettingChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 8: _t->buffersSettingChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 9: _t->showBacklogSettingChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 10: _t->includeReadSettingChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 11: _t->showSenderBracketsSettingChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ChatMonitorFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<MessageFilter::staticMetaObject>(),
    qt_meta_stringdata_ChatMonitorFilter.data,
    qt_meta_data_ChatMonitorFilter,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ChatMonitorFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChatMonitorFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ChatMonitorFilter.stringdata0))
        return static_cast<void*>(this);
    return MessageFilter::qt_metacast(_clname);
}

int ChatMonitorFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MessageFilter::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
