/****************************************************************************
** Meta object code from reading C++ file 'client.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/client/client.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'client.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Client_t {
    QByteArrayData data[75];
    char stringdata0[1111];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Client_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Client_t qt_meta_stringdata_Client = {
    {
QT_MOC_LITERAL(0, 0, 6), // "Client"
QT_MOC_LITERAL(1, 7, 20), // "requestNetworkStates"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 16), // "showConfigWizard"
QT_MOC_LITERAL(4, 46, 8), // "coredata"
QT_MOC_LITERAL(5, 55, 15), // "showChannelList"
QT_MOC_LITERAL(6, 71, 9), // "NetworkId"
QT_MOC_LITERAL(7, 81, 9), // "networkId"
QT_MOC_LITERAL(8, 91, 14), // "channelFilters"
QT_MOC_LITERAL(9, 106, 15), // "listImmediately"
QT_MOC_LITERAL(10, 122, 14), // "showIgnoreList"
QT_MOC_LITERAL(11, 137, 10), // "ignoreRule"
QT_MOC_LITERAL(12, 148, 9), // "connected"
QT_MOC_LITERAL(13, 158, 12), // "disconnected"
QT_MOC_LITERAL(14, 171, 26), // "coreConnectionStateChanged"
QT_MOC_LITERAL(15, 198, 22), // "coreInfoResynchronized"
QT_MOC_LITERAL(16, 221, 15), // "identityCreated"
QT_MOC_LITERAL(17, 237, 10), // "IdentityId"
QT_MOC_LITERAL(18, 248, 2), // "id"
QT_MOC_LITERAL(19, 251, 15), // "identityRemoved"
QT_MOC_LITERAL(20, 267, 21), // "requestCreateIdentity"
QT_MOC_LITERAL(21, 289, 8), // "Identity"
QT_MOC_LITERAL(22, 298, 21), // "requestRemoveIdentity"
QT_MOC_LITERAL(23, 320, 14), // "networkCreated"
QT_MOC_LITERAL(24, 335, 14), // "networkRemoved"
QT_MOC_LITERAL(25, 350, 20), // "requestCreateNetwork"
QT_MOC_LITERAL(26, 371, 11), // "NetworkInfo"
QT_MOC_LITERAL(27, 383, 4), // "info"
QT_MOC_LITERAL(28, 388, 18), // "persistentChannels"
QT_MOC_LITERAL(29, 407, 20), // "requestRemoveNetwork"
QT_MOC_LITERAL(30, 428, 18), // "bufferMarkedAsRead"
QT_MOC_LITERAL(31, 447, 8), // "BufferId"
QT_MOC_LITERAL(32, 456, 21), // "requestPasswordChange"
QT_MOC_LITERAL(33, 478, 7), // "PeerPtr"
QT_MOC_LITERAL(34, 486, 4), // "peer"
QT_MOC_LITERAL(35, 491, 8), // "userName"
QT_MOC_LITERAL(36, 500, 11), // "oldPassword"
QT_MOC_LITERAL(37, 512, 11), // "newPassword"
QT_MOC_LITERAL(38, 524, 17), // "requestKickClient"
QT_MOC_LITERAL(39, 542, 6), // "peerId"
QT_MOC_LITERAL(40, 549, 15), // "passwordChanged"
QT_MOC_LITERAL(41, 565, 7), // "success"
QT_MOC_LITERAL(42, 573, 19), // "dbUpgradeInProgress"
QT_MOC_LITERAL(43, 593, 10), // "inProgress"
QT_MOC_LITERAL(44, 604, 13), // "exitRequested"
QT_MOC_LITERAL(45, 618, 6), // "reason"
QT_MOC_LITERAL(46, 625, 18), // "disconnectFromCore"
QT_MOC_LITERAL(47, 644, 13), // "bufferRemoved"
QT_MOC_LITERAL(48, 658, 8), // "bufferId"
QT_MOC_LITERAL(49, 667, 13), // "bufferRenamed"
QT_MOC_LITERAL(50, 681, 7), // "newName"
QT_MOC_LITERAL(51, 689, 24), // "buffersPermanentlyMerged"
QT_MOC_LITERAL(52, 714, 9), // "bufferId1"
QT_MOC_LITERAL(53, 724, 9), // "bufferId2"
QT_MOC_LITERAL(54, 734, 16), // "markBufferAsRead"
QT_MOC_LITERAL(55, 751, 21), // "onDbUpgradeInProgress"
QT_MOC_LITERAL(56, 773, 15), // "onExitRequested"
QT_MOC_LITERAL(57, 789, 8), // "exitCode"
QT_MOC_LITERAL(58, 798, 15), // "setSyncedToCore"
QT_MOC_LITERAL(59, 814, 23), // "setDisconnectedFromCore"
QT_MOC_LITERAL(60, 838, 22), // "connectionStateChanged"
QT_MOC_LITERAL(61, 861, 31), // "CoreConnection::ConnectionState"
QT_MOC_LITERAL(62, 893, 11), // "recvMessage"
QT_MOC_LITERAL(63, 905, 7), // "Message"
QT_MOC_LITERAL(64, 913, 7), // "message"
QT_MOC_LITERAL(65, 921, 13), // "recvStatusMsg"
QT_MOC_LITERAL(66, 935, 7), // "network"
QT_MOC_LITERAL(67, 943, 16), // "networkDestroyed"
QT_MOC_LITERAL(68, 960, 19), // "coreIdentityCreated"
QT_MOC_LITERAL(69, 980, 19), // "coreIdentityRemoved"
QT_MOC_LITERAL(70, 1000, 18), // "coreNetworkCreated"
QT_MOC_LITERAL(71, 1019, 18), // "coreNetworkRemoved"
QT_MOC_LITERAL(72, 1038, 19), // "corePasswordChanged"
QT_MOC_LITERAL(73, 1058, 30), // "finishConnectionInitialization"
QT_MOC_LITERAL(74, 1089, 21) // "sendBufferedUserInput"

    },
    "Client\0requestNetworkStates\0\0"
    "showConfigWizard\0coredata\0showChannelList\0"
    "NetworkId\0networkId\0channelFilters\0"
    "listImmediately\0showIgnoreList\0"
    "ignoreRule\0connected\0disconnected\0"
    "coreConnectionStateChanged\0"
    "coreInfoResynchronized\0identityCreated\0"
    "IdentityId\0id\0identityRemoved\0"
    "requestCreateIdentity\0Identity\0"
    "requestRemoveIdentity\0networkCreated\0"
    "networkRemoved\0requestCreateNetwork\0"
    "NetworkInfo\0info\0persistentChannels\0"
    "requestRemoveNetwork\0bufferMarkedAsRead\0"
    "BufferId\0requestPasswordChange\0PeerPtr\0"
    "peer\0userName\0oldPassword\0newPassword\0"
    "requestKickClient\0peerId\0passwordChanged\0"
    "success\0dbUpgradeInProgress\0inProgress\0"
    "exitRequested\0reason\0disconnectFromCore\0"
    "bufferRemoved\0bufferId\0bufferRenamed\0"
    "newName\0buffersPermanentlyMerged\0"
    "bufferId1\0bufferId2\0markBufferAsRead\0"
    "onDbUpgradeInProgress\0onExitRequested\0"
    "exitCode\0setSyncedToCore\0"
    "setDisconnectedFromCore\0connectionStateChanged\0"
    "CoreConnection::ConnectionState\0"
    "recvMessage\0Message\0message\0recvStatusMsg\0"
    "network\0networkDestroyed\0coreIdentityCreated\0"
    "coreIdentityRemoved\0coreNetworkCreated\0"
    "coreNetworkRemoved\0corePasswordChanged\0"
    "finishConnectionInitialization\0"
    "sendBufferedUserInput"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Client[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      45,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      25,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  239,    2, 0x06 /* Public */,
       3,    1,  240,    2, 0x06 /* Public */,
       5,    3,  243,    2, 0x06 /* Public */,
       5,    2,  250,    2, 0x26 /* Public | MethodCloned */,
       5,    1,  255,    2, 0x26 /* Public | MethodCloned */,
      10,    1,  258,    2, 0x06 /* Public */,
      12,    0,  261,    2, 0x06 /* Public */,
      13,    0,  262,    2, 0x06 /* Public */,
      14,    1,  263,    2, 0x06 /* Public */,
      15,    0,  266,    2, 0x06 /* Public */,
      16,    1,  267,    2, 0x06 /* Public */,
      19,    1,  270,    2, 0x06 /* Public */,
      20,    2,  273,    2, 0x06 /* Public */,
      22,    1,  278,    2, 0x06 /* Public */,
      23,    1,  281,    2, 0x06 /* Public */,
      24,    1,  284,    2, 0x06 /* Public */,
      25,    2,  287,    2, 0x06 /* Public */,
      25,    1,  292,    2, 0x26 /* Public | MethodCloned */,
      29,    1,  295,    2, 0x06 /* Public */,
      30,    1,  298,    2, 0x06 /* Public */,
      32,    4,  301,    2, 0x06 /* Public */,
      38,    1,  310,    2, 0x06 /* Public */,
      40,    1,  313,    2, 0x06 /* Public */,
      42,    1,  316,    2, 0x06 /* Public */,
      44,    1,  319,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      46,    0,  322,    2, 0x0a /* Public */,
      47,    1,  323,    2, 0x0a /* Public */,
      49,    2,  326,    2, 0x0a /* Public */,
      51,    2,  331,    2, 0x0a /* Public */,
      54,    1,  336,    2, 0x0a /* Public */,
      55,    1,  339,    2, 0x0a /* Public */,
      56,    2,  342,    2, 0x0a /* Public */,
      58,    0,  347,    2, 0x08 /* Private */,
      59,    0,  348,    2, 0x08 /* Private */,
      60,    1,  349,    2, 0x08 /* Private */,
      62,    1,  352,    2, 0x08 /* Private */,
      65,    2,  355,    2, 0x08 /* Private */,
      67,    0,  360,    2, 0x08 /* Private */,
      68,    1,  361,    2, 0x08 /* Private */,
      69,    1,  364,    2, 0x08 /* Private */,
      70,    1,  367,    2, 0x08 /* Private */,
      71,    1,  370,    2, 0x08 /* Private */,
      72,    2,  373,    2, 0x08 /* Private */,
      73,    0,  378,    2, 0x08 /* Private */,
      74,    0,  379,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QVariantMap,    4,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::Bool,    7,    8,    9,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString,    7,    8,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 21, QMetaType::QVariantMap,    2,    2,
    QMetaType::Void, 0x80000000 | 17,    2,
    QMetaType::Void, 0x80000000 | 6,   18,
    QMetaType::Void, 0x80000000 | 6,   18,
    QMetaType::Void, 0x80000000 | 26, QMetaType::QStringList,   27,   28,
    QMetaType::Void, 0x80000000 | 26,   27,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 31,   18,
    QMetaType::Void, 0x80000000 | 33, QMetaType::QString, QMetaType::QString, QMetaType::QString,   34,   35,   36,   37,
    QMetaType::Void, QMetaType::Int,   39,
    QMetaType::Void, QMetaType::Bool,   41,
    QMetaType::Void, QMetaType::Bool,   43,
    QMetaType::Void, QMetaType::QString,   45,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 31,   48,
    QMetaType::Void, 0x80000000 | 31, QMetaType::QString,   48,   50,
    QMetaType::Void, 0x80000000 | 31, 0x80000000 | 31,   52,   53,
    QMetaType::Void, 0x80000000 | 31,   18,
    QMetaType::Void, QMetaType::Bool,   43,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   57,   45,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 61,    2,
    QMetaType::Void, 0x80000000 | 63,   64,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   66,   64,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 21,    2,
    QMetaType::Void, 0x80000000 | 17,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, 0x80000000 | 33, QMetaType::Bool,    2,   41,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Client::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Client *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->requestNetworkStates(); break;
        case 1: _t->showConfigWizard((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 2: _t->showChannelList((*reinterpret_cast< NetworkId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 3: _t->showChannelList((*reinterpret_cast< NetworkId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->showChannelList((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 5: _t->showIgnoreList((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 6: _t->connected(); break;
        case 7: _t->disconnected(); break;
        case 8: _t->coreConnectionStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->coreInfoResynchronized(); break;
        case 10: _t->identityCreated((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 11: _t->identityRemoved((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 12: _t->requestCreateIdentity((*reinterpret_cast< const Identity(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        case 13: _t->requestRemoveIdentity((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 14: _t->networkCreated((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 15: _t->networkRemoved((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 16: _t->requestCreateNetwork((*reinterpret_cast< const NetworkInfo(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 17: _t->requestCreateNetwork((*reinterpret_cast< const NetworkInfo(*)>(_a[1]))); break;
        case 18: _t->requestRemoveNetwork((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 19: _t->bufferMarkedAsRead((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 20: _t->requestPasswordChange((*reinterpret_cast< PeerPtr(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 21: _t->requestKickClient((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->passwordChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->dbUpgradeInProgress((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->exitRequested((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 25: _t->disconnectFromCore(); break;
        case 26: _t->bufferRemoved((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 27: _t->bufferRenamed((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 28: _t->buffersPermanentlyMerged((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< BufferId(*)>(_a[2]))); break;
        case 29: _t->markBufferAsRead((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 30: _t->onDbUpgradeInProgress((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 31: _t->onExitRequested((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 32: _t->setSyncedToCore(); break;
        case 33: _t->setDisconnectedFromCore(); break;
        case 34: _t->connectionStateChanged((*reinterpret_cast< CoreConnection::ConnectionState(*)>(_a[1]))); break;
        case 35: _t->recvMessage((*reinterpret_cast< const Message(*)>(_a[1]))); break;
        case 36: _t->recvStatusMsg((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 37: _t->networkDestroyed(); break;
        case 38: _t->coreIdentityCreated((*reinterpret_cast< const Identity(*)>(_a[1]))); break;
        case 39: _t->coreIdentityRemoved((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 40: _t->coreNetworkCreated((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 41: _t->coreNetworkRemoved((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 42: _t->corePasswordChanged((*reinterpret_cast< PeerPtr(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 43: _t->finishConnectionInitialization(); break;
        case 44: _t->sendBufferedUserInput(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PeerPtr >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< CoreConnection::ConnectionState >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Message >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PeerPtr >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Client::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::requestNetworkStates)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Client::*)(const QVariantMap & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::showConfigWizard)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Client::*)(NetworkId , const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::showChannelList)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Client::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::showIgnoreList)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Client::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::connected)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Client::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::disconnected)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (Client::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::coreConnectionStateChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (Client::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::coreInfoResynchronized)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (Client::*)(IdentityId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::identityCreated)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (Client::*)(IdentityId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::identityRemoved)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (Client::*)(const Identity & , const QVariantMap & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::requestCreateIdentity)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (Client::*)(IdentityId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::requestRemoveIdentity)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (Client::*)(NetworkId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::networkCreated)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (Client::*)(NetworkId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::networkRemoved)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (Client::*)(const NetworkInfo & , const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::requestCreateNetwork)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (Client::*)(NetworkId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::requestRemoveNetwork)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (Client::*)(BufferId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::bufferMarkedAsRead)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (Client::*)(PeerPtr , const QString & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::requestPasswordChange)) {
                *result = 20;
                return;
            }
        }
        {
            using _t = void (Client::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::requestKickClient)) {
                *result = 21;
                return;
            }
        }
        {
            using _t = void (Client::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::passwordChanged)) {
                *result = 22;
                return;
            }
        }
        {
            using _t = void (Client::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::dbUpgradeInProgress)) {
                *result = 23;
                return;
            }
        }
        {
            using _t = void (Client::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Client::exitRequested)) {
                *result = 24;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Client::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Client.data,
    qt_meta_data_Client,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Client::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Client::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Client.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Singleton<Client>"))
        return static_cast< Singleton<Client>*>(this);
    return QObject::qt_metacast(_clname);
}

int Client::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    return _id;
}

// SIGNAL 0
void Client::requestNetworkStates()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Client::showConfigWizard(const QVariantMap & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Client::showChannelList(NetworkId _t1, const QString & _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 5
void Client::showIgnoreList(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Client::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Client::disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Client::coreConnectionStateChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Client::coreInfoResynchronized()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Client::identityCreated(IdentityId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Client::identityRemoved(IdentityId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void Client::requestCreateIdentity(const Identity & _t1, const QVariantMap & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void Client::requestRemoveIdentity(IdentityId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void Client::networkCreated(NetworkId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void Client::networkRemoved(NetworkId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void Client::requestCreateNetwork(const NetworkInfo & _t1, const QStringList & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 18
void Client::requestRemoveNetwork(NetworkId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void Client::bufferMarkedAsRead(BufferId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void Client::requestPasswordChange(PeerPtr _t1, const QString & _t2, const QString & _t3, const QString & _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void Client::requestKickClient(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 21, _a);
}

// SIGNAL 22
void Client::passwordChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 22, _a);
}

// SIGNAL 23
void Client::dbUpgradeInProgress(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 23, _a);
}

// SIGNAL 24
void Client::exitRequested(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 24, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
