/********************************************************************************
** Form generated from reading UI file 'coreconfigwizardadminuserpage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CORECONFIGWIZARDADMINUSERPAGE_H
#define UI_CORECONFIGWIZARDADMINUSERPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CoreConfigWizardAdminUserPage
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QLineEdit *user;
    QLabel *label_3;
    QLineEdit *password;
    QLabel *label_4;
    QLineEdit *password2;
    QCheckBox *rememberPasswd;
    QLabel *label;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *CoreConfigWizardAdminUserPage)
    {
        if (CoreConfigWizardAdminUserPage->objectName().isEmpty())
            CoreConfigWizardAdminUserPage->setObjectName(QString::fromUtf8("CoreConfigWizardAdminUserPage"));
        CoreConfigWizardAdminUserPage->resize(505, 289);
        vboxLayout = new QVBoxLayout(CoreConfigWizardAdminUserPage);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setSizeConstraint(QLayout::SetMinimumSize);
        label_2 = new QLabel(CoreConfigWizardAdminUserPage);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        user = new QLineEdit(CoreConfigWizardAdminUserPage);
        user->setObjectName(QString::fromUtf8("user"));

        gridLayout->addWidget(user, 0, 1, 1, 1);

        label_3 = new QLabel(CoreConfigWizardAdminUserPage);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        password = new QLineEdit(CoreConfigWizardAdminUserPage);
        password->setObjectName(QString::fromUtf8("password"));
        password->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(password, 1, 1, 1, 1);

        label_4 = new QLabel(CoreConfigWizardAdminUserPage);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        password2 = new QLineEdit(CoreConfigWizardAdminUserPage);
        password2->setObjectName(QString::fromUtf8("password2"));
        password2->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(password2, 2, 1, 1, 1);

        rememberPasswd = new QCheckBox(CoreConfigWizardAdminUserPage);
        rememberPasswd->setObjectName(QString::fromUtf8("rememberPasswd"));

        gridLayout->addWidget(rememberPasswd, 3, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        label = new QLabel(CoreConfigWizardAdminUserPage);
        label->setObjectName(QString::fromUtf8("label"));
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        label->setWordWrap(true);

        vboxLayout->addWidget(label);

        spacerItem = new QSpacerItem(405, 51, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(CoreConfigWizardAdminUserPage);

        QMetaObject::connectSlotsByName(CoreConfigWizardAdminUserPage);
    } // setupUi

    void retranslateUi(QWidget *CoreConfigWizardAdminUserPage)
    {
        CoreConfigWizardAdminUserPage->setWindowTitle(QCoreApplication::translate("CoreConfigWizardAdminUserPage", "Form", nullptr));
        label_2->setText(QCoreApplication::translate("CoreConfigWizardAdminUserPage", "Username:", nullptr));
        label_3->setText(QCoreApplication::translate("CoreConfigWizardAdminUserPage", "Password:", nullptr));
        label_4->setText(QCoreApplication::translate("CoreConfigWizardAdminUserPage", "Repeat password:", nullptr));
        rememberPasswd->setText(QCoreApplication::translate("CoreConfigWizardAdminUserPage", "Remember password", nullptr));
        label->setText(QCoreApplication::translate("CoreConfigWizardAdminUserPage", "<b>Note:</b> Adding more users and changing your username/password is not possible via Quassel's client interface yet.\n"
"If you need to do these things, please run \"<tt><nobr>quasselcore --help</nobr></tt>\".", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CoreConfigWizardAdminUserPage: public Ui_CoreConfigWizardAdminUserPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CORECONFIGWIZARDADMINUSERPAGE_H
