/********************************************************************************
** Form generated from reading UI file 'coreconnectionsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CORECONNECTIONSETTINGSPAGE_H
#define UI_CORECONNECTIONSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CoreConnectionSettingsPage
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QRadioButton *useQNetworkConfigurationManager;
    QHBoxLayout *horizontalLayout;
    QRadioButton *usePingTimeout;
    QSpinBox *pingTimeout;
    QSpacerItem *horizontalSpacer;
    QRadioButton *useNoTimeout;
    QCheckBox *autoReconnect;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QLabel *reconnectLabel;
    QSpinBox *reconnectInterval;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *CoreConnectionSettingsPage)
    {
        if (CoreConnectionSettingsPage->objectName().isEmpty())
            CoreConnectionSettingsPage->setObjectName(QString::fromUtf8("CoreConnectionSettingsPage"));
        CoreConnectionSettingsPage->resize(476, 465);
        verticalLayout_2 = new QVBoxLayout(CoreConnectionSettingsPage);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        groupBox = new QGroupBox(CoreConnectionSettingsPage);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        useQNetworkConfigurationManager = new QRadioButton(groupBox);
        useQNetworkConfigurationManager->setObjectName(QString::fromUtf8("useQNetworkConfigurationManager"));
        useQNetworkConfigurationManager->setChecked(false);

        verticalLayout->addWidget(useQNetworkConfigurationManager);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        usePingTimeout = new QRadioButton(groupBox);
        usePingTimeout->setObjectName(QString::fromUtf8("usePingTimeout"));
        usePingTimeout->setCheckable(true);
        usePingTimeout->setChecked(false);

        horizontalLayout->addWidget(usePingTimeout);

        pingTimeout = new QSpinBox(groupBox);
        pingTimeout->setObjectName(QString::fromUtf8("pingTimeout"));
        pingTimeout->setMinimum(30);
        pingTimeout->setMaximum(3600);
        pingTimeout->setSingleStep(30);
        pingTimeout->setValue(60);
        pingTimeout->setProperty("settingsKey", QVariant(QString::fromUtf8("PingTimeoutInterval")));
        pingTimeout->setProperty("defaultValue", QVariant(60u));

        horizontalLayout->addWidget(pingTimeout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        useNoTimeout = new QRadioButton(groupBox);
        useNoTimeout->setObjectName(QString::fromUtf8("useNoTimeout"));

        verticalLayout->addWidget(useNoTimeout);


        verticalLayout_2->addWidget(groupBox);

        autoReconnect = new QCheckBox(CoreConnectionSettingsPage);
        autoReconnect->setObjectName(QString::fromUtf8("autoReconnect"));
        autoReconnect->setChecked(true);
        autoReconnect->setProperty("settingsKey", QVariant(QString::fromUtf8("AutoReconnect")));
        autoReconnect->setProperty("defaultValue", QVariant(true));

        verticalLayout_2->addWidget(autoReconnect);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        reconnectLabel = new QLabel(CoreConnectionSettingsPage);
        reconnectLabel->setObjectName(QString::fromUtf8("reconnectLabel"));

        horizontalLayout_2->addWidget(reconnectLabel);

        reconnectInterval = new QSpinBox(CoreConnectionSettingsPage);
        reconnectInterval->setObjectName(QString::fromUtf8("reconnectInterval"));
        reconnectInterval->setMinimum(1);
        reconnectInterval->setMaximum(3600);
        reconnectInterval->setSingleStep(1);
        reconnectInterval->setValue(60);
        reconnectInterval->setProperty("settingsKey", QVariant(QString::fromUtf8("ReconnectInterval")));
        reconnectInterval->setProperty("defaultValue", QVariant(60u));

        horizontalLayout_2->addWidget(reconnectInterval);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);


        verticalLayout_2->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        QWidget::setTabOrder(useQNetworkConfigurationManager, usePingTimeout);
        QWidget::setTabOrder(usePingTimeout, pingTimeout);
        QWidget::setTabOrder(pingTimeout, useNoTimeout);
        QWidget::setTabOrder(useNoTimeout, autoReconnect);
        QWidget::setTabOrder(autoReconnect, reconnectInterval);

        retranslateUi(CoreConnectionSettingsPage);
        QObject::connect(usePingTimeout, SIGNAL(toggled(bool)), pingTimeout, SLOT(setEnabled(bool)));
        QObject::connect(autoReconnect, SIGNAL(toggled(bool)), reconnectLabel, SLOT(setEnabled(bool)));
        QObject::connect(autoReconnect, SIGNAL(toggled(bool)), reconnectInterval, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(CoreConnectionSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *CoreConnectionSettingsPage)
    {
        CoreConnectionSettingsPage->setWindowTitle(QCoreApplication::translate("CoreConnectionSettingsPage", "Form", nullptr));
        groupBox->setTitle(QCoreApplication::translate("CoreConnectionSettingsPage", "Network Status Detection", nullptr));
#if QT_CONFIG(tooltip)
        useQNetworkConfigurationManager->setToolTip(QCoreApplication::translate("CoreConnectionSettingsPage", "Rely on Qt's network configuration manager to detect if we're online", nullptr));
#endif // QT_CONFIG(tooltip)
        useQNetworkConfigurationManager->setText(QCoreApplication::translate("CoreConnectionSettingsPage", "Automatic", nullptr));
#if QT_CONFIG(tooltip)
        usePingTimeout->setToolTip(QCoreApplication::translate("CoreConnectionSettingsPage", "Actively ping the remote core and disconnect if we didn't get a reply after a certain time", nullptr));
#endif // QT_CONFIG(tooltip)
        usePingTimeout->setText(QCoreApplication::translate("CoreConnectionSettingsPage", "Ping timeout after", nullptr));
#if QT_CONFIG(tooltip)
        pingTimeout->setToolTip(QCoreApplication::translate("CoreConnectionSettingsPage", "Actively ping the remote core and disconnect if we didn't get a reply after a certain time", nullptr));
#endif // QT_CONFIG(tooltip)
        pingTimeout->setSuffix(QCoreApplication::translate("CoreConnectionSettingsPage", " seconds", nullptr));
#if QT_CONFIG(tooltip)
        useNoTimeout->setToolTip(QCoreApplication::translate("CoreConnectionSettingsPage", "Only disconnect if the network socket gets closed by the operating system. This may take a long time after actually losing connectivity", nullptr));
#endif // QT_CONFIG(tooltip)
        useNoTimeout->setText(QCoreApplication::translate("CoreConnectionSettingsPage", "Never time out actively", nullptr));
        autoReconnect->setText(QCoreApplication::translate("CoreConnectionSettingsPage", "Automatically reconnect on network failures", nullptr));
        reconnectLabel->setText(QCoreApplication::translate("CoreConnectionSettingsPage", "Retry every", nullptr));
#if QT_CONFIG(tooltip)
        reconnectInterval->setToolTip(QCoreApplication::translate("CoreConnectionSettingsPage", "Interval between consecutive connection attempts", nullptr));
#endif // QT_CONFIG(tooltip)
        reconnectInterval->setSuffix(QCoreApplication::translate("CoreConnectionSettingsPage", " seconds", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CoreConnectionSettingsPage: public Ui_CoreConnectionSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CORECONNECTIONSETTINGSPAGE_H
