/********************************************************************************
** Form generated from reading UI file 'coreinfodlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COREINFODLG_H
#define UI_COREINFODLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CoreInfoDlg
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *labelCoreVersionTitle;
    QLabel *labelCoreVersion;
    QLabel *labelCoreVersionDateTitle;
    QLabel *labelCoreVersionDate;
    QLabel *labelUptimeTitle;
    QLabel *labelUptime;
    QLabel *labelClientCountTitle;
    QLabel *labelClientCount;
    QFrame *coreUnsupportedWidget;
    QHBoxLayout *hboxLayout;
    QLabel *coreUnsupportedIcon;
    QLabel *coreUnsupportedLabel;
    QPushButton *coreUnsupportedDetails;
    QScrollArea *coreSessionScrollArea;
    QWidget *coreSessionScrollContainer;
    QVBoxLayout *verticalLayout_3;
    QVBoxLayout *coreSessionContainer;
    QSpacerItem *verticalSpacer;
    QSpacerItem *mainSpacer;
    QGridLayout *gridLayout_2;
    QPushButton *closeButton;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QDialog *CoreInfoDlg)
    {
        if (CoreInfoDlg->objectName().isEmpty())
            CoreInfoDlg->setObjectName(QString::fromUtf8("CoreInfoDlg"));
        CoreInfoDlg->resize(566, 349);
        verticalLayout = new QVBoxLayout(CoreInfoDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        labelCoreVersionTitle = new QLabel(CoreInfoDlg);
        labelCoreVersionTitle->setObjectName(QString::fromUtf8("labelCoreVersionTitle"));

        gridLayout->addWidget(labelCoreVersionTitle, 0, 0, 1, 1);

        labelCoreVersion = new QLabel(CoreInfoDlg);
        labelCoreVersion->setObjectName(QString::fromUtf8("labelCoreVersion"));
        labelCoreVersion->setText(QString::fromUtf8("<core version>"));
        labelCoreVersion->setOpenExternalLinks(true);
        labelCoreVersion->setTextInteractionFlags(Qt::TextBrowserInteraction);

        gridLayout->addWidget(labelCoreVersion, 0, 1, 1, 1);

        labelCoreVersionDateTitle = new QLabel(CoreInfoDlg);
        labelCoreVersionDateTitle->setObjectName(QString::fromUtf8("labelCoreVersionDateTitle"));

        gridLayout->addWidget(labelCoreVersionDateTitle, 1, 0, 1, 1);

        labelCoreVersionDate = new QLabel(CoreInfoDlg);
        labelCoreVersionDate->setObjectName(QString::fromUtf8("labelCoreVersionDate"));
        labelCoreVersionDate->setText(QString::fromUtf8("<version date>"));

        gridLayout->addWidget(labelCoreVersionDate, 1, 1, 1, 1);

        labelUptimeTitle = new QLabel(CoreInfoDlg);
        labelUptimeTitle->setObjectName(QString::fromUtf8("labelUptimeTitle"));

        gridLayout->addWidget(labelUptimeTitle, 2, 0, 1, 1);

        labelUptime = new QLabel(CoreInfoDlg);
        labelUptime->setObjectName(QString::fromUtf8("labelUptime"));
        labelUptime->setText(QString::fromUtf8("<core uptime>"));

        gridLayout->addWidget(labelUptime, 2, 1, 1, 1);

        labelClientCountTitle = new QLabel(CoreInfoDlg);
        labelClientCountTitle->setObjectName(QString::fromUtf8("labelClientCountTitle"));

        gridLayout->addWidget(labelClientCountTitle, 3, 0, 1, 1);

        labelClientCount = new QLabel(CoreInfoDlg);
        labelClientCount->setObjectName(QString::fromUtf8("labelClientCount"));
        labelClientCount->setText(QString::fromUtf8("<connected clients>"));

        gridLayout->addWidget(labelClientCount, 3, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);

        coreUnsupportedWidget = new QFrame(CoreInfoDlg);
        coreUnsupportedWidget->setObjectName(QString::fromUtf8("coreUnsupportedWidget"));
        coreUnsupportedWidget->setFrameShape(QFrame::NoFrame);
        coreUnsupportedWidget->setFrameShadow(QFrame::Plain);
        coreUnsupportedWidget->setLineWidth(0);
        hboxLayout = new QHBoxLayout(coreUnsupportedWidget);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        coreUnsupportedIcon = new QLabel(coreUnsupportedWidget);
        coreUnsupportedIcon->setObjectName(QString::fromUtf8("coreUnsupportedIcon"));
        coreUnsupportedIcon->setText(QString::fromUtf8("[icon]"));

        hboxLayout->addWidget(coreUnsupportedIcon);

        coreUnsupportedLabel = new QLabel(coreUnsupportedWidget);
        coreUnsupportedLabel->setObjectName(QString::fromUtf8("coreUnsupportedLabel"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(coreUnsupportedLabel->sizePolicy().hasHeightForWidth());
        coreUnsupportedLabel->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(coreUnsupportedLabel);

        coreUnsupportedDetails = new QPushButton(coreUnsupportedWidget);
        coreUnsupportedDetails->setObjectName(QString::fromUtf8("coreUnsupportedDetails"));

        hboxLayout->addWidget(coreUnsupportedDetails);


        verticalLayout->addWidget(coreUnsupportedWidget);

        coreSessionScrollArea = new QScrollArea(CoreInfoDlg);
        coreSessionScrollArea->setObjectName(QString::fromUtf8("coreSessionScrollArea"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(coreSessionScrollArea->sizePolicy().hasHeightForWidth());
        coreSessionScrollArea->setSizePolicy(sizePolicy1);
        coreSessionScrollArea->setWidgetResizable(true);
        coreSessionScrollArea->setAlignment(Qt::AlignHCenter|Qt::AlignTop);
        coreSessionScrollContainer = new QWidget();
        coreSessionScrollContainer->setObjectName(QString::fromUtf8("coreSessionScrollContainer"));
        coreSessionScrollContainer->setGeometry(QRect(0, 0, 546, 161));
        sizePolicy.setHeightForWidth(coreSessionScrollContainer->sizePolicy().hasHeightForWidth());
        coreSessionScrollContainer->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(coreSessionScrollContainer);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        coreSessionContainer = new QVBoxLayout();
        coreSessionContainer->setObjectName(QString::fromUtf8("coreSessionContainer"));
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        coreSessionContainer->addItem(verticalSpacer);


        verticalLayout_3->addLayout(coreSessionContainer);

        coreSessionScrollArea->setWidget(coreSessionScrollContainer);

        verticalLayout->addWidget(coreSessionScrollArea);

        mainSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(mainSpacer);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        closeButton = new QPushButton(CoreInfoDlg);
        closeButton->setObjectName(QString::fromUtf8("closeButton"));

        gridLayout_2->addWidget(closeButton, 1, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 1, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 1, 2, 1, 1);


        verticalLayout->addLayout(gridLayout_2);

        verticalLayout->setStretch(2, 1);

        retranslateUi(CoreInfoDlg);

        QMetaObject::connectSlotsByName(CoreInfoDlg);
    } // setupUi

    void retranslateUi(QDialog *CoreInfoDlg)
    {
        CoreInfoDlg->setWindowTitle(QCoreApplication::translate("CoreInfoDlg", "Core Information", nullptr));
        labelCoreVersionTitle->setText(QCoreApplication::translate("CoreInfoDlg", "Version:", nullptr));
        labelCoreVersionDateTitle->setText(QCoreApplication::translate("CoreInfoDlg", "Version date:", nullptr));
        labelUptimeTitle->setText(QCoreApplication::translate("CoreInfoDlg", "Uptime:", nullptr));
        labelClientCountTitle->setText(QCoreApplication::translate("CoreInfoDlg", "Connected clients:", nullptr));
        coreUnsupportedLabel->setText(QCoreApplication::translate("CoreInfoDlg", "Your Quassel core is too old to show active sessions", nullptr));
        coreUnsupportedDetails->setText(QCoreApplication::translate("CoreInfoDlg", "Details...", nullptr));
        closeButton->setText(QCoreApplication::translate("CoreInfoDlg", "Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CoreInfoDlg: public Ui_CoreInfoDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COREINFODLG_H
