/********************************************************************************
** Form generated from reading UI file 'networkeditdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NETWORKEDITDLG_H
#define UI_NETWORKEDITDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_NetworkEditDlg
{
public:
    QVBoxLayout *vboxLayout;
    QVBoxLayout *vboxLayout1;
    QLabel *label;
    QLineEdit *networkEdit;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *NetworkEditDlg)
    {
        if (NetworkEditDlg->objectName().isEmpty())
            NetworkEditDlg->setObjectName(QString::fromUtf8("NetworkEditDlg"));
        NetworkEditDlg->resize(254, 93);
        vboxLayout = new QVBoxLayout(NetworkEditDlg);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        label = new QLabel(NetworkEditDlg);
        label->setObjectName(QString::fromUtf8("label"));

        vboxLayout1->addWidget(label);

        networkEdit = new QLineEdit(NetworkEditDlg);
        networkEdit->setObjectName(QString::fromUtf8("networkEdit"));

        vboxLayout1->addWidget(networkEdit);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(NetworkEditDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::NoButton|QDialogButtonBox::Ok);

        vboxLayout1->addWidget(buttonBox);


        vboxLayout->addLayout(vboxLayout1);


        retranslateUi(NetworkEditDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), NetworkEditDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), NetworkEditDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(NetworkEditDlg);
    } // setupUi

    void retranslateUi(QDialog *NetworkEditDlg)
    {
        NetworkEditDlg->setWindowTitle(QCoreApplication::translate("NetworkEditDlg", "Dialog", nullptr));
        label->setText(QCoreApplication::translate("NetworkEditDlg", "Please enter a network name:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NetworkEditDlg: public Ui_NetworkEditDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NETWORKEDITDLG_H
