/********************************************************************************
** Form generated from reading UI file 'createidentitydlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CREATEIDENTITYDLG_H
#define UI_CREATEIDENTITYDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_CreateIdentityDlg
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *label;
    QLineEdit *identityName;
    QRadioButton *createBlankIdentity;
    QHBoxLayout *hboxLayout1;
    QRadioButton *duplicateIdentity;
    QComboBox *identityList;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CreateIdentityDlg)
    {
        if (CreateIdentityDlg->objectName().isEmpty())
            CreateIdentityDlg->setObjectName(QString::fromUtf8("CreateIdentityDlg"));
        CreateIdentityDlg->setWindowModality(Qt::WindowModal);
        CreateIdentityDlg->resize(399, 135);
        vboxLayout = new QVBoxLayout(CreateIdentityDlg);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        label = new QLabel(CreateIdentityDlg);
        label->setObjectName(QString::fromUtf8("label"));

        hboxLayout->addWidget(label);

        identityName = new QLineEdit(CreateIdentityDlg);
        identityName->setObjectName(QString::fromUtf8("identityName"));

        hboxLayout->addWidget(identityName);


        vboxLayout->addLayout(hboxLayout);

        createBlankIdentity = new QRadioButton(CreateIdentityDlg);
        createBlankIdentity->setObjectName(QString::fromUtf8("createBlankIdentity"));
        createBlankIdentity->setChecked(true);

        vboxLayout->addWidget(createBlankIdentity);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        duplicateIdentity = new QRadioButton(CreateIdentityDlg);
        duplicateIdentity->setObjectName(QString::fromUtf8("duplicateIdentity"));

        hboxLayout1->addWidget(duplicateIdentity);

        identityList = new QComboBox(CreateIdentityDlg);
        identityList->setObjectName(QString::fromUtf8("identityList"));
        identityList->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(identityList->sizePolicy().hasHeightForWidth());
        identityList->setSizePolicy(sizePolicy);

        hboxLayout1->addWidget(identityList);


        vboxLayout->addLayout(hboxLayout1);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(CreateIdentityDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);

        QWidget::setTabOrder(identityName, createBlankIdentity);
        QWidget::setTabOrder(createBlankIdentity, duplicateIdentity);
        QWidget::setTabOrder(duplicateIdentity, identityList);
        QWidget::setTabOrder(identityList, buttonBox);

        retranslateUi(CreateIdentityDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), CreateIdentityDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), CreateIdentityDlg, SLOT(reject()));
        QObject::connect(duplicateIdentity, SIGNAL(toggled(bool)), identityList, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(CreateIdentityDlg);
    } // setupUi

    void retranslateUi(QDialog *CreateIdentityDlg)
    {
        CreateIdentityDlg->setWindowTitle(QCoreApplication::translate("CreateIdentityDlg", "Create New Identity", nullptr));
        label->setText(QCoreApplication::translate("CreateIdentityDlg", "Identity name:", nullptr));
        createBlankIdentity->setText(QCoreApplication::translate("CreateIdentityDlg", "Create blank identity", nullptr));
        duplicateIdentity->setText(QCoreApplication::translate("CreateIdentityDlg", "Duplicate:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CreateIdentityDlg: public Ui_CreateIdentityDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CREATEIDENTITYDLG_H
