/********************************************************************************
** Form generated from reading UI file 'qtmultimedianotificationconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QTMULTIMEDIANOTIFICATIONCONFIGWIDGET_H
#define UI_QTMULTIMEDIANOTIFICATIONCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_QtMultimediaNotificationConfigWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QCheckBox *enabled;
    QSpacerItem *horizontalSpacer;
    QToolButton *play;
    QLineEdit *filename;
    QToolButton *open;

    void setupUi(QWidget *QtMultimediaNotificationConfigWidget)
    {
        if (QtMultimediaNotificationConfigWidget->objectName().isEmpty())
            QtMultimediaNotificationConfigWidget->setObjectName(QString::fromUtf8("QtMultimediaNotificationConfigWidget"));
        QtMultimediaNotificationConfigWidget->resize(439, 36);
        horizontalLayout = new QHBoxLayout(QtMultimediaNotificationConfigWidget);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        enabled = new QCheckBox(QtMultimediaNotificationConfigWidget);
        enabled->setObjectName(QString::fromUtf8("enabled"));

        horizontalLayout->addWidget(enabled);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        play = new QToolButton(QtMultimediaNotificationConfigWidget);
        play->setObjectName(QString::fromUtf8("play"));
        play->setEnabled(false);

        horizontalLayout->addWidget(play);

        filename = new QLineEdit(QtMultimediaNotificationConfigWidget);
        filename->setObjectName(QString::fromUtf8("filename"));
        filename->setEnabled(false);

        horizontalLayout->addWidget(filename);

        open = new QToolButton(QtMultimediaNotificationConfigWidget);
        open->setObjectName(QString::fromUtf8("open"));
        open->setEnabled(false);

        horizontalLayout->addWidget(open);


        retranslateUi(QtMultimediaNotificationConfigWidget);
        QObject::connect(enabled, SIGNAL(toggled(bool)), filename, SLOT(setEnabled(bool)));
        QObject::connect(enabled, SIGNAL(toggled(bool)), open, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(QtMultimediaNotificationConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *QtMultimediaNotificationConfigWidget)
    {
        QtMultimediaNotificationConfigWidget->setWindowTitle(QCoreApplication::translate("QtMultimediaNotificationConfigWidget", "Form", nullptr));
        enabled->setText(QCoreApplication::translate("QtMultimediaNotificationConfigWidget", "Play a sound", nullptr));
#if QT_CONFIG(tooltip)
        play->setToolTip(QCoreApplication::translate("QtMultimediaNotificationConfigWidget", "Prelisten to the selected sound", nullptr));
#endif // QT_CONFIG(tooltip)
        play->setText(QString());
#if QT_CONFIG(tooltip)
        filename->setToolTip(QCoreApplication::translate("QtMultimediaNotificationConfigWidget", "Select the sound file to play", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        open->setToolTip(QCoreApplication::translate("QtMultimediaNotificationConfigWidget", "Select the sound file to play", nullptr));
#endif // QT_CONFIG(tooltip)
        open->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class QtMultimediaNotificationConfigWidget: public Ui_QtMultimediaNotificationConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QTMULTIMEDIANOTIFICATIONCONFIGWIDGET_H
