/****************************************************************************
** Meta object code from reading C++ file 'chatviewsearchcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/chatviewsearchcontroller.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'chatviewsearchcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ChatViewSearchController_t {
    QByteArrayData data[23];
    char stringdata0[340];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChatViewSearchController_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChatViewSearchController_t qt_meta_stringdata_ChatViewSearchController = {
    {
QT_MOC_LITERAL(0, 0, 24), // "ChatViewSearchController"
QT_MOC_LITERAL(1, 25, 19), // "newCurrentHighlight"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 14), // "QGraphicsItem*"
QT_MOC_LITERAL(4, 61, 13), // "highlightItem"
QT_MOC_LITERAL(5, 75, 15), // "setSearchString"
QT_MOC_LITERAL(6, 91, 12), // "searchString"
QT_MOC_LITERAL(7, 104, 16), // "setCaseSensitive"
QT_MOC_LITERAL(8, 121, 13), // "caseSensitive"
QT_MOC_LITERAL(9, 135, 16), // "setSearchSenders"
QT_MOC_LITERAL(10, 152, 13), // "searchSenders"
QT_MOC_LITERAL(11, 166, 13), // "setSearchMsgs"
QT_MOC_LITERAL(12, 180, 10), // "searchMsgs"
QT_MOC_LITERAL(13, 191, 24), // "setSearchOnlyRegularMsgs"
QT_MOC_LITERAL(14, 216, 21), // "searchOnlyRegularMsgs"
QT_MOC_LITERAL(15, 238, 13), // "highlightNext"
QT_MOC_LITERAL(16, 252, 13), // "highlightPrev"
QT_MOC_LITERAL(17, 266, 14), // "sceneDestroyed"
QT_MOC_LITERAL(18, 281, 16), // "updateHighlights"
QT_MOC_LITERAL(19, 298, 5), // "reuse"
QT_MOC_LITERAL(20, 304, 20), // "repositionHighlights"
QT_MOC_LITERAL(21, 325, 9), // "ChatLine*"
QT_MOC_LITERAL(22, 335, 4) // "line"

    },
    "ChatViewSearchController\0newCurrentHighlight\0"
    "\0QGraphicsItem*\0highlightItem\0"
    "setSearchString\0searchString\0"
    "setCaseSensitive\0caseSensitive\0"
    "setSearchSenders\0searchSenders\0"
    "setSearchMsgs\0searchMsgs\0"
    "setSearchOnlyRegularMsgs\0searchOnlyRegularMsgs\0"
    "highlightNext\0highlightPrev\0sceneDestroyed\0"
    "updateHighlights\0reuse\0repositionHighlights\0"
    "ChatLine*\0line"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChatViewSearchController[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   79,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   82,    2, 0x0a /* Public */,
       7,    1,   85,    2, 0x0a /* Public */,
       9,    1,   88,    2, 0x0a /* Public */,
      11,    1,   91,    2, 0x0a /* Public */,
      13,    1,   94,    2, 0x0a /* Public */,
      15,    0,   97,    2, 0x0a /* Public */,
      16,    0,   98,    2, 0x0a /* Public */,
      17,    0,   99,    2, 0x08 /* Private */,
      18,    1,  100,    2, 0x08 /* Private */,
      18,    0,  103,    2, 0x28 /* Private | MethodCloned */,
      20,    0,  104,    2, 0x08 /* Private */,
      20,    1,  105,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 21,   22,

       0        // eod
};

void ChatViewSearchController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ChatViewSearchController *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->newCurrentHighlight((*reinterpret_cast< QGraphicsItem*(*)>(_a[1]))); break;
        case 1: _t->setSearchString((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->setCaseSensitive((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->setSearchSenders((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->setSearchMsgs((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->setSearchOnlyRegularMsgs((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->highlightNext(); break;
        case 7: _t->highlightPrev(); break;
        case 8: _t->sceneDestroyed(); break;
        case 9: _t->updateHighlights((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->updateHighlights(); break;
        case 11: _t->repositionHighlights(); break;
        case 12: _t->repositionHighlights((*reinterpret_cast< ChatLine*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QGraphicsItem* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ChatViewSearchController::*)(QGraphicsItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChatViewSearchController::newCurrentHighlight)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ChatViewSearchController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_ChatViewSearchController.data,
    qt_meta_data_ChatViewSearchController,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ChatViewSearchController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChatViewSearchController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ChatViewSearchController.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ChatViewSearchController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ChatViewSearchController::newCurrentHighlight(QGraphicsItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_SearchHighlightItem_t {
    QByteArrayData data[4];
    char stringdata0[43];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SearchHighlightItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SearchHighlightItem_t qt_meta_stringdata_SearchHighlightItem = {
    {
QT_MOC_LITERAL(0, 0, 19), // "SearchHighlightItem"
QT_MOC_LITERAL(1, 20, 15), // "updateHighlight"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 5) // "value"

    },
    "SearchHighlightItem\0updateHighlight\0"
    "\0value"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SearchHighlightItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QReal,    3,

       0        // eod
};

void SearchHighlightItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SearchHighlightItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->updateHighlight((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject SearchHighlightItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_SearchHighlightItem.data,
    qt_meta_data_SearchHighlightItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SearchHighlightItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SearchHighlightItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SearchHighlightItem.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QGraphicsItem"))
        return static_cast< QGraphicsItem*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QGraphicsItem"))
        return static_cast< QGraphicsItem*>(this);
    return QObject::qt_metacast(_clname);
}

int SearchHighlightItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
