/****************************************************************************
** Meta object code from reading C++ file 'corebacklogmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/corebacklogmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'corebacklogmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreBacklogManager_t {
    QByteArrayData data[16];
    char stringdata0[187];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreBacklogManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreBacklogManager_t qt_meta_stringdata_CoreBacklogManager = {
    {
QT_MOC_LITERAL(0, 0, 18), // "CoreBacklogManager"
QT_MOC_LITERAL(1, 19, 14), // "requestBacklog"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 8), // "BufferId"
QT_MOC_LITERAL(4, 44, 8), // "bufferId"
QT_MOC_LITERAL(5, 53, 5), // "MsgId"
QT_MOC_LITERAL(6, 59, 5), // "first"
QT_MOC_LITERAL(7, 65, 4), // "last"
QT_MOC_LITERAL(8, 70, 5), // "limit"
QT_MOC_LITERAL(9, 76, 10), // "additional"
QT_MOC_LITERAL(10, 87, 22), // "requestBacklogFiltered"
QT_MOC_LITERAL(11, 110, 4), // "type"
QT_MOC_LITERAL(12, 115, 5), // "flags"
QT_MOC_LITERAL(13, 121, 21), // "requestBacklogForward"
QT_MOC_LITERAL(14, 143, 17), // "requestBacklogAll"
QT_MOC_LITERAL(15, 161, 25) // "requestBacklogAllFiltered"

    },
    "CoreBacklogManager\0requestBacklog\0\0"
    "BufferId\0bufferId\0MsgId\0first\0last\0"
    "limit\0additional\0requestBacklogFiltered\0"
    "type\0flags\0requestBacklogForward\0"
    "requestBacklogAll\0requestBacklogAllFiltered"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreBacklogManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      30,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    5,  164,    2, 0x0a /* Public */,
       1,    4,  175,    2, 0x2a /* Public | MethodCloned */,
       1,    3,  184,    2, 0x2a /* Public | MethodCloned */,
       1,    2,  191,    2, 0x2a /* Public | MethodCloned */,
       1,    1,  196,    2, 0x2a /* Public | MethodCloned */,
      10,    7,  199,    2, 0x0a /* Public */,
      10,    6,  214,    2, 0x2a /* Public | MethodCloned */,
      10,    5,  227,    2, 0x2a /* Public | MethodCloned */,
      10,    4,  238,    2, 0x2a /* Public | MethodCloned */,
      10,    3,  247,    2, 0x2a /* Public | MethodCloned */,
      10,    2,  254,    2, 0x2a /* Public | MethodCloned */,
      10,    1,  259,    2, 0x2a /* Public | MethodCloned */,
      13,    6,  262,    2, 0x0a /* Public */,
      13,    5,  275,    2, 0x2a /* Public | MethodCloned */,
      13,    4,  286,    2, 0x2a /* Public | MethodCloned */,
      13,    3,  295,    2, 0x2a /* Public | MethodCloned */,
      13,    2,  302,    2, 0x2a /* Public | MethodCloned */,
      13,    1,  307,    2, 0x2a /* Public | MethodCloned */,
      14,    4,  310,    2, 0x0a /* Public */,
      14,    3,  319,    2, 0x2a /* Public | MethodCloned */,
      14,    2,  326,    2, 0x2a /* Public | MethodCloned */,
      14,    1,  331,    2, 0x2a /* Public | MethodCloned */,
      14,    0,  334,    2, 0x2a /* Public | MethodCloned */,
      15,    6,  335,    2, 0x0a /* Public */,
      15,    5,  348,    2, 0x2a /* Public | MethodCloned */,
      15,    4,  359,    2, 0x2a /* Public | MethodCloned */,
      15,    3,  368,    2, 0x2a /* Public | MethodCloned */,
      15,    2,  375,    2, 0x2a /* Public | MethodCloned */,
      15,    1,  380,    2, 0x2a /* Public | MethodCloned */,
      15,    0,  383,    2, 0x2a /* Public | MethodCloned */,

 // slots: parameters
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    4,    6,    7,    8,    9,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int,    4,    6,    7,    8,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5,    4,    6,    7,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::QVariantList, 0x80000000 | 3,    4,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    4,    6,    7,    8,    9,   11,   12,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int, QMetaType::Int, QMetaType::Int,    4,    6,    7,    8,    9,   11,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    4,    6,    7,    8,    9,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int,    4,    6,    7,    8,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5,    4,    6,    7,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::QVariantList, 0x80000000 | 3,    4,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int, QMetaType::Int, QMetaType::Int,    4,    6,    7,    8,   11,   12,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    4,    6,    7,    8,   11,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int,    4,    6,    7,    8,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5, 0x80000000 | 5,    4,    6,    7,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::QVariantList, 0x80000000 | 3,    4,
    QMetaType::QVariantList, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    6,    7,    8,    9,
    QMetaType::QVariantList, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int,    6,    7,    8,
    QMetaType::QVariantList, 0x80000000 | 5, 0x80000000 | 5,    6,    7,
    QMetaType::QVariantList, 0x80000000 | 5,    6,
    QMetaType::QVariantList,
    QMetaType::QVariantList, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    6,    7,    8,    9,   11,   12,
    QMetaType::QVariantList, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int, QMetaType::Int, QMetaType::Int,    6,    7,    8,    9,   11,
    QMetaType::QVariantList, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int, QMetaType::Int,    6,    7,    8,    9,
    QMetaType::QVariantList, 0x80000000 | 5, 0x80000000 | 5, QMetaType::Int,    6,    7,    8,
    QMetaType::QVariantList, 0x80000000 | 5, 0x80000000 | 5,    6,    7,
    QMetaType::QVariantList, 0x80000000 | 5,    6,
    QMetaType::QVariantList,

       0        // eod
};

void CoreBacklogManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreBacklogManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 1: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 2: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 3: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 4: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 5: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 7: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 8: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 9: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 10: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 11: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 12: { QVariantList _r = _t->requestBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 13: { QVariantList _r = _t->requestBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 14: { QVariantList _r = _t->requestBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 15: { QVariantList _r = _t->requestBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 16: { QVariantList _r = _t->requestBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 17: { QVariantList _r = _t->requestBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 18: { QVariantList _r = _t->requestBacklogAll((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 19: { QVariantList _r = _t->requestBacklogAll((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 20: { QVariantList _r = _t->requestBacklogAll((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 21: { QVariantList _r = _t->requestBacklogAll((*reinterpret_cast< MsgId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 22: { QVariantList _r = _t->requestBacklogAll();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 23: { QVariantList _r = _t->requestBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 24: { QVariantList _r = _t->requestBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 25: { QVariantList _r = _t->requestBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 26: { QVariantList _r = _t->requestBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 27: { QVariantList _r = _t->requestBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 28: { QVariantList _r = _t->requestBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 29: { QVariantList _r = _t->requestBacklogAllFiltered();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreBacklogManager::staticMetaObject = { {
    QMetaObject::SuperData::link<BacklogManager::staticMetaObject>(),
    qt_meta_stringdata_CoreBacklogManager.data,
    qt_meta_data_CoreBacklogManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreBacklogManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreBacklogManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreBacklogManager.stringdata0))
        return static_cast<void*>(this);
    return BacklogManager::qt_metacast(_clname);
}

int CoreBacklogManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BacklogManager::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
