/****************************************************************************
** Meta object code from reading C++ file 'abstractbuffercontainer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/uisupport/abstractbuffercontainer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractbuffercontainer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_AbstractBufferContainer_t {
    QByteArrayData data[15];
    char stringdata0[168];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AbstractBufferContainer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AbstractBufferContainer_t qt_meta_stringdata_AbstractBufferContainer = {
    {
QT_MOC_LITERAL(0, 0, 23), // "AbstractBufferContainer"
QT_MOC_LITERAL(1, 24, 14), // "currentChanged"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 8), // "BufferId"
QT_MOC_LITERAL(4, 49, 11), // "QModelIndex"
QT_MOC_LITERAL(5, 61, 7), // "current"
QT_MOC_LITERAL(6, 69, 8), // "previous"
QT_MOC_LITERAL(7, 78, 20), // "rowsAboutToBeRemoved"
QT_MOC_LITERAL(8, 99, 6), // "parent"
QT_MOC_LITERAL(9, 106, 5), // "start"
QT_MOC_LITERAL(10, 112, 3), // "end"
QT_MOC_LITERAL(11, 116, 12), // "showChatView"
QT_MOC_LITERAL(12, 129, 12), // "removeBuffer"
QT_MOC_LITERAL(13, 142, 8), // "bufferId"
QT_MOC_LITERAL(14, 151, 16) // "setCurrentBuffer"

    },
    "AbstractBufferContainer\0currentChanged\0"
    "\0BufferId\0QModelIndex\0current\0previous\0"
    "rowsAboutToBeRemoved\0parent\0start\0end\0"
    "showChatView\0removeBuffer\0bufferId\0"
    "setCurrentBuffer"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AbstractBufferContainer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,
       1,    1,   52,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       1,    2,   55,    2, 0x09 /* Protected */,
       7,    3,   60,    2, 0x09 /* Protected */,
      11,    1,   67,    2, 0x09 /* Protected */,
      12,    1,   70,    2, 0x08 /* Private */,
      14,    1,   73,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 4,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4,    5,    6,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    8,    9,   10,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3,   13,
    QMetaType::Void, 0x80000000 | 3,   13,

       0        // eod
};

void AbstractBufferContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AbstractBufferContainer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->currentChanged((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 1: _t->currentChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 2: _t->currentChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 3: _t->rowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 4: _t->showChatView((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 5: _t->removeBuffer((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 6: _t->setCurrentBuffer((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (AbstractBufferContainer::*)(BufferId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractBufferContainer::currentChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (AbstractBufferContainer::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractBufferContainer::currentChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject AbstractBufferContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractItemView::staticMetaObject>(),
    qt_meta_stringdata_AbstractBufferContainer.data,
    qt_meta_data_AbstractBufferContainer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *AbstractBufferContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractBufferContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AbstractBufferContainer.stringdata0))
        return static_cast<void*>(this);
    return AbstractItemView::qt_metacast(_clname);
}

int AbstractBufferContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractItemView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void AbstractBufferContainer::currentChanged(BufferId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void AbstractBufferContainer::currentChanged(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
