/********************************************************************************
** Form generated from reading UI file 'corehighlightsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COREHIGHLIGHTSETTINGSPAGE_H
#define UI_COREHIGHLIGHTSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CoreHighlightSettingsPage
{
public:
    QVBoxLayout *vboxLayout;
    QFrame *coreUnsupportedWidget;
    QHBoxLayout *hboxLayout;
    QLabel *coreUnsupportedIcon;
    QLabel *coreUnsupportedLabel;
    QPushButton *coreUnsupportedDetails;
    QWidget *highlightsConfigWidget;
    QVBoxLayout *highlightConfigLayout;
    QTabWidget *tabWidget;
    QWidget *highlightTab;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *nickBox;
    QHBoxLayout *horizontalLayout;
    QComboBox *highlightNicksComboBox;
    QCheckBox *nicksCaseSensitive;
    QSpacerItem *horizontalSpacer;
    QGroupBox *rulesBox;
    QVBoxLayout *highlightLayout;
    QTableWidget *highlightTable;
    QHBoxLayout *highlightButtonBarLayout;
    QPushButton *highlightAdd;
    QPushButton *highlightRemove;
    QSpacerItem *highlightButtonBarSpacer;
    QPushButton *highlightImport;
    QWidget *ignoredTab;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *ignoresBox;
    QVBoxLayout *ignoredLayout;
    QTableWidget *ignoredTable;
    QHBoxLayout *ignoredButtonBarLayout;
    QPushButton *ignoredAdd;
    QPushButton *ignoredRemove;
    QSpacerItem *ignoredButtonBarSpacer;

    void setupUi(QWidget *CoreHighlightSettingsPage)
    {
        if (CoreHighlightSettingsPage->objectName().isEmpty())
            CoreHighlightSettingsPage->setObjectName(QString::fromUtf8("CoreHighlightSettingsPage"));
        CoreHighlightSettingsPage->resize(541, 404);
        vboxLayout = new QVBoxLayout(CoreHighlightSettingsPage);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        coreUnsupportedWidget = new QFrame(CoreHighlightSettingsPage);
        coreUnsupportedWidget->setObjectName(QString::fromUtf8("coreUnsupportedWidget"));
        coreUnsupportedWidget->setFrameShape(QFrame::NoFrame);
        coreUnsupportedWidget->setFrameShadow(QFrame::Plain);
        coreUnsupportedWidget->setLineWidth(0);
        hboxLayout = new QHBoxLayout(coreUnsupportedWidget);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        coreUnsupportedIcon = new QLabel(coreUnsupportedWidget);
        coreUnsupportedIcon->setObjectName(QString::fromUtf8("coreUnsupportedIcon"));
        coreUnsupportedIcon->setText(QString::fromUtf8("[icon]"));

        hboxLayout->addWidget(coreUnsupportedIcon);

        coreUnsupportedLabel = new QLabel(coreUnsupportedWidget);
        coreUnsupportedLabel->setObjectName(QString::fromUtf8("coreUnsupportedLabel"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(coreUnsupportedLabel->sizePolicy().hasHeightForWidth());
        coreUnsupportedLabel->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(coreUnsupportedLabel);

        coreUnsupportedDetails = new QPushButton(coreUnsupportedWidget);
        coreUnsupportedDetails->setObjectName(QString::fromUtf8("coreUnsupportedDetails"));

        hboxLayout->addWidget(coreUnsupportedDetails);


        vboxLayout->addWidget(coreUnsupportedWidget);

        highlightsConfigWidget = new QWidget(CoreHighlightSettingsPage);
        highlightsConfigWidget->setObjectName(QString::fromUtf8("highlightsConfigWidget"));
        highlightConfigLayout = new QVBoxLayout(highlightsConfigWidget);
        highlightConfigLayout->setObjectName(QString::fromUtf8("highlightConfigLayout"));
        highlightConfigLayout->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(highlightsConfigWidget);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        highlightTab = new QWidget();
        highlightTab->setObjectName(QString::fromUtf8("highlightTab"));
        verticalLayout_3 = new QVBoxLayout(highlightTab);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        nickBox = new QGroupBox(highlightTab);
        nickBox->setObjectName(QString::fromUtf8("nickBox"));
        horizontalLayout = new QHBoxLayout(nickBox);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        highlightNicksComboBox = new QComboBox(nickBox);
        highlightNicksComboBox->setObjectName(QString::fromUtf8("highlightNicksComboBox"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(highlightNicksComboBox->sizePolicy().hasHeightForWidth());
        highlightNicksComboBox->setSizePolicy(sizePolicy1);
        highlightNicksComboBox->setMinimumSize(QSize(0, 0));
        highlightNicksComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout->addWidget(highlightNicksComboBox);

        nicksCaseSensitive = new QCheckBox(nickBox);
        nicksCaseSensitive->setObjectName(QString::fromUtf8("nicksCaseSensitive"));
        nicksCaseSensitive->setChecked(true);

        horizontalLayout->addWidget(nicksCaseSensitive);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_3->addWidget(nickBox);

        rulesBox = new QGroupBox(highlightTab);
        rulesBox->setObjectName(QString::fromUtf8("rulesBox"));
        highlightLayout = new QVBoxLayout(rulesBox);
        highlightLayout->setObjectName(QString::fromUtf8("highlightLayout"));
        highlightTable = new QTableWidget(rulesBox);
        if (highlightTable->columnCount() < 6)
            highlightTable->setColumnCount(6);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        highlightTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        highlightTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        highlightTable->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        highlightTable->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        highlightTable->setHorizontalHeaderItem(4, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        highlightTable->setHorizontalHeaderItem(5, __qtablewidgetitem5);
        highlightTable->setObjectName(QString::fromUtf8("highlightTable"));
        highlightTable->setStyleSheet(QString::fromUtf8(""));

        highlightLayout->addWidget(highlightTable);

        highlightButtonBarLayout = new QHBoxLayout();
        highlightButtonBarLayout->setObjectName(QString::fromUtf8("highlightButtonBarLayout"));
        highlightButtonBarLayout->setContentsMargins(-1, 0, -1, 0);
        highlightAdd = new QPushButton(rulesBox);
        highlightAdd->setObjectName(QString::fromUtf8("highlightAdd"));

        highlightButtonBarLayout->addWidget(highlightAdd);

        highlightRemove = new QPushButton(rulesBox);
        highlightRemove->setObjectName(QString::fromUtf8("highlightRemove"));

        highlightButtonBarLayout->addWidget(highlightRemove);

        highlightButtonBarSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        highlightButtonBarLayout->addItem(highlightButtonBarSpacer);

        highlightImport = new QPushButton(rulesBox);
        highlightImport->setObjectName(QString::fromUtf8("highlightImport"));
#if QT_CONFIG(tooltip)
        highlightImport->setToolTip(QString::fromUtf8("Import highlight rules configured in ${source}"));
#endif // QT_CONFIG(tooltip)
        highlightImport->setText(QString::fromUtf8("Import ${source}"));

        highlightButtonBarLayout->addWidget(highlightImport);


        highlightLayout->addLayout(highlightButtonBarLayout);


        verticalLayout_3->addWidget(rulesBox);

        tabWidget->addTab(highlightTab, QString());
        ignoredTab = new QWidget();
        ignoredTab->setObjectName(QString::fromUtf8("ignoredTab"));
        verticalLayout_4 = new QVBoxLayout(ignoredTab);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        ignoresBox = new QGroupBox(ignoredTab);
        ignoresBox->setObjectName(QString::fromUtf8("ignoresBox"));
        ignoredLayout = new QVBoxLayout(ignoresBox);
        ignoredLayout->setObjectName(QString::fromUtf8("ignoredLayout"));
        ignoredTable = new QTableWidget(ignoresBox);
        if (ignoredTable->columnCount() < 6)
            ignoredTable->setColumnCount(6);
        QTableWidgetItem *__qtablewidgetitem6 = new QTableWidgetItem();
        ignoredTable->setHorizontalHeaderItem(0, __qtablewidgetitem6);
        QTableWidgetItem *__qtablewidgetitem7 = new QTableWidgetItem();
        ignoredTable->setHorizontalHeaderItem(1, __qtablewidgetitem7);
        QTableWidgetItem *__qtablewidgetitem8 = new QTableWidgetItem();
        ignoredTable->setHorizontalHeaderItem(2, __qtablewidgetitem8);
        QTableWidgetItem *__qtablewidgetitem9 = new QTableWidgetItem();
        ignoredTable->setHorizontalHeaderItem(3, __qtablewidgetitem9);
        QTableWidgetItem *__qtablewidgetitem10 = new QTableWidgetItem();
        ignoredTable->setHorizontalHeaderItem(4, __qtablewidgetitem10);
        QTableWidgetItem *__qtablewidgetitem11 = new QTableWidgetItem();
        ignoredTable->setHorizontalHeaderItem(5, __qtablewidgetitem11);
        ignoredTable->setObjectName(QString::fromUtf8("ignoredTable"));
        ignoredTable->setStyleSheet(QString::fromUtf8(""));

        ignoredLayout->addWidget(ignoredTable);

        ignoredButtonBarLayout = new QHBoxLayout();
        ignoredButtonBarLayout->setObjectName(QString::fromUtf8("ignoredButtonBarLayout"));
        ignoredButtonBarLayout->setContentsMargins(-1, 0, -1, 0);
        ignoredAdd = new QPushButton(ignoresBox);
        ignoredAdd->setObjectName(QString::fromUtf8("ignoredAdd"));

        ignoredButtonBarLayout->addWidget(ignoredAdd);

        ignoredRemove = new QPushButton(ignoresBox);
        ignoredRemove->setObjectName(QString::fromUtf8("ignoredRemove"));

        ignoredButtonBarLayout->addWidget(ignoredRemove);

        ignoredButtonBarSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        ignoredButtonBarLayout->addItem(ignoredButtonBarSpacer);


        ignoredLayout->addLayout(ignoredButtonBarLayout);


        verticalLayout_4->addWidget(ignoresBox);

        tabWidget->addTab(ignoredTab, QString());

        highlightConfigLayout->addWidget(tabWidget);


        vboxLayout->addWidget(highlightsConfigWidget);


        retranslateUi(CoreHighlightSettingsPage);

        tabWidget->setCurrentIndex(0);
        highlightNicksComboBox->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(CoreHighlightSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *CoreHighlightSettingsPage)
    {
        CoreHighlightSettingsPage->setWindowTitle(QCoreApplication::translate("CoreHighlightSettingsPage", "Form", nullptr));
        coreUnsupportedLabel->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Your Quassel core is too old to support remote highlights", nullptr));
        coreUnsupportedDetails->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Details...", nullptr));
        nickBox->setTitle(QCoreApplication::translate("CoreHighlightSettingsPage", "Highlight Nicks", nullptr));
        nicksCaseSensitive->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Case sensitive", nullptr));
        rulesBox->setTitle(QCoreApplication::translate("CoreHighlightSettingsPage", "Custom Highlights", nullptr));
        QTableWidgetItem *___qtablewidgetitem = highlightTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Enabled", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = highlightTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Rule", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = highlightTable->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "RegEx", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = highlightTable->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "CS", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = highlightTable->horizontalHeaderItem(4);
        ___qtablewidgetitem4->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Sender", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = highlightTable->horizontalHeaderItem(5);
        ___qtablewidgetitem5->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Channel", nullptr));
#if QT_CONFIG(tooltip)
        highlightTable->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        highlightAdd->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Add", nullptr));
        highlightRemove->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Remove", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(highlightTab), QCoreApplication::translate("CoreHighlightSettingsPage", "Highlight Rules", nullptr));
        ignoresBox->setTitle(QCoreApplication::translate("CoreHighlightSettingsPage", "Never Highlight For", nullptr));
        QTableWidgetItem *___qtablewidgetitem6 = ignoredTable->horizontalHeaderItem(0);
        ___qtablewidgetitem6->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Enabled", nullptr));
        QTableWidgetItem *___qtablewidgetitem7 = ignoredTable->horizontalHeaderItem(1);
        ___qtablewidgetitem7->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Rule", nullptr));
        QTableWidgetItem *___qtablewidgetitem8 = ignoredTable->horizontalHeaderItem(2);
        ___qtablewidgetitem8->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "RegEx", nullptr));
        QTableWidgetItem *___qtablewidgetitem9 = ignoredTable->horizontalHeaderItem(3);
        ___qtablewidgetitem9->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "CS", nullptr));
        QTableWidgetItem *___qtablewidgetitem10 = ignoredTable->horizontalHeaderItem(4);
        ___qtablewidgetitem10->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Sender", nullptr));
        QTableWidgetItem *___qtablewidgetitem11 = ignoredTable->horizontalHeaderItem(5);
        ___qtablewidgetitem11->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Channel", nullptr));
#if QT_CONFIG(tooltip)
        ignoredTable->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        ignoredAdd->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Add", nullptr));
        ignoredRemove->setText(QCoreApplication::translate("CoreHighlightSettingsPage", "Remove", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(ignoredTab), QCoreApplication::translate("CoreHighlightSettingsPage", "Highlight Ignore Rules", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CoreHighlightSettingsPage: public Ui_CoreHighlightSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COREHIGHLIGHTSETTINGSPAGE_H
