/****************************************************************************
** Meta object code from reading C++ file 'dccconfig.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/dccconfig.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dccconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DccConfig_t {
    QByteArrayData data[33];
    char stringdata0[426];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DccConfig_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DccConfig_t qt_meta_stringdata_DccConfig = {
    {
QT_MOC_LITERAL(0, 0, 9), // "DccConfig"
QT_MOC_LITERAL(1, 10, 13), // "setDccEnabled"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 7), // "enabled"
QT_MOC_LITERAL(4, 33, 13), // "setOutgoingIp"
QT_MOC_LITERAL(5, 47, 12), // "QHostAddress"
QT_MOC_LITERAL(6, 60, 10), // "outgoingIp"
QT_MOC_LITERAL(7, 71, 18), // "setIpDetectionMode"
QT_MOC_LITERAL(8, 90, 26), // "DccConfig::IpDetectionMode"
QT_MOC_LITERAL(9, 117, 15), // "ipDetectionMode"
QT_MOC_LITERAL(10, 133, 20), // "setPortSelectionMode"
QT_MOC_LITERAL(11, 154, 28), // "DccConfig::PortSelectionMode"
QT_MOC_LITERAL(12, 183, 17), // "portSelectionMode"
QT_MOC_LITERAL(13, 201, 10), // "setMinPort"
QT_MOC_LITERAL(14, 212, 4), // "port"
QT_MOC_LITERAL(15, 217, 10), // "setMaxPort"
QT_MOC_LITERAL(16, 228, 12), // "setChunkSize"
QT_MOC_LITERAL(17, 241, 9), // "chunkSize"
QT_MOC_LITERAL(18, 251, 14), // "setSendTimeout"
QT_MOC_LITERAL(19, 266, 7), // "timeout"
QT_MOC_LITERAL(20, 274, 16), // "setUsePassiveDcc"
QT_MOC_LITERAL(21, 291, 3), // "use"
QT_MOC_LITERAL(22, 295, 14), // "setUseFastSend"
QT_MOC_LITERAL(23, 310, 10), // "dccEnabled"
QT_MOC_LITERAL(24, 321, 7), // "minPort"
QT_MOC_LITERAL(25, 329, 7), // "maxPort"
QT_MOC_LITERAL(26, 337, 11), // "sendTimeout"
QT_MOC_LITERAL(27, 349, 13), // "usePassiveDcc"
QT_MOC_LITERAL(28, 363, 11), // "useFastSend"
QT_MOC_LITERAL(29, 375, 15), // "IpDetectionMode"
QT_MOC_LITERAL(30, 391, 9), // "Automatic"
QT_MOC_LITERAL(31, 401, 6), // "Manual"
QT_MOC_LITERAL(32, 408, 17) // "PortSelectionMode"

    },
    "DccConfig\0setDccEnabled\0\0enabled\0"
    "setOutgoingIp\0QHostAddress\0outgoingIp\0"
    "setIpDetectionMode\0DccConfig::IpDetectionMode\0"
    "ipDetectionMode\0setPortSelectionMode\0"
    "DccConfig::PortSelectionMode\0"
    "portSelectionMode\0setMinPort\0port\0"
    "setMaxPort\0setChunkSize\0chunkSize\0"
    "setSendTimeout\0timeout\0setUsePassiveDcc\0"
    "use\0setUseFastSend\0dccEnabled\0minPort\0"
    "maxPort\0sendTimeout\0usePassiveDcc\0"
    "useFastSend\0IpDetectionMode\0Automatic\0"
    "Manual\0PortSelectionMode"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DccConfig[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
      10,   94, // properties
       2,  124, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x0a /* Public */,
       4,    1,   67,    2, 0x0a /* Public */,
       7,    1,   70,    2, 0x0a /* Public */,
      10,    1,   73,    2, 0x0a /* Public */,
      13,    1,   76,    2, 0x0a /* Public */,
      15,    1,   79,    2, 0x0a /* Public */,
      16,    1,   82,    2, 0x0a /* Public */,
      18,    1,   85,    2, 0x0a /* Public */,
      20,    1,   88,    2, 0x0a /* Public */,
      22,    1,   91,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, QMetaType::UShort,   14,
    QMetaType::Void, QMetaType::UShort,   14,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Bool,   21,
    QMetaType::Void, QMetaType::Bool,   21,

 // properties: name, type, flags
      23, QMetaType::Bool, 0x00095103,
       6, 0x80000000 | 5, 0x0009510b,
       9, 0x80000000 | 8, 0x0009510b,
      12, 0x80000000 | 11, 0x0009510b,
      24, QMetaType::UShort, 0x00095103,
      25, QMetaType::UShort, 0x00095103,
      17, QMetaType::Int, 0x00095103,
      26, QMetaType::Int, 0x00095103,
      27, QMetaType::Bool, 0x00095103,
      28, QMetaType::Bool, 0x00095103,

 // enums: name, alias, flags, count, data
      29,   29, 0x2,    2,  134,
      32,   32, 0x2,    2,  138,

 // enum data: key, value
      30, uint(DccConfig::IpDetectionMode::Automatic),
      31, uint(DccConfig::IpDetectionMode::Manual),
      30, uint(DccConfig::PortSelectionMode::Automatic),
      31, uint(DccConfig::PortSelectionMode::Manual),

       0        // eod
};

void DccConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DccConfig *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setDccEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->setOutgoingIp((*reinterpret_cast< const QHostAddress(*)>(_a[1]))); break;
        case 2: _t->setIpDetectionMode((*reinterpret_cast< DccConfig::IpDetectionMode(*)>(_a[1]))); break;
        case 3: _t->setPortSelectionMode((*reinterpret_cast< DccConfig::PortSelectionMode(*)>(_a[1]))); break;
        case 4: _t->setMinPort((*reinterpret_cast< quint16(*)>(_a[1]))); break;
        case 5: _t->setMaxPort((*reinterpret_cast< quint16(*)>(_a[1]))); break;
        case 6: _t->setChunkSize((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->setSendTimeout((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->setUsePassiveDcc((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->setUseFastSend((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QHostAddress >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QHostAddress >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DccConfig *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isDccEnabled(); break;
        case 1: *reinterpret_cast< QHostAddress*>(_v) = _t->outgoingIp(); break;
        case 2: *reinterpret_cast< DccConfig::IpDetectionMode*>(_v) = _t->ipDetectionMode(); break;
        case 3: *reinterpret_cast< DccConfig::PortSelectionMode*>(_v) = _t->portSelectionMode(); break;
        case 4: *reinterpret_cast< quint16*>(_v) = _t->minPort(); break;
        case 5: *reinterpret_cast< quint16*>(_v) = _t->maxPort(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->chunkSize(); break;
        case 7: *reinterpret_cast< int*>(_v) = _t->sendTimeout(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->usePassiveDcc(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->useFastSend(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DccConfig *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDccEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setOutgoingIp(*reinterpret_cast< QHostAddress*>(_v)); break;
        case 2: _t->setIpDetectionMode(*reinterpret_cast< DccConfig::IpDetectionMode*>(_v)); break;
        case 3: _t->setPortSelectionMode(*reinterpret_cast< DccConfig::PortSelectionMode*>(_v)); break;
        case 4: _t->setMinPort(*reinterpret_cast< quint16*>(_v)); break;
        case 5: _t->setMaxPort(*reinterpret_cast< quint16*>(_v)); break;
        case 6: _t->setChunkSize(*reinterpret_cast< int*>(_v)); break;
        case 7: _t->setSendTimeout(*reinterpret_cast< int*>(_v)); break;
        case 8: _t->setUsePassiveDcc(*reinterpret_cast< bool*>(_v)); break;
        case 9: _t->setUseFastSend(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject DccConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_DccConfig.data,
    qt_meta_data_DccConfig,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DccConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DccConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DccConfig.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int DccConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 10;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
