/********************************************************************************
** Form generated from reading UI file 'capseditdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CAPSEDITDLG_H
#define UI_CAPSEDITDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_CapsEditDlg
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QLineEdit *skipCapsEdit;
    QLabel *label_2;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CapsEditDlg)
    {
        if (CapsEditDlg->objectName().isEmpty())
            CapsEditDlg->setObjectName(QString::fromUtf8("CapsEditDlg"));
        CapsEditDlg->resize(475, 154);
        verticalLayout = new QVBoxLayout(CapsEditDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        label = new QLabel(CapsEditDlg);
        label->setObjectName(QString::fromUtf8("label"));
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        skipCapsEdit = new QLineEdit(CapsEditDlg);
        skipCapsEdit->setObjectName(QString::fromUtf8("skipCapsEdit"));

        verticalLayout->addWidget(skipCapsEdit);

        label_2 = new QLabel(CapsEditDlg);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        label_2->setWordWrap(true);
        label_2->setOpenExternalLinks(true);
        label_2->setTextInteractionFlags(Qt::LinksAccessibleByKeyboard|Qt::LinksAccessibleByMouse);

        verticalLayout->addWidget(label_2);

        spacerItem = new QSpacerItem(270, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(CapsEditDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::RestoreDefaults);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(CapsEditDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), CapsEditDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), CapsEditDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(CapsEditDlg);
    } // setupUi

    void retranslateUi(QDialog *CapsEditDlg)
    {
        CapsEditDlg->setWindowTitle(QCoreApplication::translate("CapsEditDlg", "Edit Network Features", nullptr));
        label->setText(QCoreApplication::translate("CapsEditDlg", "<p>Enter a space-separated list of IRCv3 capabilities to ignore:</p>", nullptr));
        label_2->setText(QCoreApplication::translate("CapsEditDlg", "<p>A list of capabilities may be found at <a href=\"https://ircv3.net/irc/\">https://ircv3.net/irc/</a>.</p>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CapsEditDlg: public Ui_CapsEditDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CAPSEDITDLG_H
