/****************************************************************************
** Meta object code from reading C++ file 'ignorelistmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/ignorelistmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ignorelistmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_IgnoreListManager_t {
    QByteArrayData data[23];
    char stringdata0[312];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_IgnoreListManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_IgnoreListManager_t qt_meta_stringdata_IgnoreListManager = {
    {
QT_MOC_LITERAL(0, 0, 17), // "IgnoreListManager"
QT_MOC_LITERAL(1, 18, 11), // "ignoreAdded"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 10), // "IgnoreType"
QT_MOC_LITERAL(4, 42, 4), // "type"
QT_MOC_LITERAL(5, 47, 10), // "ignoreRule"
QT_MOC_LITERAL(6, 58, 7), // "isRegex"
QT_MOC_LITERAL(7, 66, 14), // "StrictnessType"
QT_MOC_LITERAL(8, 81, 10), // "strictness"
QT_MOC_LITERAL(9, 92, 9), // "ScopeType"
QT_MOC_LITERAL(10, 102, 5), // "scope"
QT_MOC_LITERAL(11, 108, 9), // "scopeRule"
QT_MOC_LITERAL(12, 118, 8), // "isActive"
QT_MOC_LITERAL(13, 127, 14), // "initIgnoreList"
QT_MOC_LITERAL(14, 142, 17), // "initSetIgnoreList"
QT_MOC_LITERAL(15, 160, 10), // "ignoreList"
QT_MOC_LITERAL(16, 171, 27), // "requestRemoveIgnoreListItem"
QT_MOC_LITERAL(17, 199, 20), // "removeIgnoreListItem"
QT_MOC_LITERAL(18, 220, 23), // "requestToggleIgnoreRule"
QT_MOC_LITERAL(19, 244, 16), // "toggleIgnoreRule"
QT_MOC_LITERAL(20, 261, 24), // "requestAddIgnoreListItem"
QT_MOC_LITERAL(21, 286, 7), // "isRegEx"
QT_MOC_LITERAL(22, 294, 17) // "addIgnoreListItem"

    },
    "IgnoreListManager\0ignoreAdded\0\0"
    "IgnoreType\0type\0ignoreRule\0isRegex\0"
    "StrictnessType\0strictness\0ScopeType\0"
    "scope\0scopeRule\0isActive\0initIgnoreList\0"
    "initSetIgnoreList\0ignoreList\0"
    "requestRemoveIgnoreListItem\0"
    "removeIgnoreListItem\0requestToggleIgnoreRule\0"
    "toggleIgnoreRule\0requestAddIgnoreListItem\0"
    "isRegEx\0addIgnoreListItem"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_IgnoreListManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    7,   59,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    0,   74,    2, 0x0a /* Public */,
      14,    1,   75,    2, 0x0a /* Public */,
      16,    1,   78,    2, 0x0a /* Public */,
      17,    1,   81,    2, 0x0a /* Public */,
      18,    1,   84,    2, 0x0a /* Public */,
      19,    1,   87,    2, 0x0a /* Public */,
      20,    7,   90,    2, 0x0a /* Public */,
      22,    7,  105,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::Bool, 0x80000000 | 7, 0x80000000 | 9, QMetaType::QVariant, QMetaType::Bool,    4,    5,    6,    8,   10,   11,   12,

 // slots: parameters
    QMetaType::QVariantMap,
    QMetaType::Void, QMetaType::QVariantMap,   15,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::Bool,    4,    5,   21,    8,   10,   11,   12,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Int, QMetaType::Int, QMetaType::QString, QMetaType::Bool,    4,    5,   21,    8,   10,   11,   12,

       0        // eod
};

void IgnoreListManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<IgnoreListManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->ignoreAdded((*reinterpret_cast< IgnoreType(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< StrictnessType(*)>(_a[4])),(*reinterpret_cast< ScopeType(*)>(_a[5])),(*reinterpret_cast< const QVariant(*)>(_a[6])),(*reinterpret_cast< bool(*)>(_a[7]))); break;
        case 1: { QVariantMap _r = _t->initIgnoreList();
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->initSetIgnoreList((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 3: _t->requestRemoveIgnoreListItem((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->removeIgnoreListItem((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->requestToggleIgnoreRule((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->toggleIgnoreRule((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->requestAddIgnoreListItem((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< bool(*)>(_a[7]))); break;
        case 8: _t->addIgnoreListItem((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< bool(*)>(_a[7]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (IgnoreListManager::*)(IgnoreType , const QString & , bool , StrictnessType , ScopeType , const QVariant & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IgnoreListManager::ignoreAdded)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject IgnoreListManager::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_IgnoreListManager.data,
    qt_meta_data_IgnoreListManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *IgnoreListManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IgnoreListManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_IgnoreListManager.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int IgnoreListManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void IgnoreListManager::ignoreAdded(IgnoreType _t1, const QString & _t2, bool _t3, StrictnessType _t4, ScopeType _t5, const QVariant & _t6, bool _t7)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t6))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t7))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
