/********************************************************************************
** Form generated from reading UI file 'coreconfigwizardintropage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CORECONFIGWIZARDINTROPAGE_H
#define UI_CORECONFIGWIZARDINTROPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CoreConfigWizardIntroPage
{
public:
    QHBoxLayout *hboxLayout;
    QLabel *label;

    void setupUi(QWidget *CoreConfigWizardIntroPage)
    {
        if (CoreConfigWizardIntroPage->objectName().isEmpty())
            CoreConfigWizardIntroPage->setObjectName(QString::fromUtf8("CoreConfigWizardIntroPage"));
        CoreConfigWizardIntroPage->resize(430, 202);
        hboxLayout = new QHBoxLayout(CoreConfigWizardIntroPage);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        label = new QLabel(CoreConfigWizardIntroPage);
        label->setObjectName(QString::fromUtf8("label"));
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        hboxLayout->addWidget(label);


        retranslateUi(CoreConfigWizardIntroPage);

        QMetaObject::connectSlotsByName(CoreConfigWizardIntroPage);
    } // setupUi

    void retranslateUi(QWidget *CoreConfigWizardIntroPage)
    {
        CoreConfigWizardIntroPage->setWindowTitle(QCoreApplication::translate("CoreConfigWizardIntroPage", "Form", nullptr));
        label->setText(QCoreApplication::translate("CoreConfigWizardIntroPage", "This wizard will guide you through the setup of your Quassel Core.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CoreConfigWizardIntroPage: public Ui_CoreConfigWizardIntroPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CORECONFIGWIZARDINTROPAGE_H
