/********************************************************************************
** Form generated from reading UI file 'nickeditdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NICKEDITDLG_H
#define UI_NICKEDITDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_NickEditDlg
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QLineEdit *nickEdit;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *NickEditDlg)
    {
        if (NickEditDlg->objectName().isEmpty())
            NickEditDlg->setObjectName(QString::fromUtf8("NickEditDlg"));
        NickEditDlg->resize(281, 100);
        verticalLayout = new QVBoxLayout(NickEditDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        label = new QLabel(NickEditDlg);
        label->setObjectName(QString::fromUtf8("label"));
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        nickEdit = new QLineEdit(NickEditDlg);
        nickEdit->setObjectName(QString::fromUtf8("nickEdit"));

        verticalLayout->addWidget(nickEdit);

        spacerItem = new QSpacerItem(270, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(NickEditDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(NickEditDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), NickEditDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), NickEditDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(NickEditDlg);
    } // setupUi

    void retranslateUi(QDialog *NickEditDlg)
    {
        NickEditDlg->setWindowTitle(QCoreApplication::translate("NickEditDlg", "Edit Nickname", nullptr));
        label->setText(QCoreApplication::translate("NickEditDlg", "Please enter a valid nickname:", nullptr));
#if QT_CONFIG(whatsthis)
        nickEdit->setWhatsThis(QCoreApplication::translate("NickEditDlg", "A valid nickname may contain letters from the English alphabet, digits, and the special characters {, }, [, ], \\, |, `, ^, _ and -.", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class NickEditDlg: public Ui_NickEditDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NICKEDITDLG_H
