/****************************************************************************
** Meta object code from reading C++ file 'netsplit.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/netsplit.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'netsplit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Netsplit_t {
    QByteArrayData data[14];
    char stringdata0[124];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Netsplit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Netsplit_t qt_meta_stringdata_Netsplit = {
    {
QT_MOC_LITERAL(0, 0, 8), // "Netsplit"
QT_MOC_LITERAL(1, 9, 12), // "netsplitJoin"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 8), // "Network*"
QT_MOC_LITERAL(4, 32, 3), // "net"
QT_MOC_LITERAL(5, 36, 7), // "channel"
QT_MOC_LITERAL(6, 44, 5), // "users"
QT_MOC_LITERAL(7, 50, 5), // "modes"
QT_MOC_LITERAL(8, 56, 11), // "quitMessage"
QT_MOC_LITERAL(9, 68, 9), // "earlyJoin"
QT_MOC_LITERAL(10, 78, 12), // "netsplitQuit"
QT_MOC_LITERAL(11, 91, 8), // "finished"
QT_MOC_LITERAL(12, 100, 11), // "joinTimeout"
QT_MOC_LITERAL(13, 112, 11) // "quitTimeout"

    },
    "Netsplit\0netsplitJoin\0\0Network*\0net\0"
    "channel\0users\0modes\0quitMessage\0"
    "earlyJoin\0netsplitQuit\0finished\0"
    "joinTimeout\0quitTimeout"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Netsplit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    5,   44,    2, 0x06 /* Public */,
       9,    4,   55,    2, 0x06 /* Public */,
      10,    4,   64,    2, 0x06 /* Public */,
      11,    0,   73,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    0,   74,    2, 0x08 /* Private */,
      13,    0,   75,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QStringList, QMetaType::QStringList, QMetaType::QString,    4,    5,    6,    7,    8,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QStringList, QMetaType::QStringList,    4,    5,    6,    7,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::QStringList, QMetaType::QString,    4,    5,    6,    8,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Netsplit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Netsplit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->netsplitJoin((*reinterpret_cast< Network*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QStringList(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5]))); break;
        case 1: _t->earlyJoin((*reinterpret_cast< Network*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QStringList(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4]))); break;
        case 2: _t->netsplitQuit((*reinterpret_cast< Network*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QStringList(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 3: _t->finished(); break;
        case 4: _t->joinTimeout(); break;
        case 5: _t->quitTimeout(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Netsplit::*)(Network * , const QString & , const QStringList & , const QStringList & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Netsplit::netsplitJoin)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Netsplit::*)(Network * , const QString & , const QStringList & , const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Netsplit::earlyJoin)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Netsplit::*)(Network * , const QString & , const QStringList & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Netsplit::netsplitQuit)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Netsplit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Netsplit::finished)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Netsplit::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Netsplit.data,
    qt_meta_data_Netsplit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Netsplit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Netsplit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Netsplit.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Netsplit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Netsplit::netsplitJoin(Network * _t1, const QString & _t2, const QStringList & _t3, const QStringList & _t4, const QString & _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Netsplit::earlyJoin(Network * _t1, const QString & _t2, const QStringList & _t3, const QStringList & _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Netsplit::netsplitQuit(Network * _t1, const QString & _t2, const QStringList & _t3, const QString & _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Netsplit::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
