/****************************************************************************
** Meta object code from reading C++ file 'channellistdlg.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/channellistdlg.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'channellistdlg.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ChannelListDlg_t {
    QByteArrayData data[15];
    char stringdata0[203];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChannelListDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChannelListDlg_t qt_meta_stringdata_ChannelListDlg = {
    {
QT_MOC_LITERAL(0, 0, 14), // "ChannelListDlg"
QT_MOC_LITERAL(1, 15, 13), // "requestSearch"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 18), // "receiveChannelList"
QT_MOC_LITERAL(4, 49, 9), // "NetworkId"
QT_MOC_LITERAL(5, 59, 5), // "netId"
QT_MOC_LITERAL(6, 65, 14), // "channelFilters"
QT_MOC_LITERAL(7, 80, 40), // "QList<IrcListHelper::ChannelD..."
QT_MOC_LITERAL(8, 121, 11), // "channelList"
QT_MOC_LITERAL(9, 133, 18), // "reportFinishedList"
QT_MOC_LITERAL(10, 152, 11), // "joinChannel"
QT_MOC_LITERAL(11, 164, 11), // "QModelIndex"
QT_MOC_LITERAL(12, 176, 10), // "toggleMode"
QT_MOC_LITERAL(13, 187, 9), // "showError"
QT_MOC_LITERAL(14, 197, 5) // "error"

    },
    "ChannelListDlg\0requestSearch\0\0"
    "receiveChannelList\0NetworkId\0netId\0"
    "channelFilters\0QList<IrcListHelper::ChannelDescription>\0"
    "channelList\0reportFinishedList\0"
    "joinChannel\0QModelIndex\0toggleMode\0"
    "showError\0error"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChannelListDlg[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x0a /* Public */,
       3,    3,   45,    2, 0x09 /* Protected */,
       9,    0,   52,    2, 0x09 /* Protected */,
      10,    1,   53,    2, 0x09 /* Protected */,
      12,    0,   56,    2, 0x08 /* Private */,
      13,    1,   57,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, QMetaType::QStringList, 0x80000000 | 7,    5,    6,    8,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   14,

       0        // eod
};

void ChannelListDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ChannelListDlg *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->requestSearch(); break;
        case 1: _t->receiveChannelList((*reinterpret_cast< const NetworkId(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])),(*reinterpret_cast< const QList<IrcListHelper::ChannelDescription>(*)>(_a[3]))); break;
        case 2: _t->reportFinishedList(); break;
        case 3: _t->joinChannel((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 4: _t->toggleMode(); break;
        case 5: _t->showError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ChannelListDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_ChannelListDlg.data,
    qt_meta_data_ChannelListDlg,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ChannelListDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChannelListDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ChannelListDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int ChannelListDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
