/********************************************************************************
** Form generated from reading UI file 'coresessionwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CORESESSIONWIDGET_H
#define UI_CORESESSIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CoreSessionWidget
{
public:
    QGridLayout *sessionLayout;
    QGroupBox *sessionGroup;
    QVBoxLayout *sessionGroupLayout;
    QGridLayout *contentLayout;
    QLabel *labelClientTitle;
    QLabel *labelClient;
    QLabel *labelVersionDateTitle;
    QLabel *labelVersionDate;
    QLabel *labelLocationTitle;
    QLabel *labelLocation;
    QLabel *labelUptimeTitle;
    QLabel *labelUptime;
    QLabel *labelSecureTitle;
    QLabel *labelSecure;
    QHBoxLayout *actionsLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *disconnectButton;

    void setupUi(QWidget *CoreSessionWidget)
    {
        if (CoreSessionWidget->objectName().isEmpty())
            CoreSessionWidget->setObjectName(QString::fromUtf8("CoreSessionWidget"));
        CoreSessionWidget->resize(480, 212);
        CoreSessionWidget->setMinimumSize(QSize(480, 0));
        sessionLayout = new QGridLayout(CoreSessionWidget);
        sessionLayout->setObjectName(QString::fromUtf8("sessionLayout"));
        sessionGroup = new QGroupBox(CoreSessionWidget);
        sessionGroup->setObjectName(QString::fromUtf8("sessionGroup"));
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(sessionGroup->sizePolicy().hasHeightForWidth());
        sessionGroup->setSizePolicy(sizePolicy);
        sessionGroupLayout = new QVBoxLayout(sessionGroup);
        sessionGroupLayout->setObjectName(QString::fromUtf8("sessionGroupLayout"));
        contentLayout = new QGridLayout();
        contentLayout->setObjectName(QString::fromUtf8("contentLayout"));
        labelClientTitle = new QLabel(sessionGroup);
        labelClientTitle->setObjectName(QString::fromUtf8("labelClientTitle"));

        contentLayout->addWidget(labelClientTitle, 0, 0, 1, 1);

        labelClient = new QLabel(sessionGroup);
        labelClient->setObjectName(QString::fromUtf8("labelClient"));
        labelClient->setText(QString::fromUtf8("v0.13-pre (0.12.0+372 git-12df418)"));
        labelClient->setOpenExternalLinks(true);
        labelClient->setTextInteractionFlags(Qt::TextBrowserInteraction);

        contentLayout->addWidget(labelClient, 0, 1, 1, 1);

        labelVersionDateTitle = new QLabel(sessionGroup);
        labelVersionDateTitle->setObjectName(QString::fromUtf8("labelVersionDateTitle"));

        contentLayout->addWidget(labelVersionDateTitle, 1, 0, 1, 1);

        labelVersionDate = new QLabel(sessionGroup);
        labelVersionDate->setObjectName(QString::fromUtf8("labelVersionDate"));
        labelVersionDate->setText(QString::fromUtf8("Sun Aug 27 04:29:53 2017"));

        contentLayout->addWidget(labelVersionDate, 1, 1, 1, 1);

        labelLocationTitle = new QLabel(sessionGroup);
        labelLocationTitle->setObjectName(QString::fromUtf8("labelLocationTitle"));

        contentLayout->addWidget(labelLocationTitle, 2, 0, 1, 1);

        labelLocation = new QLabel(sessionGroup);
        labelLocation->setObjectName(QString::fromUtf8("labelLocation"));
        labelLocation->setText(QString::fromUtf8("Kiel, Germany"));

        contentLayout->addWidget(labelLocation, 2, 1, 1, 1);

        labelUptimeTitle = new QLabel(sessionGroup);
        labelUptimeTitle->setObjectName(QString::fromUtf8("labelUptimeTitle"));

        contentLayout->addWidget(labelUptimeTitle, 3, 0, 1, 1);

        labelUptime = new QLabel(sessionGroup);
        labelUptime->setObjectName(QString::fromUtf8("labelUptime"));
        labelUptime->setText(QString::fromUtf8("Sun Aug 27 15:03:10 2017"));

        contentLayout->addWidget(labelUptime, 3, 1, 1, 1);

        labelSecureTitle = new QLabel(sessionGroup);
        labelSecureTitle->setObjectName(QString::fromUtf8("labelSecureTitle"));

        contentLayout->addWidget(labelSecureTitle, 4, 0, 1, 1);

        labelSecure = new QLabel(sessionGroup);
        labelSecure->setObjectName(QString::fromUtf8("labelSecure"));
        labelSecure->setText(QString::fromUtf8("No"));

        contentLayout->addWidget(labelSecure, 4, 1, 1, 1);

        contentLayout->setColumnStretch(0, 1);
        contentLayout->setColumnStretch(1, 3);

        sessionGroupLayout->addLayout(contentLayout);

        actionsLayout = new QHBoxLayout();
        actionsLayout->setObjectName(QString::fromUtf8("actionsLayout"));
        horizontalSpacer = new QSpacerItem(40, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        actionsLayout->addItem(horizontalSpacer);

        disconnectButton = new QPushButton(sessionGroup);
        disconnectButton->setObjectName(QString::fromUtf8("disconnectButton"));

        actionsLayout->addWidget(disconnectButton);


        sessionGroupLayout->addLayout(actionsLayout);


        sessionLayout->addWidget(sessionGroup, 0, 0, 1, 1);


        retranslateUi(CoreSessionWidget);

        QMetaObject::connectSlotsByName(CoreSessionWidget);
    } // setupUi

    void retranslateUi(QWidget *CoreSessionWidget)
    {
        sessionGroup->setTitle(QCoreApplication::translate("CoreSessionWidget", "12.34.56.78", nullptr));
        labelClientTitle->setText(QCoreApplication::translate("CoreSessionWidget", "Client:", nullptr));
        labelVersionDateTitle->setText(QCoreApplication::translate("CoreSessionWidget", "Version date:", nullptr));
        labelLocationTitle->setText(QCoreApplication::translate("CoreSessionWidget", "Location:", nullptr));
        labelUptimeTitle->setText(QCoreApplication::translate("CoreSessionWidget", "Connected since:", nullptr));
        labelSecureTitle->setText(QCoreApplication::translate("CoreSessionWidget", "Secure:", nullptr));
        disconnectButton->setText(QCoreApplication::translate("CoreSessionWidget", "End Session", nullptr));
        (void)CoreSessionWidget;
    } // retranslateUi

};

namespace Ui {
    class CoreSessionWidget: public Ui_CoreSessionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CORESESSIONWIDGET_H
