/********************************************************************************
** Form generated from reading UI file 'aliasessettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ALIASESSETTINGSPAGE_H
#define UI_ALIASESSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AliasesSettingsPage
{
public:
    QVBoxLayout *verticalLayout;
    QTableView *aliasesView;
    QHBoxLayout *horizontalLayout;
    QPushButton *newAliasButton;
    QPushButton *deleteAliasButton;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *AliasesSettingsPage)
    {
        if (AliasesSettingsPage->objectName().isEmpty())
            AliasesSettingsPage->setObjectName(QString::fromUtf8("AliasesSettingsPage"));
        AliasesSettingsPage->resize(291, 229);
        verticalLayout = new QVBoxLayout(AliasesSettingsPage);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        aliasesView = new QTableView(AliasesSettingsPage);
        aliasesView->setObjectName(QString::fromUtf8("aliasesView"));

        verticalLayout->addWidget(aliasesView);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        newAliasButton = new QPushButton(AliasesSettingsPage);
        newAliasButton->setObjectName(QString::fromUtf8("newAliasButton"));
        newAliasButton->setEnabled(false);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/list-add.png"), QSize(), QIcon::Normal, QIcon::Off);
        newAliasButton->setIcon(icon);

        horizontalLayout->addWidget(newAliasButton);

        deleteAliasButton = new QPushButton(AliasesSettingsPage);
        deleteAliasButton->setObjectName(QString::fromUtf8("deleteAliasButton"));
        deleteAliasButton->setEnabled(false);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/edit-delete.png"), QSize(), QIcon::Normal, QIcon::Off);
        deleteAliasButton->setIcon(icon1);

        horizontalLayout->addWidget(deleteAliasButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(AliasesSettingsPage);

        QMetaObject::connectSlotsByName(AliasesSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *AliasesSettingsPage)
    {
        AliasesSettingsPage->setWindowTitle(QCoreApplication::translate("AliasesSettingsPage", "Form", nullptr));
        newAliasButton->setText(QCoreApplication::translate("AliasesSettingsPage", "New", nullptr));
        deleteAliasButton->setText(QCoreApplication::translate("AliasesSettingsPage", "Delete", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AliasesSettingsPage: public Ui_AliasesSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ALIASESSETTINGSPAGE_H
