/****************************************************************************
** Meta object code from reading C++ file 'identitiessettingspage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/settingspages/identitiessettingspage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'identitiessettingspage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_IdentitiesSettingsPage_t {
    QByteArrayData data[17];
    char stringdata0[306];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_IdentitiesSettingsPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_IdentitiesSettingsPage_t qt_meta_stringdata_IdentitiesSettingsPage = {
    {
QT_MOC_LITERAL(0, 0, 22), // "IdentitiesSettingsPage"
QT_MOC_LITERAL(1, 23, 4), // "save"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 4), // "load"
QT_MOC_LITERAL(4, 34, 26), // "coreConnectionStateChanged"
QT_MOC_LITERAL(5, 61, 21), // "clientIdentityCreated"
QT_MOC_LITERAL(6, 83, 10), // "IdentityId"
QT_MOC_LITERAL(7, 94, 21), // "clientIdentityUpdated"
QT_MOC_LITERAL(8, 116, 21), // "clientIdentityRemoved"
QT_MOC_LITERAL(9, 138, 35), // "on_identityList_currentIndexC..."
QT_MOC_LITERAL(10, 174, 5), // "index"
QT_MOC_LITERAL(11, 180, 22), // "on_addIdentity_clicked"
QT_MOC_LITERAL(12, 203, 25), // "on_deleteIdentity_clicked"
QT_MOC_LITERAL(13, 229, 25), // "on_renameIdentity_clicked"
QT_MOC_LITERAL(14, 255, 17), // "continueUnsecured"
QT_MOC_LITERAL(15, 273, 16), // "widgetHasChanged"
QT_MOC_LITERAL(16, 290, 15) // "setWidgetStates"

    },
    "IdentitiesSettingsPage\0save\0\0load\0"
    "coreConnectionStateChanged\0"
    "clientIdentityCreated\0IdentityId\0"
    "clientIdentityUpdated\0clientIdentityRemoved\0"
    "on_identityList_currentIndexChanged\0"
    "index\0on_addIdentity_clicked\0"
    "on_deleteIdentity_clicked\0"
    "on_renameIdentity_clicked\0continueUnsecured\0"
    "widgetHasChanged\0setWidgetStates"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_IdentitiesSettingsPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x0a /* Public */,
       3,    0,   80,    2, 0x0a /* Public */,
       4,    1,   81,    2, 0x08 /* Private */,
       5,    1,   84,    2, 0x08 /* Private */,
       7,    0,   87,    2, 0x08 /* Private */,
       8,    1,   88,    2, 0x08 /* Private */,
       9,    1,   91,    2, 0x08 /* Private */,
      11,    0,   94,    2, 0x08 /* Private */,
      12,    0,   95,    2, 0x08 /* Private */,
      13,    0,   96,    2, 0x08 /* Private */,
      14,    0,   97,    2, 0x08 /* Private */,
      15,    0,   98,    2, 0x08 /* Private */,
      16,    0,   99,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void IdentitiesSettingsPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<IdentitiesSettingsPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->save(); break;
        case 1: _t->load(); break;
        case 2: _t->coreConnectionStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->clientIdentityCreated((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 4: _t->clientIdentityUpdated(); break;
        case 5: _t->clientIdentityRemoved((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 6: _t->on_identityList_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->on_addIdentity_clicked(); break;
        case 8: _t->on_deleteIdentity_clicked(); break;
        case 9: _t->on_renameIdentity_clicked(); break;
        case 10: _t->continueUnsecured(); break;
        case 11: _t->widgetHasChanged(); break;
        case 12: _t->setWidgetStates(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject IdentitiesSettingsPage::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingsPage::staticMetaObject>(),
    qt_meta_stringdata_IdentitiesSettingsPage.data,
    qt_meta_data_IdentitiesSettingsPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *IdentitiesSettingsPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IdentitiesSettingsPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_IdentitiesSettingsPage.stringdata0))
        return static_cast<void*>(this);
    return SettingsPage::qt_metacast(_clname);
}

int IdentitiesSettingsPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingsPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}
struct qt_meta_stringdata_CreateIdentityDlg_t {
    QByteArrayData data[4];
    char stringdata0[52];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CreateIdentityDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CreateIdentityDlg_t qt_meta_stringdata_CreateIdentityDlg = {
    {
QT_MOC_LITERAL(0, 0, 17), // "CreateIdentityDlg"
QT_MOC_LITERAL(1, 18, 27), // "on_identityName_textChanged"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 4) // "text"

    },
    "CreateIdentityDlg\0on_identityName_textChanged\0"
    "\0text"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CreateIdentityDlg[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,

       0        // eod
};

void CreateIdentityDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CreateIdentityDlg *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_identityName_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CreateIdentityDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_CreateIdentityDlg.data,
    qt_meta_data_CreateIdentityDlg,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CreateIdentityDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CreateIdentityDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CreateIdentityDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int CreateIdentityDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_SaveIdentitiesDlg_t {
    QByteArrayData data[3];
    char stringdata0[31];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SaveIdentitiesDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SaveIdentitiesDlg_t qt_meta_stringdata_SaveIdentitiesDlg = {
    {
QT_MOC_LITERAL(0, 0, 17), // "SaveIdentitiesDlg"
QT_MOC_LITERAL(1, 18, 11), // "clientEvent"
QT_MOC_LITERAL(2, 30, 0) // ""

    },
    "SaveIdentitiesDlg\0clientEvent\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SaveIdentitiesDlg[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void SaveIdentitiesDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SaveIdentitiesDlg *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clientEvent(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject SaveIdentitiesDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_SaveIdentitiesDlg.data,
    qt_meta_data_SaveIdentitiesDlg,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SaveIdentitiesDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SaveIdentitiesDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SaveIdentitiesDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int SaveIdentitiesDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
