/********************************************************************************
** Form generated from reading UI file 'inputwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INPUTWIDGET_H
#define UI_INPUTWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "multilineedit.h"

QT_BEGIN_NAMESPACE

class Ui_InputWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QFrame *controlsFrame;
    QHBoxLayout *controlsFrameLayout;
    QComboBox *ownNick;
    QToolButton *showStyleButton;
    QFrame *styleFrame;
    QHBoxLayout *styleHorizontalLayout;
    QToolButton *boldButton;
    QToolButton *italicButton;
    QToolButton *underlineButton;
    QToolButton *strikethroughButton;
    QToolButton *textcolorButton;
    QToolButton *highlightcolorButton;
    QToolButton *clearButton;
    QFrame *inputFrame;
    QVBoxLayout *inputFrameLayout;
    MultiLineEdit *inputEdit;
    QLabel *encryptionIconLabel;

    void setupUi(QWidget *InputWidget)
    {
        if (InputWidget->objectName().isEmpty())
            InputWidget->setObjectName(QString::fromUtf8("InputWidget"));
        InputWidget->resize(585, 192);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(InputWidget->sizePolicy().hasHeightForWidth());
        InputWidget->setSizePolicy(sizePolicy);
        InputWidget->setMinimumSize(QSize(384, 0));
        horizontalLayout = new QHBoxLayout(InputWidget);
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        controlsFrame = new QFrame(InputWidget);
        controlsFrame->setObjectName(QString::fromUtf8("controlsFrame"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(controlsFrame->sizePolicy().hasHeightForWidth());
        controlsFrame->setSizePolicy(sizePolicy1);
        controlsFrame->setFrameShape(QFrame::NoFrame);
        controlsFrame->setFrameShadow(QFrame::Raised);
        controlsFrameLayout = new QHBoxLayout(controlsFrame);
        controlsFrameLayout->setSpacing(0);
        controlsFrameLayout->setObjectName(QString::fromUtf8("controlsFrameLayout"));
        controlsFrameLayout->setContentsMargins(0, 0, 0, 0);
        ownNick = new QComboBox(controlsFrame);
        ownNick->setObjectName(QString::fromUtf8("ownNick"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::MinimumExpanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(ownNick->sizePolicy().hasHeightForWidth());
        ownNick->setSizePolicy(sizePolicy2);
        ownNick->setMinimumSize(QSize(0, 24));
        ownNick->setFrame(true);

        controlsFrameLayout->addWidget(ownNick);

        showStyleButton = new QToolButton(controlsFrame);
        showStyleButton->setObjectName(QString::fromUtf8("showStyleButton"));
        QSizePolicy sizePolicy3(QSizePolicy::Fixed, QSizePolicy::Maximum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(showStyleButton->sizePolicy().hasHeightForWidth());
        showStyleButton->setSizePolicy(sizePolicy3);
        showStyleButton->setMinimumSize(QSize(16, 24));
        showStyleButton->setMaximumSize(QSize(16, 16777215));
        showStyleButton->setCheckable(true);
        showStyleButton->setArrowType(Qt::RightArrow);

        controlsFrameLayout->addWidget(showStyleButton);

        styleFrame = new QFrame(controlsFrame);
        styleFrame->setObjectName(QString::fromUtf8("styleFrame"));
        QSizePolicy sizePolicy4(QSizePolicy::Preferred, QSizePolicy::Maximum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(styleFrame->sizePolicy().hasHeightForWidth());
        styleFrame->setSizePolicy(sizePolicy4);
        styleHorizontalLayout = new QHBoxLayout(styleFrame);
        styleHorizontalLayout->setSpacing(1);
        styleHorizontalLayout->setObjectName(QString::fromUtf8("styleHorizontalLayout"));
        styleHorizontalLayout->setContentsMargins(0, 0, 0, 0);
        boldButton = new QToolButton(styleFrame);
        boldButton->setObjectName(QString::fromUtf8("boldButton"));
        boldButton->setEnabled(true);
        sizePolicy3.setHeightForWidth(boldButton->sizePolicy().hasHeightForWidth());
        boldButton->setSizePolicy(sizePolicy3);
        boldButton->setMinimumSize(QSize(26, 24));
        boldButton->setMaximumSize(QSize(16777215, 16777215));
        boldButton->setIconSize(QSize(16, 16));
        boldButton->setCheckable(true);

        styleHorizontalLayout->addWidget(boldButton);

        italicButton = new QToolButton(styleFrame);
        italicButton->setObjectName(QString::fromUtf8("italicButton"));
        italicButton->setEnabled(true);
        sizePolicy3.setHeightForWidth(italicButton->sizePolicy().hasHeightForWidth());
        italicButton->setSizePolicy(sizePolicy3);
        italicButton->setMinimumSize(QSize(26, 24));
        italicButton->setMaximumSize(QSize(16777215, 16777215));
        italicButton->setIconSize(QSize(16, 16));
        italicButton->setCheckable(true);
        italicButton->setChecked(false);

        styleHorizontalLayout->addWidget(italicButton);

        underlineButton = new QToolButton(styleFrame);
        underlineButton->setObjectName(QString::fromUtf8("underlineButton"));
        underlineButton->setEnabled(true);
        sizePolicy3.setHeightForWidth(underlineButton->sizePolicy().hasHeightForWidth());
        underlineButton->setSizePolicy(sizePolicy3);
        underlineButton->setMinimumSize(QSize(26, 24));
        underlineButton->setMaximumSize(QSize(16777215, 16777215));
        underlineButton->setIconSize(QSize(16, 16));
        underlineButton->setCheckable(true);
        underlineButton->setChecked(false);

        styleHorizontalLayout->addWidget(underlineButton);

        strikethroughButton = new QToolButton(styleFrame);
        strikethroughButton->setObjectName(QString::fromUtf8("strikethroughButton"));
        strikethroughButton->setEnabled(true);
        sizePolicy3.setHeightForWidth(strikethroughButton->sizePolicy().hasHeightForWidth());
        strikethroughButton->setSizePolicy(sizePolicy3);
        strikethroughButton->setMinimumSize(QSize(26, 24));
        strikethroughButton->setMaximumSize(QSize(16777215, 16777215));
        strikethroughButton->setIconSize(QSize(16, 16));
        strikethroughButton->setCheckable(true);
        strikethroughButton->setChecked(false);

        styleHorizontalLayout->addWidget(strikethroughButton);

        textcolorButton = new QToolButton(styleFrame);
        textcolorButton->setObjectName(QString::fromUtf8("textcolorButton"));
        sizePolicy3.setHeightForWidth(textcolorButton->sizePolicy().hasHeightForWidth());
        textcolorButton->setSizePolicy(sizePolicy3);
        textcolorButton->setMinimumSize(QSize(0, 24));
        textcolorButton->setMaximumSize(QSize(16777215, 16777215));
        textcolorButton->setPopupMode(QToolButton::MenuButtonPopup);

        styleHorizontalLayout->addWidget(textcolorButton);

        highlightcolorButton = new QToolButton(styleFrame);
        highlightcolorButton->setObjectName(QString::fromUtf8("highlightcolorButton"));
        sizePolicy3.setHeightForWidth(highlightcolorButton->sizePolicy().hasHeightForWidth());
        highlightcolorButton->setSizePolicy(sizePolicy3);
        highlightcolorButton->setMinimumSize(QSize(0, 24));
        highlightcolorButton->setMaximumSize(QSize(16777215, 16777215));
        highlightcolorButton->setPopupMode(QToolButton::MenuButtonPopup);

        styleHorizontalLayout->addWidget(highlightcolorButton);

        clearButton = new QToolButton(styleFrame);
        clearButton->setObjectName(QString::fromUtf8("clearButton"));
        clearButton->setEnabled(true);
        sizePolicy3.setHeightForWidth(clearButton->sizePolicy().hasHeightForWidth());
        clearButton->setSizePolicy(sizePolicy3);
        clearButton->setMinimumSize(QSize(26, 24));
        clearButton->setMaximumSize(QSize(16777215, 16777215));
        clearButton->setIconSize(QSize(16, 16));

        styleHorizontalLayout->addWidget(clearButton);


        controlsFrameLayout->addWidget(styleFrame);


        horizontalLayout->addWidget(controlsFrame);

        inputFrame = new QFrame(InputWidget);
        inputFrame->setObjectName(QString::fromUtf8("inputFrame"));
        QSizePolicy sizePolicy5(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(inputFrame->sizePolicy().hasHeightForWidth());
        inputFrame->setSizePolicy(sizePolicy5);
        inputFrame->setFrameShape(QFrame::NoFrame);
        inputFrame->setFrameShadow(QFrame::Raised);
        inputFrameLayout = new QVBoxLayout(inputFrame);
        inputFrameLayout->setSpacing(0);
        inputFrameLayout->setObjectName(QString::fromUtf8("inputFrameLayout"));
        inputFrameLayout->setContentsMargins(0, 0, 0, 0);
        inputEdit = new MultiLineEdit(inputFrame);
        inputEdit->setObjectName(QString::fromUtf8("inputEdit"));
        inputEdit->setEnabled(true);
        QSizePolicy sizePolicy6(QSizePolicy::MinimumExpanding, QSizePolicy::Maximum);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(24);
        sizePolicy6.setHeightForWidth(inputEdit->sizePolicy().hasHeightForWidth());
        inputEdit->setSizePolicy(sizePolicy6);
        inputEdit->setMinimumSize(QSize(24, 0));
        inputEdit->setMaximumSize(QSize(16777215, 16777215));
        inputEdit->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        inputEdit->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        inputEdit->setLineWrapMode(QTextEdit::NoWrap);

        inputFrameLayout->addWidget(inputEdit);


        horizontalLayout->addWidget(inputFrame);

        encryptionIconLabel = new QLabel(InputWidget);
        encryptionIconLabel->setObjectName(QString::fromUtf8("encryptionIconLabel"));
        sizePolicy4.setHeightForWidth(encryptionIconLabel->sizePolicy().hasHeightForWidth());
        encryptionIconLabel->setSizePolicy(sizePolicy4);
        encryptionIconLabel->setText(QString::fromUtf8("<img src=\":/icons/oxygen/16x16/actions/document-encrypt.png\">"));

        horizontalLayout->addWidget(encryptionIconLabel);


        retranslateUi(InputWidget);

        QMetaObject::connectSlotsByName(InputWidget);
    } // setupUi

    void retranslateUi(QWidget *InputWidget)
    {
        InputWidget->setWindowTitle(QCoreApplication::translate("InputWidget", "Form", nullptr));
#if QT_CONFIG(tooltip)
        ownNick->setToolTip(QCoreApplication::translate("InputWidget", "View and change nick", nullptr));
#endif // QT_CONFIG(tooltip)
        showStyleButton->setText(QString());
#if QT_CONFIG(tooltip)
        boldButton->setToolTip(QCoreApplication::translate("InputWidget", "Bold", nullptr));
#endif // QT_CONFIG(tooltip)
        boldButton->setText(QString());
#if QT_CONFIG(tooltip)
        italicButton->setToolTip(QCoreApplication::translate("InputWidget", "Italic", nullptr));
#endif // QT_CONFIG(tooltip)
        italicButton->setText(QString());
#if QT_CONFIG(tooltip)
        underlineButton->setToolTip(QCoreApplication::translate("InputWidget", "Underline", nullptr));
#endif // QT_CONFIG(tooltip)
        underlineButton->setText(QString());
#if QT_CONFIG(tooltip)
        strikethroughButton->setToolTip(QCoreApplication::translate("InputWidget", "Strikethrough", nullptr));
#endif // QT_CONFIG(tooltip)
        strikethroughButton->setText(QString());
#if QT_CONFIG(tooltip)
        textcolorButton->setToolTip(QCoreApplication::translate("InputWidget", "Set foreground color", nullptr));
#endif // QT_CONFIG(tooltip)
        textcolorButton->setText(QString());
#if QT_CONFIG(tooltip)
        highlightcolorButton->setToolTip(QCoreApplication::translate("InputWidget", "Set background color", nullptr));
#endif // QT_CONFIG(tooltip)
        highlightcolorButton->setText(QString());
#if QT_CONFIG(tooltip)
        clearButton->setToolTip(QCoreApplication::translate("InputWidget", "Clear formatting", nullptr));
#endif // QT_CONFIG(tooltip)
        clearButton->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class InputWidget: public Ui_InputWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_INPUTWIDGET_H
