/****************************************************************************
** Meta object code from reading C++ file 'treemodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/client/treemodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'treemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_AbstractTreeItem_t {
    QByteArrayData data[10];
    char stringdata0[122];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AbstractTreeItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AbstractTreeItem_t qt_meta_stringdata_AbstractTreeItem = {
    {
QT_MOC_LITERAL(0, 0, 16), // "AbstractTreeItem"
QT_MOC_LITERAL(1, 17, 11), // "dataChanged"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 6), // "column"
QT_MOC_LITERAL(4, 37, 17), // "beginAppendChilds"
QT_MOC_LITERAL(5, 55, 8), // "firstRow"
QT_MOC_LITERAL(6, 64, 7), // "lastRow"
QT_MOC_LITERAL(7, 72, 15), // "endAppendChilds"
QT_MOC_LITERAL(8, 88, 17), // "beginRemoveChilds"
QT_MOC_LITERAL(9, 106, 15) // "endRemoveChilds"

    },
    "AbstractTreeItem\0dataChanged\0\0column\0"
    "beginAppendChilds\0firstRow\0lastRow\0"
    "endAppendChilds\0beginRemoveChilds\0"
    "endRemoveChilds"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AbstractTreeItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       1,    0,   47,    2, 0x26 /* Public | MethodCloned */,
       4,    2,   48,    2, 0x06 /* Public */,
       7,    0,   53,    2, 0x06 /* Public */,
       8,    2,   54,    2, 0x06 /* Public */,
       9,    0,   59,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    5,    6,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    5,    6,
    QMetaType::Void,

       0        // eod
};

void AbstractTreeItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AbstractTreeItem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->dataChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->dataChanged(); break;
        case 2: _t->beginAppendChilds((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->endAppendChilds(); break;
        case 4: _t->beginRemoveChilds((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->endRemoveChilds(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (AbstractTreeItem::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractTreeItem::dataChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (AbstractTreeItem::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractTreeItem::beginAppendChilds)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (AbstractTreeItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractTreeItem::endAppendChilds)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (AbstractTreeItem::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractTreeItem::beginRemoveChilds)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (AbstractTreeItem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AbstractTreeItem::endRemoveChilds)) {
                *result = 5;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject AbstractTreeItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_AbstractTreeItem.data,
    qt_meta_data_AbstractTreeItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *AbstractTreeItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractTreeItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AbstractTreeItem.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractTreeItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void AbstractTreeItem::dataChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 2
void AbstractTreeItem::beginAppendChilds(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void AbstractTreeItem::endAppendChilds()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AbstractTreeItem::beginRemoveChilds(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void AbstractTreeItem::endRemoveChilds()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
struct qt_meta_stringdata_SimpleTreeItem_t {
    QByteArrayData data[1];
    char stringdata0[15];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SimpleTreeItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SimpleTreeItem_t qt_meta_stringdata_SimpleTreeItem = {
    {
QT_MOC_LITERAL(0, 0, 14) // "SimpleTreeItem"

    },
    "SimpleTreeItem"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SimpleTreeItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void SimpleTreeItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject SimpleTreeItem::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractTreeItem::staticMetaObject>(),
    qt_meta_stringdata_SimpleTreeItem.data,
    qt_meta_data_SimpleTreeItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SimpleTreeItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SimpleTreeItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SimpleTreeItem.stringdata0))
        return static_cast<void*>(this);
    return AbstractTreeItem::qt_metacast(_clname);
}

int SimpleTreeItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTreeItem::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_PropertyMapItem_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PropertyMapItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PropertyMapItem_t qt_meta_stringdata_PropertyMapItem = {
    {
QT_MOC_LITERAL(0, 0, 15) // "PropertyMapItem"

    },
    "PropertyMapItem"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PropertyMapItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void PropertyMapItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject PropertyMapItem::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractTreeItem::staticMetaObject>(),
    qt_meta_stringdata_PropertyMapItem.data,
    qt_meta_data_PropertyMapItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *PropertyMapItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PropertyMapItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PropertyMapItem.stringdata0))
        return static_cast<void*>(this);
    return AbstractTreeItem::qt_metacast(_clname);
}

int PropertyMapItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTreeItem::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_TreeModel_t {
    QByteArrayData data[21];
    char stringdata0[278];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TreeModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TreeModel_t qt_meta_stringdata_TreeModel = {
    {
QT_MOC_LITERAL(0, 0, 9), // "TreeModel"
QT_MOC_LITERAL(1, 10, 15), // "itemDataChanged"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 6), // "column"
QT_MOC_LITERAL(4, 34, 17), // "beginAppendChilds"
QT_MOC_LITERAL(5, 52, 8), // "firstRow"
QT_MOC_LITERAL(6, 61, 7), // "lastRow"
QT_MOC_LITERAL(7, 69, 15), // "endAppendChilds"
QT_MOC_LITERAL(8, 85, 17), // "beginRemoveChilds"
QT_MOC_LITERAL(9, 103, 15), // "endRemoveChilds"
QT_MOC_LITERAL(10, 119, 27), // "debug_rowsAboutToBeInserted"
QT_MOC_LITERAL(11, 147, 11), // "QModelIndex"
QT_MOC_LITERAL(12, 159, 6), // "parent"
QT_MOC_LITERAL(13, 166, 5), // "start"
QT_MOC_LITERAL(14, 172, 3), // "end"
QT_MOC_LITERAL(15, 176, 26), // "debug_rowsAboutToBeRemoved"
QT_MOC_LITERAL(16, 203, 18), // "debug_rowsInserted"
QT_MOC_LITERAL(17, 222, 17), // "debug_rowsRemoved"
QT_MOC_LITERAL(18, 240, 17), // "debug_dataChanged"
QT_MOC_LITERAL(19, 258, 7), // "topLeft"
QT_MOC_LITERAL(20, 266, 11) // "bottomRight"

    },
    "TreeModel\0itemDataChanged\0\0column\0"
    "beginAppendChilds\0firstRow\0lastRow\0"
    "endAppendChilds\0beginRemoveChilds\0"
    "endRemoveChilds\0debug_rowsAboutToBeInserted\0"
    "QModelIndex\0parent\0start\0end\0"
    "debug_rowsAboutToBeRemoved\0"
    "debug_rowsInserted\0debug_rowsRemoved\0"
    "debug_dataChanged\0topLeft\0bottomRight"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TreeModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x08 /* Private */,
       1,    0,   72,    2, 0x28 /* Private | MethodCloned */,
       4,    2,   73,    2, 0x08 /* Private */,
       7,    0,   78,    2, 0x08 /* Private */,
       8,    2,   79,    2, 0x08 /* Private */,
       9,    0,   84,    2, 0x08 /* Private */,
      10,    3,   85,    2, 0x08 /* Private */,
      15,    3,   92,    2, 0x08 /* Private */,
      16,    3,   99,    2, 0x08 /* Private */,
      17,    3,  106,    2, 0x08 /* Private */,
      18,    2,  113,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    5,    6,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    5,    6,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11, QMetaType::Int, QMetaType::Int,   12,   13,   14,
    QMetaType::Void, 0x80000000 | 11, QMetaType::Int, QMetaType::Int,   12,   13,   14,
    QMetaType::Void, 0x80000000 | 11, QMetaType::Int, QMetaType::Int,   12,   13,   14,
    QMetaType::Void, 0x80000000 | 11, QMetaType::Int, QMetaType::Int,   12,   13,   14,
    QMetaType::Void, 0x80000000 | 11, 0x80000000 | 11,   19,   20,

       0        // eod
};

void TreeModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<TreeModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->itemDataChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->itemDataChanged(); break;
        case 2: _t->beginAppendChilds((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: _t->endAppendChilds(); break;
        case 4: _t->beginRemoveChilds((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->endRemoveChilds(); break;
        case 6: _t->debug_rowsAboutToBeInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 7: _t->debug_rowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 8: _t->debug_rowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 9: _t->debug_rowsRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 10: _t->debug_dataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject TreeModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_meta_stringdata_TreeModel.data,
    qt_meta_data_TreeModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *TreeModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TreeModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TreeModel.stringdata0))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int TreeModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
