/****************************************************************************
** Meta object code from reading C++ file 'bufferviewconfig.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/bufferviewconfig.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bufferviewconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BufferViewConfig_t {
    QByteArrayData data[54];
    char stringdata0[919];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferViewConfig_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferViewConfig_t qt_meta_stringdata_BufferViewConfig = {
    {
QT_MOC_LITERAL(0, 0, 16), // "BufferViewConfig"
QT_MOC_LITERAL(1, 17, 13), // "configChanged"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 17), // "bufferViewNameSet"
QT_MOC_LITERAL(4, 50, 14), // "bufferViewName"
QT_MOC_LITERAL(5, 65, 12), // "networkIdSet"
QT_MOC_LITERAL(6, 78, 9), // "NetworkId"
QT_MOC_LITERAL(7, 88, 9), // "networkId"
QT_MOC_LITERAL(8, 98, 13), // "bufferListSet"
QT_MOC_LITERAL(9, 112, 11), // "bufferAdded"
QT_MOC_LITERAL(10, 124, 8), // "BufferId"
QT_MOC_LITERAL(11, 133, 8), // "bufferId"
QT_MOC_LITERAL(12, 142, 3), // "pos"
QT_MOC_LITERAL(13, 146, 11), // "bufferMoved"
QT_MOC_LITERAL(14, 158, 13), // "bufferRemoved"
QT_MOC_LITERAL(15, 172, 24), // "bufferPermanentlyRemoved"
QT_MOC_LITERAL(16, 197, 14), // "initBufferList"
QT_MOC_LITERAL(17, 212, 17), // "initSetBufferList"
QT_MOC_LITERAL(18, 230, 7), // "buffers"
QT_MOC_LITERAL(19, 238, 18), // "initRemovedBuffers"
QT_MOC_LITERAL(20, 257, 21), // "initSetRemovedBuffers"
QT_MOC_LITERAL(21, 279, 29), // "initTemporarilyRemovedBuffers"
QT_MOC_LITERAL(22, 309, 32), // "initSetTemporarilyRemovedBuffers"
QT_MOC_LITERAL(23, 342, 17), // "setBufferViewName"
QT_MOC_LITERAL(24, 360, 12), // "setNetworkId"
QT_MOC_LITERAL(25, 373, 29), // "setAddNewBuffersAutomatically"
QT_MOC_LITERAL(26, 403, 26), // "addNewBuffersAutomatically"
QT_MOC_LITERAL(27, 430, 21), // "setSortAlphabetically"
QT_MOC_LITERAL(28, 452, 18), // "sortAlphabetically"
QT_MOC_LITERAL(29, 471, 20), // "setDisableDecoration"
QT_MOC_LITERAL(30, 492, 17), // "disableDecoration"
QT_MOC_LITERAL(31, 510, 21), // "setAllowedBufferTypes"
QT_MOC_LITERAL(32, 532, 11), // "bufferTypes"
QT_MOC_LITERAL(33, 544, 18), // "setMinimumActivity"
QT_MOC_LITERAL(34, 563, 8), // "activity"
QT_MOC_LITERAL(35, 572, 22), // "setHideInactiveBuffers"
QT_MOC_LITERAL(36, 595, 19), // "hideInactiveBuffers"
QT_MOC_LITERAL(37, 615, 23), // "setHideInactiveNetworks"
QT_MOC_LITERAL(38, 639, 20), // "hideInactiveNetworks"
QT_MOC_LITERAL(39, 660, 13), // "setShowSearch"
QT_MOC_LITERAL(40, 674, 10), // "showSearch"
QT_MOC_LITERAL(41, 685, 13), // "setBufferList"
QT_MOC_LITERAL(42, 699, 15), // "QList<BufferId>"
QT_MOC_LITERAL(43, 715, 9), // "addBuffer"
QT_MOC_LITERAL(44, 725, 10), // "moveBuffer"
QT_MOC_LITERAL(45, 736, 12), // "removeBuffer"
QT_MOC_LITERAL(46, 749, 23), // "removeBufferPermanently"
QT_MOC_LITERAL(47, 773, 24), // "requestSetBufferViewName"
QT_MOC_LITERAL(48, 798, 16), // "requestAddBuffer"
QT_MOC_LITERAL(49, 815, 17), // "requestMoveBuffer"
QT_MOC_LITERAL(50, 833, 19), // "requestRemoveBuffer"
QT_MOC_LITERAL(51, 853, 30), // "requestRemoveBufferPermanently"
QT_MOC_LITERAL(52, 884, 18), // "allowedBufferTypes"
QT_MOC_LITERAL(53, 903, 15) // "minimumActivity"

    },
    "BufferViewConfig\0configChanged\0\0"
    "bufferViewNameSet\0bufferViewName\0"
    "networkIdSet\0NetworkId\0networkId\0"
    "bufferListSet\0bufferAdded\0BufferId\0"
    "bufferId\0pos\0bufferMoved\0bufferRemoved\0"
    "bufferPermanentlyRemoved\0initBufferList\0"
    "initSetBufferList\0buffers\0initRemovedBuffers\0"
    "initSetRemovedBuffers\0"
    "initTemporarilyRemovedBuffers\0"
    "initSetTemporarilyRemovedBuffers\0"
    "setBufferViewName\0setNetworkId\0"
    "setAddNewBuffersAutomatically\0"
    "addNewBuffersAutomatically\0"
    "setSortAlphabetically\0sortAlphabetically\0"
    "setDisableDecoration\0disableDecoration\0"
    "setAllowedBufferTypes\0bufferTypes\0"
    "setMinimumActivity\0activity\0"
    "setHideInactiveBuffers\0hideInactiveBuffers\0"
    "setHideInactiveNetworks\0hideInactiveNetworks\0"
    "setShowSearch\0showSearch\0setBufferList\0"
    "QList<BufferId>\0addBuffer\0moveBuffer\0"
    "removeBuffer\0removeBufferPermanently\0"
    "requestSetBufferViewName\0requestAddBuffer\0"
    "requestMoveBuffer\0requestRemoveBuffer\0"
    "requestRemoveBufferPermanently\0"
    "allowedBufferTypes\0minimumActivity"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferViewConfig[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      34,   14, // methods
      10,  288, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  184,    2, 0x06 /* Public */,
       3,    1,  185,    2, 0x06 /* Public */,
       5,    1,  188,    2, 0x06 /* Public */,
       8,    0,  191,    2, 0x06 /* Public */,
       9,    2,  192,    2, 0x06 /* Public */,
      13,    2,  197,    2, 0x06 /* Public */,
      14,    1,  202,    2, 0x06 /* Public */,
      15,    1,  205,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    0,  208,    2, 0x0a /* Public */,
      17,    1,  209,    2, 0x0a /* Public */,
      19,    0,  212,    2, 0x0a /* Public */,
      20,    1,  213,    2, 0x0a /* Public */,
      21,    0,  216,    2, 0x0a /* Public */,
      22,    1,  217,    2, 0x0a /* Public */,
      23,    1,  220,    2, 0x0a /* Public */,
      24,    1,  223,    2, 0x0a /* Public */,
      25,    1,  226,    2, 0x0a /* Public */,
      27,    1,  229,    2, 0x0a /* Public */,
      29,    1,  232,    2, 0x0a /* Public */,
      31,    1,  235,    2, 0x0a /* Public */,
      33,    1,  238,    2, 0x0a /* Public */,
      35,    1,  241,    2, 0x0a /* Public */,
      37,    1,  244,    2, 0x0a /* Public */,
      39,    1,  247,    2, 0x0a /* Public */,
      41,    1,  250,    2, 0x0a /* Public */,
      43,    2,  253,    2, 0x0a /* Public */,
      44,    2,  258,    2, 0x0a /* Public */,
      45,    1,  263,    2, 0x0a /* Public */,
      46,    1,  266,    2, 0x0a /* Public */,
      47,    1,  269,    2, 0x0a /* Public */,
      48,    2,  272,    2, 0x0a /* Public */,
      49,    2,  277,    2, 0x0a /* Public */,
      50,    1,  282,    2, 0x0a /* Public */,
      51,    1,  285,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10, QMetaType::Int,   11,   12,
    QMetaType::Void, 0x80000000 | 10, QMetaType::Int,   11,   12,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10,   11,

 // slots: parameters
    QMetaType::QVariantList,
    QMetaType::Void, QMetaType::QVariantList,   18,
    QMetaType::QVariantList,
    QMetaType::Void, QMetaType::QVariantList,   18,
    QMetaType::QVariantList,
    QMetaType::Void, QMetaType::QVariantList,   18,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::Bool,   26,
    QMetaType::Void, QMetaType::Bool,   28,
    QMetaType::Void, QMetaType::Bool,   30,
    QMetaType::Void, QMetaType::Int,   32,
    QMetaType::Void, QMetaType::Int,   34,
    QMetaType::Void, QMetaType::Bool,   36,
    QMetaType::Void, QMetaType::Bool,   38,
    QMetaType::Void, QMetaType::Bool,   40,
    QMetaType::Void, 0x80000000 | 42,   18,
    QMetaType::Void, 0x80000000 | 10, QMetaType::Int,   11,   12,
    QMetaType::Void, 0x80000000 | 10, QMetaType::Int,   11,   12,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, 0x80000000 | 10, QMetaType::Int,   11,   12,
    QMetaType::Void, 0x80000000 | 10, QMetaType::Int,   11,   12,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10,   11,

 // properties: name, type, flags
       4, QMetaType::QString, 0x00095103,
       7, 0x80000000 | 6, 0x0009510b,
      26, QMetaType::Bool, 0x00095103,
      28, QMetaType::Bool, 0x00095103,
      36, QMetaType::Bool, 0x00095103,
      38, QMetaType::Bool, 0x00095103,
      30, QMetaType::Bool, 0x00095103,
      52, QMetaType::Int, 0x00095103,
      53, QMetaType::Int, 0x00095103,
      40, QMetaType::Bool, 0x00095103,

       0        // eod
};

void BufferViewConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferViewConfig *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->configChanged(); break;
        case 1: _t->bufferViewNameSet((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->networkIdSet((*reinterpret_cast< const NetworkId(*)>(_a[1]))); break;
        case 3: _t->bufferListSet(); break;
        case 4: _t->bufferAdded((*reinterpret_cast< const BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->bufferMoved((*reinterpret_cast< const BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 6: _t->bufferRemoved((*reinterpret_cast< const BufferId(*)>(_a[1]))); break;
        case 7: _t->bufferPermanentlyRemoved((*reinterpret_cast< const BufferId(*)>(_a[1]))); break;
        case 8: { QVariantList _r = _t->initBufferList();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->initSetBufferList((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 10: { QVariantList _r = _t->initRemovedBuffers();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->initSetRemovedBuffers((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 12: { QVariantList _r = _t->initTemporarilyRemovedBuffers();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->initSetTemporarilyRemovedBuffers((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 14: _t->setBufferViewName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->setNetworkId((*reinterpret_cast< const NetworkId(*)>(_a[1]))); break;
        case 16: _t->setAddNewBuffersAutomatically((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->setSortAlphabetically((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->setDisableDecoration((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: _t->setAllowedBufferTypes((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->setMinimumActivity((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: _t->setHideInactiveBuffers((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: _t->setHideInactiveNetworks((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->setShowSearch((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->setBufferList((*reinterpret_cast< const QList<BufferId>(*)>(_a[1]))); break;
        case 25: _t->addBuffer((*reinterpret_cast< const BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 26: _t->moveBuffer((*reinterpret_cast< const BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 27: _t->removeBuffer((*reinterpret_cast< const BufferId(*)>(_a[1]))); break;
        case 28: _t->removeBufferPermanently((*reinterpret_cast< const BufferId(*)>(_a[1]))); break;
        case 29: _t->requestSetBufferViewName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 30: _t->requestAddBuffer((*reinterpret_cast< const BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 31: _t->requestMoveBuffer((*reinterpret_cast< const BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 32: _t->requestRemoveBuffer((*reinterpret_cast< const BufferId(*)>(_a[1]))); break;
        case 33: _t->requestRemoveBufferPermanently((*reinterpret_cast< const BufferId(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<BufferId> >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BufferViewConfig::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferViewConfig::configChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (BufferViewConfig::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferViewConfig::bufferViewNameSet)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (BufferViewConfig::*)(const NetworkId & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferViewConfig::networkIdSet)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (BufferViewConfig::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferViewConfig::bufferListSet)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (BufferViewConfig::*)(const BufferId & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferViewConfig::bufferAdded)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (BufferViewConfig::*)(const BufferId & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferViewConfig::bufferMoved)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (BufferViewConfig::*)(const BufferId & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferViewConfig::bufferRemoved)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (BufferViewConfig::*)(const BufferId & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferViewConfig::bufferPermanentlyRemoved)) {
                *result = 7;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<BufferViewConfig *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->bufferViewName(); break;
        case 1: *reinterpret_cast< NetworkId*>(_v) = _t->networkId(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->addNewBuffersAutomatically(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->sortAlphabetically(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->hideInactiveBuffers(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->hideInactiveNetworks(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->disableDecoration(); break;
        case 7: *reinterpret_cast< int*>(_v) = _t->allowedBufferTypes(); break;
        case 8: *reinterpret_cast< int*>(_v) = _t->minimumActivity(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->showSearch(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<BufferViewConfig *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBufferViewName(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setNetworkId(*reinterpret_cast< NetworkId*>(_v)); break;
        case 2: _t->setAddNewBuffersAutomatically(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setSortAlphabetically(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setHideInactiveBuffers(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setHideInactiveNetworks(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setDisableDecoration(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setAllowedBufferTypes(*reinterpret_cast< int*>(_v)); break;
        case 8: _t->setMinimumActivity(*reinterpret_cast< int*>(_v)); break;
        case 9: _t->setShowSearch(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject BufferViewConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_BufferViewConfig.data,
    qt_meta_data_BufferViewConfig,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferViewConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferViewConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferViewConfig.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int BufferViewConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 10;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 10;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void BufferViewConfig::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BufferViewConfig::bufferViewNameSet(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void BufferViewConfig::networkIdSet(const NetworkId & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void BufferViewConfig::bufferListSet()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void BufferViewConfig::bufferAdded(const BufferId & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void BufferViewConfig::bufferMoved(const BufferId & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void BufferViewConfig::bufferRemoved(const BufferId & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void BufferViewConfig::bufferPermanentlyRemoved(const BufferId & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
