/****************************************************************************
** Meta object code from reading C++ file 'buffersyncer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/buffersyncer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'buffersyncer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BufferSyncer_t {
    QByteArrayData data[47];
    char stringdata0[728];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferSyncer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferSyncer_t qt_meta_stringdata_BufferSyncer = {
    {
QT_MOC_LITERAL(0, 0, 12), // "BufferSyncer"
QT_MOC_LITERAL(1, 13, 10), // "lastMsgSet"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 8), // "BufferId"
QT_MOC_LITERAL(4, 34, 6), // "buffer"
QT_MOC_LITERAL(5, 41, 5), // "MsgId"
QT_MOC_LITERAL(6, 47, 5), // "msgId"
QT_MOC_LITERAL(7, 53, 14), // "lastSeenMsgSet"
QT_MOC_LITERAL(8, 68, 13), // "markerLineSet"
QT_MOC_LITERAL(9, 82, 13), // "bufferRemoved"
QT_MOC_LITERAL(10, 96, 13), // "bufferRenamed"
QT_MOC_LITERAL(11, 110, 7), // "newName"
QT_MOC_LITERAL(12, 118, 24), // "buffersPermanentlyMerged"
QT_MOC_LITERAL(13, 143, 7), // "buffer1"
QT_MOC_LITERAL(14, 151, 7), // "buffer2"
QT_MOC_LITERAL(15, 159, 18), // "bufferMarkedAsRead"
QT_MOC_LITERAL(16, 178, 21), // "bufferActivityChanged"
QT_MOC_LITERAL(17, 200, 14), // "Message::Types"
QT_MOC_LITERAL(18, 215, 21), // "highlightCountChanged"
QT_MOC_LITERAL(19, 237, 11), // "initLastMsg"
QT_MOC_LITERAL(20, 249, 14), // "initSetLastMsg"
QT_MOC_LITERAL(21, 264, 15), // "initLastSeenMsg"
QT_MOC_LITERAL(22, 280, 18), // "initSetLastSeenMsg"
QT_MOC_LITERAL(23, 299, 15), // "initMarkerLines"
QT_MOC_LITERAL(24, 315, 18), // "initSetMarkerLines"
QT_MOC_LITERAL(25, 334, 14), // "initActivities"
QT_MOC_LITERAL(26, 349, 17), // "initSetActivities"
QT_MOC_LITERAL(27, 367, 19), // "initHighlightCounts"
QT_MOC_LITERAL(28, 387, 22), // "initSetHighlightCounts"
QT_MOC_LITERAL(29, 410, 10), // "setLastMsg"
QT_MOC_LITERAL(30, 421, 21), // "requestSetLastSeenMsg"
QT_MOC_LITERAL(31, 443, 20), // "requestSetMarkerLine"
QT_MOC_LITERAL(32, 464, 17), // "setBufferActivity"
QT_MOC_LITERAL(33, 482, 8), // "activity"
QT_MOC_LITERAL(34, 491, 17), // "setHighlightCount"
QT_MOC_LITERAL(35, 509, 5), // "count"
QT_MOC_LITERAL(36, 515, 19), // "requestRemoveBuffer"
QT_MOC_LITERAL(37, 535, 12), // "removeBuffer"
QT_MOC_LITERAL(38, 548, 19), // "requestRenameBuffer"
QT_MOC_LITERAL(39, 568, 12), // "renameBuffer"
QT_MOC_LITERAL(40, 581, 30), // "requestMergeBuffersPermanently"
QT_MOC_LITERAL(41, 612, 23), // "mergeBuffersPermanently"
QT_MOC_LITERAL(42, 636, 21), // "requestPurgeBufferIds"
QT_MOC_LITERAL(43, 658, 23), // "requestMarkBufferAsRead"
QT_MOC_LITERAL(44, 682, 16), // "markBufferAsRead"
QT_MOC_LITERAL(45, 699, 14), // "setLastSeenMsg"
QT_MOC_LITERAL(46, 714, 13) // "setMarkerLine"

    },
    "BufferSyncer\0lastMsgSet\0\0BufferId\0"
    "buffer\0MsgId\0msgId\0lastSeenMsgSet\0"
    "markerLineSet\0bufferRemoved\0bufferRenamed\0"
    "newName\0buffersPermanentlyMerged\0"
    "buffer1\0buffer2\0bufferMarkedAsRead\0"
    "bufferActivityChanged\0Message::Types\0"
    "highlightCountChanged\0initLastMsg\0"
    "initSetLastMsg\0initLastSeenMsg\0"
    "initSetLastSeenMsg\0initMarkerLines\0"
    "initSetMarkerLines\0initActivities\0"
    "initSetActivities\0initHighlightCounts\0"
    "initSetHighlightCounts\0setLastMsg\0"
    "requestSetLastSeenMsg\0requestSetMarkerLine\0"
    "setBufferActivity\0activity\0setHighlightCount\0"
    "count\0requestRemoveBuffer\0removeBuffer\0"
    "requestRenameBuffer\0renameBuffer\0"
    "requestMergeBuffersPermanently\0"
    "mergeBuffersPermanently\0requestPurgeBufferIds\0"
    "requestMarkBufferAsRead\0markBufferAsRead\0"
    "setLastSeenMsg\0setMarkerLine"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferSyncer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      35,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  189,    2, 0x06 /* Public */,
       7,    2,  194,    2, 0x06 /* Public */,
       8,    2,  199,    2, 0x06 /* Public */,
       9,    1,  204,    2, 0x06 /* Public */,
      10,    2,  207,    2, 0x06 /* Public */,
      12,    2,  212,    2, 0x06 /* Public */,
      15,    1,  217,    2, 0x06 /* Public */,
      16,    2,  220,    2, 0x06 /* Public */,
      18,    2,  225,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    0,  230,    2, 0x0a /* Public */,
      20,    1,  231,    2, 0x0a /* Public */,
      21,    0,  234,    2, 0x0a /* Public */,
      22,    1,  235,    2, 0x0a /* Public */,
      23,    0,  238,    2, 0x0a /* Public */,
      24,    1,  239,    2, 0x0a /* Public */,
      25,    0,  242,    2, 0x0a /* Public */,
      26,    1,  243,    2, 0x0a /* Public */,
      27,    0,  246,    2, 0x0a /* Public */,
      28,    1,  247,    2, 0x0a /* Public */,
      29,    2,  250,    2, 0x0a /* Public */,
      30,    2,  255,    2, 0x0a /* Public */,
      31,    2,  260,    2, 0x0a /* Public */,
      32,    2,  265,    2, 0x0a /* Public */,
      34,    2,  270,    2, 0x0a /* Public */,
      36,    1,  275,    2, 0x0a /* Public */,
      37,    1,  278,    2, 0x0a /* Public */,
      38,    2,  281,    2, 0x0a /* Public */,
      39,    2,  286,    2, 0x0a /* Public */,
      40,    2,  291,    2, 0x0a /* Public */,
      41,    2,  296,    2, 0x0a /* Public */,
      42,    0,  301,    2, 0x0a /* Public */,
      43,    1,  302,    2, 0x0a /* Public */,
      44,    1,  305,    2, 0x0a /* Public */,
      45,    2,  308,    2, 0x09 /* Protected */,
      46,    2,  313,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   11,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,   13,   14,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 17,    2,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    2,    2,

 // slots: parameters
    QMetaType::QVariantList,
    QMetaType::Void, QMetaType::QVariantList,    2,
    QMetaType::QVariantList,
    QMetaType::Void, QMetaType::QVariantList,    2,
    QMetaType::QVariantList,
    QMetaType::Void, QMetaType::QVariantList,    2,
    QMetaType::QVariantList,
    QMetaType::Void, QMetaType::QVariantList,    2,
    QMetaType::QVariantList,
    QMetaType::Void, QMetaType::QVariantList,    2,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,   33,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,   35,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   11,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   11,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,   13,   14,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,   13,   14,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Bool, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Bool, 0x80000000 | 3, 0x80000000 | 5,    4,    6,

       0        // eod
};

void BufferSyncer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferSyncer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->lastMsgSet((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const MsgId(*)>(_a[2]))); break;
        case 1: _t->lastSeenMsgSet((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const MsgId(*)>(_a[2]))); break;
        case 2: _t->markerLineSet((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const MsgId(*)>(_a[2]))); break;
        case 3: _t->bufferRemoved((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 4: _t->bufferRenamed((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 5: _t->buffersPermanentlyMerged((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< BufferId(*)>(_a[2]))); break;
        case 6: _t->bufferMarkedAsRead((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 7: _t->bufferActivityChanged((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< Message::Types(*)>(_a[2]))); break;
        case 8: _t->highlightCountChanged((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 9: { QVariantList _r = _t->initLastMsg();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->initSetLastMsg((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 11: { QVariantList _r = _t->initLastSeenMsg();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->initSetLastSeenMsg((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 13: { QVariantList _r = _t->initMarkerLines();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->initSetMarkerLines((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 15: { QVariantList _r = _t->initActivities();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->initSetActivities((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 17: { QVariantList _r = _t->initHighlightCounts();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->initSetHighlightCounts((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 19: _t->setLastMsg((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const MsgId(*)>(_a[2]))); break;
        case 20: _t->requestSetLastSeenMsg((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const MsgId(*)>(_a[2]))); break;
        case 21: _t->requestSetMarkerLine((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const MsgId(*)>(_a[2]))); break;
        case 22: _t->setBufferActivity((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 23: _t->setHighlightCount((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 24: _t->requestRemoveBuffer((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 25: _t->removeBuffer((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 26: _t->requestRenameBuffer((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 27: _t->renameBuffer((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 28: _t->requestMergeBuffersPermanently((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< BufferId(*)>(_a[2]))); break;
        case 29: _t->mergeBuffersPermanently((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< BufferId(*)>(_a[2]))); break;
        case 30: _t->requestPurgeBufferIds(); break;
        case 31: _t->requestMarkBufferAsRead((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 32: _t->markBufferAsRead((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 33: { bool _r = _t->setLastSeenMsg((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->setMarkerLine((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BufferSyncer::*)(BufferId , const MsgId & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferSyncer::lastMsgSet)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (BufferSyncer::*)(BufferId , const MsgId & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferSyncer::lastSeenMsgSet)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (BufferSyncer::*)(BufferId , const MsgId & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferSyncer::markerLineSet)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (BufferSyncer::*)(BufferId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferSyncer::bufferRemoved)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (BufferSyncer::*)(BufferId , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferSyncer::bufferRenamed)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (BufferSyncer::*)(BufferId , BufferId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferSyncer::buffersPermanentlyMerged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (BufferSyncer::*)(BufferId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferSyncer::bufferMarkedAsRead)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (BufferSyncer::*)(BufferId , Message::Types );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferSyncer::bufferActivityChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (BufferSyncer::*)(BufferId , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferSyncer::highlightCountChanged)) {
                *result = 8;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BufferSyncer::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_BufferSyncer.data,
    qt_meta_data_BufferSyncer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferSyncer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferSyncer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferSyncer.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int BufferSyncer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void BufferSyncer::lastMsgSet(BufferId _t1, const MsgId & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void BufferSyncer::lastSeenMsgSet(BufferId _t1, const MsgId & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void BufferSyncer::markerLineSet(BufferId _t1, const MsgId & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void BufferSyncer::bufferRemoved(BufferId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void BufferSyncer::bufferRenamed(BufferId _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void BufferSyncer::buffersPermanentlyMerged(BufferId _t1, BufferId _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void BufferSyncer::bufferMarkedAsRead(BufferId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void BufferSyncer::bufferActivityChanged(BufferId _t1, Message::Types _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void BufferSyncer::highlightCountChanged(BufferId _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
