/********************************************************************************
** Form generated from reading UI file 'settingsdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSDLG_H
#define UI_SETTINGSDLG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SettingsDlg
{
public:
    QVBoxLayout *verticalLayout_2;
    QSplitter *splitter;
    QTreeWidget *settingsTree;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout;
    QLabel *pageTitle;
    QFrame *line;
    QStackedWidget *settingsStack;
    QWidget *page;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SettingsDlg)
    {
        if (SettingsDlg->objectName().isEmpty())
            SettingsDlg->setObjectName(QString::fromUtf8("SettingsDlg"));
        SettingsDlg->resize(725, 575);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/16x16/actions/configure"), QSize(), QIcon::Normal, QIcon::Off);
        SettingsDlg->setWindowIcon(icon);
        verticalLayout_2 = new QVBoxLayout(SettingsDlg);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        splitter = new QSplitter(SettingsDlg);
        splitter->setObjectName(QString::fromUtf8("splitter"));
        splitter->setOrientation(Qt::Horizontal);
        settingsTree = new QTreeWidget(splitter);
        settingsTree->setObjectName(QString::fromUtf8("settingsTree"));
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(settingsTree->sizePolicy().hasHeightForWidth());
        settingsTree->setSizePolicy(sizePolicy);
        settingsTree->setMaximumSize(QSize(200, 16777215));
        splitter->addWidget(settingsTree);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName(QString::fromUtf8("layoutWidget"));
        verticalLayout = new QVBoxLayout(layoutWidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        pageTitle = new QLabel(layoutWidget);
        pageTitle->setObjectName(QString::fromUtf8("pageTitle"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        pageTitle->setFont(font);

        verticalLayout->addWidget(pageTitle);

        line = new QFrame(layoutWidget);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(line);

        settingsStack = new QStackedWidget(layoutWidget);
        settingsStack->setObjectName(QString::fromUtf8("settingsStack"));
        page = new QWidget();
        page->setObjectName(QString::fromUtf8("page"));
        settingsStack->addWidget(page);

        verticalLayout->addWidget(settingsStack);

        splitter->addWidget(layoutWidget);

        verticalLayout_2->addWidget(splitter);

        buttonBox = new QDialogButtonBox(SettingsDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset|QDialogButtonBox::RestoreDefaults);

        verticalLayout_2->addWidget(buttonBox);

        QWidget::setTabOrder(settingsTree, buttonBox);

        retranslateUi(SettingsDlg);

        QMetaObject::connectSlotsByName(SettingsDlg);
    } // setupUi

    void retranslateUi(QDialog *SettingsDlg)
    {
        SettingsDlg->setWindowTitle(QCoreApplication::translate("SettingsDlg", "Configure Quassel", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = settingsTree->headerItem();
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("SettingsDlg", "Settings", nullptr));
        pageTitle->setText(QCoreApplication::translate("SettingsDlg", "Settings", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SettingsDlg: public Ui_SettingsDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SETTINGSDLG_H
