/****************************************************************************
** Meta object code from reading C++ file 'multilineedit.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/uisupport/multilineedit.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multilineedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MultiLineEdit_t {
    QByteArrayData data[41];
    char stringdata0[532];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MultiLineEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MultiLineEdit_t qt_meta_stringdata_MultiLineEdit = {
    {
QT_MOC_LITERAL(0, 0, 13), // "MultiLineEdit"
QT_MOC_LITERAL(1, 14, 11), // "textEntered"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 4), // "text"
QT_MOC_LITERAL(4, 32, 13), // "noTextEntered"
QT_MOC_LITERAL(5, 46, 7), // "setMode"
QT_MOC_LITERAL(6, 54, 4), // "Mode"
QT_MOC_LITERAL(7, 59, 4), // "mode"
QT_MOC_LITERAL(8, 64, 12), // "setMinHeight"
QT_MOC_LITERAL(9, 77, 8), // "numLines"
QT_MOC_LITERAL(10, 86, 12), // "setMaxHeight"
QT_MOC_LITERAL(11, 99, 12), // "setEmacsMode"
QT_MOC_LITERAL(12, 112, 6), // "enable"
QT_MOC_LITERAL(13, 119, 20), // "setScrollBarsEnabled"
QT_MOC_LITERAL(14, 140, 25), // "setPasteProtectionEnabled"
QT_MOC_LITERAL(15, 166, 8), // "QWidget*"
QT_MOC_LITERAL(16, 175, 12), // "msgBoxParent"
QT_MOC_LITERAL(17, 188, 18), // "setLineWrapEnabled"
QT_MOC_LITERAL(18, 207, 10), // "setHistory"
QT_MOC_LITERAL(19, 218, 7), // "history"
QT_MOC_LITERAL(20, 226, 14), // "setTempHistory"
QT_MOC_LITERAL(21, 241, 18), // "QHash<int,QString>"
QT_MOC_LITERAL(22, 260, 11), // "tempHistory"
QT_MOC_LITERAL(23, 272, 6), // "setIdx"
QT_MOC_LITERAL(24, 279, 3), // "idx"
QT_MOC_LITERAL(25, 283, 16), // "on_returnPressed"
QT_MOC_LITERAL(26, 300, 14), // "on_textChanged"
QT_MOC_LITERAL(27, 315, 24), // "on_documentHeightChanged"
QT_MOC_LITERAL(28, 340, 6), // "height"
QT_MOC_LITERAL(29, 347, 12), // "addToHistory"
QT_MOC_LITERAL(30, 360, 9), // "temporary"
QT_MOC_LITERAL(31, 370, 18), // "historyMoveForward"
QT_MOC_LITERAL(32, 389, 15), // "historyMoveBack"
QT_MOC_LITERAL(33, 405, 26), // "convertRichtextToMircCodes"
QT_MOC_LITERAL(34, 432, 22), // "convertMircCodesToHtml"
QT_MOC_LITERAL(35, 455, 16), // "mircCodesChanged"
QT_MOC_LITERAL(36, 472, 12), // "QTextCursor&"
QT_MOC_LITERAL(37, 485, 6), // "cursor"
QT_MOC_LITERAL(38, 492, 10), // "peekcursor"
QT_MOC_LITERAL(39, 503, 20), // "setSpellCheckEnabled"
QT_MOC_LITERAL(40, 524, 7) // "enabled"

    },
    "MultiLineEdit\0textEntered\0\0text\0"
    "noTextEntered\0setMode\0Mode\0mode\0"
    "setMinHeight\0numLines\0setMaxHeight\0"
    "setEmacsMode\0enable\0setScrollBarsEnabled\0"
    "setPasteProtectionEnabled\0QWidget*\0"
    "msgBoxParent\0setLineWrapEnabled\0"
    "setHistory\0history\0setTempHistory\0"
    "QHash<int,QString>\0tempHistory\0setIdx\0"
    "idx\0on_returnPressed\0on_textChanged\0"
    "on_documentHeightChanged\0height\0"
    "addToHistory\0temporary\0historyMoveForward\0"
    "historyMoveBack\0convertRichtextToMircCodes\0"
    "convertMircCodesToHtml\0mircCodesChanged\0"
    "QTextCursor&\0cursor\0peekcursor\0"
    "setSpellCheckEnabled\0enabled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MultiLineEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  159,    2, 0x06 /* Public */,
       4,    0,  162,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,  163,    2, 0x0a /* Public */,
       8,    1,  166,    2, 0x0a /* Public */,
      10,    1,  169,    2, 0x0a /* Public */,
      11,    1,  172,    2, 0x0a /* Public */,
      11,    0,  175,    2, 0x2a /* Public | MethodCloned */,
      13,    1,  176,    2, 0x0a /* Public */,
      13,    0,  179,    2, 0x2a /* Public | MethodCloned */,
      14,    2,  180,    2, 0x0a /* Public */,
      14,    1,  185,    2, 0x2a /* Public | MethodCloned */,
      14,    0,  188,    2, 0x2a /* Public | MethodCloned */,
      17,    1,  189,    2, 0x0a /* Public */,
      17,    0,  192,    2, 0x2a /* Public | MethodCloned */,
      18,    1,  193,    2, 0x0a /* Public */,
      20,    1,  196,    2, 0x0a /* Public */,
      23,    1,  199,    2, 0x0a /* Public */,
      25,    0,  202,    2, 0x08 /* Private */,
      25,    1,  203,    2, 0x08 /* Private */,
      26,    0,  206,    2, 0x08 /* Private */,
      27,    1,  207,    2, 0x08 /* Private */,
      29,    2,  210,    2, 0x08 /* Private */,
      29,    1,  215,    2, 0x28 /* Private | MethodCloned */,
      31,    0,  218,    2, 0x08 /* Private */,
      32,    0,  219,    2, 0x08 /* Private */,
      33,    0,  220,    2, 0x08 /* Private */,
      34,    1,  221,    2, 0x08 /* Private */,
      35,    2,  224,    2, 0x08 /* Private */,
      39,    1,  229,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, 0x80000000 | 15,   12,   16,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QStringList,   19,
    QMetaType::Void, 0x80000000 | 21,   22,
    QMetaType::Void, QMetaType::Int,   24,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QReal,   28,
    QMetaType::Bool, QMetaType::QString, QMetaType::Bool,    3,   30,
    QMetaType::Bool, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::QString,
    QMetaType::QString, QMetaType::QString,    3,
    QMetaType::Bool, 0x80000000 | 36, 0x80000000 | 36,   37,   38,
    QMetaType::Void, QMetaType::Bool,   40,

       0        // eod
};

void MultiLineEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MultiLineEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->textEntered((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->noTextEntered(); break;
        case 2: _t->setMode((*reinterpret_cast< Mode(*)>(_a[1]))); break;
        case 3: _t->setMinHeight((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->setMaxHeight((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->setEmacsMode((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->setEmacsMode(); break;
        case 7: _t->setScrollBarsEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->setScrollBarsEnabled(); break;
        case 9: _t->setPasteProtectionEnabled((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2]))); break;
        case 10: _t->setPasteProtectionEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->setPasteProtectionEnabled(); break;
        case 12: _t->setLineWrapEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->setLineWrapEnabled(); break;
        case 14: _t->setHistory((*reinterpret_cast< QStringList(*)>(_a[1]))); break;
        case 15: _t->setTempHistory((*reinterpret_cast< QHash<int,QString>(*)>(_a[1]))); break;
        case 16: _t->setIdx((*reinterpret_cast< qint32(*)>(_a[1]))); break;
        case 17: _t->on_returnPressed(); break;
        case 18: _t->on_returnPressed((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 19: _t->on_textChanged(); break;
        case 20: _t->on_documentHeightChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 21: { bool _r = _t->addToHistory((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->addToHistory((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->historyMoveForward(); break;
        case 24: _t->historyMoveBack(); break;
        case 25: { QString _r = _t->convertRichtextToMircCodes();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 26: { QString _r = _t->convertMircCodesToHtml((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->mircCodesChanged((*reinterpret_cast< QTextCursor(*)>(_a[1])),(*reinterpret_cast< QTextCursor(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->setSpellCheckEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MultiLineEdit::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiLineEdit::textEntered)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (MultiLineEdit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MultiLineEdit::noTextEntered)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MultiLineEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QTextEdit::staticMetaObject>(),
    qt_meta_stringdata_MultiLineEdit.data,
    qt_meta_data_MultiLineEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MultiLineEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MultiLineEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MultiLineEdit.stringdata0))
        return static_cast<void*>(this);
    return QTextEdit::qt_metacast(_clname);
}

int MultiLineEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void MultiLineEdit::textEntered(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void MultiLineEdit::noTextEntered()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
