/****************************************************************************
** Meta object code from reading C++ file 'network.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/network.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'network.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Network_t {
    QByteArrayData data[139];
    char stringdata0[2060];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Network_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Network_t qt_meta_stringdata_Network = {
    {
QT_MOC_LITERAL(0, 0, 7), // "Network"
QT_MOC_LITERAL(1, 8, 18), // "aboutToBeDestroyed"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 14), // "networkNameSet"
QT_MOC_LITERAL(4, 43, 11), // "networkName"
QT_MOC_LITERAL(5, 55, 16), // "currentServerSet"
QT_MOC_LITERAL(6, 72, 13), // "currentServer"
QT_MOC_LITERAL(7, 86, 12), // "connectedSet"
QT_MOC_LITERAL(8, 99, 11), // "isConnected"
QT_MOC_LITERAL(9, 111, 18), // "connectionStateSet"
QT_MOC_LITERAL(10, 130, 24), // "Network::ConnectionState"
QT_MOC_LITERAL(11, 155, 15), // "connectionError"
QT_MOC_LITERAL(12, 171, 8), // "errorMsg"
QT_MOC_LITERAL(13, 180, 9), // "myNickSet"
QT_MOC_LITERAL(14, 190, 6), // "mynick"
QT_MOC_LITERAL(15, 197, 11), // "identitySet"
QT_MOC_LITERAL(16, 209, 10), // "IdentityId"
QT_MOC_LITERAL(17, 220, 13), // "configChanged"
QT_MOC_LITERAL(18, 234, 23), // "useCustomMessageRateSet"
QT_MOC_LITERAL(19, 258, 13), // "useCustomRate"
QT_MOC_LITERAL(20, 272, 23), // "messageRateBurstSizeSet"
QT_MOC_LITERAL(21, 296, 9), // "burstSize"
QT_MOC_LITERAL(22, 306, 19), // "messageRateDelaySet"
QT_MOC_LITERAL(23, 326, 12), // "messageDelay"
QT_MOC_LITERAL(24, 339, 23), // "unlimitedMessageRateSet"
QT_MOC_LITERAL(25, 363, 13), // "unlimitedRate"
QT_MOC_LITERAL(26, 377, 8), // "capAdded"
QT_MOC_LITERAL(27, 386, 10), // "capability"
QT_MOC_LITERAL(28, 397, 15), // "capAcknowledged"
QT_MOC_LITERAL(29, 413, 10), // "capRemoved"
QT_MOC_LITERAL(30, 424, 12), // "ircUserAdded"
QT_MOC_LITERAL(31, 437, 8), // "IrcUser*"
QT_MOC_LITERAL(32, 446, 15), // "ircChannelAdded"
QT_MOC_LITERAL(33, 462, 11), // "IrcChannel*"
QT_MOC_LITERAL(34, 474, 14), // "setNetworkName"
QT_MOC_LITERAL(35, 489, 16), // "setCurrentServer"
QT_MOC_LITERAL(36, 506, 12), // "setConnected"
QT_MOC_LITERAL(37, 519, 18), // "setConnectionState"
QT_MOC_LITERAL(38, 538, 5), // "state"
QT_MOC_LITERAL(39, 544, 9), // "setMyNick"
QT_MOC_LITERAL(40, 554, 10), // "setLatency"
QT_MOC_LITERAL(41, 565, 7), // "latency"
QT_MOC_LITERAL(42, 573, 11), // "setIdentity"
QT_MOC_LITERAL(43, 585, 13), // "setServerList"
QT_MOC_LITERAL(44, 599, 10), // "serverList"
QT_MOC_LITERAL(45, 610, 18), // "setUseRandomServer"
QT_MOC_LITERAL(46, 629, 10), // "setPerform"
QT_MOC_LITERAL(47, 640, 11), // "setSkipCaps"
QT_MOC_LITERAL(48, 652, 8), // "skipCaps"
QT_MOC_LITERAL(49, 661, 18), // "setUseAutoIdentify"
QT_MOC_LITERAL(50, 680, 22), // "setAutoIdentifyService"
QT_MOC_LITERAL(51, 703, 23), // "setAutoIdentifyPassword"
QT_MOC_LITERAL(52, 727, 10), // "setUseSasl"
QT_MOC_LITERAL(53, 738, 14), // "setSaslAccount"
QT_MOC_LITERAL(54, 753, 15), // "setSaslPassword"
QT_MOC_LITERAL(55, 769, 19), // "setUseAutoReconnect"
QT_MOC_LITERAL(56, 789, 24), // "setAutoReconnectInterval"
QT_MOC_LITERAL(57, 814, 23), // "setAutoReconnectRetries"
QT_MOC_LITERAL(58, 838, 28), // "setUnlimitedReconnectRetries"
QT_MOC_LITERAL(59, 867, 17), // "setRejoinChannels"
QT_MOC_LITERAL(60, 885, 23), // "setUseCustomMessageRate"
QT_MOC_LITERAL(61, 909, 23), // "setMessageRateBurstSize"
QT_MOC_LITERAL(62, 933, 19), // "setMessageRateDelay"
QT_MOC_LITERAL(63, 953, 23), // "setUnlimitedMessageRate"
QT_MOC_LITERAL(64, 977, 17), // "setCodecForServer"
QT_MOC_LITERAL(65, 995, 9), // "codecName"
QT_MOC_LITERAL(66, 1005, 19), // "setCodecForEncoding"
QT_MOC_LITERAL(67, 1025, 19), // "setCodecForDecoding"
QT_MOC_LITERAL(68, 1045, 10), // "addSupport"
QT_MOC_LITERAL(69, 1056, 5), // "param"
QT_MOC_LITERAL(70, 1062, 5), // "value"
QT_MOC_LITERAL(71, 1068, 13), // "removeSupport"
QT_MOC_LITERAL(72, 1082, 6), // "addCap"
QT_MOC_LITERAL(73, 1089, 14), // "acknowledgeCap"
QT_MOC_LITERAL(74, 1104, 9), // "removeCap"
QT_MOC_LITERAL(75, 1114, 9), // "clearCaps"
QT_MOC_LITERAL(76, 1124, 10), // "addIrcUser"
QT_MOC_LITERAL(77, 1135, 8), // "hostmask"
QT_MOC_LITERAL(78, 1144, 13), // "addIrcChannel"
QT_MOC_LITERAL(79, 1158, 7), // "channel"
QT_MOC_LITERAL(80, 1166, 12), // "initSupports"
QT_MOC_LITERAL(81, 1179, 8), // "initCaps"
QT_MOC_LITERAL(82, 1188, 15), // "initCapsEnabled"
QT_MOC_LITERAL(83, 1204, 14), // "initServerList"
QT_MOC_LITERAL(84, 1219, 23), // "initIrcUsersAndChannels"
QT_MOC_LITERAL(85, 1243, 15), // "initSetSupports"
QT_MOC_LITERAL(86, 1259, 8), // "supports"
QT_MOC_LITERAL(87, 1268, 11), // "initSetCaps"
QT_MOC_LITERAL(88, 1280, 4), // "caps"
QT_MOC_LITERAL(89, 1285, 18), // "initSetCapsEnabled"
QT_MOC_LITERAL(90, 1304, 11), // "capsEnabled"
QT_MOC_LITERAL(91, 1316, 17), // "initSetServerList"
QT_MOC_LITERAL(92, 1334, 26), // "initSetIrcUsersAndChannels"
QT_MOC_LITERAL(93, 1361, 16), // "usersAndChannels"
QT_MOC_LITERAL(94, 1378, 18), // "updateNickFromMask"
QT_MOC_LITERAL(95, 1397, 4), // "mask"
QT_MOC_LITERAL(96, 1402, 18), // "ircUserNickChanged"
QT_MOC_LITERAL(97, 1421, 7), // "newnick"
QT_MOC_LITERAL(98, 1429, 14), // "requestConnect"
QT_MOC_LITERAL(99, 1444, 17), // "requestDisconnect"
QT_MOC_LITERAL(100, 1462, 21), // "requestSetNetworkInfo"
QT_MOC_LITERAL(101, 1484, 11), // "NetworkInfo"
QT_MOC_LITERAL(102, 1496, 4), // "info"
QT_MOC_LITERAL(103, 1501, 19), // "emitConnectionError"
QT_MOC_LITERAL(104, 1521, 13), // "removeIrcUser"
QT_MOC_LITERAL(105, 1535, 7), // "ircuser"
QT_MOC_LITERAL(106, 1543, 16), // "removeIrcChannel"
QT_MOC_LITERAL(107, 1560, 10), // "ircChannel"
QT_MOC_LITERAL(108, 1571, 19), // "removeChansAndUsers"
QT_MOC_LITERAL(109, 1591, 6), // "myNick"
QT_MOC_LITERAL(110, 1598, 14), // "codecForServer"
QT_MOC_LITERAL(111, 1613, 16), // "codecForEncoding"
QT_MOC_LITERAL(112, 1630, 16), // "codecForDecoding"
QT_MOC_LITERAL(113, 1647, 10), // "identityId"
QT_MOC_LITERAL(114, 1658, 15), // "connectionState"
QT_MOC_LITERAL(115, 1674, 15), // "useRandomServer"
QT_MOC_LITERAL(116, 1690, 7), // "perform"
QT_MOC_LITERAL(117, 1698, 15), // "useAutoIdentify"
QT_MOC_LITERAL(118, 1714, 19), // "autoIdentifyService"
QT_MOC_LITERAL(119, 1734, 20), // "autoIdentifyPassword"
QT_MOC_LITERAL(120, 1755, 7), // "useSasl"
QT_MOC_LITERAL(121, 1763, 11), // "saslAccount"
QT_MOC_LITERAL(122, 1775, 12), // "saslPassword"
QT_MOC_LITERAL(123, 1788, 16), // "useAutoReconnect"
QT_MOC_LITERAL(124, 1805, 21), // "autoReconnectInterval"
QT_MOC_LITERAL(125, 1827, 20), // "autoReconnectRetries"
QT_MOC_LITERAL(126, 1848, 25), // "unlimitedReconnectRetries"
QT_MOC_LITERAL(127, 1874, 14), // "rejoinChannels"
QT_MOC_LITERAL(128, 1889, 20), // "useCustomMessageRate"
QT_MOC_LITERAL(129, 1910, 16), // "msgRateBurstSize"
QT_MOC_LITERAL(130, 1927, 19), // "msgRateMessageDelay"
QT_MOC_LITERAL(131, 1947, 20), // "unlimitedMessageRate"
QT_MOC_LITERAL(132, 1968, 15), // "ConnectionState"
QT_MOC_LITERAL(133, 1984, 12), // "Disconnected"
QT_MOC_LITERAL(134, 1997, 10), // "Connecting"
QT_MOC_LITERAL(135, 2008, 12), // "Initializing"
QT_MOC_LITERAL(136, 2021, 11), // "Initialized"
QT_MOC_LITERAL(137, 2033, 12), // "Reconnecting"
QT_MOC_LITERAL(138, 2046, 13) // "Disconnecting"

    },
    "Network\0aboutToBeDestroyed\0\0networkNameSet\0"
    "networkName\0currentServerSet\0currentServer\0"
    "connectedSet\0isConnected\0connectionStateSet\0"
    "Network::ConnectionState\0connectionError\0"
    "errorMsg\0myNickSet\0mynick\0identitySet\0"
    "IdentityId\0configChanged\0"
    "useCustomMessageRateSet\0useCustomRate\0"
    "messageRateBurstSizeSet\0burstSize\0"
    "messageRateDelaySet\0messageDelay\0"
    "unlimitedMessageRateSet\0unlimitedRate\0"
    "capAdded\0capability\0capAcknowledged\0"
    "capRemoved\0ircUserAdded\0IrcUser*\0"
    "ircChannelAdded\0IrcChannel*\0setNetworkName\0"
    "setCurrentServer\0setConnected\0"
    "setConnectionState\0state\0setMyNick\0"
    "setLatency\0latency\0setIdentity\0"
    "setServerList\0serverList\0setUseRandomServer\0"
    "setPerform\0setSkipCaps\0skipCaps\0"
    "setUseAutoIdentify\0setAutoIdentifyService\0"
    "setAutoIdentifyPassword\0setUseSasl\0"
    "setSaslAccount\0setSaslPassword\0"
    "setUseAutoReconnect\0setAutoReconnectInterval\0"
    "setAutoReconnectRetries\0"
    "setUnlimitedReconnectRetries\0"
    "setRejoinChannels\0setUseCustomMessageRate\0"
    "setMessageRateBurstSize\0setMessageRateDelay\0"
    "setUnlimitedMessageRate\0setCodecForServer\0"
    "codecName\0setCodecForEncoding\0"
    "setCodecForDecoding\0addSupport\0param\0"
    "value\0removeSupport\0addCap\0acknowledgeCap\0"
    "removeCap\0clearCaps\0addIrcUser\0hostmask\0"
    "addIrcChannel\0channel\0initSupports\0"
    "initCaps\0initCapsEnabled\0initServerList\0"
    "initIrcUsersAndChannels\0initSetSupports\0"
    "supports\0initSetCaps\0caps\0initSetCapsEnabled\0"
    "capsEnabled\0initSetServerList\0"
    "initSetIrcUsersAndChannels\0usersAndChannels\0"
    "updateNickFromMask\0mask\0ircUserNickChanged\0"
    "newnick\0requestConnect\0requestDisconnect\0"
    "requestSetNetworkInfo\0NetworkInfo\0"
    "info\0emitConnectionError\0removeIrcUser\0"
    "ircuser\0removeIrcChannel\0ircChannel\0"
    "removeChansAndUsers\0myNick\0codecForServer\0"
    "codecForEncoding\0codecForDecoding\0"
    "identityId\0connectionState\0useRandomServer\0"
    "perform\0useAutoIdentify\0autoIdentifyService\0"
    "autoIdentifyPassword\0useSasl\0saslAccount\0"
    "saslPassword\0useAutoReconnect\0"
    "autoReconnectInterval\0autoReconnectRetries\0"
    "unlimitedReconnectRetries\0rejoinChannels\0"
    "useCustomMessageRate\0msgRateBurstSize\0"
    "msgRateMessageDelay\0unlimitedMessageRate\0"
    "ConnectionState\0Disconnected\0Connecting\0"
    "Initializing\0Initialized\0Reconnecting\0"
    "Disconnecting"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Network[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      76,   14, // methods
      28,  604, // properties
       1,  688, // enums/sets
       0,    0, // constructors
       0,       // flags
      18,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  394,    2, 0x06 /* Public */,
       3,    1,  395,    2, 0x06 /* Public */,
       5,    1,  398,    2, 0x06 /* Public */,
       7,    1,  401,    2, 0x06 /* Public */,
       9,    1,  404,    2, 0x06 /* Public */,
      11,    1,  407,    2, 0x06 /* Public */,
      13,    1,  410,    2, 0x06 /* Public */,
      15,    1,  413,    2, 0x06 /* Public */,
      17,    0,  416,    2, 0x06 /* Public */,
      18,    1,  417,    2, 0x06 /* Public */,
      20,    1,  420,    2, 0x06 /* Public */,
      22,    1,  423,    2, 0x06 /* Public */,
      24,    1,  426,    2, 0x06 /* Public */,
      26,    1,  429,    2, 0x06 /* Public */,
      28,    1,  432,    2, 0x06 /* Public */,
      29,    1,  435,    2, 0x06 /* Public */,
      30,    1,  438,    2, 0x06 /* Public */,
      32,    1,  441,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      34,    1,  444,    2, 0x0a /* Public */,
      35,    1,  447,    2, 0x0a /* Public */,
      36,    1,  450,    2, 0x0a /* Public */,
      37,    1,  453,    2, 0x0a /* Public */,
      39,    1,  456,    2, 0x0a /* Public */,
      40,    1,  459,    2, 0x0a /* Public */,
      42,    1,  462,    2, 0x0a /* Public */,
      43,    1,  465,    2, 0x0a /* Public */,
      45,    1,  468,    2, 0x0a /* Public */,
      46,    1,  471,    2, 0x0a /* Public */,
      47,    1,  474,    2, 0x0a /* Public */,
      49,    1,  477,    2, 0x0a /* Public */,
      50,    1,  480,    2, 0x0a /* Public */,
      51,    1,  483,    2, 0x0a /* Public */,
      52,    1,  486,    2, 0x0a /* Public */,
      53,    1,  489,    2, 0x0a /* Public */,
      54,    1,  492,    2, 0x0a /* Public */,
      55,    1,  495,    2, 0x0a /* Public */,
      56,    1,  498,    2, 0x0a /* Public */,
      57,    1,  501,    2, 0x0a /* Public */,
      58,    1,  504,    2, 0x0a /* Public */,
      59,    1,  507,    2, 0x0a /* Public */,
      60,    1,  510,    2, 0x0a /* Public */,
      61,    1,  513,    2, 0x0a /* Public */,
      62,    1,  516,    2, 0x0a /* Public */,
      63,    1,  519,    2, 0x0a /* Public */,
      64,    1,  522,    2, 0x0a /* Public */,
      66,    1,  525,    2, 0x0a /* Public */,
      67,    1,  528,    2, 0x0a /* Public */,
      68,    2,  531,    2, 0x0a /* Public */,
      68,    1,  536,    2, 0x2a /* Public | MethodCloned */,
      71,    1,  539,    2, 0x0a /* Public */,
      72,    2,  542,    2, 0x0a /* Public */,
      72,    1,  547,    2, 0x2a /* Public | MethodCloned */,
      73,    1,  550,    2, 0x0a /* Public */,
      74,    1,  553,    2, 0x0a /* Public */,
      75,    0,  556,    2, 0x0a /* Public */,
      76,    1,  557,    2, 0x0a /* Public */,
      78,    1,  560,    2, 0x0a /* Public */,
      80,    0,  563,    2, 0x0a /* Public */,
      81,    0,  564,    2, 0x0a /* Public */,
      82,    0,  565,    2, 0x0a /* Public */,
      83,    0,  566,    2, 0x0a /* Public */,
      84,    0,  567,    2, 0x0a /* Public */,
      85,    1,  568,    2, 0x0a /* Public */,
      87,    1,  571,    2, 0x0a /* Public */,
      89,    1,  574,    2, 0x0a /* Public */,
      91,    1,  577,    2, 0x0a /* Public */,
      92,    1,  580,    2, 0x0a /* Public */,
      94,    1,  583,    2, 0x0a /* Public */,
      96,    1,  586,    2, 0x0a /* Public */,
      98,    0,  589,    2, 0x0a /* Public */,
      99,    0,  590,    2, 0x0a /* Public */,
     100,    1,  591,    2, 0x0a /* Public */,
     103,    1,  594,    2, 0x0a /* Public */,
     104,    1,  597,    2, 0x09 /* Protected */,
     106,    1,  600,    2, 0x09 /* Protected */,
     108,    0,  603,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, 0x80000000 | 10,    2,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void, QMetaType::UInt,   21,
    QMetaType::Void, QMetaType::UInt,   23,
    QMetaType::Void, QMetaType::Bool,   25,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void, 0x80000000 | 31,    2,
    QMetaType::Void, 0x80000000 | 33,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, QMetaType::Int,   38,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::Int,   41,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, QMetaType::QVariantList,   44,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QStringList,    2,
    QMetaType::Void, QMetaType::QStringList,   48,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::UInt,    2,
    QMetaType::Void, QMetaType::UShort,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void, QMetaType::UInt,   21,
    QMetaType::Void, QMetaType::UInt,   23,
    QMetaType::Void, QMetaType::Bool,   25,
    QMetaType::Void, QMetaType::QByteArray,   65,
    QMetaType::Void, QMetaType::QByteArray,   65,
    QMetaType::Void, QMetaType::QByteArray,   65,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   69,   70,
    QMetaType::Void, QMetaType::QString,   69,
    QMetaType::Void, QMetaType::QString,   69,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   27,   70,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   77,
    QMetaType::Void, QMetaType::QString,   79,
    QMetaType::QVariantMap,
    QMetaType::QVariantMap,
    QMetaType::QVariantList,
    QMetaType::QVariantList,
    QMetaType::QVariantMap,
    QMetaType::Void, QMetaType::QVariantMap,   86,
    QMetaType::Void, QMetaType::QVariantMap,   88,
    QMetaType::Void, QMetaType::QVariantList,   90,
    QMetaType::Void, QMetaType::QVariantList,   44,
    QMetaType::Void, QMetaType::QVariantMap,   93,
    0x80000000 | 31, QMetaType::QString,   95,
    QMetaType::Void, QMetaType::QString,   97,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 101,  102,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 31,  105,
    QMetaType::Void, 0x80000000 | 33,  107,
    QMetaType::Void,

 // properties: name, type, flags
       4, QMetaType::QString, 0x00095103,
       6, QMetaType::QString, 0x00095103,
     109, QMetaType::QString, 0x00095103,
      41, QMetaType::Int, 0x00095103,
     110, QMetaType::QByteArray, 0x00095103,
     111, QMetaType::QByteArray, 0x00095103,
     112, QMetaType::QByteArray, 0x00095103,
     113, 0x80000000 | 16, 0x0009500b,
       8, QMetaType::Bool, 0x00095003,
     114, QMetaType::Int, 0x00095103,
     115, QMetaType::Bool, 0x00095103,
     116, QMetaType::QStringList, 0x00095103,
      48, QMetaType::QStringList, 0x00095103,
     117, QMetaType::Bool, 0x00095103,
     118, QMetaType::QString, 0x00095103,
     119, QMetaType::QString, 0x00095103,
     120, QMetaType::Bool, 0x00095103,
     121, QMetaType::QString, 0x00095103,
     122, QMetaType::QString, 0x00095103,
     123, QMetaType::Bool, 0x00095103,
     124, QMetaType::UInt, 0x00095103,
     125, QMetaType::UShort, 0x00095103,
     126, QMetaType::Bool, 0x00095103,
     127, QMetaType::Bool, 0x00095103,
     128, QMetaType::Bool, 0x00095103,
     129, QMetaType::UInt, 0x00095003,
     130, QMetaType::UInt, 0x00095003,
     131, QMetaType::Bool, 0x00095103,

 // enums: name, alias, flags, count, data
     132,  132, 0x0,    6,  693,

 // enum data: key, value
     133, uint(Network::Disconnected),
     134, uint(Network::Connecting),
     135, uint(Network::Initializing),
     136, uint(Network::Initialized),
     137, uint(Network::Reconnecting),
     138, uint(Network::Disconnecting),

       0        // eod
};

void Network::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Network *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->aboutToBeDestroyed(); break;
        case 1: _t->networkNameSet((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->currentServerSet((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->connectedSet((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->connectionStateSet((*reinterpret_cast< Network::ConnectionState(*)>(_a[1]))); break;
        case 5: _t->connectionError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->myNickSet((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->identitySet((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 8: _t->configChanged(); break;
        case 9: _t->useCustomMessageRateSet((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 10: _t->messageRateBurstSizeSet((*reinterpret_cast< const quint32(*)>(_a[1]))); break;
        case 11: _t->messageRateDelaySet((*reinterpret_cast< const quint32(*)>(_a[1]))); break;
        case 12: _t->unlimitedMessageRateSet((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 13: _t->capAdded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->capAcknowledged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->capRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 16: _t->ircUserAdded((*reinterpret_cast< IrcUser*(*)>(_a[1]))); break;
        case 17: _t->ircChannelAdded((*reinterpret_cast< IrcChannel*(*)>(_a[1]))); break;
        case 18: _t->setNetworkName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->setCurrentServer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->setConnected((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->setConnectionState((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->setMyNick((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 23: _t->setLatency((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: _t->setIdentity((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 25: _t->setServerList((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 26: _t->setUseRandomServer((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 27: _t->setPerform((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 28: _t->setSkipCaps((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 29: _t->setUseAutoIdentify((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 30: _t->setAutoIdentifyService((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 31: _t->setAutoIdentifyPassword((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 32: _t->setUseSasl((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 33: _t->setSaslAccount((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 34: _t->setSaslPassword((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 35: _t->setUseAutoReconnect((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 36: _t->setAutoReconnectInterval((*reinterpret_cast< quint32(*)>(_a[1]))); break;
        case 37: _t->setAutoReconnectRetries((*reinterpret_cast< quint16(*)>(_a[1]))); break;
        case 38: _t->setUnlimitedReconnectRetries((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 39: _t->setRejoinChannels((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 40: _t->setUseCustomMessageRate((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 41: _t->setMessageRateBurstSize((*reinterpret_cast< quint32(*)>(_a[1]))); break;
        case 42: _t->setMessageRateDelay((*reinterpret_cast< quint32(*)>(_a[1]))); break;
        case 43: _t->setUnlimitedMessageRate((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 44: _t->setCodecForServer((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 45: _t->setCodecForEncoding((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 46: _t->setCodecForDecoding((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 47: _t->addSupport((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 48: _t->addSupport((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 49: _t->removeSupport((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 50: _t->addCap((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 51: _t->addCap((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 52: _t->acknowledgeCap((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 53: _t->removeCap((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 54: _t->clearCaps(); break;
        case 55: _t->addIrcUser((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 56: _t->addIrcChannel((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 57: { QVariantMap _r = _t->initSupports();
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 58: { QVariantMap _r = _t->initCaps();
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 59: { QVariantList _r = _t->initCapsEnabled();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 60: { QVariantList _r = _t->initServerList();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 61: { QVariantMap _r = _t->initIrcUsersAndChannels();
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 62: _t->initSetSupports((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 63: _t->initSetCaps((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 64: _t->initSetCapsEnabled((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 65: _t->initSetServerList((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 66: _t->initSetIrcUsersAndChannels((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 67: { IrcUser* _r = _t->updateNickFromMask((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< IrcUser**>(_a[0]) = std::move(_r); }  break;
        case 68: _t->ircUserNickChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 69: _t->requestConnect(); break;
        case 70: _t->requestDisconnect(); break;
        case 71: _t->requestSetNetworkInfo((*reinterpret_cast< const NetworkInfo(*)>(_a[1]))); break;
        case 72: _t->emitConnectionError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 73: _t->removeIrcUser((*reinterpret_cast< IrcUser*(*)>(_a[1]))); break;
        case 74: _t->removeIrcChannel((*reinterpret_cast< IrcChannel*(*)>(_a[1]))); break;
        case 75: _t->removeChansAndUsers(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IrcUser* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IrcChannel* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 71:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkInfo >(); break;
            }
            break;
        case 73:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IrcUser* >(); break;
            }
            break;
        case 74:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IrcChannel* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Network::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::aboutToBeDestroyed)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Network::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::networkNameSet)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Network::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::currentServerSet)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Network::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::connectedSet)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Network::*)(Network::ConnectionState );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::connectionStateSet)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Network::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::connectionError)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Network::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::myNickSet)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Network::*)(IdentityId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::identitySet)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (Network::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::configChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (Network::*)(const bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::useCustomMessageRateSet)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (Network::*)(const quint32 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::messageRateBurstSizeSet)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (Network::*)(const quint32 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::messageRateDelaySet)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (Network::*)(const bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::unlimitedMessageRateSet)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (Network::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::capAdded)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (Network::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::capAcknowledged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (Network::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::capRemoved)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (Network::*)(IrcUser * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::ircUserAdded)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (Network::*)(IrcChannel * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Network::ircChannelAdded)) {
                *result = 17;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Network *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->networkName(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->currentServer(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->myNick(); break;
        case 3: *reinterpret_cast< int*>(_v) = _t->latency(); break;
        case 4: *reinterpret_cast< QByteArray*>(_v) = _t->codecForServer(); break;
        case 5: *reinterpret_cast< QByteArray*>(_v) = _t->codecForEncoding(); break;
        case 6: *reinterpret_cast< QByteArray*>(_v) = _t->codecForDecoding(); break;
        case 7: *reinterpret_cast< IdentityId*>(_v) = _t->identity(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->isConnected(); break;
        case 9: *reinterpret_cast< int*>(_v) = _t->connectionState(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->useRandomServer(); break;
        case 11: *reinterpret_cast< QStringList*>(_v) = _t->perform(); break;
        case 12: *reinterpret_cast< QStringList*>(_v) = _t->skipCaps(); break;
        case 13: *reinterpret_cast< bool*>(_v) = _t->useAutoIdentify(); break;
        case 14: *reinterpret_cast< QString*>(_v) = _t->autoIdentifyService(); break;
        case 15: *reinterpret_cast< QString*>(_v) = _t->autoIdentifyPassword(); break;
        case 16: *reinterpret_cast< bool*>(_v) = _t->useSasl(); break;
        case 17: *reinterpret_cast< QString*>(_v) = _t->saslAccount(); break;
        case 18: *reinterpret_cast< QString*>(_v) = _t->saslPassword(); break;
        case 19: *reinterpret_cast< bool*>(_v) = _t->useAutoReconnect(); break;
        case 20: *reinterpret_cast< quint32*>(_v) = _t->autoReconnectInterval(); break;
        case 21: *reinterpret_cast< quint16*>(_v) = _t->autoReconnectRetries(); break;
        case 22: *reinterpret_cast< bool*>(_v) = _t->unlimitedReconnectRetries(); break;
        case 23: *reinterpret_cast< bool*>(_v) = _t->rejoinChannels(); break;
        case 24: *reinterpret_cast< bool*>(_v) = _t->useCustomMessageRate(); break;
        case 25: *reinterpret_cast< quint32*>(_v) = _t->messageRateBurstSize(); break;
        case 26: *reinterpret_cast< quint32*>(_v) = _t->messageRateDelay(); break;
        case 27: *reinterpret_cast< bool*>(_v) = _t->unlimitedMessageRate(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<Network *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setNetworkName(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setCurrentServer(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setMyNick(*reinterpret_cast< QString*>(_v)); break;
        case 3: _t->setLatency(*reinterpret_cast< int*>(_v)); break;
        case 4: _t->setCodecForServer(*reinterpret_cast< QByteArray*>(_v)); break;
        case 5: _t->setCodecForEncoding(*reinterpret_cast< QByteArray*>(_v)); break;
        case 6: _t->setCodecForDecoding(*reinterpret_cast< QByteArray*>(_v)); break;
        case 7: _t->setIdentity(*reinterpret_cast< IdentityId*>(_v)); break;
        case 8: _t->setConnected(*reinterpret_cast< bool*>(_v)); break;
        case 9: _t->setConnectionState(*reinterpret_cast< int*>(_v)); break;
        case 10: _t->setUseRandomServer(*reinterpret_cast< bool*>(_v)); break;
        case 11: _t->setPerform(*reinterpret_cast< QStringList*>(_v)); break;
        case 12: _t->setSkipCaps(*reinterpret_cast< QStringList*>(_v)); break;
        case 13: _t->setUseAutoIdentify(*reinterpret_cast< bool*>(_v)); break;
        case 14: _t->setAutoIdentifyService(*reinterpret_cast< QString*>(_v)); break;
        case 15: _t->setAutoIdentifyPassword(*reinterpret_cast< QString*>(_v)); break;
        case 16: _t->setUseSasl(*reinterpret_cast< bool*>(_v)); break;
        case 17: _t->setSaslAccount(*reinterpret_cast< QString*>(_v)); break;
        case 18: _t->setSaslPassword(*reinterpret_cast< QString*>(_v)); break;
        case 19: _t->setUseAutoReconnect(*reinterpret_cast< bool*>(_v)); break;
        case 20: _t->setAutoReconnectInterval(*reinterpret_cast< quint32*>(_v)); break;
        case 21: _t->setAutoReconnectRetries(*reinterpret_cast< quint16*>(_v)); break;
        case 22: _t->setUnlimitedReconnectRetries(*reinterpret_cast< bool*>(_v)); break;
        case 23: _t->setRejoinChannels(*reinterpret_cast< bool*>(_v)); break;
        case 24: _t->setUseCustomMessageRate(*reinterpret_cast< bool*>(_v)); break;
        case 25: _t->setMessageRateBurstSize(*reinterpret_cast< quint32*>(_v)); break;
        case 26: _t->setMessageRateDelay(*reinterpret_cast< quint32*>(_v)); break;
        case 27: _t->setUnlimitedMessageRate(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Network::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_Network.data,
    qt_meta_data_Network,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Network::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Network::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Network.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int Network::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 76)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 76;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 76)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 76;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 28;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 28;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 28;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 28;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 28;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Network::aboutToBeDestroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Network::networkNameSet(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Network::currentServerSet(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Network::connectedSet(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Network::connectionStateSet(Network::ConnectionState _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Network::connectionError(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Network::myNickSet(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Network::identitySet(IdentityId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Network::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Network::useCustomMessageRateSet(const bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void Network::messageRateBurstSizeSet(const quint32 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Network::messageRateDelaySet(const quint32 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void Network::unlimitedMessageRateSet(const bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void Network::capAdded(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void Network::capAcknowledged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void Network::capRemoved(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void Network::ircUserAdded(IrcUser * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void Network::ircChannelAdded(IrcChannel * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
