/********************************************************************************
** Form generated from reading UI file 'channellistdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHANNELLISTDLG_H
#define UI_CHANNELLISTDLG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableView>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <clickablelabel.h>

QT_BEGIN_NAMESPACE

class Ui_ChannelListDlg
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *searchLayout;
    QLabel *searchPatternLabel;
    QLineEdit *channelNameLineEdit;
    ClickableLabel *advancedModeLabel;
    QPushButton *searchChannelsButton;
    QFrame *line;
    QHBoxLayout *horizontalLayout_2;
    QLabel *filterLabel;
    QLineEdit *filterLineEdit;
    QLabel *errorLabel;
    QTextEdit *errorTextEdit;
    QTableView *channelListView;

    void setupUi(QDialog *ChannelListDlg)
    {
        if (ChannelListDlg->objectName().isEmpty())
            ChannelListDlg->setObjectName(QString::fromUtf8("ChannelListDlg"));
        ChannelListDlg->resize(566, 580);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/format-list-unordered.png"), QSize(), QIcon::Normal, QIcon::Off);
        ChannelListDlg->setWindowIcon(icon);
        verticalLayout = new QVBoxLayout(ChannelListDlg);
        verticalLayout->setSpacing(2);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        searchLayout = new QHBoxLayout();
        searchLayout->setSpacing(6);
        searchLayout->setObjectName(QString::fromUtf8("searchLayout"));
        searchLayout->setContentsMargins(6, -1, -1, -1);
        searchPatternLabel = new QLabel(ChannelListDlg);
        searchPatternLabel->setObjectName(QString::fromUtf8("searchPatternLabel"));

        searchLayout->addWidget(searchPatternLabel);

        channelNameLineEdit = new QLineEdit(ChannelListDlg);
        channelNameLineEdit->setObjectName(QString::fromUtf8("channelNameLineEdit"));

        searchLayout->addWidget(channelNameLineEdit);

        advancedModeLabel = new ClickableLabel(ChannelListDlg);
        advancedModeLabel->setObjectName(QString::fromUtf8("advancedModeLabel"));
        advancedModeLabel->setPixmap(QPixmap(QString::fromUtf8(":/22x22/actions/oxygen/22x22/actions/edit-clear-locationbar-rtl.png")));

        searchLayout->addWidget(advancedModeLabel);

        searchChannelsButton = new QPushButton(ChannelListDlg);
        searchChannelsButton->setObjectName(QString::fromUtf8("searchChannelsButton"));

        searchLayout->addWidget(searchChannelsButton);


        verticalLayout->addLayout(searchLayout);

        line = new QFrame(ChannelListDlg);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(line);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalLayout_2->setContentsMargins(6, -1, -1, -1);
        filterLabel = new QLabel(ChannelListDlg);
        filterLabel->setObjectName(QString::fromUtf8("filterLabel"));

        horizontalLayout_2->addWidget(filterLabel);

        filterLineEdit = new QLineEdit(ChannelListDlg);
        filterLineEdit->setObjectName(QString::fromUtf8("filterLineEdit"));

        horizontalLayout_2->addWidget(filterLineEdit);


        verticalLayout->addLayout(horizontalLayout_2);

        errorLabel = new QLabel(ChannelListDlg);
        errorLabel->setObjectName(QString::fromUtf8("errorLabel"));

        verticalLayout->addWidget(errorLabel);

        errorTextEdit = new QTextEdit(ChannelListDlg);
        errorTextEdit->setObjectName(QString::fromUtf8("errorTextEdit"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(errorTextEdit->sizePolicy().hasHeightForWidth());
        errorTextEdit->setSizePolicy(sizePolicy);
        errorTextEdit->setMinimumSize(QSize(0, 0));
        errorTextEdit->setMaximumSize(QSize(16777215, 100));
        errorTextEdit->setAcceptDrops(false);
        errorTextEdit->setUndoRedoEnabled(false);
        errorTextEdit->setReadOnly(true);

        verticalLayout->addWidget(errorTextEdit);

        channelListView = new QTableView(ChannelListDlg);
        channelListView->setObjectName(QString::fromUtf8("channelListView"));
        sizePolicy.setHeightForWidth(channelListView->sizePolicy().hasHeightForWidth());
        channelListView->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(channelListView);

        QWidget::setTabOrder(channelNameLineEdit, searchChannelsButton);
        QWidget::setTabOrder(searchChannelsButton, filterLineEdit);
        QWidget::setTabOrder(filterLineEdit, errorTextEdit);
        QWidget::setTabOrder(errorTextEdit, channelListView);

        retranslateUi(ChannelListDlg);

        QMetaObject::connectSlotsByName(ChannelListDlg);
    } // setupUi

    void retranslateUi(QDialog *ChannelListDlg)
    {
        ChannelListDlg->setWindowTitle(QCoreApplication::translate("ChannelListDlg", "Channel List", nullptr));
        searchPatternLabel->setText(QCoreApplication::translate("ChannelListDlg", "Search Pattern:", nullptr));
#if QT_CONFIG(tooltip)
        advancedModeLabel->setToolTip(QCoreApplication::translate("ChannelListDlg", "Toggle between simple and advanced mode.\n"
"Advanced mode allows one to pass search strings to the IRC Server.", nullptr));
#endif // QT_CONFIG(tooltip)
        advancedModeLabel->setText(QString());
        searchChannelsButton->setText(QCoreApplication::translate("ChannelListDlg", "Show Channels", nullptr));
        filterLabel->setText(QCoreApplication::translate("ChannelListDlg", "Filter:", nullptr));
        errorLabel->setText(QCoreApplication::translate("ChannelListDlg", "Errors Occurred:", nullptr));
        errorTextEdit->setHtml(QCoreApplication::translate("ChannelListDlg", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'DejaVu Sans'; font-size:8pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Lucida Grande'; font-size:13pt;\">SUPER EVIL CATASTROPHIC ERROR!!11</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:'Lucida Grande'; font-size:13pt;\"></p></body></html>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ChannelListDlg: public Ui_ChannelListDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CHANNELLISTDLG_H
