/****************************************************************************
** Meta object code from reading C++ file 'clientuserinputhandler.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/client/clientuserinputhandler.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'clientuserinputhandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ClientUserInputHandler_t {
    QByteArrayData data[17];
    char stringdata0[193];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ClientUserInputHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ClientUserInputHandler_t qt_meta_stringdata_ClientUserInputHandler = {
    {
QT_MOC_LITERAL(0, 0, 22), // "ClientUserInputHandler"
QT_MOC_LITERAL(1, 23, 9), // "sendInput"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 10), // "BufferInfo"
QT_MOC_LITERAL(4, 45, 15), // "handleUserInput"
QT_MOC_LITERAL(5, 61, 10), // "bufferInfo"
QT_MOC_LITERAL(6, 72, 3), // "msg"
QT_MOC_LITERAL(7, 76, 23), // "completionSuffixChanged"
QT_MOC_LITERAL(8, 100, 10), // "handleExec"
QT_MOC_LITERAL(9, 111, 10), // "execString"
QT_MOC_LITERAL(10, 122, 10), // "handleJoin"
QT_MOC_LITERAL(11, 133, 4), // "text"
QT_MOC_LITERAL(12, 138, 11), // "handleQuery"
QT_MOC_LITERAL(13, 150, 12), // "handleIgnore"
QT_MOC_LITERAL(14, 163, 10), // "handleList"
QT_MOC_LITERAL(15, 174, 14), // "defaultHandler"
QT_MOC_LITERAL(16, 189, 3) // "cmd"

    },
    "ClientUserInputHandler\0sendInput\0\0"
    "BufferInfo\0handleUserInput\0bufferInfo\0"
    "msg\0completionSuffixChanged\0handleExec\0"
    "execString\0handleJoin\0text\0handleQuery\0"
    "handleIgnore\0handleList\0defaultHandler\0"
    "cmd"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ClientUserInputHandler[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   59,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    2,   64,    2, 0x0a /* Public */,
       7,    1,   69,    2, 0x08 /* Private */,
       8,    2,   72,    2, 0x08 /* Private */,
      10,    2,   77,    2, 0x08 /* Private */,
      12,    2,   82,    2, 0x08 /* Private */,
      13,    2,   87,    2, 0x08 /* Private */,
      14,    2,   92,    2, 0x08 /* Private */,
      15,    3,   97,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    2,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    5,    6,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    5,    9,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    5,   11,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    5,   11,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    5,   11,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    5,   11,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 3, QMetaType::QString,   16,    5,   11,

       0        // eod
};

void ClientUserInputHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ClientUserInputHandler *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sendInput((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->handleUserInput((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->completionSuffixChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 3: _t->handleExec((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->handleJoin((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->handleQuery((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: _t->handleIgnore((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 7: _t->handleList((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 8: _t->defaultHandler((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const BufferInfo(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ClientUserInputHandler::*)(const BufferInfo & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientUserInputHandler::sendInput)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ClientUserInputHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<BasicHandler::staticMetaObject>(),
    qt_meta_stringdata_ClientUserInputHandler.data,
    qt_meta_data_ClientUserInputHandler,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ClientUserInputHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClientUserInputHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ClientUserInputHandler.stringdata0))
        return static_cast<void*>(this);
    return BasicHandler::qt_metacast(_clname);
}

int ClientUserInputHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BasicHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ClientUserInputHandler::sendInput(const BufferInfo & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
