/********************************************************************************
** Form generated from reading UI file 'topicwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TOPICWIDGET_H
#define UI_TOPICWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "multilineedit.h"
#include "resizingstackedwidget.h"
#include "styledlabel.h"

QT_BEGIN_NAMESPACE

class Ui_TopicWidget
{
public:
    QHBoxLayout *horizontalLayout_2;
    ResizingStackedWidget *stackedWidget;
    QWidget *page;
    QHBoxLayout *horizontalLayout;
    StyledLabel *topicLabel;
    QToolButton *topicEditButton;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_3;
    MultiLineEdit *topicLineEdit;

    void setupUi(QWidget *TopicWidget)
    {
        if (TopicWidget->objectName().isEmpty())
            TopicWidget->setObjectName(QString::fromUtf8("TopicWidget"));
        TopicWidget->resize(643, 27);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(TopicWidget->sizePolicy().hasHeightForWidth());
        TopicWidget->setSizePolicy(sizePolicy);
        TopicWidget->setMinimumSize(QSize(0, 0));
        TopicWidget->setBaseSize(QSize(0, 0));
        horizontalLayout_2 = new QHBoxLayout(TopicWidget);
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        stackedWidget = new ResizingStackedWidget(TopicWidget);
        stackedWidget->setObjectName(QString::fromUtf8("stackedWidget"));
        sizePolicy.setHeightForWidth(stackedWidget->sizePolicy().hasHeightForWidth());
        stackedWidget->setSizePolicy(sizePolicy);
        page = new QWidget();
        page->setObjectName(QString::fromUtf8("page"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Ignored);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(page->sizePolicy().hasHeightForWidth());
        page->setSizePolicy(sizePolicy1);
        horizontalLayout = new QHBoxLayout(page);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        topicLabel = new StyledLabel(page);
        topicLabel->setObjectName(QString::fromUtf8("topicLabel"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(topicLabel->sizePolicy().hasHeightForWidth());
        topicLabel->setSizePolicy(sizePolicy2);
        topicLabel->setFrameShape(QFrame::StyledPanel);
        topicLabel->setFrameShadow(QFrame::Plain);

        horizontalLayout->addWidget(topicLabel);

        topicEditButton = new QToolButton(page);
        topicEditButton->setObjectName(QString::fromUtf8("topicEditButton"));

        horizontalLayout->addWidget(topicEditButton);

        stackedWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName(QString::fromUtf8("page_2"));
        sizePolicy1.setHeightForWidth(page_2->sizePolicy().hasHeightForWidth());
        page_2->setSizePolicy(sizePolicy1);
        verticalLayout_3 = new QVBoxLayout(page_2);
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        topicLineEdit = new MultiLineEdit(page_2);
        topicLineEdit->setObjectName(QString::fromUtf8("topicLineEdit"));
        QSizePolicy sizePolicy3(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(topicLineEdit->sizePolicy().hasHeightForWidth());
        topicLineEdit->setSizePolicy(sizePolicy3);

        verticalLayout_3->addWidget(topicLineEdit);

        stackedWidget->addWidget(page_2);

        horizontalLayout_2->addWidget(stackedWidget);


        retranslateUi(TopicWidget);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(TopicWidget);
    } // setupUi

    void retranslateUi(QWidget *TopicWidget)
    {
        TopicWidget->setWindowTitle(QCoreApplication::translate("TopicWidget", "Form", nullptr));
        topicEditButton->setText(QCoreApplication::translate("TopicWidget", "...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TopicWidget: public Ui_TopicWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TOPICWIDGET_H
