/****************************************************************************
** Meta object code from reading C++ file 'coreconnection.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/client/coreconnection.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QPointer>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'coreconnection.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreConnection_t {
    QByteArrayData data[90];
    char stringdata0[1308];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreConnection_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreConnection_t qt_meta_stringdata_CoreConnection = {
    {
QT_MOC_LITERAL(0, 0, 14), // "CoreConnection"
QT_MOC_LITERAL(1, 15, 12), // "stateChanged"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 31), // "CoreConnection::ConnectionState"
QT_MOC_LITERAL(4, 61, 9), // "encrypted"
QT_MOC_LITERAL(5, 71, 11), // "isEncrypted"
QT_MOC_LITERAL(6, 83, 12), // "synchronized"
QT_MOC_LITERAL(7, 96, 10), // "lagUpdated"
QT_MOC_LITERAL(8, 107, 5), // "msecs"
QT_MOC_LITERAL(9, 113, 15), // "connectionError"
QT_MOC_LITERAL(10, 129, 8), // "errorMsg"
QT_MOC_LITERAL(11, 138, 20), // "connectionErrorPopup"
QT_MOC_LITERAL(12, 159, 13), // "connectionMsg"
QT_MOC_LITERAL(13, 173, 3), // "msg"
QT_MOC_LITERAL(14, 177, 12), // "disconnected"
QT_MOC_LITERAL(15, 190, 20), // "progressRangeChanged"
QT_MOC_LITERAL(16, 211, 7), // "minimum"
QT_MOC_LITERAL(17, 219, 7), // "maximum"
QT_MOC_LITERAL(18, 227, 20), // "progressValueChanged"
QT_MOC_LITERAL(19, 248, 5), // "value"
QT_MOC_LITERAL(20, 254, 19), // "progressTextChanged"
QT_MOC_LITERAL(21, 274, 14), // "startCoreSetup"
QT_MOC_LITERAL(22, 289, 11), // "backendInfo"
QT_MOC_LITERAL(23, 301, 17), // "authenticatorInfo"
QT_MOC_LITERAL(24, 319, 16), // "coreSetupSuccess"
QT_MOC_LITERAL(25, 336, 15), // "coreSetupFailed"
QT_MOC_LITERAL(26, 352, 5), // "error"
QT_MOC_LITERAL(27, 358, 21), // "connectToInternalCore"
QT_MOC_LITERAL(28, 380, 22), // "QPointer<InternalPeer>"
QT_MOC_LITERAL(29, 403, 10), // "connection"
QT_MOC_LITERAL(30, 414, 26), // "userAuthenticationRequired"
QT_MOC_LITERAL(31, 441, 12), // "CoreAccount*"
QT_MOC_LITERAL(32, 454, 5), // "bool*"
QT_MOC_LITERAL(33, 460, 5), // "valid"
QT_MOC_LITERAL(34, 466, 12), // "errorMessage"
QT_MOC_LITERAL(35, 479, 19), // "handleNoSslInClient"
QT_MOC_LITERAL(36, 499, 8), // "accepted"
QT_MOC_LITERAL(37, 508, 17), // "handleNoSslInCore"
QT_MOC_LITERAL(38, 526, 15), // "handleSslErrors"
QT_MOC_LITERAL(39, 542, 17), // "const QSslSocket*"
QT_MOC_LITERAL(40, 560, 6), // "socket"
QT_MOC_LITERAL(41, 567, 11), // "permanently"
QT_MOC_LITERAL(42, 579, 13), // "connectToCore"
QT_MOC_LITERAL(43, 593, 9), // "AccountId"
QT_MOC_LITERAL(44, 603, 15), // "reconnectToCore"
QT_MOC_LITERAL(45, 619, 18), // "disconnectFromCore"
QT_MOC_LITERAL(46, 638, 28), // "internalSessionStateReceived"
QT_MOC_LITERAL(47, 667, 22), // "Protocol::SessionState"
QT_MOC_LITERAL(48, 690, 12), // "sessionState"
QT_MOC_LITERAL(49, 703, 9), // "setupCore"
QT_MOC_LITERAL(50, 713, 19), // "Protocol::SetupData"
QT_MOC_LITERAL(51, 733, 9), // "setupData"
QT_MOC_LITERAL(52, 743, 23), // "connectToCurrentAccount"
QT_MOC_LITERAL(53, 767, 11), // "errorString"
QT_MOC_LITERAL(54, 779, 13), // "wantReconnect"
QT_MOC_LITERAL(55, 793, 15), // "coreSocketError"
QT_MOC_LITERAL(56, 809, 28), // "QAbstractSocket::SocketError"
QT_MOC_LITERAL(57, 838, 22), // "coreSocketDisconnected"
QT_MOC_LITERAL(58, 861, 15), // "networkInitDone"
QT_MOC_LITERAL(59, 877, 14), // "checkSyncState"
QT_MOC_LITERAL(60, 892, 11), // "loginToCore"
QT_MOC_LITERAL(61, 904, 4), // "user"
QT_MOC_LITERAL(62, 909, 8), // "password"
QT_MOC_LITERAL(63, 918, 8), // "remember"
QT_MOC_LITERAL(64, 927, 10), // "syncToCore"
QT_MOC_LITERAL(65, 938, 15), // "resetConnection"
QT_MOC_LITERAL(66, 954, 17), // "onConnectionReady"
QT_MOC_LITERAL(67, 972, 17), // "onLoginSuccessful"
QT_MOC_LITERAL(68, 990, 11), // "CoreAccount"
QT_MOC_LITERAL(69, 1002, 7), // "account"
QT_MOC_LITERAL(70, 1010, 19), // "onHandshakeComplete"
QT_MOC_LITERAL(71, 1030, 11), // "RemotePeer*"
QT_MOC_LITERAL(72, 1042, 4), // "peer"
QT_MOC_LITERAL(73, 1047, 14), // "updateProgress"
QT_MOC_LITERAL(74, 1062, 15), // "setProgressText"
QT_MOC_LITERAL(75, 1078, 4), // "text"
QT_MOC_LITERAL(76, 1083, 16), // "setProgressValue"
QT_MOC_LITERAL(77, 1100, 18), // "setProgressMinimum"
QT_MOC_LITERAL(78, 1119, 18), // "setProgressMaximum"
QT_MOC_LITERAL(79, 1138, 8), // "setState"
QT_MOC_LITERAL(80, 1147, 15), // "ConnectionState"
QT_MOC_LITERAL(81, 1163, 5), // "state"
QT_MOC_LITERAL(82, 1169, 27), // "networkDetectionModeChanged"
QT_MOC_LITERAL(83, 1197, 4), // "mode"
QT_MOC_LITERAL(84, 1202, 26), // "pingTimeoutIntervalChanged"
QT_MOC_LITERAL(85, 1229, 8), // "interval"
QT_MOC_LITERAL(86, 1238, 24), // "reconnectIntervalChanged"
QT_MOC_LITERAL(87, 1263, 16), // "reconnectTimeout"
QT_MOC_LITERAL(88, 1280, 18), // "onlineStateChanged"
QT_MOC_LITERAL(89, 1299, 8) // "isOnline"

    },
    "CoreConnection\0stateChanged\0\0"
    "CoreConnection::ConnectionState\0"
    "encrypted\0isEncrypted\0synchronized\0"
    "lagUpdated\0msecs\0connectionError\0"
    "errorMsg\0connectionErrorPopup\0"
    "connectionMsg\0msg\0disconnected\0"
    "progressRangeChanged\0minimum\0maximum\0"
    "progressValueChanged\0value\0"
    "progressTextChanged\0startCoreSetup\0"
    "backendInfo\0authenticatorInfo\0"
    "coreSetupSuccess\0coreSetupFailed\0error\0"
    "connectToInternalCore\0QPointer<InternalPeer>\0"
    "connection\0userAuthenticationRequired\0"
    "CoreAccount*\0bool*\0valid\0errorMessage\0"
    "handleNoSslInClient\0accepted\0"
    "handleNoSslInCore\0handleSslErrors\0"
    "const QSslSocket*\0socket\0permanently\0"
    "connectToCore\0AccountId\0reconnectToCore\0"
    "disconnectFromCore\0internalSessionStateReceived\0"
    "Protocol::SessionState\0sessionState\0"
    "setupCore\0Protocol::SetupData\0setupData\0"
    "connectToCurrentAccount\0errorString\0"
    "wantReconnect\0coreSocketError\0"
    "QAbstractSocket::SocketError\0"
    "coreSocketDisconnected\0networkInitDone\0"
    "checkSyncState\0loginToCore\0user\0"
    "password\0remember\0syncToCore\0"
    "resetConnection\0onConnectionReady\0"
    "onLoginSuccessful\0CoreAccount\0account\0"
    "onHandshakeComplete\0RemotePeer*\0peer\0"
    "updateProgress\0setProgressText\0text\0"
    "setProgressValue\0setProgressMinimum\0"
    "setProgressMaximum\0setState\0ConnectionState\0"
    "state\0networkDetectionModeChanged\0"
    "mode\0pingTimeoutIntervalChanged\0"
    "interval\0reconnectIntervalChanged\0"
    "reconnectTimeout\0onlineStateChanged\0"
    "isOnline"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreConnection[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      52,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      21,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  274,    2, 0x06 /* Public */,
       4,    1,  277,    2, 0x06 /* Public */,
       4,    0,  280,    2, 0x26 /* Public | MethodCloned */,
       6,    0,  281,    2, 0x06 /* Public */,
       7,    1,  282,    2, 0x06 /* Public */,
       9,    1,  285,    2, 0x06 /* Public */,
      11,    1,  288,    2, 0x06 /* Public */,
      12,    1,  291,    2, 0x06 /* Public */,
      14,    0,  294,    2, 0x06 /* Public */,
      15,    2,  295,    2, 0x06 /* Public */,
      18,    1,  300,    2, 0x06 /* Public */,
      20,    1,  303,    2, 0x06 /* Public */,
      21,    2,  306,    2, 0x06 /* Public */,
      24,    0,  311,    2, 0x06 /* Public */,
      25,    1,  312,    2, 0x06 /* Public */,
      27,    1,  315,    2, 0x06 /* Public */,
      30,    3,  318,    2, 0x06 /* Public */,
      30,    2,  325,    2, 0x26 /* Public | MethodCloned */,
      35,    1,  330,    2, 0x06 /* Public */,
      37,    1,  333,    2, 0x06 /* Public */,
      38,    3,  336,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      42,    1,  343,    2, 0x0a /* Public */,
      42,    0,  346,    2, 0x2a /* Public | MethodCloned */,
      44,    0,  347,    2, 0x0a /* Public */,
      45,    0,  348,    2, 0x0a /* Public */,
      46,    1,  349,    2, 0x0a /* Public */,
      49,    1,  352,    2, 0x0a /* Public */,
      52,    0,  355,    2, 0x08 /* Private */,
      45,    2,  356,    2, 0x08 /* Private */,
      45,    1,  361,    2, 0x28 /* Private | MethodCloned */,
      55,    2,  364,    2, 0x08 /* Private */,
      57,    0,  369,    2, 0x08 /* Private */,
      58,    0,  370,    2, 0x08 /* Private */,
      59,    0,  371,    2, 0x08 /* Private */,
      60,    3,  372,    2, 0x08 /* Private */,
      64,    1,  379,    2, 0x08 /* Private */,
      65,    1,  382,    2, 0x08 /* Private */,
      65,    0,  385,    2, 0x28 /* Private | MethodCloned */,
      66,    0,  386,    2, 0x08 /* Private */,
      67,    1,  387,    2, 0x08 /* Private */,
      70,    2,  390,    2, 0x08 /* Private */,
      73,    2,  395,    2, 0x08 /* Private */,
      74,    1,  400,    2, 0x08 /* Private */,
      76,    1,  403,    2, 0x08 /* Private */,
      77,    1,  406,    2, 0x08 /* Private */,
      78,    1,  409,    2, 0x08 /* Private */,
      79,    1,  412,    2, 0x08 /* Private */,
      82,    1,  415,    2, 0x08 /* Private */,
      84,    1,  418,    2, 0x08 /* Private */,
      86,    1,  421,    2, 0x08 /* Private */,
      87,    0,  424,    2, 0x08 /* Private */,
      88,    1,  425,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   16,   17,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QVariantList, QMetaType::QVariantList,   22,   23,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   26,
    QMetaType::Void, 0x80000000 | 28,   29,
    QMetaType::Void, 0x80000000 | 31, 0x80000000 | 32, QMetaType::QString,    2,   33,   34,
    QMetaType::Void, 0x80000000 | 31, 0x80000000 | 32,    2,   33,
    QMetaType::Void, 0x80000000 | 32,   36,
    QMetaType::Void, 0x80000000 | 32,   36,
    QMetaType::Void, 0x80000000 | 39, 0x80000000 | 32, 0x80000000 | 32,   40,   36,   41,

 // slots: parameters
    QMetaType::Bool, 0x80000000 | 43,    2,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 47,   48,
    QMetaType::Void, 0x80000000 | 50,   51,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   53,   54,
    QMetaType::Void, QMetaType::QString,   53,
    QMetaType::Void, 0x80000000 | 56, QMetaType::QString,   26,   53,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::Bool,   61,   62,   63,
    QMetaType::Void, 0x80000000 | 47,   48,
    QMetaType::Void, QMetaType::Bool,   54,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 68,   69,
    QMetaType::Void, 0x80000000 | 71, 0x80000000 | 47,   72,   48,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   19,   17,
    QMetaType::Void, QMetaType::QString,   75,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Int,   16,
    QMetaType::Void, QMetaType::Int,   17,
    QMetaType::Void, 0x80000000 | 80,   81,
    QMetaType::Void, QMetaType::QVariant,   83,
    QMetaType::Void, QMetaType::QVariant,   85,
    QMetaType::Void, QMetaType::QVariant,   85,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   89,

       0        // eod
};

void CoreConnection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreConnection *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast< CoreConnection::ConnectionState(*)>(_a[1]))); break;
        case 1: _t->encrypted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->encrypted(); break;
        case 3: _t->synchronized(); break;
        case 4: _t->lagUpdated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->connectionError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->connectionErrorPopup((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->connectionMsg((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->disconnected(); break;
        case 9: _t->progressRangeChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->progressValueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->progressTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->startCoreSetup((*reinterpret_cast< const QVariantList(*)>(_a[1])),(*reinterpret_cast< const QVariantList(*)>(_a[2]))); break;
        case 13: _t->coreSetupSuccess(); break;
        case 14: _t->coreSetupFailed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->connectToInternalCore((*reinterpret_cast< QPointer<InternalPeer>(*)>(_a[1]))); break;
        case 16: _t->userAuthenticationRequired((*reinterpret_cast< CoreAccount*(*)>(_a[1])),(*reinterpret_cast< bool*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 17: _t->userAuthenticationRequired((*reinterpret_cast< CoreAccount*(*)>(_a[1])),(*reinterpret_cast< bool*(*)>(_a[2]))); break;
        case 18: _t->handleNoSslInClient((*reinterpret_cast< bool*(*)>(_a[1]))); break;
        case 19: _t->handleNoSslInCore((*reinterpret_cast< bool*(*)>(_a[1]))); break;
        case 20: _t->handleSslErrors((*reinterpret_cast< const QSslSocket*(*)>(_a[1])),(*reinterpret_cast< bool*(*)>(_a[2])),(*reinterpret_cast< bool*(*)>(_a[3]))); break;
        case 21: { bool _r = _t->connectToCore((*reinterpret_cast< AccountId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->connectToCore();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->reconnectToCore(); break;
        case 24: _t->disconnectFromCore(); break;
        case 25: _t->internalSessionStateReceived((*reinterpret_cast< const Protocol::SessionState(*)>(_a[1]))); break;
        case 26: _t->setupCore((*reinterpret_cast< const Protocol::SetupData(*)>(_a[1]))); break;
        case 27: _t->connectToCurrentAccount(); break;
        case 28: _t->disconnectFromCore((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 29: _t->disconnectFromCore((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 30: _t->coreSocketError((*reinterpret_cast< QAbstractSocket::SocketError(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 31: _t->coreSocketDisconnected(); break;
        case 32: _t->networkInitDone(); break;
        case 33: _t->checkSyncState(); break;
        case 34: _t->loginToCore((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 35: _t->syncToCore((*reinterpret_cast< const Protocol::SessionState(*)>(_a[1]))); break;
        case 36: _t->resetConnection((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 37: _t->resetConnection(); break;
        case 38: _t->onConnectionReady(); break;
        case 39: _t->onLoginSuccessful((*reinterpret_cast< const CoreAccount(*)>(_a[1]))); break;
        case 40: _t->onHandshakeComplete((*reinterpret_cast< RemotePeer*(*)>(_a[1])),(*reinterpret_cast< const Protocol::SessionState(*)>(_a[2]))); break;
        case 41: _t->updateProgress((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 42: _t->setProgressText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 43: _t->setProgressValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 44: _t->setProgressMinimum((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 45: _t->setProgressMaximum((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 46: _t->setState((*reinterpret_cast< ConnectionState(*)>(_a[1]))); break;
        case 47: _t->networkDetectionModeChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 48: _t->pingTimeoutIntervalChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 49: _t->reconnectIntervalChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 50: _t->reconnectTimeout(); break;
        case 51: _t->onlineStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< CoreConnection::ConnectionState >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AccountId >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RemotePeer* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CoreConnection::*)(CoreConnection::ConnectionState );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::stateChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::encrypted)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::synchronized)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::lagUpdated)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::connectionError)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::connectionErrorPopup)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::connectionMsg)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::disconnected)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::progressRangeChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::progressValueChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::progressTextChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(const QVariantList & , const QVariantList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::startCoreSetup)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::coreSetupSuccess)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::coreSetupFailed)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(QPointer<InternalPeer> );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::connectToInternalCore)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(CoreAccount * , bool * , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::userAuthenticationRequired)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(bool * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::handleNoSslInClient)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(bool * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::handleNoSslInCore)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (CoreConnection::*)(const QSslSocket * , bool * , bool * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConnection::handleSslErrors)) {
                *result = 20;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreConnection::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_CoreConnection.data,
    qt_meta_data_CoreConnection,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreConnection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreConnection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreConnection.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CoreConnection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    }
    return _id;
}

// SIGNAL 0
void CoreConnection::stateChanged(CoreConnection::ConnectionState _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void CoreConnection::encrypted(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 3
void CoreConnection::synchronized()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CoreConnection::lagUpdated(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void CoreConnection::connectionError(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void CoreConnection::connectionErrorPopup(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void CoreConnection::connectionMsg(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void CoreConnection::disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void CoreConnection::progressRangeChanged(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void CoreConnection::progressValueChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void CoreConnection::progressTextChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void CoreConnection::startCoreSetup(const QVariantList & _t1, const QVariantList & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void CoreConnection::coreSetupSuccess()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void CoreConnection::coreSetupFailed(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void CoreConnection::connectToInternalCore(QPointer<InternalPeer> _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void CoreConnection::userAuthenticationRequired(CoreAccount * _t1, bool * _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 18
void CoreConnection::handleNoSslInClient(bool * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void CoreConnection::handleNoSslInCore(bool * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void CoreConnection::handleSslErrors(const QSslSocket * _t1, bool * _t2, bool * _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
