/****************************************************************************
** Meta object code from reading C++ file 'coreuserinputhandler.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/coreuserinputhandler.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'coreuserinputhandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreUserInputHandler_t {
    QByteArrayData data[53];
    char stringdata0[587];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreUserInputHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreUserInputHandler_t qt_meta_stringdata_CoreUserInputHandler = {
    {
QT_MOC_LITERAL(0, 0, 20), // "CoreUserInputHandler"
QT_MOC_LITERAL(1, 21, 10), // "handleAway"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 10), // "BufferInfo"
QT_MOC_LITERAL(4, 44, 10), // "bufferInfo"
QT_MOC_LITERAL(5, 55, 4), // "text"
QT_MOC_LITERAL(6, 60, 14), // "skipFormatting"
QT_MOC_LITERAL(7, 75, 9), // "handleBan"
QT_MOC_LITERAL(8, 85, 11), // "handleUnban"
QT_MOC_LITERAL(9, 97, 10), // "handleCtcp"
QT_MOC_LITERAL(10, 108, 12), // "handleDelkey"
QT_MOC_LITERAL(11, 121, 10), // "handleDeop"
QT_MOC_LITERAL(12, 132, 5), // "nicks"
QT_MOC_LITERAL(13, 138, 14), // "handleDehalfop"
QT_MOC_LITERAL(14, 153, 13), // "handleDevoice"
QT_MOC_LITERAL(15, 167, 12), // "handleInvite"
QT_MOC_LITERAL(16, 180, 10), // "handleJoin"
QT_MOC_LITERAL(17, 191, 10), // "handleKeyx"
QT_MOC_LITERAL(18, 202, 10), // "handleKick"
QT_MOC_LITERAL(19, 213, 10), // "handleKill"
QT_MOC_LITERAL(20, 224, 10), // "handleList"
QT_MOC_LITERAL(21, 235, 8), // "handleMe"
QT_MOC_LITERAL(22, 244, 10), // "handleMode"
QT_MOC_LITERAL(23, 255, 9), // "handleMsg"
QT_MOC_LITERAL(24, 265, 10), // "handleNick"
QT_MOC_LITERAL(25, 276, 12), // "handleNotice"
QT_MOC_LITERAL(26, 289, 10), // "handleOper"
QT_MOC_LITERAL(27, 300, 8), // "handleOp"
QT_MOC_LITERAL(28, 309, 12), // "handleHalfop"
QT_MOC_LITERAL(29, 322, 10), // "handlePart"
QT_MOC_LITERAL(30, 333, 10), // "handlePing"
QT_MOC_LITERAL(31, 344, 11), // "handlePrint"
QT_MOC_LITERAL(32, 356, 11), // "handleQuery"
QT_MOC_LITERAL(33, 368, 10), // "handleQuit"
QT_MOC_LITERAL(34, 379, 11), // "handleQuote"
QT_MOC_LITERAL(35, 391, 9), // "handleSay"
QT_MOC_LITERAL(36, 401, 12), // "handleSetkey"
QT_MOC_LITERAL(37, 414, 13), // "handleSetname"
QT_MOC_LITERAL(38, 428, 13), // "handleShowkey"
QT_MOC_LITERAL(39, 442, 11), // "handleTopic"
QT_MOC_LITERAL(40, 454, 11), // "handleVoice"
QT_MOC_LITERAL(41, 466, 10), // "handleWait"
QT_MOC_LITERAL(42, 477, 9), // "handleWho"
QT_MOC_LITERAL(43, 487, 11), // "handleWhois"
QT_MOC_LITERAL(44, 499, 12), // "handleWhowas"
QT_MOC_LITERAL(45, 512, 14), // "defaultHandler"
QT_MOC_LITERAL(46, 527, 3), // "cmd"
QT_MOC_LITERAL(47, 531, 9), // "issueQuit"
QT_MOC_LITERAL(48, 541, 6), // "reason"
QT_MOC_LITERAL(49, 548, 14), // "forceImmediate"
QT_MOC_LITERAL(50, 563, 9), // "issueAway"
QT_MOC_LITERAL(51, 573, 3), // "msg"
QT_MOC_LITERAL(52, 577, 9) // "autoCheck"

    },
    "CoreUserInputHandler\0handleAway\0\0"
    "BufferInfo\0bufferInfo\0text\0skipFormatting\0"
    "handleBan\0handleUnban\0handleCtcp\0"
    "handleDelkey\0handleDeop\0nicks\0"
    "handleDehalfop\0handleDevoice\0handleInvite\0"
    "handleJoin\0handleKeyx\0handleKick\0"
    "handleKill\0handleList\0handleMe\0"
    "handleMode\0handleMsg\0handleNick\0"
    "handleNotice\0handleOper\0handleOp\0"
    "handleHalfop\0handlePart\0handlePing\0"
    "handlePrint\0handleQuery\0handleQuit\0"
    "handleQuote\0handleSay\0handleSetkey\0"
    "handleSetname\0handleShowkey\0handleTopic\0"
    "handleVoice\0handleWait\0handleWho\0"
    "handleWhois\0handleWhowas\0defaultHandler\0"
    "cmd\0issueQuit\0reason\0forceImmediate\0"
    "issueAway\0msg\0autoCheck"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreUserInputHandler[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      45,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    3,  239,    2, 0x0a /* Public */,
       1,    2,  246,    2, 0x2a /* Public | MethodCloned */,
       7,    2,  251,    2, 0x0a /* Public */,
       8,    2,  256,    2, 0x0a /* Public */,
       9,    2,  261,    2, 0x0a /* Public */,
      10,    2,  266,    2, 0x0a /* Public */,
      11,    2,  271,    2, 0x0a /* Public */,
      13,    2,  276,    2, 0x0a /* Public */,
      14,    2,  281,    2, 0x0a /* Public */,
      15,    2,  286,    2, 0x0a /* Public */,
      16,    2,  291,    2, 0x0a /* Public */,
      17,    2,  296,    2, 0x0a /* Public */,
      18,    2,  301,    2, 0x0a /* Public */,
      19,    2,  306,    2, 0x0a /* Public */,
      20,    2,  311,    2, 0x0a /* Public */,
      21,    2,  316,    2, 0x0a /* Public */,
      22,    2,  321,    2, 0x0a /* Public */,
      23,    2,  326,    2, 0x0a /* Public */,
      24,    2,  331,    2, 0x0a /* Public */,
      25,    2,  336,    2, 0x0a /* Public */,
      26,    2,  341,    2, 0x0a /* Public */,
      27,    2,  346,    2, 0x0a /* Public */,
      28,    2,  351,    2, 0x0a /* Public */,
      29,    2,  356,    2, 0x0a /* Public */,
      30,    2,  361,    2, 0x0a /* Public */,
      31,    2,  366,    2, 0x0a /* Public */,
      32,    2,  371,    2, 0x0a /* Public */,
      33,    2,  376,    2, 0x0a /* Public */,
      34,    2,  381,    2, 0x0a /* Public */,
      35,    2,  386,    2, 0x0a /* Public */,
      36,    2,  391,    2, 0x0a /* Public */,
      37,    2,  396,    2, 0x0a /* Public */,
      38,    2,  401,    2, 0x0a /* Public */,
      39,    2,  406,    2, 0x0a /* Public */,
      40,    2,  411,    2, 0x0a /* Public */,
      41,    2,  416,    2, 0x0a /* Public */,
      42,    2,  421,    2, 0x0a /* Public */,
      43,    2,  426,    2, 0x0a /* Public */,
      44,    2,  431,    2, 0x0a /* Public */,
      45,    3,  436,    2, 0x0a /* Public */,
      47,    2,  443,    2, 0x0a /* Public */,
      47,    1,  448,    2, 0x2a /* Public | MethodCloned */,
      50,    3,  451,    2, 0x0a /* Public */,
      50,    2,  458,    2, 0x2a /* Public | MethodCloned */,
      50,    1,  463,    2, 0x2a /* Public | MethodCloned */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString, QMetaType::Bool,    4,    5,    6,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   12,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   12,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   12,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   12,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   12,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    5,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 3, QMetaType::QString,   46,    4,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   48,   49,
    QMetaType::Void, QMetaType::QString,   48,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,   51,   52,    6,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   51,   52,
    QMetaType::Void, QMetaType::QString,   51,

       0        // eod
};

void CoreUserInputHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreUserInputHandler *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->handleAway((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const bool(*)>(_a[3]))); break;
        case 1: _t->handleAway((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->handleBan((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->handleUnban((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->handleCtcp((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->handleDelkey((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: _t->handleDeop((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 7: _t->handleDehalfop((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 8: _t->handleDevoice((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 9: _t->handleInvite((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 10: _t->handleJoin((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 11: _t->handleKeyx((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 12: _t->handleKick((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 13: _t->handleKill((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 14: _t->handleList((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 15: _t->handleMe((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 16: _t->handleMode((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 17: _t->handleMsg((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 18: _t->handleNick((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 19: _t->handleNotice((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 20: _t->handleOper((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 21: _t->handleOp((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 22: _t->handleHalfop((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 23: _t->handlePart((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 24: _t->handlePing((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 25: _t->handlePrint((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 26: _t->handleQuery((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 27: _t->handleQuit((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 28: _t->handleQuote((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 29: _t->handleSay((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 30: _t->handleSetkey((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 31: _t->handleSetname((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 32: _t->handleShowkey((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 33: _t->handleTopic((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 34: _t->handleVoice((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 35: _t->handleWait((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 36: _t->handleWho((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 37: _t->handleWhois((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 38: _t->handleWhowas((*reinterpret_cast< const BufferInfo(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 39: _t->defaultHandler((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< const BufferInfo(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 40: _t->issueQuit((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 41: _t->issueQuit((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 42: _t->issueAway((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< const bool(*)>(_a[3]))); break;
        case 43: _t->issueAway((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 44: _t->issueAway((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreUserInputHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<CoreBasicHandler::staticMetaObject>(),
    qt_meta_stringdata_CoreUserInputHandler.data,
    qt_meta_data_CoreUserInputHandler,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreUserInputHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreUserInputHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreUserInputHandler.stringdata0))
        return static_cast<void*>(this);
    return CoreBasicHandler::qt_metacast(_clname);
}

int CoreUserInputHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = CoreBasicHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
