/********************************************************************************
** Form generated from reading UI file 'systrayanimationconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SYSTRAYANIMATIONCONFIGWIDGET_H
#define UI_SYSTRAYANIMATIONCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SystrayAnimationConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QCheckBox *enableAlert;
    QComboBox *attentionBehavior;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *SystrayAnimationConfigWidget)
    {
        if (SystrayAnimationConfigWidget->objectName().isEmpty())
            SystrayAnimationConfigWidget->setObjectName(QString::fromUtf8("SystrayAnimationConfigWidget"));
        SystrayAnimationConfigWidget->resize(438, 50);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SystrayAnimationConfigWidget->sizePolicy().hasHeightForWidth());
        SystrayAnimationConfigWidget->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(SystrayAnimationConfigWidget);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        enableAlert = new QCheckBox(SystrayAnimationConfigWidget);
        enableAlert->setObjectName(QString::fromUtf8("enableAlert"));
        enableAlert->setProperty("settingsKey", QVariant(QString::fromUtf8("Systray/Alert")));
        enableAlert->setProperty("defaultValue", QVariant(true));

        horizontalLayout->addWidget(enableAlert);

        attentionBehavior = new QComboBox(SystrayAnimationConfigWidget);
        attentionBehavior->addItem(QString());
        attentionBehavior->addItem(QString());
        attentionBehavior->addItem(QString());
        attentionBehavior->setObjectName(QString::fromUtf8("attentionBehavior"));
        attentionBehavior->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        attentionBehavior->setProperty("defaultValue", QVariant(1));

        horizontalLayout->addWidget(attentionBehavior);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(SystrayAnimationConfigWidget);
        QObject::connect(enableAlert, SIGNAL(toggled(bool)), attentionBehavior, SLOT(setEnabled(bool)));

        attentionBehavior->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(SystrayAnimationConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *SystrayAnimationConfigWidget)
    {
        SystrayAnimationConfigWidget->setWindowTitle(QCoreApplication::translate("SystrayAnimationConfigWidget", "Form", nullptr));
#if QT_CONFIG(tooltip)
        enableAlert->setToolTip(QCoreApplication::translate("SystrayAnimationConfigWidget", "<html><head/><body><p>If enabled, alert the system tray or dock in case of a notification.</p><p>It depends on your desktop environment how an alert is visualized. For example, Plasma will pulsate the tray icon, while Windows will change the icon's color. You may choose to forcefully change color or even letting the icon blink, if desired.</p><p>Note that not all icon themes support changing the color of the tray icon.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        enableAlert->setText(QCoreApplication::translate("SystrayAnimationConfigWidget", "Alert tray icon and", nullptr));
        attentionBehavior->setItemText(0, QCoreApplication::translate("SystrayAnimationConfigWidget", "do nothing", nullptr));
        attentionBehavior->setItemText(1, QCoreApplication::translate("SystrayAnimationConfigWidget", "change color", nullptr));
        attentionBehavior->setItemText(2, QCoreApplication::translate("SystrayAnimationConfigWidget", "blink", nullptr));

    } // retranslateUi

};

namespace Ui {
    class SystrayAnimationConfigWidget: public Ui_SystrayAnimationConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SYSTRAYANIMATIONCONFIGWIDGET_H
