/********************************************************************************
** Form generated from reading UI file 'coreaccountsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COREACCOUNTSETTINGSPAGE_H
#define UI_COREACCOUNTSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CoreAccountSettingsPage
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QHBoxLayout *hboxLayout;
    QListView *accountView;
    QVBoxLayout *vboxLayout;
    QPushButton *editAccountButton;
    QPushButton *addAccountButton;
    QPushButton *deleteAccountButton;
    QSpacerItem *spacerItem;
    QCheckBox *autoConnectOnStartup;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_3;
    QWidget *widget;
    QVBoxLayout *verticalLayout;
    QRadioButton *autoConnectToLast;
    QHBoxLayout *horizontalLayout_3;
    QRadioButton *autoConnectToFixedAccount;
    QComboBox *autoConnectAccount;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *CoreAccountSettingsPage)
    {
        if (CoreAccountSettingsPage->objectName().isEmpty())
            CoreAccountSettingsPage->setObjectName(QString::fromUtf8("CoreAccountSettingsPage"));
        CoreAccountSettingsPage->resize(388, 464);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(CoreAccountSettingsPage->sizePolicy().hasHeightForWidth());
        CoreAccountSettingsPage->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/16x16/actions/network-disconnect"), QSize(), QIcon::Normal, QIcon::Off);
        CoreAccountSettingsPage->setWindowIcon(icon);
        verticalLayout_2 = new QVBoxLayout(CoreAccountSettingsPage);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        groupBox = new QGroupBox(CoreAccountSettingsPage);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        hboxLayout = new QHBoxLayout(groupBox);
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        accountView = new QListView(groupBox);
        accountView->setObjectName(QString::fromUtf8("accountView"));
        accountView->setSelectionBehavior(QAbstractItemView::SelectRows);

        hboxLayout->addWidget(accountView);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        editAccountButton = new QPushButton(groupBox);
        editAccountButton->setObjectName(QString::fromUtf8("editAccountButton"));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/document-properties.png"), QSize(), QIcon::Normal, QIcon::Off);
        editAccountButton->setIcon(icon1);

        vboxLayout->addWidget(editAccountButton);

        addAccountButton = new QPushButton(groupBox);
        addAccountButton->setObjectName(QString::fromUtf8("addAccountButton"));
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/list-add.png"), QSize(), QIcon::Normal, QIcon::Off);
        addAccountButton->setIcon(icon2);

        vboxLayout->addWidget(addAccountButton);

        deleteAccountButton = new QPushButton(groupBox);
        deleteAccountButton->setObjectName(QString::fromUtf8("deleteAccountButton"));
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/list-remove.png"), QSize(), QIcon::Normal, QIcon::Off);
        deleteAccountButton->setIcon(icon3);

        vboxLayout->addWidget(deleteAccountButton);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem);


        hboxLayout->addLayout(vboxLayout);


        verticalLayout_2->addWidget(groupBox);

        autoConnectOnStartup = new QCheckBox(CoreAccountSettingsPage);
        autoConnectOnStartup->setObjectName(QString::fromUtf8("autoConnectOnStartup"));
        autoConnectOnStartup->setChecked(true);
        autoConnectOnStartup->setProperty("settingsKey", QVariant(QString::fromUtf8("AutoConnectOnStartup")));
        autoConnectOnStartup->setProperty("defaultValue", QVariant(true));

        verticalLayout_2->addWidget(autoConnectOnStartup);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        horizontalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);

        widget = new QWidget(CoreAccountSettingsPage);
        widget->setObjectName(QString::fromUtf8("widget"));
        verticalLayout = new QVBoxLayout(widget);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        autoConnectToLast = new QRadioButton(widget);
        autoConnectToLast->setObjectName(QString::fromUtf8("autoConnectToLast"));
        autoConnectToLast->setChecked(true);

        verticalLayout->addWidget(autoConnectToLast);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        autoConnectToFixedAccount = new QRadioButton(widget);
        autoConnectToFixedAccount->setObjectName(QString::fromUtf8("autoConnectToFixedAccount"));
        autoConnectToFixedAccount->setProperty("settingsKey", QVariant(QString::fromUtf8("AutoConnectToFixedAccount")));
        autoConnectToFixedAccount->setProperty("defaultValue", QVariant(false));

        horizontalLayout_3->addWidget(autoConnectToFixedAccount);

        autoConnectAccount = new QComboBox(widget);
        autoConnectAccount->setObjectName(QString::fromUtf8("autoConnectAccount"));
        autoConnectAccount->setEnabled(false);

        horizontalLayout_3->addWidget(autoConnectAccount);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_3);


        horizontalLayout_4->addWidget(widget);


        verticalLayout_2->addLayout(horizontalLayout_4);

        QWidget::setTabOrder(accountView, editAccountButton);
        QWidget::setTabOrder(editAccountButton, addAccountButton);
        QWidget::setTabOrder(addAccountButton, deleteAccountButton);
        QWidget::setTabOrder(deleteAccountButton, autoConnectOnStartup);
        QWidget::setTabOrder(autoConnectOnStartup, autoConnectToLast);
        QWidget::setTabOrder(autoConnectToLast, autoConnectToFixedAccount);
        QWidget::setTabOrder(autoConnectToFixedAccount, autoConnectAccount);

        retranslateUi(CoreAccountSettingsPage);
        QObject::connect(autoConnectOnStartup, SIGNAL(toggled(bool)), widget, SLOT(setEnabled(bool)));
        QObject::connect(autoConnectToFixedAccount, SIGNAL(toggled(bool)), autoConnectAccount, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(CoreAccountSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *CoreAccountSettingsPage)
    {
        CoreAccountSettingsPage->setWindowTitle(QCoreApplication::translate("CoreAccountSettingsPage", "Connect to Quassel Core", nullptr));
        groupBox->setTitle(QCoreApplication::translate("CoreAccountSettingsPage", "Core Accounts", nullptr));
        editAccountButton->setText(QCoreApplication::translate("CoreAccountSettingsPage", "Edit...", nullptr));
        addAccountButton->setText(QCoreApplication::translate("CoreAccountSettingsPage", "Add...", nullptr));
        deleteAccountButton->setText(QCoreApplication::translate("CoreAccountSettingsPage", "Delete", nullptr));
        autoConnectOnStartup->setText(QCoreApplication::translate("CoreAccountSettingsPage", "Automatically connect on startup", nullptr));
        autoConnectToLast->setText(QCoreApplication::translate("CoreAccountSettingsPage", "Connect to last account used", nullptr));
        autoConnectToFixedAccount->setText(QCoreApplication::translate("CoreAccountSettingsPage", "Always connect to", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CoreAccountSettingsPage: public Ui_CoreAccountSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COREACCOUNTSETTINGSPAGE_H
