/********************************************************************************
** Form generated from reading UI file 'networkssettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NETWORKSSETTINGSPAGE_H
#define UI_NETWORKSSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_NetworksSettingsPage
{
public:
    QVBoxLayout *verticalLayout_7;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QListWidget *networkList;
    QVBoxLayout *verticalLayout_2;
    QPushButton *renameNetwork;
    QPushButton *addNetwork;
    QPushButton *deleteNetwork;
    QSpacerItem *verticalSpacer;
    QGroupBox *detailsBox;
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *label_6;
    QComboBox *identityList;
    QToolButton *editIdentities;
    QSpacerItem *horizontalSpacer_2;
    QTabWidget *tabWidget;
    QWidget *serversTab;
    QHBoxLayout *horizontalLayout_2;
    QListWidget *serverList;
    QVBoxLayout *vboxLayout1;
    QPushButton *editServer;
    QPushButton *addServer;
    QPushButton *deleteServer;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem;
    QToolButton *upServer;
    QToolButton *downServer;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;
    QWidget *performTab;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTextEdit *performEdit;
    QWidget *connectionTab;
    QVBoxLayout *verticalLayout_9;
    QGroupBox *autoReconnect;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_7;
    QSpinBox *reconnectInterval;
    QLabel *label_12;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_8;
    QSpinBox *reconnectRetries;
    QCheckBox *unlimitedRetries;
    QSpacerItem *horizontalSpacer;
    QCheckBox *rejoinOnReconnect;
    QGroupBox *useCustomMessageRate;
    QVBoxLayout *verticalLayout_8;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_11;
    QSpinBox *messageRateBurstSize;
    QCheckBox *unlimitedMessageRate;
    QSpacerItem *horizontalSpacer_5;
    QFrame *messageRateDelayFrame;
    QVBoxLayout *verticalLayout_10;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_10;
    QDoubleSpinBox *messageRateDelay;
    QLabel *label_13;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer_3;
    QWidget *autoIdentifyTab;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *sasl;
    QVBoxLayout *verticalLayout_11;
    QFrame *saslPlainContents;
    QVBoxLayout *verticalLayout_12;
    QGridLayout *gridLayout_2;
    QLineEdit *saslAccount;
    QLabel *saslAccountLabel;
    QLineEdit *saslPassword;
    QLabel *saslPasswordLabel;
    QLabel *saslExtInfo;
    QHBoxLayout *horizontalLayout_7;
    QLabel *saslStatusIcon;
    QLabel *saslStatusLabel;
    QPushButton *saslStatusDetails;
    QGroupBox *autoIdentify;
    QGridLayout *gridLayout;
    QLineEdit *autoIdentifyService;
    QLineEdit *autoIdentifyPassword;
    QLabel *identifyServiceLabel;
    QLabel *identifyPasswordLabel;
    QSpacerItem *verticalSpacer_2;
    QWidget *featuresTab;
    QVBoxLayout *verticalLayout_14;
    QWidget *enableCapsStatusWidget;
    QHBoxLayout *horizontalLayout_8;
    QLabel *enableCapsStatusIcon;
    QLabel *enableCapsStatusLabel;
    QPushButton *enableCapsStatusDetails;
    QWidget *enableCapsConfigWidget;
    QVBoxLayout *verticalLayout_6;
    QCheckBox *enableCapServerTime;
    QHBoxLayout *horizontalLayout_9;
    QPushButton *enableCapsAdvanced;
    QSpacerItem *horizontalSpacer_6;
    QLabel *enableCapsReconnectNotice;
    QSpacerItem *verticalSpacer_5;
    QWidget *encodingsTab;
    QVBoxLayout *verticalLayout_13;
    QGroupBox *useCustomEncodings;
    QVBoxLayout *vboxLayout2;
    QGridLayout *gridLayout1;
    QLabel *label_4;
    QComboBox *sendEncoding;
    QLabel *label_5;
    QComboBox *recvEncoding;
    QLabel *label_9;
    QComboBox *serverEncoding;
    QSpacerItem *verticalSpacer_4;

    void setupUi(QWidget *NetworksSettingsPage)
    {
        if (NetworksSettingsPage->objectName().isEmpty())
            NetworksSettingsPage->setObjectName(QString::fromUtf8("NetworksSettingsPage"));
        NetworksSettingsPage->resize(510, 553);
        verticalLayout_7 = new QVBoxLayout(NetworksSettingsPage);
        verticalLayout_7->setObjectName(QString::fromUtf8("verticalLayout_7"));
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        networkList = new QListWidget(NetworksSettingsPage);
        networkList->setObjectName(QString::fromUtf8("networkList"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(10);
        sizePolicy.setHeightForWidth(networkList->sizePolicy().hasHeightForWidth());
        networkList->setSizePolicy(sizePolicy);
        networkList->setSelectionBehavior(QAbstractItemView::SelectRows);
        networkList->setSortingEnabled(true);

        horizontalLayout->addWidget(networkList);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        renameNetwork = new QPushButton(NetworksSettingsPage);
        renameNetwork->setObjectName(QString::fromUtf8("renameNetwork"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(renameNetwork->sizePolicy().hasHeightForWidth());
        renameNetwork->setSizePolicy(sizePolicy1);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/edit-rename.png"), QSize(), QIcon::Normal, QIcon::Off);
        renameNetwork->setIcon(icon);

        verticalLayout_2->addWidget(renameNetwork);

        addNetwork = new QPushButton(NetworksSettingsPage);
        addNetwork->setObjectName(QString::fromUtf8("addNetwork"));
        sizePolicy1.setHeightForWidth(addNetwork->sizePolicy().hasHeightForWidth());
        addNetwork->setSizePolicy(sizePolicy1);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/list-add.png"), QSize(), QIcon::Normal, QIcon::Off);
        addNetwork->setIcon(icon1);
        addNetwork->setIconSize(QSize(16, 16));

        verticalLayout_2->addWidget(addNetwork);

        deleteNetwork = new QPushButton(NetworksSettingsPage);
        deleteNetwork->setObjectName(QString::fromUtf8("deleteNetwork"));
        sizePolicy1.setHeightForWidth(deleteNetwork->sizePolicy().hasHeightForWidth());
        deleteNetwork->setSizePolicy(sizePolicy1);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/edit-delete.png"), QSize(), QIcon::Normal, QIcon::Off);
        deleteNetwork->setIcon(icon2);

        verticalLayout_2->addWidget(deleteNetwork);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout_2);


        verticalLayout_3->addLayout(horizontalLayout);


        verticalLayout_7->addLayout(verticalLayout_3);

        detailsBox = new QGroupBox(NetworksSettingsPage);
        detailsBox->setObjectName(QString::fromUtf8("detailsBox"));
        QSizePolicy sizePolicy2(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(10);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(detailsBox->sizePolicy().hasHeightForWidth());
        detailsBox->setSizePolicy(sizePolicy2);
        vboxLayout = new QVBoxLayout(detailsBox);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        label_6 = new QLabel(detailsBox);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        hboxLayout->addWidget(label_6);

        identityList = new QComboBox(detailsBox);
        identityList->setObjectName(QString::fromUtf8("identityList"));
        QSizePolicy sizePolicy3(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(identityList->sizePolicy().hasHeightForWidth());
        identityList->setSizePolicy(sizePolicy3);

        hboxLayout->addWidget(identityList);

        editIdentities = new QToolButton(detailsBox);
        editIdentities->setObjectName(QString::fromUtf8("editIdentities"));

        hboxLayout->addWidget(editIdentities);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(horizontalSpacer_2);


        vboxLayout->addLayout(hboxLayout);

        tabWidget = new QTabWidget(detailsBox);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        tabWidget->setEnabled(true);
        QSizePolicy sizePolicy4(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy4);
        serversTab = new QWidget();
        serversTab->setObjectName(QString::fromUtf8("serversTab"));
        serversTab->setEnabled(true);
        horizontalLayout_2 = new QHBoxLayout(serversTab);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        serverList = new QListWidget(serversTab);
        serverList->setObjectName(QString::fromUtf8("serverList"));
        QSizePolicy sizePolicy5(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy5.setHorizontalStretch(1);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(serverList->sizePolicy().hasHeightForWidth());
        serverList->setSizePolicy(sizePolicy5);

        horizontalLayout_2->addWidget(serverList);

        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        editServer = new QPushButton(serversTab);
        editServer->setObjectName(QString::fromUtf8("editServer"));
        sizePolicy1.setHeightForWidth(editServer->sizePolicy().hasHeightForWidth());
        editServer->setSizePolicy(sizePolicy1);
        QIcon icon3;
        icon3.addFile(QString::fromUtf8("."), QSize(), QIcon::Normal, QIcon::Off);
        editServer->setIcon(icon3);

        vboxLayout1->addWidget(editServer);

        addServer = new QPushButton(serversTab);
        addServer->setObjectName(QString::fromUtf8("addServer"));
        sizePolicy1.setHeightForWidth(addServer->sizePolicy().hasHeightForWidth());
        addServer->setSizePolicy(sizePolicy1);
        addServer->setIcon(icon1);

        vboxLayout1->addWidget(addServer);

        deleteServer = new QPushButton(serversTab);
        deleteServer->setObjectName(QString::fromUtf8("deleteServer"));
        sizePolicy1.setHeightForWidth(deleteServer->sizePolicy().hasHeightForWidth());
        deleteServer->setSizePolicy(sizePolicy1);
        deleteServer->setIcon(icon2);

        vboxLayout1->addWidget(deleteServer);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QString::fromUtf8("hboxLayout1"));
        spacerItem = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem);

        upServer = new QToolButton(serversTab);
        upServer->setObjectName(QString::fromUtf8("upServer"));
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/go-up.png"), QSize(), QIcon::Normal, QIcon::Off);
        upServer->setIcon(icon4);

        hboxLayout1->addWidget(upServer);

        downServer = new QToolButton(serversTab);
        downServer->setObjectName(QString::fromUtf8("downServer"));
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/go-down.png"), QSize(), QIcon::Normal, QIcon::Off);
        downServer->setIcon(icon5);

        hboxLayout1->addWidget(downServer);

        spacerItem1 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem1);


        vboxLayout1->addLayout(hboxLayout1);

        spacerItem2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacerItem2);


        horizontalLayout_2->addLayout(vboxLayout1);

        tabWidget->addTab(serversTab, QString());
        performTab = new QWidget();
        performTab->setObjectName(QString::fromUtf8("performTab"));
        verticalLayout = new QVBoxLayout(performTab);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        label = new QLabel(performTab);
        label->setObjectName(QString::fromUtf8("label"));

        verticalLayout->addWidget(label);

        performEdit = new QTextEdit(performTab);
        performEdit->setObjectName(QString::fromUtf8("performEdit"));
        performEdit->setEnabled(true);
        QSizePolicy sizePolicy6(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(performEdit->sizePolicy().hasHeightForWidth());
        performEdit->setSizePolicy(sizePolicy6);
        performEdit->setLineWrapMode(QTextEdit::NoWrap);

        verticalLayout->addWidget(performEdit);

        tabWidget->addTab(performTab, QString());
        connectionTab = new QWidget();
        connectionTab->setObjectName(QString::fromUtf8("connectionTab"));
        verticalLayout_9 = new QVBoxLayout(connectionTab);
        verticalLayout_9->setObjectName(QString::fromUtf8("verticalLayout_9"));
        autoReconnect = new QGroupBox(connectionTab);
        autoReconnect->setObjectName(QString::fromUtf8("autoReconnect"));
        autoReconnect->setEnabled(true);
        autoReconnect->setCheckable(true);
        verticalLayout_5 = new QVBoxLayout(autoReconnect);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        label_7 = new QLabel(autoReconnect);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        horizontalLayout_4->addWidget(label_7);

        reconnectInterval = new QSpinBox(autoReconnect);
        reconnectInterval->setObjectName(QString::fromUtf8("reconnectInterval"));
        reconnectInterval->setMinimum(10);
        reconnectInterval->setMaximum(3600);
        reconnectInterval->setValue(30);

        horizontalLayout_4->addWidget(reconnectInterval);

        label_12 = new QLabel(autoReconnect);
        label_12->setObjectName(QString::fromUtf8("label_12"));

        horizontalLayout_4->addWidget(label_12);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);


        verticalLayout_5->addLayout(horizontalLayout_4);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label_8 = new QLabel(autoReconnect);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        horizontalLayout_3->addWidget(label_8);

        reconnectRetries = new QSpinBox(autoReconnect);
        reconnectRetries->setObjectName(QString::fromUtf8("reconnectRetries"));
        reconnectRetries->setMinimum(1);
        reconnectRetries->setMaximum(999);
        reconnectRetries->setValue(10);

        horizontalLayout_3->addWidget(reconnectRetries);

        unlimitedRetries = new QCheckBox(autoReconnect);
        unlimitedRetries->setObjectName(QString::fromUtf8("unlimitedRetries"));

        horizontalLayout_3->addWidget(unlimitedRetries);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);


        verticalLayout_5->addLayout(horizontalLayout_3);

        rejoinOnReconnect = new QCheckBox(autoReconnect);
        rejoinOnReconnect->setObjectName(QString::fromUtf8("rejoinOnReconnect"));
        rejoinOnReconnect->setEnabled(true);
        rejoinOnReconnect->setChecked(true);

        verticalLayout_5->addWidget(rejoinOnReconnect);


        verticalLayout_9->addWidget(autoReconnect);

        useCustomMessageRate = new QGroupBox(connectionTab);
        useCustomMessageRate->setObjectName(QString::fromUtf8("useCustomMessageRate"));
        useCustomMessageRate->setEnabled(true);
#if QT_CONFIG(tooltip)
        useCustomMessageRate->setToolTip(QString::fromUtf8("Tooltip not yet loaded - to modify tooltip, edit NetworksSettingsPage::load()"));
#endif // QT_CONFIG(tooltip)
        useCustomMessageRate->setCheckable(true);
        useCustomMessageRate->setChecked(false);
        verticalLayout_8 = new QVBoxLayout(useCustomMessageRate);
        verticalLayout_8->setObjectName(QString::fromUtf8("verticalLayout_8"));
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QString::fromUtf8("horizontalLayout_6"));
        label_11 = new QLabel(useCustomMessageRate);
        label_11->setObjectName(QString::fromUtf8("label_11"));

        horizontalLayout_6->addWidget(label_11);

        messageRateBurstSize = new QSpinBox(useCustomMessageRate);
        messageRateBurstSize->setObjectName(QString::fromUtf8("messageRateBurstSize"));
        messageRateBurstSize->setMinimum(1);
        messageRateBurstSize->setMaximum(999);
        messageRateBurstSize->setValue(5);

        horizontalLayout_6->addWidget(messageRateBurstSize);

        unlimitedMessageRate = new QCheckBox(useCustomMessageRate);
        unlimitedMessageRate->setObjectName(QString::fromUtf8("unlimitedMessageRate"));

        horizontalLayout_6->addWidget(unlimitedMessageRate);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_5);


        verticalLayout_8->addLayout(horizontalLayout_6);

        messageRateDelayFrame = new QFrame(useCustomMessageRate);
        messageRateDelayFrame->setObjectName(QString::fromUtf8("messageRateDelayFrame"));
        messageRateDelayFrame->setFrameShape(QFrame::NoFrame);
        messageRateDelayFrame->setFrameShadow(QFrame::Plain);
        messageRateDelayFrame->setLineWidth(1);
        verticalLayout_10 = new QVBoxLayout(messageRateDelayFrame);
        verticalLayout_10->setObjectName(QString::fromUtf8("verticalLayout_10"));
        verticalLayout_10->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        label_10 = new QLabel(messageRateDelayFrame);
        label_10->setObjectName(QString::fromUtf8("label_10"));

        horizontalLayout_5->addWidget(label_10);

        messageRateDelay = new QDoubleSpinBox(messageRateDelayFrame);
        messageRateDelay->setObjectName(QString::fromUtf8("messageRateDelay"));
        messageRateDelay->setMinimum(0.010000000000000);
        messageRateDelay->setSingleStep(0.100000000000000);
        messageRateDelay->setValue(2.200000000000000);

        horizontalLayout_5->addWidget(messageRateDelay);

        label_13 = new QLabel(messageRateDelayFrame);
        label_13->setObjectName(QString::fromUtf8("label_13"));

        horizontalLayout_5->addWidget(label_13);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_4);


        verticalLayout_10->addLayout(horizontalLayout_5);


        verticalLayout_8->addWidget(messageRateDelayFrame);


        verticalLayout_9->addWidget(useCustomMessageRate);

        verticalSpacer_3 = new QSpacerItem(20, 1, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_9->addItem(verticalSpacer_3);

        tabWidget->addTab(connectionTab, QString());
        autoIdentifyTab = new QWidget();
        autoIdentifyTab->setObjectName(QString::fromUtf8("autoIdentifyTab"));
        verticalLayout_4 = new QVBoxLayout(autoIdentifyTab);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        sasl = new QGroupBox(autoIdentifyTab);
        sasl->setObjectName(QString::fromUtf8("sasl"));
        sasl->setEnabled(true);
        sasl->setCheckable(true);
        sasl->setChecked(true);
        verticalLayout_11 = new QVBoxLayout(sasl);
        verticalLayout_11->setObjectName(QString::fromUtf8("verticalLayout_11"));
        saslPlainContents = new QFrame(sasl);
        saslPlainContents->setObjectName(QString::fromUtf8("saslPlainContents"));
        saslPlainContents->setFrameShape(QFrame::NoFrame);
        saslPlainContents->setFrameShadow(QFrame::Plain);
        saslPlainContents->setLineWidth(0);
        verticalLayout_12 = new QVBoxLayout(saslPlainContents);
        verticalLayout_12->setObjectName(QString::fromUtf8("verticalLayout_12"));
        verticalLayout_12->setContentsMargins(0, 0, 0, 0);
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        saslAccount = new QLineEdit(saslPlainContents);
        saslAccount->setObjectName(QString::fromUtf8("saslAccount"));
        saslAccount->setEnabled(true);

        gridLayout_2->addWidget(saslAccount, 0, 1, 1, 1);

        saslAccountLabel = new QLabel(saslPlainContents);
        saslAccountLabel->setObjectName(QString::fromUtf8("saslAccountLabel"));
        saslAccountLabel->setEnabled(true);

        gridLayout_2->addWidget(saslAccountLabel, 0, 0, 1, 1);

        saslPassword = new QLineEdit(saslPlainContents);
        saslPassword->setObjectName(QString::fromUtf8("saslPassword"));
        saslPassword->setEnabled(true);
        saslPassword->setEchoMode(QLineEdit::Password);

        gridLayout_2->addWidget(saslPassword, 1, 1, 1, 1);

        saslPasswordLabel = new QLabel(saslPlainContents);
        saslPasswordLabel->setObjectName(QString::fromUtf8("saslPasswordLabel"));
        saslPasswordLabel->setEnabled(true);

        gridLayout_2->addWidget(saslPasswordLabel, 1, 0, 1, 1);


        verticalLayout_12->addLayout(gridLayout_2);


        verticalLayout_11->addWidget(saslPlainContents);

        saslExtInfo = new QLabel(sasl);
        saslExtInfo->setObjectName(QString::fromUtf8("saslExtInfo"));
        saslExtInfo->setWordWrap(true);

        verticalLayout_11->addWidget(saslExtInfo);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName(QString::fromUtf8("horizontalLayout_7"));
        saslStatusIcon = new QLabel(sasl);
        saslStatusIcon->setObjectName(QString::fromUtf8("saslStatusIcon"));
        saslStatusIcon->setText(QString::fromUtf8("[icon]"));

        horizontalLayout_7->addWidget(saslStatusIcon);

        saslStatusLabel = new QLabel(sasl);
        saslStatusLabel->setObjectName(QString::fromUtf8("saslStatusLabel"));
        sizePolicy4.setHeightForWidth(saslStatusLabel->sizePolicy().hasHeightForWidth());
        saslStatusLabel->setSizePolicy(sizePolicy4);

        horizontalLayout_7->addWidget(saslStatusLabel);

        saslStatusDetails = new QPushButton(sasl);
        saslStatusDetails->setObjectName(QString::fromUtf8("saslStatusDetails"));

        horizontalLayout_7->addWidget(saslStatusDetails);


        verticalLayout_11->addLayout(horizontalLayout_7);


        verticalLayout_4->addWidget(sasl);

        autoIdentify = new QGroupBox(autoIdentifyTab);
        autoIdentify->setObjectName(QString::fromUtf8("autoIdentify"));
        autoIdentify->setEnabled(true);
        autoIdentify->setCheckable(true);
        autoIdentify->setChecked(true);
        gridLayout = new QGridLayout(autoIdentify);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        autoIdentifyService = new QLineEdit(autoIdentify);
        autoIdentifyService->setObjectName(QString::fromUtf8("autoIdentifyService"));
        autoIdentifyService->setEnabled(true);

        gridLayout->addWidget(autoIdentifyService, 0, 1, 1, 1);

        autoIdentifyPassword = new QLineEdit(autoIdentify);
        autoIdentifyPassword->setObjectName(QString::fromUtf8("autoIdentifyPassword"));
        autoIdentifyPassword->setEnabled(true);
        autoIdentifyPassword->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(autoIdentifyPassword, 1, 1, 1, 1);

        identifyServiceLabel = new QLabel(autoIdentify);
        identifyServiceLabel->setObjectName(QString::fromUtf8("identifyServiceLabel"));

        gridLayout->addWidget(identifyServiceLabel, 0, 0, 1, 1);

        identifyPasswordLabel = new QLabel(autoIdentify);
        identifyPasswordLabel->setObjectName(QString::fromUtf8("identifyPasswordLabel"));
        identifyPasswordLabel->setEnabled(true);

        gridLayout->addWidget(identifyPasswordLabel, 1, 0, 1, 1);


        verticalLayout_4->addWidget(autoIdentify);

        verticalSpacer_2 = new QSpacerItem(20, 10, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_2);

        tabWidget->addTab(autoIdentifyTab, QString());
        featuresTab = new QWidget();
        featuresTab->setObjectName(QString::fromUtf8("featuresTab"));
        verticalLayout_14 = new QVBoxLayout(featuresTab);
        verticalLayout_14->setObjectName(QString::fromUtf8("verticalLayout_14"));
        enableCapsStatusWidget = new QWidget(featuresTab);
        enableCapsStatusWidget->setObjectName(QString::fromUtf8("enableCapsStatusWidget"));
        horizontalLayout_8 = new QHBoxLayout(enableCapsStatusWidget);
        horizontalLayout_8->setObjectName(QString::fromUtf8("horizontalLayout_8"));
        horizontalLayout_8->setContentsMargins(0, 0, 0, 0);
        enableCapsStatusIcon = new QLabel(enableCapsStatusWidget);
        enableCapsStatusIcon->setObjectName(QString::fromUtf8("enableCapsStatusIcon"));
        enableCapsStatusIcon->setText(QString::fromUtf8("[icon]"));

        horizontalLayout_8->addWidget(enableCapsStatusIcon);

        enableCapsStatusLabel = new QLabel(enableCapsStatusWidget);
        enableCapsStatusLabel->setObjectName(QString::fromUtf8("enableCapsStatusLabel"));
        sizePolicy4.setHeightForWidth(enableCapsStatusLabel->sizePolicy().hasHeightForWidth());
        enableCapsStatusLabel->setSizePolicy(sizePolicy4);
        enableCapsStatusLabel->setWordWrap(true);

        horizontalLayout_8->addWidget(enableCapsStatusLabel);

        enableCapsStatusDetails = new QPushButton(enableCapsStatusWidget);
        enableCapsStatusDetails->setObjectName(QString::fromUtf8("enableCapsStatusDetails"));

        horizontalLayout_8->addWidget(enableCapsStatusDetails);


        verticalLayout_14->addWidget(enableCapsStatusWidget);

        enableCapsConfigWidget = new QWidget(featuresTab);
        enableCapsConfigWidget->setObjectName(QString::fromUtf8("enableCapsConfigWidget"));
        verticalLayout_6 = new QVBoxLayout(enableCapsConfigWidget);
        verticalLayout_6->setObjectName(QString::fromUtf8("verticalLayout_6"));
        verticalLayout_6->setContentsMargins(0, 0, 0, 0);
        enableCapServerTime = new QCheckBox(enableCapsConfigWidget);
        enableCapServerTime->setObjectName(QString::fromUtf8("enableCapServerTime"));
        sizePolicy3.setHeightForWidth(enableCapServerTime->sizePolicy().hasHeightForWidth());
        enableCapServerTime->setSizePolicy(sizePolicy3);

        verticalLayout_6->addWidget(enableCapServerTime);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName(QString::fromUtf8("horizontalLayout_9"));
        enableCapsAdvanced = new QPushButton(enableCapsConfigWidget);
        enableCapsAdvanced->setObjectName(QString::fromUtf8("enableCapsAdvanced"));

        horizontalLayout_9->addWidget(enableCapsAdvanced);

        horizontalSpacer_6 = new QSpacerItem(13, 35, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_6);


        verticalLayout_6->addLayout(horizontalLayout_9);

        enableCapsReconnectNotice = new QLabel(enableCapsConfigWidget);
        enableCapsReconnectNotice->setObjectName(QString::fromUtf8("enableCapsReconnectNotice"));

        verticalLayout_6->addWidget(enableCapsReconnectNotice);


        verticalLayout_14->addWidget(enableCapsConfigWidget);

        verticalSpacer_5 = new QSpacerItem(20, 178, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_14->addItem(verticalSpacer_5);

        tabWidget->addTab(featuresTab, QString());
        encodingsTab = new QWidget();
        encodingsTab->setObjectName(QString::fromUtf8("encodingsTab"));
        verticalLayout_13 = new QVBoxLayout(encodingsTab);
        verticalLayout_13->setObjectName(QString::fromUtf8("verticalLayout_13"));
        useCustomEncodings = new QGroupBox(encodingsTab);
        useCustomEncodings->setObjectName(QString::fromUtf8("useCustomEncodings"));
        useCustomEncodings->setEnabled(true);
        useCustomEncodings->setCheckable(true);
        vboxLayout2 = new QVBoxLayout(useCustomEncodings);
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName(QString::fromUtf8("gridLayout1"));
        label_4 = new QLabel(useCustomEncodings);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout1->addWidget(label_4, 0, 0, 1, 1);

        sendEncoding = new QComboBox(useCustomEncodings);
        sendEncoding->setObjectName(QString::fromUtf8("sendEncoding"));
        sendEncoding->setEnabled(true);
        sizePolicy3.setHeightForWidth(sendEncoding->sizePolicy().hasHeightForWidth());
        sendEncoding->setSizePolicy(sizePolicy3);
        sendEncoding->setInsertPolicy(QComboBox::InsertAlphabetically);

        gridLayout1->addWidget(sendEncoding, 0, 1, 1, 1);

        label_5 = new QLabel(useCustomEncodings);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout1->addWidget(label_5, 1, 0, 1, 1);

        recvEncoding = new QComboBox(useCustomEncodings);
        recvEncoding->setObjectName(QString::fromUtf8("recvEncoding"));
        recvEncoding->setEnabled(true);
        sizePolicy3.setHeightForWidth(recvEncoding->sizePolicy().hasHeightForWidth());
        recvEncoding->setSizePolicy(sizePolicy3);
        recvEncoding->setInsertPolicy(QComboBox::InsertAlphabetically);

        gridLayout1->addWidget(recvEncoding, 1, 1, 1, 1);

        label_9 = new QLabel(useCustomEncodings);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        gridLayout1->addWidget(label_9, 2, 0, 1, 1);

        serverEncoding = new QComboBox(useCustomEncodings);
        serverEncoding->setObjectName(QString::fromUtf8("serverEncoding"));
        serverEncoding->setEnabled(true);

        gridLayout1->addWidget(serverEncoding, 2, 1, 1, 1);


        vboxLayout2->addLayout(gridLayout1);


        verticalLayout_13->addWidget(useCustomEncodings);

        verticalSpacer_4 = new QSpacerItem(20, 79, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_13->addItem(verticalSpacer_4);

        tabWidget->addTab(encodingsTab, QString());

        vboxLayout->addWidget(tabWidget);


        verticalLayout_7->addWidget(detailsBox);

        QWidget::setTabOrder(networkList, renameNetwork);
        QWidget::setTabOrder(renameNetwork, addNetwork);
        QWidget::setTabOrder(addNetwork, deleteNetwork);
        QWidget::setTabOrder(deleteNetwork, identityList);
        QWidget::setTabOrder(identityList, editIdentities);
        QWidget::setTabOrder(editIdentities, tabWidget);
        QWidget::setTabOrder(tabWidget, serverList);
        QWidget::setTabOrder(serverList, editServer);
        QWidget::setTabOrder(editServer, addServer);
        QWidget::setTabOrder(addServer, deleteServer);
        QWidget::setTabOrder(deleteServer, upServer);
        QWidget::setTabOrder(upServer, downServer);
        QWidget::setTabOrder(downServer, performEdit);
        QWidget::setTabOrder(performEdit, autoReconnect);
        QWidget::setTabOrder(autoReconnect, reconnectInterval);
        QWidget::setTabOrder(reconnectInterval, reconnectRetries);
        QWidget::setTabOrder(reconnectRetries, unlimitedRetries);
        QWidget::setTabOrder(unlimitedRetries, rejoinOnReconnect);
        QWidget::setTabOrder(rejoinOnReconnect, useCustomMessageRate);
        QWidget::setTabOrder(useCustomMessageRate, messageRateBurstSize);
        QWidget::setTabOrder(messageRateBurstSize, unlimitedMessageRate);
        QWidget::setTabOrder(unlimitedMessageRate, messageRateDelay);
        QWidget::setTabOrder(messageRateDelay, sasl);
        QWidget::setTabOrder(sasl, saslAccount);
        QWidget::setTabOrder(saslAccount, saslPassword);
        QWidget::setTabOrder(saslPassword, saslStatusDetails);
        QWidget::setTabOrder(saslStatusDetails, autoIdentify);
        QWidget::setTabOrder(autoIdentify, autoIdentifyService);
        QWidget::setTabOrder(autoIdentifyService, autoIdentifyPassword);
        QWidget::setTabOrder(autoIdentifyPassword, enableCapsStatusDetails);
        QWidget::setTabOrder(enableCapsStatusDetails, enableCapServerTime);
        QWidget::setTabOrder(enableCapServerTime, enableCapsAdvanced);
        QWidget::setTabOrder(enableCapsAdvanced, useCustomEncodings);
        QWidget::setTabOrder(useCustomEncodings, sendEncoding);
        QWidget::setTabOrder(sendEncoding, recvEncoding);
        QWidget::setTabOrder(recvEncoding, serverEncoding);

        retranslateUi(NetworksSettingsPage);
        QObject::connect(unlimitedRetries, SIGNAL(toggled(bool)), reconnectRetries, SLOT(setDisabled(bool)));
        QObject::connect(unlimitedMessageRate, SIGNAL(toggled(bool)), messageRateBurstSize, SLOT(setDisabled(bool)));
        QObject::connect(unlimitedMessageRate, SIGNAL(toggled(bool)), messageRateDelayFrame, SLOT(setDisabled(bool)));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(NetworksSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *NetworksSettingsPage)
    {
        NetworksSettingsPage->setWindowTitle(QCoreApplication::translate("NetworksSettingsPage", "Form", nullptr));
        renameNetwork->setText(QCoreApplication::translate("NetworksSettingsPage", "Re&name...", nullptr));
        addNetwork->setText(QCoreApplication::translate("NetworksSettingsPage", "&Add...", nullptr));
        deleteNetwork->setText(QCoreApplication::translate("NetworksSettingsPage", "De&lete", nullptr));
        detailsBox->setTitle(QCoreApplication::translate("NetworksSettingsPage", "Network Details", nullptr));
        label_6->setText(QCoreApplication::translate("NetworksSettingsPage", "Identity:", nullptr));
        editIdentities->setText(QCoreApplication::translate("NetworksSettingsPage", "...", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        editServer->setText(QCoreApplication::translate("NetworksSettingsPage", "&Edit...", nullptr));
        addServer->setText(QCoreApplication::translate("NetworksSettingsPage", "&Add...", nullptr));
        deleteServer->setText(QCoreApplication::translate("NetworksSettingsPage", "De&lete", nullptr));
#if QT_CONFIG(tooltip)
        upServer->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Move upwards in list", nullptr));
#endif // QT_CONFIG(tooltip)
        upServer->setText(QCoreApplication::translate("NetworksSettingsPage", "...", nullptr));
#if QT_CONFIG(tooltip)
        downServer->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Move downwards in list", nullptr));
#endif // QT_CONFIG(tooltip)
        downServer->setText(QCoreApplication::translate("NetworksSettingsPage", "...", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(serversTab), QCoreApplication::translate("NetworksSettingsPage", "Servers", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(serversTab), QCoreApplication::translate("NetworksSettingsPage", "Manage servers for this network", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(QCoreApplication::translate("NetworksSettingsPage", "Commands to execute on connect:", nullptr));
#if QT_CONFIG(tooltip)
        performEdit->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Specify a list of IRC commands to be executed upon connect.\n"
"Note that Quassel IRC automatically rejoins channels, so /join will rarely be needed here!", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(performTab), QCoreApplication::translate("NetworksSettingsPage", "Commands", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(performTab), QCoreApplication::translate("NetworksSettingsPage", "Configure automatic identification or misc. commands to be executed after connecting to a server", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        autoReconnect->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Automatically reconnect to the IRC network after connection failures", nullptr));
#endif // QT_CONFIG(tooltip)
        autoReconnect->setTitle(QCoreApplication::translate("NetworksSettingsPage", "Automatic Reconnect", nullptr));
        label_7->setText(QCoreApplication::translate("NetworksSettingsPage", "Wait", nullptr));
        reconnectInterval->setSuffix(QCoreApplication::translate("NetworksSettingsPage", " s", nullptr));
        label_12->setText(QCoreApplication::translate("NetworksSettingsPage", "between retries", nullptr));
        label_8->setText(QCoreApplication::translate("NetworksSettingsPage", "Number of retries:", nullptr));
        unlimitedRetries->setText(QCoreApplication::translate("NetworksSettingsPage", "Unlimited", nullptr));
        rejoinOnReconnect->setText(QCoreApplication::translate("NetworksSettingsPage", "Rejoin all channels after reconnect", nullptr));
        useCustomMessageRate->setTitle(QCoreApplication::translate("NetworksSettingsPage", "Use Custom Rate Limits", nullptr));
        label_11->setText(QCoreApplication::translate("NetworksSettingsPage", "Max. messages at once:", nullptr));
#if QT_CONFIG(tooltip)
        messageRateBurstSize->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Maximum number of messages to send without any delays", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        unlimitedMessageRate->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "<html><head/><body><p>Disable all rate limiting, e.g. for IRC bridges.</p><p>Don't use with most normal networks.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        unlimitedMessageRate->setText(QCoreApplication::translate("NetworksSettingsPage", "Unlimited", nullptr));
        label_10->setText(QCoreApplication::translate("NetworksSettingsPage", "Wait", nullptr));
#if QT_CONFIG(tooltip)
        messageRateDelay->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "<html><head/><body><p>Delay between messages after the maximum number of undelayed messages have been sent.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        messageRateDelay->setSuffix(QCoreApplication::translate("NetworksSettingsPage", " s", nullptr));
        label_13->setText(QCoreApplication::translate("NetworksSettingsPage", "between future messages", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(connectionTab), QCoreApplication::translate("NetworksSettingsPage", "Connection", nullptr));
#if QT_CONFIG(tooltip)
        sasl->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Authenticate using your nickname and password before joining any channels", nullptr));
#endif // QT_CONFIG(tooltip)
        sasl->setTitle(QCoreApplication::translate("NetworksSettingsPage", "Use SASL Authentication", nullptr));
#if QT_CONFIG(tooltip)
        saslAccount->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Account name, often the same as your nickname", nullptr));
#endif // QT_CONFIG(tooltip)
        saslAccount->setText(QString());
        saslAccountLabel->setText(QCoreApplication::translate("NetworksSettingsPage", "Account:", nullptr));
#if QT_CONFIG(tooltip)
        saslPassword->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Account password", nullptr));
#endif // QT_CONFIG(tooltip)
        saslPasswordLabel->setText(QCoreApplication::translate("NetworksSettingsPage", "Password:", nullptr));
        saslExtInfo->setText(QCoreApplication::translate("NetworksSettingsPage", "<html><head/><body><p><span style=\" font-weight:600;\">Note:</span> because the identity has an ssl certificate set, SASL EXTERNAL will be used.</p></body></html>", nullptr));
        saslStatusLabel->setText(QCoreApplication::translate("NetworksSettingsPage", "Could not detect if supported by server", nullptr));
        saslStatusDetails->setText(QCoreApplication::translate("NetworksSettingsPage", "Details...", nullptr));
#if QT_CONFIG(tooltip)
        autoIdentify->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Authenticate to services using your password.  Use SASL instead to identify before joining channels.", nullptr));
#endif // QT_CONFIG(tooltip)
        autoIdentify->setTitle(QCoreApplication::translate("NetworksSettingsPage", "Auto Identify", nullptr));
#if QT_CONFIG(tooltip)
        autoIdentifyService->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Service user to send your password to, usually NickServ", nullptr));
#endif // QT_CONFIG(tooltip)
        autoIdentifyService->setText(QCoreApplication::translate("NetworksSettingsPage", "NickServ", nullptr));
#if QT_CONFIG(tooltip)
        autoIdentifyPassword->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Account password", nullptr));
#endif // QT_CONFIG(tooltip)
        identifyServiceLabel->setText(QCoreApplication::translate("NetworksSettingsPage", "Service:", nullptr));
        identifyPasswordLabel->setText(QCoreApplication::translate("NetworksSettingsPage", "Password:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(autoIdentifyTab), QCoreApplication::translate("NetworksSettingsPage", "Auto Identify", nullptr));
        enableCapsStatusLabel->setText(QCoreApplication::translate("NetworksSettingsPage", "These features require support from the network", nullptr));
        enableCapsStatusDetails->setText(QCoreApplication::translate("NetworksSettingsPage", "Details...", nullptr));
#if QT_CONFIG(tooltip)
        enableCapServerTime->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "<p>Let the IRC network control the timestamps for messages, such as when viewing messages from the past.</p>\n"
"<p>This is useful when connecting to bouncers, IRC bridges, or networks that send messages you've missed when reconnecting.</p>\n"
"<p><i>Toggles the IRCv3 'server-time' capability.</i></p>", nullptr));
#endif // QT_CONFIG(tooltip)
        enableCapServerTime->setText(QCoreApplication::translate("NetworksSettingsPage", "Use network timestamps for messages", nullptr));
#if QT_CONFIG(tooltip)
        enableCapsAdvanced->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Configure which IRC capabilities Quassel will ignore during negotiation", nullptr));
#endif // QT_CONFIG(tooltip)
        enableCapsAdvanced->setText(QCoreApplication::translate("NetworksSettingsPage", "Advanced...", nullptr));
        enableCapsReconnectNotice->setText(QCoreApplication::translate("NetworksSettingsPage", "<i>Changes apply after reconnecting to the network</i>", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(featuresTab), QCoreApplication::translate("NetworksSettingsPage", "Features", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(featuresTab), QCoreApplication::translate("NetworksSettingsPage", "Configure the modern IRC messaging features Quassel supports", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        useCustomEncodings->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Control encodings for in- and outgoing messages", nullptr));
#endif // QT_CONFIG(tooltip)
        useCustomEncodings->setTitle(QCoreApplication::translate("NetworksSettingsPage", "Use Custom Encodings", nullptr));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Specify which encoding your messages will be sent in.\n"
"UTF-8 should be a sane choice for most networks.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(QCoreApplication::translate("NetworksSettingsPage", "Send messages in:", nullptr));
#if QT_CONFIG(tooltip)
        sendEncoding->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Specify which encoding your messages will be sent in.\n"
"UTF-8 should be a sane choice for most networks.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_5->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Incoming messages encoded in UTF-8 will always be treated as such.\n"
"This setting defines the encoding for messages that are not UTF-8.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(QCoreApplication::translate("NetworksSettingsPage", "Receive fallback:", nullptr));
#if QT_CONFIG(tooltip)
        recvEncoding->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "Incoming messages encoded in UTF-8 will always be treated as such.\n"
"This setting defines the encoding for messages that are not UTF-8.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_9->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "<qt><p>This specifies how control messages, nicks and servernames are encoded.</p><p><b>UTF-8</b> should be fine for modern networks.  On other networks, you may need to use <b>ISO-8859-1</b> to avoid errors with illegal characters and invalid encoding.</p></qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_9->setText(QCoreApplication::translate("NetworksSettingsPage", "Server encoding:", nullptr));
#if QT_CONFIG(tooltip)
        serverEncoding->setToolTip(QCoreApplication::translate("NetworksSettingsPage", "<qt><p>This specifies how control messages, nicks and servernames are encoded.</p><p><b>UTF-8</b> should be fine for modern networks.  On other networks, you may need to use <b>ISO-8859-1</b> to avoid errors with illegal characters and invalid encoding.</p></qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(encodingsTab), QCoreApplication::translate("NetworksSettingsPage", "Encodings", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setTabToolTip(tabWidget->indexOf(encodingsTab), QCoreApplication::translate("NetworksSettingsPage", "Configure advanced settings such as message encodings", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class NetworksSettingsPage: public Ui_NetworksSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NETWORKSSETTINGSPAGE_H
