/********************************************************************************
** Form generated from reading UI file 'highlightsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HIGHLIGHTSETTINGSPAGE_H
#define UI_HIGHLIGHTSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_HighlightSettingsPage
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *localHighlightsIcon;
    QLabel *localHighlightsLabel;
    QPushButton *localHighlightsDetails;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QTableWidget *highlightTable;
    QHBoxLayout *horizontalLayout;
    QPushButton *add;
    QPushButton *remove;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout1;
    QRadioButton *highlightAllNicks;
    QRadioButton *highlightCurrentNick;
    QRadioButton *highlightNoNick;
    QCheckBox *nicksCaseSensitive;

    void setupUi(QWidget *HighlightSettingsPage)
    {
        if (HighlightSettingsPage->objectName().isEmpty())
            HighlightSettingsPage->setObjectName(QString::fromUtf8("HighlightSettingsPage"));
        HighlightSettingsPage->resize(438, 404);
        vboxLayout = new QVBoxLayout(HighlightSettingsPage);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        localHighlightsIcon = new QLabel(HighlightSettingsPage);
        localHighlightsIcon->setObjectName(QString::fromUtf8("localHighlightsIcon"));
        localHighlightsIcon->setText(QString::fromUtf8("[icon]"));

        hboxLayout->addWidget(localHighlightsIcon);

        localHighlightsLabel = new QLabel(HighlightSettingsPage);
        localHighlightsLabel->setObjectName(QString::fromUtf8("localHighlightsLabel"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(localHighlightsLabel->sizePolicy().hasHeightForWidth());
        localHighlightsLabel->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(localHighlightsLabel);

        localHighlightsDetails = new QPushButton(HighlightSettingsPage);
        localHighlightsDetails->setObjectName(QString::fromUtf8("localHighlightsDetails"));

        hboxLayout->addWidget(localHighlightsDetails);


        vboxLayout->addLayout(hboxLayout);

        groupBox = new QGroupBox(HighlightSettingsPage);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        highlightTable = new QTableWidget(groupBox);
        if (highlightTable->columnCount() < 5)
            highlightTable->setColumnCount(5);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        highlightTable->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        highlightTable->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        highlightTable->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        highlightTable->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        highlightTable->setHorizontalHeaderItem(4, __qtablewidgetitem4);
        highlightTable->setObjectName(QString::fromUtf8("highlightTable"));
        highlightTable->setStyleSheet(QString::fromUtf8(""));

        verticalLayout->addWidget(highlightTable);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalLayout->setContentsMargins(-1, 0, -1, 0);
        add = new QPushButton(groupBox);
        add->setObjectName(QString::fromUtf8("add"));

        horizontalLayout->addWidget(add);

        remove = new QPushButton(groupBox);
        remove->setObjectName(QString::fromUtf8("remove"));

        horizontalLayout->addWidget(remove);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);


        vboxLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(HighlightSettingsPage);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        vboxLayout1 = new QVBoxLayout(groupBox_2);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        highlightAllNicks = new QRadioButton(groupBox_2);
        highlightAllNicks->setObjectName(QString::fromUtf8("highlightAllNicks"));

        vboxLayout1->addWidget(highlightAllNicks);

        highlightCurrentNick = new QRadioButton(groupBox_2);
        highlightCurrentNick->setObjectName(QString::fromUtf8("highlightCurrentNick"));
        highlightCurrentNick->setChecked(true);

        vboxLayout1->addWidget(highlightCurrentNick);

        highlightNoNick = new QRadioButton(groupBox_2);
        highlightNoNick->setObjectName(QString::fromUtf8("highlightNoNick"));

        vboxLayout1->addWidget(highlightNoNick);

        nicksCaseSensitive = new QCheckBox(groupBox_2);
        nicksCaseSensitive->setObjectName(QString::fromUtf8("nicksCaseSensitive"));

        vboxLayout1->addWidget(nicksCaseSensitive);


        vboxLayout->addWidget(groupBox_2);


        retranslateUi(HighlightSettingsPage);
        QObject::connect(highlightNoNick, SIGNAL(toggled(bool)), nicksCaseSensitive, SLOT(setDisabled(bool)));

        QMetaObject::connectSlotsByName(HighlightSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *HighlightSettingsPage)
    {
        HighlightSettingsPage->setWindowTitle(QCoreApplication::translate("HighlightSettingsPage", "Form", nullptr));
        localHighlightsLabel->setText(QCoreApplication::translate("HighlightSettingsPage", "Legacy Highlights are replaced by Highlights", nullptr));
        localHighlightsDetails->setText(QCoreApplication::translate("HighlightSettingsPage", "Details...", nullptr));
        groupBox->setTitle(QCoreApplication::translate("HighlightSettingsPage", "Custom Highlights", nullptr));
        QTableWidgetItem *___qtablewidgetitem = highlightTable->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("HighlightSettingsPage", "Enabled", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = highlightTable->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QCoreApplication::translate("HighlightSettingsPage", "Highlight", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = highlightTable->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(QCoreApplication::translate("HighlightSettingsPage", "RegEx", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = highlightTable->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(QCoreApplication::translate("HighlightSettingsPage", "CS", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = highlightTable->horizontalHeaderItem(4);
        ___qtablewidgetitem4->setText(QCoreApplication::translate("HighlightSettingsPage", "Channel", nullptr));
#if QT_CONFIG(tooltip)
        highlightTable->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        add->setText(QCoreApplication::translate("HighlightSettingsPage", "Add", nullptr));
        remove->setText(QCoreApplication::translate("HighlightSettingsPage", "Remove", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("HighlightSettingsPage", "Highlight Nicks", nullptr));
        highlightAllNicks->setText(QCoreApplication::translate("HighlightSettingsPage", "All nicks from identity", nullptr));
        highlightCurrentNick->setText(QCoreApplication::translate("HighlightSettingsPage", "Current nick", nullptr));
        highlightNoNick->setText(QCoreApplication::translate("HighlightSettingsPage", "None", nullptr));
        nicksCaseSensitive->setText(QCoreApplication::translate("HighlightSettingsPage", "Case sensitive", nullptr));
    } // retranslateUi

};

namespace Ui {
    class HighlightSettingsPage: public Ui_HighlightSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_HIGHLIGHTSETTINGSPAGE_H
