/********************************************************************************
** Form generated from reading UI file 'chatviewsearchbar.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHATVIEWSEARCHBAR_H
#define UI_CHATVIEWSEARCHBAR_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <clearablelineedit.h>

QT_BEGIN_NAMESPACE

class Ui_ChatViewSearchBar
{
public:
    QHBoxLayout *horizontalLayout;
    QToolButton *hideButton;
    ClearableLineEdit *searchEditLine;
    QToolButton *searchDownButton;
    QToolButton *searchUpButton;
    QCheckBox *caseSensitiveBox;
    QCheckBox *searchSendersBox;
    QCheckBox *searchMsgsBox;
    QCheckBox *searchOnlyRegularMsgsBox;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *ChatViewSearchBar)
    {
        if (ChatViewSearchBar->objectName().isEmpty())
            ChatViewSearchBar->setObjectName(QString::fromUtf8("ChatViewSearchBar"));
        ChatViewSearchBar->resize(727, 51);
        horizontalLayout = new QHBoxLayout(ChatViewSearchBar);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        hideButton = new QToolButton(ChatViewSearchBar);
        hideButton->setObjectName(QString::fromUtf8("hideButton"));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/application-exit.png"), QSize(), QIcon::Normal, QIcon::Off);
        hideButton->setIcon(icon);

        horizontalLayout->addWidget(hideButton);

        searchEditLine = new ClearableLineEdit(ChatViewSearchBar);
        searchEditLine->setObjectName(QString::fromUtf8("searchEditLine"));

        horizontalLayout->addWidget(searchEditLine);

        searchDownButton = new QToolButton(ChatViewSearchBar);
        searchDownButton->setObjectName(QString::fromUtf8("searchDownButton"));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/go-down.png"), QSize(), QIcon::Normal, QIcon::Off);
        searchDownButton->setIcon(icon1);

        horizontalLayout->addWidget(searchDownButton);

        searchUpButton = new QToolButton(ChatViewSearchBar);
        searchUpButton->setObjectName(QString::fromUtf8("searchUpButton"));
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/go-up.png"), QSize(), QIcon::Normal, QIcon::Off);
        searchUpButton->setIcon(icon2);

        horizontalLayout->addWidget(searchUpButton);

        caseSensitiveBox = new QCheckBox(ChatViewSearchBar);
        caseSensitiveBox->setObjectName(QString::fromUtf8("caseSensitiveBox"));

        horizontalLayout->addWidget(caseSensitiveBox);

        searchSendersBox = new QCheckBox(ChatViewSearchBar);
        searchSendersBox->setObjectName(QString::fromUtf8("searchSendersBox"));

        horizontalLayout->addWidget(searchSendersBox);

        searchMsgsBox = new QCheckBox(ChatViewSearchBar);
        searchMsgsBox->setObjectName(QString::fromUtf8("searchMsgsBox"));
        searchMsgsBox->setCheckable(true);
        searchMsgsBox->setChecked(true);

        horizontalLayout->addWidget(searchMsgsBox);

        searchOnlyRegularMsgsBox = new QCheckBox(ChatViewSearchBar);
        searchOnlyRegularMsgsBox->setObjectName(QString::fromUtf8("searchOnlyRegularMsgsBox"));
        searchOnlyRegularMsgsBox->setChecked(true);

        horizontalLayout->addWidget(searchOnlyRegularMsgsBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        retranslateUi(ChatViewSearchBar);

        QMetaObject::connectSlotsByName(ChatViewSearchBar);
    } // setupUi

    void retranslateUi(QWidget *ChatViewSearchBar)
    {
        ChatViewSearchBar->setWindowTitle(QCoreApplication::translate("ChatViewSearchBar", "Form", nullptr));
        hideButton->setText(QCoreApplication::translate("ChatViewSearchBar", "...", nullptr));
        searchDownButton->setText(QCoreApplication::translate("ChatViewSearchBar", "...", nullptr));
        searchUpButton->setText(QCoreApplication::translate("ChatViewSearchBar", "...", nullptr));
        caseSensitiveBox->setText(QCoreApplication::translate("ChatViewSearchBar", "case sensitive", nullptr));
        searchSendersBox->setText(QCoreApplication::translate("ChatViewSearchBar", "search nick", nullptr));
        searchMsgsBox->setText(QCoreApplication::translate("ChatViewSearchBar", "search message", nullptr));
        searchOnlyRegularMsgsBox->setText(QCoreApplication::translate("ChatViewSearchBar", "ignore joins, parts, etc.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ChatViewSearchBar: public Ui_ChatViewSearchBar {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CHATVIEWSEARCHBAR_H
