/****************************************************************************
** Meta object code from reading C++ file 'ircuser.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/ircuser.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ircuser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_IrcUser_t {
    QByteArrayData data[65];
    char stringdata0[749];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_IrcUser_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_IrcUser_t qt_meta_stringdata_IrcUser = {
    {
QT_MOC_LITERAL(0, 0, 7), // "IrcUser"
QT_MOC_LITERAL(1, 8, 7), // "nickSet"
QT_MOC_LITERAL(2, 16, 0), // ""
QT_MOC_LITERAL(3, 17, 7), // "newnick"
QT_MOC_LITERAL(4, 25, 7), // "awaySet"
QT_MOC_LITERAL(5, 33, 4), // "away"
QT_MOC_LITERAL(6, 38, 12), // "encryptedSet"
QT_MOC_LITERAL(7, 51, 9), // "encrypted"
QT_MOC_LITERAL(8, 61, 12), // "userModesSet"
QT_MOC_LITERAL(9, 74, 5), // "modes"
QT_MOC_LITERAL(10, 80, 14), // "userModesAdded"
QT_MOC_LITERAL(11, 95, 16), // "userModesRemoved"
QT_MOC_LITERAL(12, 112, 13), // "channelParted"
QT_MOC_LITERAL(13, 126, 7), // "channel"
QT_MOC_LITERAL(14, 134, 6), // "quited"
QT_MOC_LITERAL(15, 141, 26), // "lastChannelActivityUpdated"
QT_MOC_LITERAL(16, 168, 8), // "BufferId"
QT_MOC_LITERAL(17, 177, 2), // "id"
QT_MOC_LITERAL(18, 180, 7), // "newTime"
QT_MOC_LITERAL(19, 188, 19), // "lastSpokenToUpdated"
QT_MOC_LITERAL(20, 208, 7), // "setUser"
QT_MOC_LITERAL(21, 216, 4), // "user"
QT_MOC_LITERAL(22, 221, 7), // "setHost"
QT_MOC_LITERAL(23, 229, 4), // "host"
QT_MOC_LITERAL(24, 234, 7), // "setNick"
QT_MOC_LITERAL(25, 242, 4), // "nick"
QT_MOC_LITERAL(26, 247, 11), // "setRealName"
QT_MOC_LITERAL(27, 259, 8), // "realName"
QT_MOC_LITERAL(28, 268, 10), // "setAccount"
QT_MOC_LITERAL(29, 279, 7), // "account"
QT_MOC_LITERAL(30, 287, 7), // "setAway"
QT_MOC_LITERAL(31, 295, 14), // "setAwayMessage"
QT_MOC_LITERAL(32, 310, 11), // "awayMessage"
QT_MOC_LITERAL(33, 322, 11), // "setIdleTime"
QT_MOC_LITERAL(34, 334, 8), // "idleTime"
QT_MOC_LITERAL(35, 343, 12), // "setLoginTime"
QT_MOC_LITERAL(36, 356, 9), // "loginTime"
QT_MOC_LITERAL(37, 366, 9), // "setServer"
QT_MOC_LITERAL(38, 376, 6), // "server"
QT_MOC_LITERAL(39, 383, 14), // "setIrcOperator"
QT_MOC_LITERAL(40, 398, 11), // "ircOperator"
QT_MOC_LITERAL(41, 410, 18), // "setLastAwayMessage"
QT_MOC_LITERAL(42, 429, 15), // "lastAwayMessage"
QT_MOC_LITERAL(43, 445, 22), // "setLastAwayMessageTime"
QT_MOC_LITERAL(44, 468, 19), // "lastAwayMessageTime"
QT_MOC_LITERAL(45, 488, 20), // "setWhoisServiceReply"
QT_MOC_LITERAL(46, 509, 17), // "whoisServiceReply"
QT_MOC_LITERAL(47, 527, 12), // "setSuserHost"
QT_MOC_LITERAL(48, 540, 9), // "suserHost"
QT_MOC_LITERAL(49, 550, 12), // "setEncrypted"
QT_MOC_LITERAL(50, 563, 14), // "updateHostmask"
QT_MOC_LITERAL(51, 578, 4), // "mask"
QT_MOC_LITERAL(52, 583, 12), // "setUserModes"
QT_MOC_LITERAL(53, 596, 11), // "joinChannel"
QT_MOC_LITERAL(54, 608, 11), // "IrcChannel*"
QT_MOC_LITERAL(55, 620, 17), // "skip_channel_join"
QT_MOC_LITERAL(56, 638, 11), // "channelname"
QT_MOC_LITERAL(57, 650, 11), // "partChannel"
QT_MOC_LITERAL(58, 662, 4), // "quit"
QT_MOC_LITERAL(59, 667, 12), // "addUserModes"
QT_MOC_LITERAL(60, 680, 15), // "removeUserModes"
QT_MOC_LITERAL(61, 696, 16), // "updateObjectName"
QT_MOC_LITERAL(62, 713, 16), // "channelDestroyed"
QT_MOC_LITERAL(63, 730, 8), // "channels"
QT_MOC_LITERAL(64, 739, 9) // "userModes"

    },
    "IrcUser\0nickSet\0\0newnick\0awaySet\0away\0"
    "encryptedSet\0encrypted\0userModesSet\0"
    "modes\0userModesAdded\0userModesRemoved\0"
    "channelParted\0channel\0quited\0"
    "lastChannelActivityUpdated\0BufferId\0"
    "id\0newTime\0lastSpokenToUpdated\0setUser\0"
    "user\0setHost\0host\0setNick\0nick\0"
    "setRealName\0realName\0setAccount\0account\0"
    "setAway\0setAwayMessage\0awayMessage\0"
    "setIdleTime\0idleTime\0setLoginTime\0"
    "loginTime\0setServer\0server\0setIrcOperator\0"
    "ircOperator\0setLastAwayMessage\0"
    "lastAwayMessage\0setLastAwayMessageTime\0"
    "lastAwayMessageTime\0setWhoisServiceReply\0"
    "whoisServiceReply\0setSuserHost\0suserHost\0"
    "setEncrypted\0updateHostmask\0mask\0"
    "setUserModes\0joinChannel\0IrcChannel*\0"
    "skip_channel_join\0channelname\0partChannel\0"
    "quit\0addUserModes\0removeUserModes\0"
    "updateObjectName\0channelDestroyed\0"
    "channels\0userModes"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_IrcUser[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      38,   14, // methods
      17,  316, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  204,    2, 0x06 /* Public */,
       4,    1,  207,    2, 0x06 /* Public */,
       6,    1,  210,    2, 0x06 /* Public */,
       8,    1,  213,    2, 0x06 /* Public */,
      10,    1,  216,    2, 0x06 /* Public */,
      11,    1,  219,    2, 0x06 /* Public */,
      12,    1,  222,    2, 0x06 /* Public */,
      14,    0,  225,    2, 0x06 /* Public */,
      15,    2,  226,    2, 0x06 /* Public */,
      19,    2,  231,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      20,    1,  236,    2, 0x0a /* Public */,
      22,    1,  239,    2, 0x0a /* Public */,
      24,    1,  242,    2, 0x0a /* Public */,
      26,    1,  245,    2, 0x0a /* Public */,
      28,    1,  248,    2, 0x0a /* Public */,
      30,    1,  251,    2, 0x0a /* Public */,
      31,    1,  254,    2, 0x0a /* Public */,
      33,    1,  257,    2, 0x0a /* Public */,
      35,    1,  260,    2, 0x0a /* Public */,
      37,    1,  263,    2, 0x0a /* Public */,
      39,    1,  266,    2, 0x0a /* Public */,
      41,    1,  269,    2, 0x0a /* Public */,
      43,    1,  272,    2, 0x0a /* Public */,
      45,    1,  275,    2, 0x0a /* Public */,
      47,    1,  278,    2, 0x0a /* Public */,
      49,    1,  281,    2, 0x0a /* Public */,
      50,    1,  284,    2, 0x0a /* Public */,
      52,    1,  287,    2, 0x0a /* Public */,
      53,    2,  290,    2, 0x0a /* Public */,
      53,    1,  295,    2, 0x2a /* Public | MethodCloned */,
      53,    1,  298,    2, 0x0a /* Public */,
      57,    1,  301,    2, 0x0a /* Public */,
      57,    1,  304,    2, 0x0a /* Public */,
      58,    0,  307,    2, 0x0a /* Public */,
      59,    1,  308,    2, 0x0a /* Public */,
      60,    1,  311,    2, 0x0a /* Public */,
      61,    0,  314,    2, 0x08 /* Private */,
      62,    0,  315,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 16, QMetaType::QDateTime,   17,   18,
    QMetaType::Void, 0x80000000 | 16, QMetaType::QDateTime,   17,   18,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,   21,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void, QMetaType::QString,   25,
    QMetaType::Void, QMetaType::QString,   27,
    QMetaType::Void, QMetaType::QString,   29,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::QString,   32,
    QMetaType::Void, QMetaType::QDateTime,   34,
    QMetaType::Void, QMetaType::QDateTime,   36,
    QMetaType::Void, QMetaType::QString,   38,
    QMetaType::Void, QMetaType::QString,   40,
    QMetaType::Void, QMetaType::Int,   42,
    QMetaType::Void, QMetaType::QDateTime,   44,
    QMetaType::Void, QMetaType::QString,   46,
    QMetaType::Void, QMetaType::QString,   48,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::QString,   51,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, 0x80000000 | 54, QMetaType::Bool,   13,   55,
    QMetaType::Void, 0x80000000 | 54,   13,
    QMetaType::Void, QMetaType::QString,   56,
    QMetaType::Void, 0x80000000 | 54,   13,
    QMetaType::Void, QMetaType::QString,   56,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      21, QMetaType::QString, 0x00095103,
      23, QMetaType::QString, 0x00095103,
      25, QMetaType::QString, 0x00095103,
      27, QMetaType::QString, 0x00095103,
      29, QMetaType::QString, 0x00095103,
       5, QMetaType::Bool, 0x00095103,
      32, QMetaType::QString, 0x00095103,
      34, QMetaType::QDateTime, 0x00095103,
      36, QMetaType::QDateTime, 0x00095103,
      38, QMetaType::QString, 0x00095103,
      40, QMetaType::QString, 0x00095103,
      44, QMetaType::QDateTime, 0x00095103,
      46, QMetaType::QString, 0x00095103,
      48, QMetaType::QString, 0x00095103,
       7, QMetaType::Bool, 0x00095103,
      63, QMetaType::QStringList, 0x00095001,
      64, QMetaType::QString, 0x00095103,

       0        // eod
};

void IrcUser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<IrcUser *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->nickSet((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 1: _t->awaySet((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->encryptedSet((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->userModesSet((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 4: _t->userModesAdded((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->userModesRemoved((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 6: _t->channelParted((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 7: _t->quited(); break;
        case 8: _t->lastChannelActivityUpdated((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const QDateTime(*)>(_a[2]))); break;
        case 9: _t->lastSpokenToUpdated((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< const QDateTime(*)>(_a[2]))); break;
        case 10: _t->setUser((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->setHost((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->setNick((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->setRealName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->setAccount((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: _t->setAway((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->setAwayMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: _t->setIdleTime((*reinterpret_cast< const QDateTime(*)>(_a[1]))); break;
        case 18: _t->setLoginTime((*reinterpret_cast< const QDateTime(*)>(_a[1]))); break;
        case 19: _t->setServer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->setIrcOperator((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->setLastAwayMessage((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->setLastAwayMessageTime((*reinterpret_cast< const QDateTime(*)>(_a[1]))); break;
        case 23: _t->setWhoisServiceReply((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 24: _t->setSuserHost((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 25: _t->setEncrypted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: _t->updateHostmask((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 27: _t->setUserModes((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 28: _t->joinChannel((*reinterpret_cast< IrcChannel*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 29: _t->joinChannel((*reinterpret_cast< IrcChannel*(*)>(_a[1]))); break;
        case 30: _t->joinChannel((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 31: _t->partChannel((*reinterpret_cast< IrcChannel*(*)>(_a[1]))); break;
        case 32: _t->partChannel((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 33: _t->quit(); break;
        case 34: _t->addUserModes((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 35: _t->removeUserModes((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 36: _t->updateObjectName(); break;
        case 37: _t->channelDestroyed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (IrcUser::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcUser::nickSet)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (IrcUser::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcUser::awaySet)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (IrcUser::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcUser::encryptedSet)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (IrcUser::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcUser::userModesSet)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (IrcUser::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcUser::userModesAdded)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (IrcUser::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcUser::userModesRemoved)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (IrcUser::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcUser::channelParted)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (IrcUser::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcUser::quited)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (IrcUser::*)(BufferId , const QDateTime & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcUser::lastChannelActivityUpdated)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (IrcUser::*)(BufferId , const QDateTime & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcUser::lastSpokenToUpdated)) {
                *result = 9;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<IrcUser *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->user(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->host(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->nick(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->realName(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->account(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->isAway(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->awayMessage(); break;
        case 7: *reinterpret_cast< QDateTime*>(_v) = _t->idleTime(); break;
        case 8: *reinterpret_cast< QDateTime*>(_v) = _t->loginTime(); break;
        case 9: *reinterpret_cast< QString*>(_v) = _t->server(); break;
        case 10: *reinterpret_cast< QString*>(_v) = _t->ircOperator(); break;
        case 11: *reinterpret_cast< QDateTime*>(_v) = _t->lastAwayMessageTime(); break;
        case 12: *reinterpret_cast< QString*>(_v) = _t->whoisServiceReply(); break;
        case 13: *reinterpret_cast< QString*>(_v) = _t->suserHost(); break;
        case 14: *reinterpret_cast< bool*>(_v) = _t->encrypted(); break;
        case 15: *reinterpret_cast< QStringList*>(_v) = _t->channels(); break;
        case 16: *reinterpret_cast< QString*>(_v) = _t->userModes(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<IrcUser *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUser(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setHost(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setNick(*reinterpret_cast< QString*>(_v)); break;
        case 3: _t->setRealName(*reinterpret_cast< QString*>(_v)); break;
        case 4: _t->setAccount(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setAway(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setAwayMessage(*reinterpret_cast< QString*>(_v)); break;
        case 7: _t->setIdleTime(*reinterpret_cast< QDateTime*>(_v)); break;
        case 8: _t->setLoginTime(*reinterpret_cast< QDateTime*>(_v)); break;
        case 9: _t->setServer(*reinterpret_cast< QString*>(_v)); break;
        case 10: _t->setIrcOperator(*reinterpret_cast< QString*>(_v)); break;
        case 11: _t->setLastAwayMessageTime(*reinterpret_cast< QDateTime*>(_v)); break;
        case 12: _t->setWhoisServiceReply(*reinterpret_cast< QString*>(_v)); break;
        case 13: _t->setSuserHost(*reinterpret_cast< QString*>(_v)); break;
        case 14: _t->setEncrypted(*reinterpret_cast< bool*>(_v)); break;
        case 16: _t->setUserModes(*reinterpret_cast< QString*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject IrcUser::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_IrcUser.data,
    qt_meta_data_IrcUser,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *IrcUser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IrcUser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_IrcUser.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int IrcUser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 17;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 17;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void IrcUser::nickSet(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void IrcUser::awaySet(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void IrcUser::encryptedSet(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void IrcUser::userModesSet(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void IrcUser::userModesAdded(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void IrcUser::userModesRemoved(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void IrcUser::channelParted(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void IrcUser::quited()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void IrcUser::lastChannelActivityUpdated(BufferId _t1, const QDateTime & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void IrcUser::lastSpokenToUpdated(BufferId _t1, const QDateTime & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
