/********************************************************************************
** Form generated from reading UI file 'debuglogdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEBUGLOGDLG_H
#define UI_DEBUGLOGDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DebugLogDlg
{
public:
    QVBoxLayout *verticalLayout;
    QTextEdit *textEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *DebugLogDlg)
    {
        if (DebugLogDlg->objectName().isEmpty())
            DebugLogDlg->setObjectName(QString::fromUtf8("DebugLogDlg"));
        DebugLogDlg->resize(400, 300);
        verticalLayout = new QVBoxLayout(DebugLogDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        textEdit = new QTextEdit(DebugLogDlg);
        textEdit->setObjectName(QString::fromUtf8("textEdit"));

        verticalLayout->addWidget(textEdit);

        buttonBox = new QDialogButtonBox(DebugLogDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(DebugLogDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), DebugLogDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), DebugLogDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(DebugLogDlg);
    } // setupUi

    void retranslateUi(QDialog *DebugLogDlg)
    {
        DebugLogDlg->setWindowTitle(QCoreApplication::translate("DebugLogDlg", "Debug Log", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DebugLogDlg: public Ui_DebugLogDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DEBUGLOGDLG_H
