/****************************************************************************
** Meta object code from reading C++ file 'identity.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/identity.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'identity.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Identity_t {
    QByteArrayData data[50];
    char stringdata0[642];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Identity_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Identity_t qt_meta_stringdata_Identity = {
    {
QT_MOC_LITERAL(0, 0, 8), // "Identity"
QT_MOC_LITERAL(1, 9, 5), // "idSet"
QT_MOC_LITERAL(2, 15, 0), // ""
QT_MOC_LITERAL(3, 16, 10), // "IdentityId"
QT_MOC_LITERAL(4, 27, 2), // "id"
QT_MOC_LITERAL(5, 30, 8), // "nicksSet"
QT_MOC_LITERAL(6, 39, 5), // "nicks"
QT_MOC_LITERAL(7, 45, 5), // "setId"
QT_MOC_LITERAL(8, 51, 15), // "setIdentityName"
QT_MOC_LITERAL(9, 67, 4), // "name"
QT_MOC_LITERAL(10, 72, 11), // "setRealName"
QT_MOC_LITERAL(11, 84, 8), // "realName"
QT_MOC_LITERAL(12, 93, 8), // "setNicks"
QT_MOC_LITERAL(13, 102, 11), // "setAwayNick"
QT_MOC_LITERAL(14, 114, 8), // "awayNick"
QT_MOC_LITERAL(15, 123, 18), // "setAwayNickEnabled"
QT_MOC_LITERAL(16, 142, 7), // "enabled"
QT_MOC_LITERAL(17, 150, 13), // "setAwayReason"
QT_MOC_LITERAL(18, 164, 10), // "awayReason"
QT_MOC_LITERAL(19, 175, 20), // "setAwayReasonEnabled"
QT_MOC_LITERAL(20, 196, 18), // "setAutoAwayEnabled"
QT_MOC_LITERAL(21, 215, 15), // "setAutoAwayTime"
QT_MOC_LITERAL(22, 231, 4), // "time"
QT_MOC_LITERAL(23, 236, 17), // "setAutoAwayReason"
QT_MOC_LITERAL(24, 254, 6), // "reason"
QT_MOC_LITERAL(25, 261, 24), // "setAutoAwayReasonEnabled"
QT_MOC_LITERAL(26, 286, 20), // "setDetachAwayEnabled"
QT_MOC_LITERAL(27, 307, 19), // "setDetachAwayReason"
QT_MOC_LITERAL(28, 327, 26), // "setDetachAwayReasonEnabled"
QT_MOC_LITERAL(29, 354, 8), // "setIdent"
QT_MOC_LITERAL(30, 363, 5), // "ident"
QT_MOC_LITERAL(31, 369, 13), // "setKickReason"
QT_MOC_LITERAL(32, 383, 13), // "setPartReason"
QT_MOC_LITERAL(33, 397, 13), // "setQuitReason"
QT_MOC_LITERAL(34, 411, 8), // "copyFrom"
QT_MOC_LITERAL(35, 420, 5), // "other"
QT_MOC_LITERAL(36, 426, 10), // "identityId"
QT_MOC_LITERAL(37, 437, 12), // "identityName"
QT_MOC_LITERAL(38, 450, 15), // "awayNickEnabled"
QT_MOC_LITERAL(39, 466, 17), // "awayReasonEnabled"
QT_MOC_LITERAL(40, 484, 15), // "autoAwayEnabled"
QT_MOC_LITERAL(41, 500, 12), // "autoAwayTime"
QT_MOC_LITERAL(42, 513, 14), // "autoAwayReason"
QT_MOC_LITERAL(43, 528, 21), // "autoAwayReasonEnabled"
QT_MOC_LITERAL(44, 550, 17), // "detachAwayEnabled"
QT_MOC_LITERAL(45, 568, 16), // "detachAwayReason"
QT_MOC_LITERAL(46, 585, 23), // "detachAwayReasonEnabled"
QT_MOC_LITERAL(47, 609, 10), // "kickReason"
QT_MOC_LITERAL(48, 620, 10), // "partReason"
QT_MOC_LITERAL(49, 631, 10) // "quitReason"

    },
    "Identity\0idSet\0\0IdentityId\0id\0nicksSet\0"
    "nicks\0setId\0setIdentityName\0name\0"
    "setRealName\0realName\0setNicks\0setAwayNick\0"
    "awayNick\0setAwayNickEnabled\0enabled\0"
    "setAwayReason\0awayReason\0setAwayReasonEnabled\0"
    "setAutoAwayEnabled\0setAutoAwayTime\0"
    "time\0setAutoAwayReason\0reason\0"
    "setAutoAwayReasonEnabled\0setDetachAwayEnabled\0"
    "setDetachAwayReason\0setDetachAwayReasonEnabled\0"
    "setIdent\0ident\0setKickReason\0setPartReason\0"
    "setQuitReason\0copyFrom\0other\0identityId\0"
    "identityName\0awayNickEnabled\0"
    "awayReasonEnabled\0autoAwayEnabled\0"
    "autoAwayTime\0autoAwayReason\0"
    "autoAwayReasonEnabled\0detachAwayEnabled\0"
    "detachAwayReason\0detachAwayReasonEnabled\0"
    "kickReason\0partReason\0quitReason"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Identity[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      22,   14, // methods
      19,  190, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  124,    2, 0x06 /* Public */,
       5,    1,  127,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,  130,    2, 0x0a /* Public */,
       8,    1,  133,    2, 0x0a /* Public */,
      10,    1,  136,    2, 0x0a /* Public */,
      12,    1,  139,    2, 0x0a /* Public */,
      13,    1,  142,    2, 0x0a /* Public */,
      15,    1,  145,    2, 0x0a /* Public */,
      17,    1,  148,    2, 0x0a /* Public */,
      19,    1,  151,    2, 0x0a /* Public */,
      20,    1,  154,    2, 0x0a /* Public */,
      21,    1,  157,    2, 0x0a /* Public */,
      23,    1,  160,    2, 0x0a /* Public */,
      25,    1,  163,    2, 0x0a /* Public */,
      26,    1,  166,    2, 0x0a /* Public */,
      27,    1,  169,    2, 0x0a /* Public */,
      28,    1,  172,    2, 0x0a /* Public */,
      29,    1,  175,    2, 0x0a /* Public */,
      31,    1,  178,    2, 0x0a /* Public */,
      32,    1,  181,    2, 0x0a /* Public */,
      33,    1,  184,    2, 0x0a /* Public */,
      34,    1,  187,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::QStringList,    6,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::QStringList,    6,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::QString,   18,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void, QMetaType::QString,   24,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::QString,   24,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::QString,   30,
    QMetaType::Void, QMetaType::QString,   24,
    QMetaType::Void, QMetaType::QString,   24,
    QMetaType::Void, QMetaType::QString,   24,
    QMetaType::Void, 0x80000000 | 0,   35,

 // properties: name, type, flags
      36, 0x80000000 | 3, 0x0009500b,
      37, QMetaType::QString, 0x00095103,
      11, QMetaType::QString, 0x00095103,
       6, QMetaType::QStringList, 0x00095103,
      14, QMetaType::QString, 0x00095103,
      38, QMetaType::Bool, 0x00095103,
      18, QMetaType::QString, 0x00095103,
      39, QMetaType::Bool, 0x00095103,
      40, QMetaType::Bool, 0x00095103,
      41, QMetaType::Int, 0x00095103,
      42, QMetaType::QString, 0x00095103,
      43, QMetaType::Bool, 0x00095103,
      44, QMetaType::Bool, 0x00095103,
      45, QMetaType::QString, 0x00095103,
      46, QMetaType::Bool, 0x00095103,
      30, QMetaType::QString, 0x00095103,
      47, QMetaType::QString, 0x00095103,
      48, QMetaType::QString, 0x00095103,
      49, QMetaType::QString, 0x00095103,

       0        // eod
};

void Identity::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Identity *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->idSet((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 1: _t->nicksSet((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 2: _t->setId((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 3: _t->setIdentityName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->setRealName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->setNicks((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 6: _t->setAwayNick((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->setAwayNickEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->setAwayReason((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->setAwayReasonEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->setAutoAwayEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->setAutoAwayTime((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->setAutoAwayReason((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 13: _t->setAutoAwayReasonEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->setDetachAwayEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->setDetachAwayReason((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 16: _t->setDetachAwayReasonEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->setIdent((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->setKickReason((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->setPartReason((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->setQuitReason((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->copyFrom((*reinterpret_cast< const Identity(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Identity >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Identity::*)(IdentityId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Identity::idSet)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Identity::*)(const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Identity::nicksSet)) {
                *result = 1;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Identity *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< IdentityId*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->identityName(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->realName(); break;
        case 3: *reinterpret_cast< QStringList*>(_v) = _t->nicks(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->awayNick(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->awayNickEnabled(); break;
        case 6: *reinterpret_cast< QString*>(_v) = _t->awayReason(); break;
        case 7: *reinterpret_cast< bool*>(_v) = _t->awayReasonEnabled(); break;
        case 8: *reinterpret_cast< bool*>(_v) = _t->autoAwayEnabled(); break;
        case 9: *reinterpret_cast< int*>(_v) = _t->autoAwayTime(); break;
        case 10: *reinterpret_cast< QString*>(_v) = _t->autoAwayReason(); break;
        case 11: *reinterpret_cast< bool*>(_v) = _t->autoAwayReasonEnabled(); break;
        case 12: *reinterpret_cast< bool*>(_v) = _t->detachAwayEnabled(); break;
        case 13: *reinterpret_cast< QString*>(_v) = _t->detachAwayReason(); break;
        case 14: *reinterpret_cast< bool*>(_v) = _t->detachAwayReasonEnabled(); break;
        case 15: *reinterpret_cast< QString*>(_v) = _t->ident(); break;
        case 16: *reinterpret_cast< QString*>(_v) = _t->kickReason(); break;
        case 17: *reinterpret_cast< QString*>(_v) = _t->partReason(); break;
        case 18: *reinterpret_cast< QString*>(_v) = _t->quitReason(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<Identity *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setId(*reinterpret_cast< IdentityId*>(_v)); break;
        case 1: _t->setIdentityName(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setRealName(*reinterpret_cast< QString*>(_v)); break;
        case 3: _t->setNicks(*reinterpret_cast< QStringList*>(_v)); break;
        case 4: _t->setAwayNick(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setAwayNickEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setAwayReason(*reinterpret_cast< QString*>(_v)); break;
        case 7: _t->setAwayReasonEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 8: _t->setAutoAwayEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 9: _t->setAutoAwayTime(*reinterpret_cast< int*>(_v)); break;
        case 10: _t->setAutoAwayReason(*reinterpret_cast< QString*>(_v)); break;
        case 11: _t->setAutoAwayReasonEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 12: _t->setDetachAwayEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 13: _t->setDetachAwayReason(*reinterpret_cast< QString*>(_v)); break;
        case 14: _t->setDetachAwayReasonEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 15: _t->setIdent(*reinterpret_cast< QString*>(_v)); break;
        case 16: _t->setKickReason(*reinterpret_cast< QString*>(_v)); break;
        case 17: _t->setPartReason(*reinterpret_cast< QString*>(_v)); break;
        case 18: _t->setQuitReason(*reinterpret_cast< QString*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Identity::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_Identity.data,
    qt_meta_data_Identity,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Identity::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Identity::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Identity.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int Identity::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 19;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 19;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Identity::idSet(IdentityId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Identity::nicksSet(const QStringList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_CertManager_t {
    QByteArrayData data[7];
    char stringdata0[57];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CertManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CertManager_t qt_meta_stringdata_CertManager = {
    {
QT_MOC_LITERAL(0, 0, 11), // "CertManager"
QT_MOC_LITERAL(1, 12, 9), // "setSslKey"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 7), // "encoded"
QT_MOC_LITERAL(4, 31, 10), // "setSslCert"
QT_MOC_LITERAL(5, 42, 6), // "sslKey"
QT_MOC_LITERAL(6, 49, 7) // "sslCert"

    },
    "CertManager\0setSslKey\0\0encoded\0"
    "setSslCert\0sslKey\0sslCert"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CertManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       2,   30, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x0a /* Public */,
       4,    1,   27,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QByteArray,    3,
    QMetaType::Void, QMetaType::QByteArray,    3,

 // properties: name, type, flags
       5, QMetaType::QByteArray, 0x00095103,
       6, QMetaType::QByteArray, 0x00095103,

       0        // eod
};

void CertManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CertManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setSslKey((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 1: _t->setSslCert((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<CertManager *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QByteArray*>(_v) = _t->sslKeyPem(); break;
        case 1: *reinterpret_cast< QByteArray*>(_v) = _t->sslCertPem(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<CertManager *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSslKey(*reinterpret_cast< QByteArray*>(_v)); break;
        case 1: _t->setSslCert(*reinterpret_cast< QByteArray*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject CertManager::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_CertManager.data,
    qt_meta_data_CertManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CertManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CertManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CertManager.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int CertManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
