/****************************************************************************
** Meta object code from reading C++ file 'settingsdlg.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/settingsdlg.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settingsdlg.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SettingsDlg_t {
    QByteArrayData data[16];
    char stringdata0[203];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SettingsDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SettingsDlg_t qt_meta_stringdata_SettingsDlg = {
    {
QT_MOC_LITERAL(0, 0, 11), // "SettingsDlg"
QT_MOC_LITERAL(1, 12, 10), // "selectPage"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 13), // "SettingsPage*"
QT_MOC_LITERAL(4, 38, 2), // "sp"
QT_MOC_LITERAL(5, 41, 26), // "coreConnectionStateChanged"
QT_MOC_LITERAL(6, 68, 12), // "itemSelected"
QT_MOC_LITERAL(7, 81, 13), // "buttonClicked"
QT_MOC_LITERAL(8, 95, 16), // "QAbstractButton*"
QT_MOC_LITERAL(9, 112, 12), // "applyChanges"
QT_MOC_LITERAL(10, 125, 11), // "undoChanges"
QT_MOC_LITERAL(11, 137, 6), // "reload"
QT_MOC_LITERAL(12, 144, 12), // "loadDefaults"
QT_MOC_LITERAL(13, 157, 15), // "setButtonStates"
QT_MOC_LITERAL(14, 173, 12), // "setItemState"
QT_MOC_LITERAL(15, 186, 16) // "QTreeWidgetItem*"

    },
    "SettingsDlg\0selectPage\0\0SettingsPage*\0"
    "sp\0coreConnectionStateChanged\0"
    "itemSelected\0buttonClicked\0QAbstractButton*\0"
    "applyChanges\0undoChanges\0reload\0"
    "loadDefaults\0setButtonStates\0setItemState\0"
    "QTreeWidgetItem*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SettingsDlg[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x0a /* Public */,
       5,    0,   67,    2, 0x08 /* Private */,
       6,    0,   68,    2, 0x08 /* Private */,
       7,    1,   69,    2, 0x08 /* Private */,
       9,    0,   72,    2, 0x08 /* Private */,
      10,    0,   73,    2, 0x08 /* Private */,
      11,    0,   74,    2, 0x08 /* Private */,
      12,    0,   75,    2, 0x08 /* Private */,
      13,    0,   76,    2, 0x08 /* Private */,
      14,    1,   77,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,    2,

       0        // eod
};

void SettingsDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SettingsDlg *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->selectPage((*reinterpret_cast< SettingsPage*(*)>(_a[1]))); break;
        case 1: _t->coreConnectionStateChanged(); break;
        case 2: _t->itemSelected(); break;
        case 3: _t->buttonClicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 4: { bool _r = _t->applyChanges();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->undoChanges(); break;
        case 6: _t->reload(); break;
        case 7: _t->loadDefaults(); break;
        case 8: _t->setButtonStates(); break;
        case 9: _t->setItemState((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SettingsPage* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject SettingsDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_SettingsDlg.data,
    qt_meta_data_SettingsDlg,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SettingsDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SettingsDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SettingsDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int SettingsDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
