/****************************************************************************
** Meta object code from reading C++ file 'inputwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/inputwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inputwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_InputWidget_t {
    QByteArrayData data[61];
    char stringdata0[919];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_InputWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_InputWidget_t qt_meta_stringdata_InputWidget = {
    {
QT_MOC_LITERAL(0, 0, 11), // "InputWidget"
QT_MOC_LITERAL(1, 12, 22), // "applyFormatActiveColor"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 26), // "applyFormatActiveColorFill"
QT_MOC_LITERAL(4, 63, 16), // "toggleFormatBold"
QT_MOC_LITERAL(5, 80, 18), // "toggleFormatItalic"
QT_MOC_LITERAL(6, 99, 21), // "toggleFormatUnderline"
QT_MOC_LITERAL(7, 121, 25), // "toggleFormatStrikethrough"
QT_MOC_LITERAL(8, 147, 11), // "clearFormat"
QT_MOC_LITERAL(9, 159, 14), // "currentChanged"
QT_MOC_LITERAL(10, 174, 11), // "QModelIndex"
QT_MOC_LITERAL(11, 186, 7), // "current"
QT_MOC_LITERAL(12, 194, 8), // "previous"
QT_MOC_LITERAL(13, 203, 20), // "rowsAboutToBeRemoved"
QT_MOC_LITERAL(14, 224, 6), // "parent"
QT_MOC_LITERAL(15, 231, 5), // "start"
QT_MOC_LITERAL(16, 237, 3), // "end"
QT_MOC_LITERAL(17, 241, 11), // "dataChanged"
QT_MOC_LITERAL(18, 253, 7), // "topLeft"
QT_MOC_LITERAL(19, 261, 11), // "bottomRight"
QT_MOC_LITERAL(20, 273, 13), // "setCustomFont"
QT_MOC_LITERAL(21, 287, 4), // "font"
QT_MOC_LITERAL(22, 292, 16), // "setUseCustomFont"
QT_MOC_LITERAL(23, 309, 18), // "setEnableEmacsMode"
QT_MOC_LITERAL(24, 328, 19), // "setShowNickSelector"
QT_MOC_LITERAL(25, 348, 19), // "setShowStyleButtons"
QT_MOC_LITERAL(26, 368, 23), // "setEnablePerChatHistory"
QT_MOC_LITERAL(27, 392, 11), // "setMaxLines"
QT_MOC_LITERAL(28, 404, 18), // "setLineWrapEnabled"
QT_MOC_LITERAL(29, 423, 19), // "setMultiLineEnabled"
QT_MOC_LITERAL(30, 443, 20), // "setScrollBarsEnabled"
QT_MOC_LITERAL(31, 464, 13), // "onTextEntered"
QT_MOC_LITERAL(32, 478, 4), // "text"
QT_MOC_LITERAL(33, 483, 10), // "changeNick"
QT_MOC_LITERAL(34, 494, 7), // "newNick"
QT_MOC_LITERAL(35, 502, 10), // "setNetwork"
QT_MOC_LITERAL(36, 513, 9), // "NetworkId"
QT_MOC_LITERAL(37, 523, 9), // "networkId"
QT_MOC_LITERAL(38, 533, 11), // "setIdentity"
QT_MOC_LITERAL(39, 545, 10), // "IdentityId"
QT_MOC_LITERAL(40, 556, 10), // "identityId"
QT_MOC_LITERAL(41, 567, 16), // "connectMyIrcUser"
QT_MOC_LITERAL(42, 584, 18), // "updateNickSelector"
QT_MOC_LITERAL(43, 603, 18), // "updateEnabledState"
QT_MOC_LITERAL(44, 622, 17), // "currentBufferInfo"
QT_MOC_LITERAL(45, 640, 10), // "BufferInfo"
QT_MOC_LITERAL(46, 651, 23), // "setStyleOptionsExpanded"
QT_MOC_LITERAL(47, 675, 7), // "visible"
QT_MOC_LITERAL(48, 683, 24), // "currentCharFormatChanged"
QT_MOC_LITERAL(49, 708, 15), // "QTextCharFormat"
QT_MOC_LITERAL(50, 724, 6), // "format"
QT_MOC_LITERAL(51, 731, 26), // "on_showStyleButton_toggled"
QT_MOC_LITERAL(52, 758, 7), // "checked"
QT_MOC_LITERAL(53, 766, 21), // "on_boldButton_clicked"
QT_MOC_LITERAL(54, 788, 23), // "on_italicButton_clicked"
QT_MOC_LITERAL(55, 812, 26), // "on_underlineButton_clicked"
QT_MOC_LITERAL(56, 839, 30), // "on_strikethroughButton_clicked"
QT_MOC_LITERAL(57, 870, 11), // "colorChosen"
QT_MOC_LITERAL(58, 882, 8), // "QAction*"
QT_MOC_LITERAL(59, 891, 6), // "action"
QT_MOC_LITERAL(60, 898, 20) // "colorHighlightChosen"

    },
    "InputWidget\0applyFormatActiveColor\0\0"
    "applyFormatActiveColorFill\0toggleFormatBold\0"
    "toggleFormatItalic\0toggleFormatUnderline\0"
    "toggleFormatStrikethrough\0clearFormat\0"
    "currentChanged\0QModelIndex\0current\0"
    "previous\0rowsAboutToBeRemoved\0parent\0"
    "start\0end\0dataChanged\0topLeft\0bottomRight\0"
    "setCustomFont\0font\0setUseCustomFont\0"
    "setEnableEmacsMode\0setShowNickSelector\0"
    "setShowStyleButtons\0setEnablePerChatHistory\0"
    "setMaxLines\0setLineWrapEnabled\0"
    "setMultiLineEnabled\0setScrollBarsEnabled\0"
    "onTextEntered\0text\0changeNick\0newNick\0"
    "setNetwork\0NetworkId\0networkId\0"
    "setIdentity\0IdentityId\0identityId\0"
    "connectMyIrcUser\0updateNickSelector\0"
    "updateEnabledState\0currentBufferInfo\0"
    "BufferInfo\0setStyleOptionsExpanded\0"
    "visible\0currentCharFormatChanged\0"
    "QTextCharFormat\0format\0"
    "on_showStyleButton_toggled\0checked\0"
    "on_boldButton_clicked\0on_italicButton_clicked\0"
    "on_underlineButton_clicked\0"
    "on_strikethroughButton_clicked\0"
    "colorChosen\0QAction*\0action\0"
    "colorHighlightChosen"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_InputWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      37,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  199,    2, 0x0a /* Public */,
       3,    0,  200,    2, 0x0a /* Public */,
       4,    0,  201,    2, 0x0a /* Public */,
       5,    0,  202,    2, 0x0a /* Public */,
       6,    0,  203,    2, 0x0a /* Public */,
       7,    0,  204,    2, 0x0a /* Public */,
       8,    0,  205,    2, 0x0a /* Public */,
       9,    2,  206,    2, 0x09 /* Protected */,
      13,    3,  211,    2, 0x09 /* Protected */,
      17,    2,  218,    2, 0x09 /* Protected */,
      20,    1,  223,    2, 0x08 /* Private */,
      22,    1,  226,    2, 0x08 /* Private */,
      23,    1,  229,    2, 0x08 /* Private */,
      24,    1,  232,    2, 0x08 /* Private */,
      25,    1,  235,    2, 0x08 /* Private */,
      26,    1,  238,    2, 0x08 /* Private */,
      27,    1,  241,    2, 0x08 /* Private */,
      28,    1,  244,    2, 0x08 /* Private */,
      29,    1,  247,    2, 0x08 /* Private */,
      30,    1,  250,    2, 0x08 /* Private */,
      31,    1,  253,    2, 0x08 /* Private */,
      33,    1,  256,    2, 0x08 /* Private */,
      35,    1,  259,    2, 0x08 /* Private */,
      38,    1,  262,    2, 0x08 /* Private */,
      41,    0,  265,    2, 0x08 /* Private */,
      42,    0,  266,    2, 0x08 /* Private */,
      43,    0,  267,    2, 0x08 /* Private */,
      44,    0,  268,    2, 0x08 /* Private */,
      46,    1,  269,    2, 0x08 /* Private */,
      48,    1,  272,    2, 0x08 /* Private */,
      51,    1,  275,    2, 0x08 /* Private */,
      53,    1,  278,    2, 0x08 /* Private */,
      54,    1,  281,    2, 0x08 /* Private */,
      55,    1,  284,    2, 0x08 /* Private */,
      56,    1,  287,    2, 0x08 /* Private */,
      57,    1,  290,    2, 0x08 /* Private */,
      60,    1,  293,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 10,   11,   12,
    QMetaType::Void, 0x80000000 | 10, QMetaType::Int, QMetaType::Int,   14,   15,   16,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 10,   18,   19,
    QMetaType::Void, QMetaType::QVariant,   21,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QString,   32,
    QMetaType::Void, QMetaType::QString,   34,
    QMetaType::Void, 0x80000000 | 36,   37,
    QMetaType::Void, 0x80000000 | 39,   40,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 45,
    QMetaType::Void, QMetaType::Bool,   47,
    QMetaType::Void, 0x80000000 | 49,   50,
    QMetaType::Void, QMetaType::Bool,   52,
    QMetaType::Void, QMetaType::Bool,   52,
    QMetaType::Void, QMetaType::Bool,   52,
    QMetaType::Void, QMetaType::Bool,   52,
    QMetaType::Void, QMetaType::Bool,   52,
    QMetaType::Void, 0x80000000 | 58,   59,
    QMetaType::Void, 0x80000000 | 58,   59,

       0        // eod
};

void InputWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<InputWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->applyFormatActiveColor(); break;
        case 1: _t->applyFormatActiveColorFill(); break;
        case 2: _t->toggleFormatBold(); break;
        case 3: _t->toggleFormatItalic(); break;
        case 4: _t->toggleFormatUnderline(); break;
        case 5: _t->toggleFormatStrikethrough(); break;
        case 6: _t->clearFormat(); break;
        case 7: _t->currentChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 8: _t->rowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 9: _t->dataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 10: _t->setCustomFont((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 11: _t->setUseCustomFont((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 12: _t->setEnableEmacsMode((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 13: _t->setShowNickSelector((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 14: _t->setShowStyleButtons((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 15: _t->setEnablePerChatHistory((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 16: _t->setMaxLines((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 17: _t->setLineWrapEnabled((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 18: _t->setMultiLineEnabled((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 19: _t->setScrollBarsEnabled((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 20: _t->onTextEntered((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->changeNick((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 22: _t->setNetwork((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 23: _t->setIdentity((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 24: _t->connectMyIrcUser(); break;
        case 25: _t->updateNickSelector(); break;
        case 26: _t->updateEnabledState(); break;
        case 27: { BufferInfo _r = _t->currentBufferInfo();
            if (_a[0]) *reinterpret_cast< BufferInfo*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->setStyleOptionsExpanded((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 29: _t->currentCharFormatChanged((*reinterpret_cast< const QTextCharFormat(*)>(_a[1]))); break;
        case 30: _t->on_showStyleButton_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 31: _t->on_boldButton_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 32: _t->on_italicButton_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 33: _t->on_underlineButton_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 34: _t->on_strikethroughButton_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 35: _t->colorChosen((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 36: _t->colorHighlightChosen((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject InputWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractItemView::staticMetaObject>(),
    qt_meta_stringdata_InputWidget.data,
    qt_meta_data_InputWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *InputWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InputWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_InputWidget.stringdata0))
        return static_cast<void*>(this);
    return AbstractItemView::qt_metacast(_clname);
}

int InputWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractItemView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    }
    return _id;
}
struct qt_meta_stringdata_MouseWheelFilter_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MouseWheelFilter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MouseWheelFilter_t qt_meta_stringdata_MouseWheelFilter = {
    {
QT_MOC_LITERAL(0, 0, 16) // "MouseWheelFilter"

    },
    "MouseWheelFilter"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MouseWheelFilter[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void MouseWheelFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject MouseWheelFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_MouseWheelFilter.data,
    qt_meta_data_MouseWheelFilter,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MouseWheelFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MouseWheelFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MouseWheelFilter.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MouseWheelFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
