/****************************************************************************
** Meta object code from reading C++ file 'transfer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/transfer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transfer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Transfer_t {
    QByteArrayData data[42];
    char stringdata0[429];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Transfer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Transfer_t qt_meta_stringdata_Transfer = {
    {
QT_MOC_LITERAL(0, 0, 8), // "Transfer"
QT_MOC_LITERAL(1, 9, 13), // "statusChanged"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 16), // "Transfer::Status"
QT_MOC_LITERAL(4, 41, 5), // "state"
QT_MOC_LITERAL(5, 47, 16), // "directionChanged"
QT_MOC_LITERAL(6, 64, 19), // "Transfer::Direction"
QT_MOC_LITERAL(7, 84, 9), // "direction"
QT_MOC_LITERAL(8, 94, 14), // "addressChanged"
QT_MOC_LITERAL(9, 109, 12), // "QHostAddress"
QT_MOC_LITERAL(10, 122, 7), // "address"
QT_MOC_LITERAL(11, 130, 11), // "portChanged"
QT_MOC_LITERAL(12, 142, 4), // "port"
QT_MOC_LITERAL(13, 147, 15), // "fileNameChanged"
QT_MOC_LITERAL(14, 163, 8), // "fileName"
QT_MOC_LITERAL(15, 172, 15), // "fileSizeChanged"
QT_MOC_LITERAL(16, 188, 8), // "fileSize"
QT_MOC_LITERAL(17, 197, 18), // "transferredChanged"
QT_MOC_LITERAL(18, 216, 11), // "transferred"
QT_MOC_LITERAL(19, 228, 11), // "nickChanged"
QT_MOC_LITERAL(20, 240, 4), // "nick"
QT_MOC_LITERAL(21, 245, 5), // "error"
QT_MOC_LITERAL(22, 251, 11), // "errorString"
QT_MOC_LITERAL(23, 263, 8), // "accepted"
QT_MOC_LITERAL(24, 272, 7), // "PeerPtr"
QT_MOC_LITERAL(25, 280, 4), // "peer"
QT_MOC_LITERAL(26, 285, 8), // "rejected"
QT_MOC_LITERAL(27, 294, 6), // "accept"
QT_MOC_LITERAL(28, 301, 8), // "savePath"
QT_MOC_LITERAL(29, 310, 6), // "reject"
QT_MOC_LITERAL(30, 317, 15), // "requestAccepted"
QT_MOC_LITERAL(31, 333, 15), // "requestRejected"
QT_MOC_LITERAL(32, 349, 9), // "setStatus"
QT_MOC_LITERAL(33, 359, 6), // "status"
QT_MOC_LITERAL(34, 366, 8), // "setError"
QT_MOC_LITERAL(35, 375, 12), // "dataReceived"
QT_MOC_LITERAL(36, 388, 4), // "data"
QT_MOC_LITERAL(37, 393, 7), // "cleanUp"
QT_MOC_LITERAL(38, 401, 4), // "uuid"
QT_MOC_LITERAL(39, 406, 9), // "Direction"
QT_MOC_LITERAL(40, 416, 4), // "Send"
QT_MOC_LITERAL(41, 421, 7) // "Receive"

    },
    "Transfer\0statusChanged\0\0Transfer::Status\0"
    "state\0directionChanged\0Transfer::Direction\0"
    "direction\0addressChanged\0QHostAddress\0"
    "address\0portChanged\0port\0fileNameChanged\0"
    "fileName\0fileSizeChanged\0fileSize\0"
    "transferredChanged\0transferred\0"
    "nickChanged\0nick\0error\0errorString\0"
    "accepted\0PeerPtr\0peer\0rejected\0accept\0"
    "savePath\0reject\0requestAccepted\0"
    "requestRejected\0setStatus\0status\0"
    "setError\0dataReceived\0data\0cleanUp\0"
    "uuid\0Direction\0Send\0Receive"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Transfer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       8,  176, // properties
       1,  208, // enums/sets
       0,    0, // constructors
       0,       // flags
      13,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  119,    2, 0x06 /* Public */,
       5,    1,  122,    2, 0x06 /* Public */,
       8,    1,  125,    2, 0x06 /* Public */,
      11,    1,  128,    2, 0x06 /* Public */,
      13,    1,  131,    2, 0x06 /* Public */,
      15,    1,  134,    2, 0x06 /* Public */,
      17,    1,  137,    2, 0x06 /* Public */,
      19,    1,  140,    2, 0x06 /* Public */,
      21,    1,  143,    2, 0x06 /* Public */,
      23,    1,  146,    2, 0x06 /* Public */,
      23,    0,  149,    2, 0x26 /* Public | MethodCloned */,
      26,    1,  150,    2, 0x06 /* Public */,
      26,    0,  153,    2, 0x26 /* Public | MethodCloned */,

 // slots: name, argc, parameters, tag, flags
      27,    1,  154,    2, 0x0a /* Public */,
      29,    0,  157,    2, 0x0a /* Public */,
      30,    1,  158,    2, 0x0a /* Public */,
      31,    1,  161,    2, 0x0a /* Public */,
      32,    1,  164,    2, 0x09 /* Protected */,
      34,    1,  167,    2, 0x09 /* Protected */,
      35,    2,  170,    2, 0x09 /* Protected */,
      37,    0,  175,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::UShort,   12,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, QMetaType::ULongLong,   16,
    QMetaType::Void, QMetaType::ULongLong,   18,
    QMetaType::Void, QMetaType::QString,   20,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void, 0x80000000 | 24,   25,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 24,   25,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,   28,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 24,   25,
    QMetaType::Void, 0x80000000 | 24,   25,
    QMetaType::Void, 0x80000000 | 3,   33,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void, 0x80000000 | 24, QMetaType::QByteArray,    2,   36,
    QMetaType::Void,

 // properties: name, type, flags
      38, QMetaType::QUuid, 0x00095001,
      33, 0x80000000 | 3, 0x0049510b,
       7, 0x80000000 | 6, 0x0049510b,
      10, 0x80000000 | 9, 0x0049510b,
      12, QMetaType::UShort, 0x00495103,
      14, QMetaType::QString, 0x00495103,
      16, QMetaType::ULongLong, 0x00495103,
      20, QMetaType::QString, 0x00495103,

 // properties: notify_signal_id
       0,
       0,
       1,
       2,
       3,
       4,
       5,
       7,

 // enums: name, alias, flags, count, data
      39,   39, 0x2,    2,  213,

 // enum data: key, value
      40, uint(Transfer::Direction::Send),
      41, uint(Transfer::Direction::Receive),

       0        // eod
};

void Transfer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Transfer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->statusChanged((*reinterpret_cast< Transfer::Status(*)>(_a[1]))); break;
        case 1: _t->directionChanged((*reinterpret_cast< Transfer::Direction(*)>(_a[1]))); break;
        case 2: _t->addressChanged((*reinterpret_cast< const QHostAddress(*)>(_a[1]))); break;
        case 3: _t->portChanged((*reinterpret_cast< quint16(*)>(_a[1]))); break;
        case 4: _t->fileNameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->fileSizeChanged((*reinterpret_cast< quint64(*)>(_a[1]))); break;
        case 6: _t->transferredChanged((*reinterpret_cast< quint64(*)>(_a[1]))); break;
        case 7: _t->nickChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->error((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->accepted((*reinterpret_cast< PeerPtr(*)>(_a[1]))); break;
        case 10: _t->accepted(); break;
        case 11: _t->rejected((*reinterpret_cast< PeerPtr(*)>(_a[1]))); break;
        case 12: _t->rejected(); break;
        case 13: _t->accept((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->reject(); break;
        case 15: _t->requestAccepted((*reinterpret_cast< PeerPtr(*)>(_a[1]))); break;
        case 16: _t->requestRejected((*reinterpret_cast< PeerPtr(*)>(_a[1]))); break;
        case 17: _t->setStatus((*reinterpret_cast< Transfer::Status(*)>(_a[1]))); break;
        case 18: _t->setError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->dataReceived((*reinterpret_cast< PeerPtr(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 20: _t->cleanUp(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Transfer::Status >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Transfer::Direction >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QHostAddress >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PeerPtr >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PeerPtr >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PeerPtr >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PeerPtr >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Transfer::Status >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PeerPtr >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Transfer::*)(Transfer::Status );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::statusChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Transfer::*)(Transfer::Direction );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::directionChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Transfer::*)(const QHostAddress & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::addressChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Transfer::*)(quint16 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::portChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Transfer::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::fileNameChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Transfer::*)(quint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::fileSizeChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Transfer::*)(quint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::transferredChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Transfer::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::nickChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (Transfer::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::error)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (Transfer::*)(PeerPtr ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::accepted)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (Transfer::*)(PeerPtr ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Transfer::rejected)) {
                *result = 11;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QHostAddress >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Transfer::Direction >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Transfer::Status >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Transfer *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QUuid*>(_v) = _t->uuid(); break;
        case 1: *reinterpret_cast< Transfer::Status*>(_v) = _t->status(); break;
        case 2: *reinterpret_cast< Transfer::Direction*>(_v) = _t->direction(); break;
        case 3: *reinterpret_cast< QHostAddress*>(_v) = _t->address(); break;
        case 4: *reinterpret_cast< quint16*>(_v) = _t->port(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->fileName(); break;
        case 6: *reinterpret_cast< quint64*>(_v) = _t->fileSize(); break;
        case 7: *reinterpret_cast< QString*>(_v) = _t->nick(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<Transfer *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setStatus(*reinterpret_cast< Transfer::Status*>(_v)); break;
        case 2: _t->setDirection(*reinterpret_cast< Transfer::Direction*>(_v)); break;
        case 3: _t->setAddress(*reinterpret_cast< QHostAddress*>(_v)); break;
        case 4: _t->setPort(*reinterpret_cast< quint16*>(_v)); break;
        case 5: _t->setFileName(*reinterpret_cast< QString*>(_v)); break;
        case 6: _t->setFileSize(*reinterpret_cast< quint64*>(_v)); break;
        case 7: _t->setNick(*reinterpret_cast< QString*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Transfer::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_Transfer.data,
    qt_meta_data_Transfer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Transfer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Transfer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Transfer.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int Transfer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Transfer::statusChanged(Transfer::Status _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Transfer::directionChanged(Transfer::Direction _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Transfer::addressChanged(const QHostAddress & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Transfer::portChanged(quint16 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Transfer::fileNameChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Transfer::fileSizeChanged(quint64 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Transfer::transferredChanged(quint64 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Transfer::nickChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void Transfer::error(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void Transfer::accepted(PeerPtr _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(const_cast< Transfer *>(this), &staticMetaObject, 9, _a);
}

// SIGNAL 11
void Transfer::rejected(PeerPtr _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(const_cast< Transfer *>(this), &staticMetaObject, 11, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
