/****************************************************************************
** Meta object code from reading C++ file 'chatscene.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/chatscene.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'chatscene.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ChatScene_t {
    QByteArrayData data[50];
    char stringdata0[729];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChatScene_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChatScene_t qt_meta_stringdata_ChatScene = {
    {
QT_MOC_LITERAL(0, 0, 9), // "ChatScene"
QT_MOC_LITERAL(1, 10, 15), // "lastLineChanged"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 14), // "QGraphicsItem*"
QT_MOC_LITERAL(4, 42, 4), // "item"
QT_MOC_LITERAL(5, 47, 6), // "offset"
QT_MOC_LITERAL(6, 54, 13), // "layoutChanged"
QT_MOC_LITERAL(7, 68, 23), // "mouseMoveWhileSelecting"
QT_MOC_LITERAL(8, 92, 8), // "scenePos"
QT_MOC_LITERAL(9, 101, 17), // "updateForViewport"
QT_MOC_LITERAL(10, 119, 5), // "width"
QT_MOC_LITERAL(11, 125, 6), // "height"
QT_MOC_LITERAL(12, 132, 8), // "setWidth"
QT_MOC_LITERAL(13, 141, 6), // "layout"
QT_MOC_LITERAL(14, 148, 5), // "start"
QT_MOC_LITERAL(15, 154, 3), // "end"
QT_MOC_LITERAL(16, 158, 17), // "resetColumnWidths"
QT_MOC_LITERAL(17, 176, 20), // "setMarkerLineVisible"
QT_MOC_LITERAL(18, 197, 7), // "visible"
QT_MOC_LITERAL(19, 205, 13), // "setMarkerLine"
QT_MOC_LITERAL(20, 219, 5), // "MsgId"
QT_MOC_LITERAL(21, 225, 5), // "msgId"
QT_MOC_LITERAL(22, 231, 16), // "jumpToMarkerLine"
QT_MOC_LITERAL(23, 248, 14), // "requestBacklog"
QT_MOC_LITERAL(24, 263, 16), // "setSelectingItem"
QT_MOC_LITERAL(25, 280, 9), // "ChatItem*"
QT_MOC_LITERAL(26, 290, 13), // "selectingItem"
QT_MOC_LITERAL(27, 304, 20), // "startGlobalSelection"
QT_MOC_LITERAL(28, 325, 7), // "itemPos"
QT_MOC_LITERAL(29, 333, 20), // "clearGlobalSelection"
QT_MOC_LITERAL(30, 354, 14), // "clearSelection"
QT_MOC_LITERAL(31, 369, 20), // "selectionToClipboard"
QT_MOC_LITERAL(32, 390, 16), // "QClipboard::Mode"
QT_MOC_LITERAL(33, 407, 17), // "stringToClipboard"
QT_MOC_LITERAL(34, 425, 3), // "str"
QT_MOC_LITERAL(35, 429, 20), // "webSearchOnSelection"
QT_MOC_LITERAL(36, 450, 12), // "rowsInserted"
QT_MOC_LITERAL(37, 463, 11), // "QModelIndex"
QT_MOC_LITERAL(38, 475, 20), // "rowsAboutToBeRemoved"
QT_MOC_LITERAL(39, 496, 11), // "dataChanged"
QT_MOC_LITERAL(40, 508, 26), // "firstHandlePositionChanged"
QT_MOC_LITERAL(41, 535, 4), // "xpos"
QT_MOC_LITERAL(42, 540, 27), // "secondHandlePositionChanged"
QT_MOC_LITERAL(43, 568, 21), // "showWebPreviewChanged"
QT_MOC_LITERAL(44, 590, 25), // "showSenderBracketsChanged"
QT_MOC_LITERAL(45, 616, 31), // "useCustomTimestampFormatChanged"
QT_MOC_LITERAL(46, 648, 28), // "timestampFormatStringChanged"
QT_MOC_LITERAL(47, 677, 26), // "updateTimestampHasBrackets"
QT_MOC_LITERAL(48, 704, 11), // "rowsRemoved"
QT_MOC_LITERAL(49, 716, 12) // "clickTimeout"

    },
    "ChatScene\0lastLineChanged\0\0QGraphicsItem*\0"
    "item\0offset\0layoutChanged\0"
    "mouseMoveWhileSelecting\0scenePos\0"
    "updateForViewport\0width\0height\0setWidth\0"
    "layout\0start\0end\0resetColumnWidths\0"
    "setMarkerLineVisible\0visible\0setMarkerLine\0"
    "MsgId\0msgId\0jumpToMarkerLine\0"
    "requestBacklog\0setSelectingItem\0"
    "ChatItem*\0selectingItem\0startGlobalSelection\0"
    "itemPos\0clearGlobalSelection\0"
    "clearSelection\0selectionToClipboard\0"
    "QClipboard::Mode\0stringToClipboard\0"
    "str\0webSearchOnSelection\0rowsInserted\0"
    "QModelIndex\0rowsAboutToBeRemoved\0"
    "dataChanged\0firstHandlePositionChanged\0"
    "xpos\0secondHandlePositionChanged\0"
    "showWebPreviewChanged\0showSenderBracketsChanged\0"
    "useCustomTimestampFormatChanged\0"
    "timestampFormatStringChanged\0"
    "updateTimestampHasBrackets\0rowsRemoved\0"
    "clickTimeout"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChatScene[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      35,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  189,    2, 0x06 /* Public */,
       6,    0,  194,    2, 0x06 /* Public */,
       7,    1,  195,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    2,  198,    2, 0x0a /* Public */,
      12,    1,  203,    2, 0x0a /* Public */,
      13,    3,  206,    2, 0x0a /* Public */,
      16,    0,  213,    2, 0x0a /* Public */,
      17,    1,  214,    2, 0x0a /* Public */,
      17,    0,  217,    2, 0x2a /* Public | MethodCloned */,
      19,    1,  218,    2, 0x0a /* Public */,
      19,    0,  221,    2, 0x2a /* Public | MethodCloned */,
      22,    1,  222,    2, 0x0a /* Public */,
      24,    1,  225,    2, 0x0a /* Public */,
      26,    0,  228,    2, 0x0a /* Public */,
      27,    2,  229,    2, 0x0a /* Public */,
      29,    0,  234,    2, 0x0a /* Public */,
      30,    0,  235,    2, 0x0a /* Public */,
      31,    1,  236,    2, 0x0a /* Public */,
      31,    0,  239,    2, 0x2a /* Public | MethodCloned */,
      33,    2,  240,    2, 0x0a /* Public */,
      33,    1,  245,    2, 0x2a /* Public | MethodCloned */,
      35,    0,  248,    2, 0x0a /* Public */,
      23,    0,  249,    2, 0x0a /* Public */,
      36,    3,  250,    2, 0x09 /* Protected */,
      38,    3,  257,    2, 0x09 /* Protected */,
      39,    2,  264,    2, 0x09 /* Protected */,
      40,    1,  269,    2, 0x08 /* Private */,
      42,    1,  272,    2, 0x08 /* Private */,
      43,    0,  275,    2, 0x08 /* Private */,
      44,    0,  276,    2, 0x08 /* Private */,
      45,    0,  277,    2, 0x08 /* Private */,
      46,    0,  278,    2, 0x08 /* Private */,
      47,    0,  279,    2, 0x08 /* Private */,
      48,    0,  280,    2, 0x08 /* Private */,
      49,    0,  281,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QReal,    4,    5,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPointF,    8,

 // slots: parameters
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,   10,   11,
    QMetaType::Void, QMetaType::QReal,   10,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QReal,   14,   15,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   23,
    QMetaType::Void, 0x80000000 | 25,    4,
    0x80000000 | 25,
    QMetaType::Void, 0x80000000 | 25, QMetaType::QPointF,    4,   28,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 32,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 32,   34,    2,
    QMetaType::Void, QMetaType::QString,   34,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 37, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 37, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 37, 0x80000000 | 37,    2,    2,
    QMetaType::Void, QMetaType::QReal,   41,
    QMetaType::Void, QMetaType::QReal,   41,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ChatScene::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ChatScene *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->lastLineChanged((*reinterpret_cast< QGraphicsItem*(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 1: _t->layoutChanged(); break;
        case 2: _t->mouseMoveWhileSelecting((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 3: _t->updateForViewport((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 4: _t->setWidth((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 5: _t->layout((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3]))); break;
        case 6: _t->resetColumnWidths(); break;
        case 7: _t->setMarkerLineVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->setMarkerLineVisible(); break;
        case 9: _t->setMarkerLine((*reinterpret_cast< MsgId(*)>(_a[1]))); break;
        case 10: _t->setMarkerLine(); break;
        case 11: _t->jumpToMarkerLine((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->setSelectingItem((*reinterpret_cast< ChatItem*(*)>(_a[1]))); break;
        case 13: { ChatItem* _r = _t->selectingItem();
            if (_a[0]) *reinterpret_cast< ChatItem**>(_a[0]) = std::move(_r); }  break;
        case 14: _t->startGlobalSelection((*reinterpret_cast< ChatItem*(*)>(_a[1])),(*reinterpret_cast< const QPointF(*)>(_a[2]))); break;
        case 15: _t->clearGlobalSelection(); break;
        case 16: _t->clearSelection(); break;
        case 17: _t->selectionToClipboard((*reinterpret_cast< QClipboard::Mode(*)>(_a[1]))); break;
        case 18: _t->selectionToClipboard(); break;
        case 19: _t->stringToClipboard((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< QClipboard::Mode(*)>(_a[2]))); break;
        case 20: _t->stringToClipboard((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->webSearchOnSelection(); break;
        case 22: _t->requestBacklog(); break;
        case 23: _t->rowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 24: _t->rowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 25: _t->dataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 26: _t->firstHandlePositionChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 27: _t->secondHandlePositionChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 28: _t->showWebPreviewChanged(); break;
        case 29: _t->showSenderBracketsChanged(); break;
        case 30: _t->useCustomTimestampFormatChanged(); break;
        case 31: _t->timestampFormatStringChanged(); break;
        case 32: _t->updateTimestampHasBrackets(); break;
        case 33: _t->rowsRemoved(); break;
        case 34: _t->clickTimeout(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QGraphicsItem* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ChatScene::*)(QGraphicsItem * , qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChatScene::lastLineChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ChatScene::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChatScene::layoutChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ChatScene::*)(const QPointF & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChatScene::mouseMoveWhileSelecting)) {
                *result = 2;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ChatScene::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsScene::staticMetaObject>(),
    qt_meta_stringdata_ChatScene.data,
    qt_meta_data_ChatScene,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ChatScene::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChatScene::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ChatScene.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int ChatScene::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void ChatScene::lastLineChanged(QGraphicsItem * _t1, qreal _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ChatScene::layoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ChatScene::mouseMoveWhileSelecting(const QPointF & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
