/********************************************************************************
** Form generated from reading UI file 'ignorelistsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IGNORELISTSETTINGSPAGE_H
#define UI_IGNORELISTSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_IgnoreListSettingsPage
{
public:
    QVBoxLayout *verticalLayout;
    QTableView *ignoreListView;
    QHBoxLayout *horizontalLayout;
    QPushButton *newIgnoreRuleButton;
    QPushButton *deleteIgnoreRuleButton;
    QPushButton *editIgnoreRuleButton;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *IgnoreListSettingsPage)
    {
        if (IgnoreListSettingsPage->objectName().isEmpty())
            IgnoreListSettingsPage->setObjectName(QString::fromUtf8("IgnoreListSettingsPage"));
        IgnoreListSettingsPage->resize(291, 229);
        verticalLayout = new QVBoxLayout(IgnoreListSettingsPage);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        ignoreListView = new QTableView(IgnoreListSettingsPage);
        ignoreListView->setObjectName(QString::fromUtf8("ignoreListView"));

        verticalLayout->addWidget(ignoreListView);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        newIgnoreRuleButton = new QPushButton(IgnoreListSettingsPage);
        newIgnoreRuleButton->setObjectName(QString::fromUtf8("newIgnoreRuleButton"));
        newIgnoreRuleButton->setEnabled(false);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/list-add.png"), QSize(), QIcon::Normal, QIcon::Off);
        newIgnoreRuleButton->setIcon(icon);

        horizontalLayout->addWidget(newIgnoreRuleButton);

        deleteIgnoreRuleButton = new QPushButton(IgnoreListSettingsPage);
        deleteIgnoreRuleButton->setObjectName(QString::fromUtf8("deleteIgnoreRuleButton"));
        deleteIgnoreRuleButton->setEnabled(false);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/edit-delete.png"), QSize(), QIcon::Normal, QIcon::Off);
        deleteIgnoreRuleButton->setIcon(icon1);

        horizontalLayout->addWidget(deleteIgnoreRuleButton);

        editIgnoreRuleButton = new QPushButton(IgnoreListSettingsPage);
        editIgnoreRuleButton->setObjectName(QString::fromUtf8("editIgnoreRuleButton"));
        editIgnoreRuleButton->setEnabled(false);
        editIgnoreRuleButton->setIcon(icon1);

        horizontalLayout->addWidget(editIgnoreRuleButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(IgnoreListSettingsPage);

        QMetaObject::connectSlotsByName(IgnoreListSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *IgnoreListSettingsPage)
    {
        IgnoreListSettingsPage->setWindowTitle(QCoreApplication::translate("IgnoreListSettingsPage", "Form", nullptr));
        newIgnoreRuleButton->setText(QCoreApplication::translate("IgnoreListSettingsPage", "New", nullptr));
        deleteIgnoreRuleButton->setText(QCoreApplication::translate("IgnoreListSettingsPage", "Delete", nullptr));
        editIgnoreRuleButton->setText(QCoreApplication::translate("IgnoreListSettingsPage", "&Edit", nullptr));
    } // retranslateUi

};

namespace Ui {
    class IgnoreListSettingsPage: public Ui_IgnoreListSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_IGNORELISTSETTINGSPAGE_H
