/********************************************************************************
** Form generated from reading UI file 'debugbufferviewoverlay.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEBUGBUFFERVIEWOVERLAY_H
#define UI_DEBUGBUFFERVIEWOVERLAY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DebugBufferViewOverlay
{
public:
    QVBoxLayout *verticalLayout_2;
    QTabWidget *tabWidget;
    QWidget *overlayView;
    QVBoxLayout *verticalLayout;
    QTreeView *bufferView;
    QWidget *overlayProperties;

    void setupUi(QWidget *DebugBufferViewOverlay)
    {
        if (DebugBufferViewOverlay->objectName().isEmpty())
            DebugBufferViewOverlay->setObjectName(QString::fromUtf8("DebugBufferViewOverlay"));
        DebugBufferViewOverlay->resize(580, 545);
        verticalLayout_2 = new QVBoxLayout(DebugBufferViewOverlay);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        tabWidget = new QTabWidget(DebugBufferViewOverlay);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        overlayView = new QWidget();
        overlayView->setObjectName(QString::fromUtf8("overlayView"));
        verticalLayout = new QVBoxLayout(overlayView);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        bufferView = new QTreeView(overlayView);
        bufferView->setObjectName(QString::fromUtf8("bufferView"));

        verticalLayout->addWidget(bufferView);

        tabWidget->addTab(overlayView, QString());
        overlayProperties = new QWidget();
        overlayProperties->setObjectName(QString::fromUtf8("overlayProperties"));
        tabWidget->addTab(overlayProperties, QString());

        verticalLayout_2->addWidget(tabWidget);


        retranslateUi(DebugBufferViewOverlay);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DebugBufferViewOverlay);
    } // setupUi

    void retranslateUi(QWidget *DebugBufferViewOverlay)
    {
        DebugBufferViewOverlay->setWindowTitle(QCoreApplication::translate("DebugBufferViewOverlay", "Debug BufferView Overlay", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(overlayView), QCoreApplication::translate("DebugBufferViewOverlay", "Overlay View", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(overlayProperties), QCoreApplication::translate("DebugBufferViewOverlay", "Overlay Properties", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DebugBufferViewOverlay: public Ui_DebugBufferViewOverlay {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DEBUGBUFFERVIEWOVERLAY_H
