/****************************************************************************
** Meta object code from reading C++ file 'signalproxy.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/signalproxy.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'signalproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SignalProxy_t {
    QByteArrayData data[22];
    char stringdata0[263];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SignalProxy_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SignalProxy_t qt_meta_stringdata_SignalProxy = {
    {
QT_MOC_LITERAL(0, 0, 11), // "SignalProxy"
QT_MOC_LITERAL(1, 12, 11), // "peerRemoved"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 5), // "Peer*"
QT_MOC_LITERAL(4, 31, 4), // "peer"
QT_MOC_LITERAL(5, 36, 9), // "connected"
QT_MOC_LITERAL(6, 46, 12), // "disconnected"
QT_MOC_LITERAL(7, 59, 17), // "objectInitialized"
QT_MOC_LITERAL(8, 77, 15), // "SyncableObject*"
QT_MOC_LITERAL(9, 93, 24), // "heartBeatIntervalChanged"
QT_MOC_LITERAL(10, 118, 4), // "secs"
QT_MOC_LITERAL(11, 123, 24), // "maxHeartBeatCountChanged"
QT_MOC_LITERAL(12, 148, 3), // "max"
QT_MOC_LITERAL(13, 152, 10), // "lagUpdated"
QT_MOC_LITERAL(14, 163, 3), // "lag"
QT_MOC_LITERAL(15, 167, 18), // "secureStateChanged"
QT_MOC_LITERAL(16, 186, 18), // "removePeerBySender"
QT_MOC_LITERAL(17, 205, 13), // "objectRenamed"
QT_MOC_LITERAL(18, 219, 9), // "classname"
QT_MOC_LITERAL(19, 229, 7), // "newname"
QT_MOC_LITERAL(20, 237, 7), // "oldname"
QT_MOC_LITERAL(21, 245, 17) // "updateSecureState"

    },
    "SignalProxy\0peerRemoved\0\0Peer*\0peer\0"
    "connected\0disconnected\0objectInitialized\0"
    "SyncableObject*\0heartBeatIntervalChanged\0"
    "secs\0maxHeartBeatCountChanged\0max\0"
    "lagUpdated\0lag\0secureStateChanged\0"
    "removePeerBySender\0objectRenamed\0"
    "classname\0newname\0oldname\0updateSecureState"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SignalProxy[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x06 /* Public */,
       5,    0,   72,    2, 0x06 /* Public */,
       6,    0,   73,    2, 0x06 /* Public */,
       7,    1,   74,    2, 0x06 /* Public */,
       9,    1,   77,    2, 0x06 /* Public */,
      11,    1,   80,    2, 0x06 /* Public */,
      13,    1,   83,    2, 0x06 /* Public */,
      15,    1,   86,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    0,   89,    2, 0x08 /* Private */,
      17,    3,   90,    2, 0x08 /* Private */,
      21,    0,   97,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QByteArray, QMetaType::QString, QMetaType::QString,   18,   19,   20,
    QMetaType::Void,

       0        // eod
};

void SignalProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SignalProxy *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->peerRemoved((*reinterpret_cast< Peer*(*)>(_a[1]))); break;
        case 1: _t->connected(); break;
        case 2: _t->disconnected(); break;
        case 3: _t->objectInitialized((*reinterpret_cast< SyncableObject*(*)>(_a[1]))); break;
        case 4: _t->heartBeatIntervalChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->maxHeartBeatCountChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->lagUpdated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->secureStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->removePeerBySender(); break;
        case 9: _t->objectRenamed((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 10: _t->updateSecureState(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SignalProxy::*)(Peer * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SignalProxy::peerRemoved)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (SignalProxy::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SignalProxy::connected)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (SignalProxy::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SignalProxy::disconnected)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (SignalProxy::*)(SyncableObject * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SignalProxy::objectInitialized)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (SignalProxy::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SignalProxy::heartBeatIntervalChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (SignalProxy::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SignalProxy::maxHeartBeatCountChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (SignalProxy::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SignalProxy::lagUpdated)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (SignalProxy::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SignalProxy::secureStateChanged)) {
                *result = 7;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject SignalProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_SignalProxy.data,
    qt_meta_data_SignalProxy,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SignalProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignalProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SignalProxy.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SignalProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void SignalProxy::peerRemoved(Peer * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void SignalProxy::connected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SignalProxy::disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SignalProxy::objectInitialized(SyncableObject * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void SignalProxy::heartBeatIntervalChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void SignalProxy::maxHeartBeatCountChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void SignalProxy::lagUpdated(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void SignalProxy::secureStateChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
