/****************************************************************************
** Meta object code from reading C++ file 'corehighlightsettingspage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/settingspages/corehighlightsettingspage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'corehighlightsettingspage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreHighlightSettingsPage_t {
    QByteArrayData data[33];
    char stringdata0[452];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreHighlightSettingsPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreHighlightSettingsPage_t qt_meta_stringdata_CoreHighlightSettingsPage = {
    {
QT_MOC_LITERAL(0, 0, 25), // "CoreHighlightSettingsPage"
QT_MOC_LITERAL(1, 26, 22), // "localHighlightsChanged"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 4), // "save"
QT_MOC_LITERAL(4, 55, 4), // "load"
QT_MOC_LITERAL(5, 60, 8), // "defaults"
QT_MOC_LITERAL(6, 69, 6), // "revert"
QT_MOC_LITERAL(7, 76, 15), // "clientConnected"
QT_MOC_LITERAL(8, 92, 26), // "coreConnectionStateChanged"
QT_MOC_LITERAL(9, 119, 5), // "state"
QT_MOC_LITERAL(10, 125, 16), // "widgetHasChanged"
QT_MOC_LITERAL(11, 142, 18), // "addNewHighlightRow"
QT_MOC_LITERAL(12, 161, 6), // "enable"
QT_MOC_LITERAL(13, 168, 2), // "id"
QT_MOC_LITERAL(14, 171, 4), // "name"
QT_MOC_LITERAL(15, 176, 5), // "regex"
QT_MOC_LITERAL(16, 182, 2), // "cs"
QT_MOC_LITERAL(17, 185, 6), // "sender"
QT_MOC_LITERAL(18, 192, 8), // "chanName"
QT_MOC_LITERAL(19, 201, 4), // "self"
QT_MOC_LITERAL(20, 206, 16), // "addNewIgnoredRow"
QT_MOC_LITERAL(21, 223, 27), // "removeSelectedHighlightRows"
QT_MOC_LITERAL(22, 251, 25), // "removeSelectedIgnoredRows"
QT_MOC_LITERAL(23, 277, 21), // "highlightNicksChanged"
QT_MOC_LITERAL(24, 299, 5), // "index"
QT_MOC_LITERAL(25, 305, 18), // "selectHighlightRow"
QT_MOC_LITERAL(26, 324, 17), // "QTableWidgetItem*"
QT_MOC_LITERAL(27, 342, 4), // "item"
QT_MOC_LITERAL(28, 347, 16), // "selectIgnoredRow"
QT_MOC_LITERAL(29, 364, 21), // "highlightTableChanged"
QT_MOC_LITERAL(30, 386, 19), // "ignoredTableChanged"
QT_MOC_LITERAL(31, 406, 11), // "importRules"
QT_MOC_LITERAL(32, 418, 33) // "on_coreUnsupportedDetails_cli..."

    },
    "CoreHighlightSettingsPage\0"
    "localHighlightsChanged\0\0save\0load\0"
    "defaults\0revert\0clientConnected\0"
    "coreConnectionStateChanged\0state\0"
    "widgetHasChanged\0addNewHighlightRow\0"
    "enable\0id\0name\0regex\0cs\0sender\0chanName\0"
    "self\0addNewIgnoredRow\0removeSelectedHighlightRows\0"
    "removeSelectedIgnoredRows\0"
    "highlightNicksChanged\0index\0"
    "selectHighlightRow\0QTableWidgetItem*\0"
    "item\0selectIgnoredRow\0highlightTableChanged\0"
    "ignoredTableChanged\0importRules\0"
    "on_coreUnsupportedDetails_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreHighlightSettingsPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      35,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  189,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,  190,    2, 0x0a /* Public */,
       4,    0,  191,    2, 0x0a /* Public */,
       5,    0,  192,    2, 0x0a /* Public */,
       6,    0,  193,    2, 0x0a /* Public */,
       7,    0,  194,    2, 0x0a /* Public */,
       8,    1,  195,    2, 0x08 /* Private */,
      10,    0,  198,    2, 0x08 /* Private */,
      11,    8,  199,    2, 0x08 /* Private */,
      11,    7,  216,    2, 0x28 /* Private | MethodCloned */,
      11,    6,  231,    2, 0x28 /* Private | MethodCloned */,
      11,    5,  244,    2, 0x28 /* Private | MethodCloned */,
      11,    4,  255,    2, 0x28 /* Private | MethodCloned */,
      11,    3,  264,    2, 0x28 /* Private | MethodCloned */,
      11,    2,  271,    2, 0x28 /* Private | MethodCloned */,
      11,    1,  276,    2, 0x28 /* Private | MethodCloned */,
      11,    0,  279,    2, 0x28 /* Private | MethodCloned */,
      20,    8,  280,    2, 0x08 /* Private */,
      20,    7,  297,    2, 0x28 /* Private | MethodCloned */,
      20,    6,  312,    2, 0x28 /* Private | MethodCloned */,
      20,    5,  325,    2, 0x28 /* Private | MethodCloned */,
      20,    4,  336,    2, 0x28 /* Private | MethodCloned */,
      20,    3,  345,    2, 0x28 /* Private | MethodCloned */,
      20,    2,  352,    2, 0x28 /* Private | MethodCloned */,
      20,    1,  357,    2, 0x28 /* Private | MethodCloned */,
      20,    0,  360,    2, 0x28 /* Private | MethodCloned */,
      21,    0,  361,    2, 0x08 /* Private */,
      22,    0,  362,    2, 0x08 /* Private */,
      23,    1,  363,    2, 0x08 /* Private */,
      25,    1,  366,    2, 0x08 /* Private */,
      28,    1,  369,    2, 0x08 /* Private */,
      29,    1,  372,    2, 0x08 /* Private */,
      30,    1,  375,    2, 0x08 /* Private */,
      31,    0,  378,    2, 0x08 /* Private */,
      32,    0,  379,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::QString, QMetaType::QString, QMetaType::Bool,   12,   13,   14,   15,   16,   17,   18,   19,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::QString, QMetaType::QString,   12,   13,   14,   15,   16,   17,   18,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::QString,   12,   13,   14,   15,   16,   17,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,   12,   13,   14,   15,   16,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::Bool,   12,   13,   14,   15,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString,   12,   13,   14,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int,   12,   13,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::QString, QMetaType::QString, QMetaType::Bool,   12,   13,   14,   15,   16,   17,   18,   19,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::QString, QMetaType::QString,   12,   13,   14,   15,   16,   17,   18,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::QString,   12,   13,   14,   15,   16,   17,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Bool,   12,   13,   14,   15,   16,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString, QMetaType::Bool,   12,   13,   14,   15,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, QMetaType::QString,   12,   13,   14,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int,   12,   13,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   24,
    QMetaType::Void, 0x80000000 | 26,   27,
    QMetaType::Void, 0x80000000 | 26,   27,
    QMetaType::Void, 0x80000000 | 26,   27,
    QMetaType::Void, 0x80000000 | 26,   27,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void CoreHighlightSettingsPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreHighlightSettingsPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->localHighlightsChanged(); break;
        case 1: _t->save(); break;
        case 2: _t->load(); break;
        case 3: _t->defaults(); break;
        case 4: _t->revert(); break;
        case 5: _t->clientConnected(); break;
        case 6: _t->coreConnectionStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->widgetHasChanged(); break;
        case 8: _t->addNewHighlightRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QString(*)>(_a[7])),(*reinterpret_cast< bool(*)>(_a[8]))); break;
        case 9: _t->addNewHighlightRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QString(*)>(_a[7]))); break;
        case 10: _t->addNewHighlightRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6]))); break;
        case 11: _t->addNewHighlightRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        case 12: _t->addNewHighlightRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 13: _t->addNewHighlightRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 14: _t->addNewHighlightRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 15: _t->addNewHighlightRow((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->addNewHighlightRow(); break;
        case 17: _t->addNewIgnoredRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QString(*)>(_a[7])),(*reinterpret_cast< bool(*)>(_a[8]))); break;
        case 18: _t->addNewIgnoredRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QString(*)>(_a[7]))); break;
        case 19: _t->addNewIgnoredRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6]))); break;
        case 20: _t->addNewIgnoredRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        case 21: _t->addNewIgnoredRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4]))); break;
        case 22: _t->addNewIgnoredRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 23: _t->addNewIgnoredRow((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 24: _t->addNewIgnoredRow((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->addNewIgnoredRow(); break;
        case 26: _t->removeSelectedHighlightRows(); break;
        case 27: _t->removeSelectedIgnoredRows(); break;
        case 28: _t->highlightNicksChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 29: _t->selectHighlightRow((*reinterpret_cast< QTableWidgetItem*(*)>(_a[1]))); break;
        case 30: _t->selectIgnoredRow((*reinterpret_cast< QTableWidgetItem*(*)>(_a[1]))); break;
        case 31: _t->highlightTableChanged((*reinterpret_cast< QTableWidgetItem*(*)>(_a[1]))); break;
        case 32: _t->ignoredTableChanged((*reinterpret_cast< QTableWidgetItem*(*)>(_a[1]))); break;
        case 33: _t->importRules(); break;
        case 34: _t->on_coreUnsupportedDetails_clicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CoreHighlightSettingsPage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreHighlightSettingsPage::localHighlightsChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreHighlightSettingsPage::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingsPage::staticMetaObject>(),
    qt_meta_stringdata_CoreHighlightSettingsPage.data,
    qt_meta_data_CoreHighlightSettingsPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreHighlightSettingsPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreHighlightSettingsPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreHighlightSettingsPage.stringdata0))
        return static_cast<void*>(this);
    return SettingsPage::qt_metacast(_clname);
}

int CoreHighlightSettingsPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingsPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void CoreHighlightSettingsPage::localHighlightsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
