/****************************************************************************
** Meta object code from reading C++ file 'clientauthhandler.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/client/clientauthhandler.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'clientauthhandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ClientAuthHandler_t {
    QByteArrayData data[63];
    char stringdata0[862];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ClientAuthHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ClientAuthHandler_t qt_meta_stringdata_ClientAuthHandler = {
    {
QT_MOC_LITERAL(0, 0, 17), // "ClientAuthHandler"
QT_MOC_LITERAL(1, 18, 13), // "statusMessage"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 7), // "message"
QT_MOC_LITERAL(4, 41, 12), // "errorMessage"
QT_MOC_LITERAL(5, 54, 10), // "errorPopup"
QT_MOC_LITERAL(6, 65, 16), // "transferProgress"
QT_MOC_LITERAL(7, 82, 7), // "current"
QT_MOC_LITERAL(8, 90, 3), // "max"
QT_MOC_LITERAL(9, 94, 17), // "requestDisconnect"
QT_MOC_LITERAL(10, 112, 11), // "errorString"
QT_MOC_LITERAL(11, 124, 13), // "wantReconnect"
QT_MOC_LITERAL(12, 138, 15), // "connectionReady"
QT_MOC_LITERAL(13, 154, 15), // "loginSuccessful"
QT_MOC_LITERAL(14, 170, 11), // "CoreAccount"
QT_MOC_LITERAL(15, 182, 7), // "account"
QT_MOC_LITERAL(16, 190, 17), // "handshakeComplete"
QT_MOC_LITERAL(17, 208, 11), // "RemotePeer*"
QT_MOC_LITERAL(18, 220, 4), // "peer"
QT_MOC_LITERAL(19, 225, 22), // "Protocol::SessionState"
QT_MOC_LITERAL(20, 248, 12), // "sessionState"
QT_MOC_LITERAL(21, 261, 26), // "userAuthenticationRequired"
QT_MOC_LITERAL(22, 288, 12), // "CoreAccount*"
QT_MOC_LITERAL(23, 301, 5), // "bool*"
QT_MOC_LITERAL(24, 307, 5), // "valid"
QT_MOC_LITERAL(25, 313, 19), // "handleNoSslInClient"
QT_MOC_LITERAL(26, 333, 8), // "accepted"
QT_MOC_LITERAL(27, 342, 17), // "handleNoSslInCore"
QT_MOC_LITERAL(28, 360, 15), // "handleSslErrors"
QT_MOC_LITERAL(29, 376, 17), // "const QSslSocket*"
QT_MOC_LITERAL(30, 394, 6), // "socket"
QT_MOC_LITERAL(31, 401, 11), // "permanently"
QT_MOC_LITERAL(32, 413, 9), // "encrypted"
QT_MOC_LITERAL(33, 423, 11), // "isEncrypted"
QT_MOC_LITERAL(34, 435, 14), // "startCoreSetup"
QT_MOC_LITERAL(35, 450, 11), // "backendInfo"
QT_MOC_LITERAL(36, 462, 17), // "authenticatorInfo"
QT_MOC_LITERAL(37, 480, 19), // "coreSetupSuccessful"
QT_MOC_LITERAL(38, 500, 15), // "coreSetupFailed"
QT_MOC_LITERAL(39, 516, 5), // "error"
QT_MOC_LITERAL(40, 522, 13), // "connectToCore"
QT_MOC_LITERAL(41, 536, 5), // "login"
QT_MOC_LITERAL(42, 542, 13), // "previousError"
QT_MOC_LITERAL(43, 556, 4), // "user"
QT_MOC_LITERAL(44, 561, 8), // "password"
QT_MOC_LITERAL(45, 570, 8), // "remember"
QT_MOC_LITERAL(46, 579, 9), // "setupCore"
QT_MOC_LITERAL(47, 589, 19), // "Protocol::SetupData"
QT_MOC_LITERAL(48, 609, 9), // "setupData"
QT_MOC_LITERAL(49, 619, 17), // "onSocketConnected"
QT_MOC_LITERAL(50, 637, 20), // "onSocketStateChanged"
QT_MOC_LITERAL(51, 658, 28), // "QAbstractSocket::SocketState"
QT_MOC_LITERAL(52, 687, 5), // "state"
QT_MOC_LITERAL(53, 693, 13), // "onSocketError"
QT_MOC_LITERAL(54, 707, 28), // "QAbstractSocket::SocketError"
QT_MOC_LITERAL(55, 736, 20), // "onSocketDisconnected"
QT_MOC_LITERAL(56, 757, 11), // "onReadyRead"
QT_MOC_LITERAL(57, 769, 20), // "onSslSocketEncrypted"
QT_MOC_LITERAL(58, 790, 11), // "onSslErrors"
QT_MOC_LITERAL(59, 802, 25), // "onProtocolVersionMismatch"
QT_MOC_LITERAL(60, 828, 6), // "actual"
QT_MOC_LITERAL(61, 835, 8), // "expected"
QT_MOC_LITERAL(62, 844, 17) // "onConnectionReady"

    },
    "ClientAuthHandler\0statusMessage\0\0"
    "message\0errorMessage\0errorPopup\0"
    "transferProgress\0current\0max\0"
    "requestDisconnect\0errorString\0"
    "wantReconnect\0connectionReady\0"
    "loginSuccessful\0CoreAccount\0account\0"
    "handshakeComplete\0RemotePeer*\0peer\0"
    "Protocol::SessionState\0sessionState\0"
    "userAuthenticationRequired\0CoreAccount*\0"
    "bool*\0valid\0handleNoSslInClient\0"
    "accepted\0handleNoSslInCore\0handleSslErrors\0"
    "const QSslSocket*\0socket\0permanently\0"
    "encrypted\0isEncrypted\0startCoreSetup\0"
    "backendInfo\0authenticatorInfo\0"
    "coreSetupSuccessful\0coreSetupFailed\0"
    "error\0connectToCore\0login\0previousError\0"
    "user\0password\0remember\0setupCore\0"
    "Protocol::SetupData\0setupData\0"
    "onSocketConnected\0onSocketStateChanged\0"
    "QAbstractSocket::SocketState\0state\0"
    "onSocketError\0QAbstractSocket::SocketError\0"
    "onSocketDisconnected\0onReadyRead\0"
    "onSslSocketEncrypted\0onSslErrors\0"
    "onProtocolVersionMismatch\0actual\0"
    "expected\0onConnectionReady"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ClientAuthHandler[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      34,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      20,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  184,    2, 0x06 /* Public */,
       4,    1,  187,    2, 0x06 /* Public */,
       5,    1,  190,    2, 0x06 /* Public */,
       6,    2,  193,    2, 0x06 /* Public */,
       9,    2,  198,    2, 0x06 /* Public */,
       9,    1,  203,    2, 0x26 /* Public | MethodCloned */,
       9,    0,  206,    2, 0x26 /* Public | MethodCloned */,
      12,    0,  207,    2, 0x06 /* Public */,
      13,    1,  208,    2, 0x06 /* Public */,
      16,    2,  211,    2, 0x06 /* Public */,
      21,    3,  216,    2, 0x06 /* Public */,
      21,    2,  223,    2, 0x26 /* Public | MethodCloned */,
      25,    1,  228,    2, 0x06 /* Public */,
      27,    1,  231,    2, 0x06 /* Public */,
      28,    3,  234,    2, 0x06 /* Public */,
      32,    1,  241,    2, 0x06 /* Public */,
      32,    0,  244,    2, 0x26 /* Public | MethodCloned */,
      34,    2,  245,    2, 0x06 /* Public */,
      37,    0,  250,    2, 0x06 /* Public */,
      38,    1,  251,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      40,    0,  254,    2, 0x0a /* Public */,
      41,    1,  255,    2, 0x0a /* Public */,
      41,    0,  258,    2, 0x2a /* Public | MethodCloned */,
      41,    3,  259,    2, 0x0a /* Public */,
      46,    1,  266,    2, 0x0a /* Public */,
      49,    0,  269,    2, 0x08 /* Private */,
      50,    1,  270,    2, 0x08 /* Private */,
      53,    1,  273,    2, 0x08 /* Private */,
      55,    0,  276,    2, 0x08 /* Private */,
      56,    0,  277,    2, 0x08 /* Private */,
      57,    0,  278,    2, 0x08 /* Private */,
      58,    0,  279,    2, 0x08 /* Private */,
      59,    2,  280,    2, 0x08 /* Private */,
      62,    0,  285,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    7,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   10,   11,
    QMetaType::Void, QMetaType::QString,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, 0x80000000 | 17, 0x80000000 | 19,   18,   20,
    QMetaType::Void, 0x80000000 | 22, 0x80000000 | 23, QMetaType::QString,   15,   24,    4,
    QMetaType::Void, 0x80000000 | 22, 0x80000000 | 23,   15,   24,
    QMetaType::Void, 0x80000000 | 23,   26,
    QMetaType::Void, 0x80000000 | 23,   26,
    QMetaType::Void, 0x80000000 | 29, 0x80000000 | 23, 0x80000000 | 23,   30,   26,   31,
    QMetaType::Void, QMetaType::Bool,   33,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QVariantList, QMetaType::QVariantList,   35,   36,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   39,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   42,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::Bool,   43,   44,   45,
    QMetaType::Void, 0x80000000 | 47,   48,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 51,   52,
    QMetaType::Void, 0x80000000 | 54,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   60,   61,
    QMetaType::Void,

       0        // eod
};

void ClientAuthHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ClientAuthHandler *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->statusMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->errorMessage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->errorPopup((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->transferProgress((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->requestDisconnect((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 5: _t->requestDisconnect((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->requestDisconnect(); break;
        case 7: _t->connectionReady(); break;
        case 8: _t->loginSuccessful((*reinterpret_cast< const CoreAccount(*)>(_a[1]))); break;
        case 9: _t->handshakeComplete((*reinterpret_cast< RemotePeer*(*)>(_a[1])),(*reinterpret_cast< const Protocol::SessionState(*)>(_a[2]))); break;
        case 10: _t->userAuthenticationRequired((*reinterpret_cast< CoreAccount*(*)>(_a[1])),(*reinterpret_cast< bool*(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 11: _t->userAuthenticationRequired((*reinterpret_cast< CoreAccount*(*)>(_a[1])),(*reinterpret_cast< bool*(*)>(_a[2]))); break;
        case 12: _t->handleNoSslInClient((*reinterpret_cast< bool*(*)>(_a[1]))); break;
        case 13: _t->handleNoSslInCore((*reinterpret_cast< bool*(*)>(_a[1]))); break;
        case 14: _t->handleSslErrors((*reinterpret_cast< const QSslSocket*(*)>(_a[1])),(*reinterpret_cast< bool*(*)>(_a[2])),(*reinterpret_cast< bool*(*)>(_a[3]))); break;
        case 15: _t->encrypted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->encrypted(); break;
        case 17: _t->startCoreSetup((*reinterpret_cast< const QVariantList(*)>(_a[1])),(*reinterpret_cast< const QVariantList(*)>(_a[2]))); break;
        case 18: _t->coreSetupSuccessful(); break;
        case 19: _t->coreSetupFailed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->connectToCore(); break;
        case 21: _t->login((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 22: _t->login(); break;
        case 23: _t->login((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 24: _t->setupCore((*reinterpret_cast< const Protocol::SetupData(*)>(_a[1]))); break;
        case 25: _t->onSocketConnected(); break;
        case 26: _t->onSocketStateChanged((*reinterpret_cast< QAbstractSocket::SocketState(*)>(_a[1]))); break;
        case 27: _t->onSocketError((*reinterpret_cast< QAbstractSocket::SocketError(*)>(_a[1]))); break;
        case 28: _t->onSocketDisconnected(); break;
        case 29: _t->onReadyRead(); break;
        case 30: _t->onSslSocketEncrypted(); break;
        case 31: _t->onSslErrors(); break;
        case 32: _t->onProtocolVersionMismatch((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 33: _t->onConnectionReady(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketState >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSocket::SocketError >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ClientAuthHandler::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::statusMessage)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::errorMessage)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::errorPopup)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::transferProgress)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::requestDisconnect)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::connectionReady)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(const CoreAccount & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::loginSuccessful)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(RemotePeer * , const Protocol::SessionState & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::handshakeComplete)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(CoreAccount * , bool * , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::userAuthenticationRequired)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(bool * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::handleNoSslInClient)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(bool * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::handleNoSslInCore)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(const QSslSocket * , bool * , bool * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::handleSslErrors)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::encrypted)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(const QVariantList & , const QVariantList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::startCoreSetup)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::coreSetupSuccessful)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (ClientAuthHandler::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientAuthHandler::coreSetupFailed)) {
                *result = 19;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ClientAuthHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<AuthHandler::staticMetaObject>(),
    qt_meta_stringdata_ClientAuthHandler.data,
    qt_meta_data_ClientAuthHandler,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ClientAuthHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClientAuthHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ClientAuthHandler.stringdata0))
        return static_cast<void*>(this);
    return AuthHandler::qt_metacast(_clname);
}

int ClientAuthHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AuthHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    return _id;
}

// SIGNAL 0
void ClientAuthHandler::statusMessage(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ClientAuthHandler::errorMessage(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void ClientAuthHandler::errorPopup(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void ClientAuthHandler::transferProgress(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void ClientAuthHandler::requestDisconnect(const QString & _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 7
void ClientAuthHandler::connectionReady()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ClientAuthHandler::loginSuccessful(const CoreAccount & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void ClientAuthHandler::handshakeComplete(RemotePeer * _t1, const Protocol::SessionState & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void ClientAuthHandler::userAuthenticationRequired(CoreAccount * _t1, bool * _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 12
void ClientAuthHandler::handleNoSslInClient(bool * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void ClientAuthHandler::handleNoSslInCore(bool * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void ClientAuthHandler::handleSslErrors(const QSslSocket * _t1, bool * _t2, bool * _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void ClientAuthHandler::encrypted(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 17
void ClientAuthHandler::startCoreSetup(const QVariantList & _t1, const QVariantList & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void ClientAuthHandler::coreSetupSuccessful()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void ClientAuthHandler::coreSetupFailed(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
