/****************************************************************************
** Meta object code from reading C++ file 'identserver.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/identserver.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'identserver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_IdentServer_t {
    QByteArrayData data[14];
    char stringdata0[158];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_IdentServer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_IdentServer_t qt_meta_stringdata_IdentServer = {
    {
QT_MOC_LITERAL(0, 0, 11), // "IdentServer"
QT_MOC_LITERAL(1, 12, 9), // "addSocket"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 19), // "const CoreIdentity*"
QT_MOC_LITERAL(4, 43, 8), // "identity"
QT_MOC_LITERAL(5, 52, 12), // "QHostAddress"
QT_MOC_LITERAL(6, 65, 12), // "localAddress"
QT_MOC_LITERAL(7, 78, 9), // "localPort"
QT_MOC_LITERAL(8, 88, 11), // "peerAddress"
QT_MOC_LITERAL(9, 100, 8), // "peerPort"
QT_MOC_LITERAL(10, 109, 8), // "socketId"
QT_MOC_LITERAL(11, 118, 12), // "removeSocket"
QT_MOC_LITERAL(12, 131, 18), // "incomingConnection"
QT_MOC_LITERAL(13, 150, 7) // "respond"

    },
    "IdentServer\0addSocket\0\0const CoreIdentity*\0"
    "identity\0QHostAddress\0localAddress\0"
    "localPort\0peerAddress\0peerPort\0socketId\0"
    "removeSocket\0incomingConnection\0respond"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_IdentServer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    6,   34,    2, 0x0a /* Public */,
      11,    6,   47,    2, 0x0a /* Public */,
      12,    0,   60,    2, 0x08 /* Private */,
      13,    0,   61,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5, QMetaType::UShort, 0x80000000 | 5, QMetaType::UShort, QMetaType::LongLong,    4,    6,    7,    8,    9,   10,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5, QMetaType::UShort, 0x80000000 | 5, QMetaType::UShort, QMetaType::LongLong,    4,    6,    7,    8,    9,   10,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void IdentServer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<IdentServer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->addSocket((*reinterpret_cast< const CoreIdentity*(*)>(_a[1])),(*reinterpret_cast< const QHostAddress(*)>(_a[2])),(*reinterpret_cast< quint16(*)>(_a[3])),(*reinterpret_cast< const QHostAddress(*)>(_a[4])),(*reinterpret_cast< quint16(*)>(_a[5])),(*reinterpret_cast< qint64(*)>(_a[6]))); break;
        case 1: _t->removeSocket((*reinterpret_cast< const CoreIdentity*(*)>(_a[1])),(*reinterpret_cast< const QHostAddress(*)>(_a[2])),(*reinterpret_cast< quint16(*)>(_a[3])),(*reinterpret_cast< const QHostAddress(*)>(_a[4])),(*reinterpret_cast< quint16(*)>(_a[5])),(*reinterpret_cast< qint64(*)>(_a[6]))); break;
        case 2: _t->incomingConnection(); break;
        case 3: _t->respond(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 3:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QHostAddress >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 3:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QHostAddress >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject IdentServer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_IdentServer.data,
    qt_meta_data_IdentServer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *IdentServer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IdentServer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_IdentServer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int IdentServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
