/********************************************************************************
** Form generated from reading UI file 'chatviewsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHATVIEWSETTINGSPAGE_H
#define UI_CHATVIEWSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "fontselector.h"

QT_BEGIN_NAMESPACE

class Ui_ChatViewSettingsPage
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QCheckBox *customTimestampFormat;
    QLineEdit *timestampFormat;
    QSpacerItem *horizontalSpacer;
    QCheckBox *showSenderBrackets;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    QComboBox *senderPrefixComboBox;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *customChatViewFont;
    FontSelector *chatViewFont;
    QCheckBox *showWebPreview;
    QCheckBox *autoMarkerLine;
    QCheckBox *autoMarkerLineOnLostFocus;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_2;
    QLineEdit *webSearchUrlFormat;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ChatViewSettingsPage)
    {
        if (ChatViewSettingsPage->objectName().isEmpty())
            ChatViewSettingsPage->setObjectName(QString::fromUtf8("ChatViewSettingsPage"));
        ChatViewSettingsPage->resize(514, 306);
        verticalLayout_2 = new QVBoxLayout(ChatViewSettingsPage);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        customTimestampFormat = new QCheckBox(ChatViewSettingsPage);
        customTimestampFormat->setObjectName(QString::fromUtf8("customTimestampFormat"));
        customTimestampFormat->setProperty("defaultValue", QVariant(false));
        customTimestampFormat->setProperty("settingsKey", QVariant(QString::fromUtf8("UseCustomTimestampFormat")));

        horizontalLayout->addWidget(customTimestampFormat);

        timestampFormat = new QLineEdit(ChatViewSettingsPage);
        timestampFormat->setObjectName(QString::fromUtf8("timestampFormat"));
        timestampFormat->setEnabled(false);
        timestampFormat->setProperty("settingsKey", QVariant(QString::fromUtf8("TimestampFormat")));

        horizontalLayout->addWidget(timestampFormat);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        showSenderBrackets = new QCheckBox(ChatViewSettingsPage);
        showSenderBrackets->setObjectName(QString::fromUtf8("showSenderBrackets"));
        showSenderBrackets->setChecked(false);
        showSenderBrackets->setProperty("defaultValue", QVariant(false));
        showSenderBrackets->setProperty("settingsKey", QVariant(QString::fromUtf8("ShowSenderBrackets")));

        verticalLayout_2->addWidget(showSenderBrackets);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label = new QLabel(ChatViewSettingsPage);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout_2->addWidget(label);

        senderPrefixComboBox = new QComboBox(ChatViewSettingsPage);
        senderPrefixComboBox->setObjectName(QString::fromUtf8("senderPrefixComboBox"));
        senderPrefixComboBox->setProperty("defaultValue", QVariant(1));
        senderPrefixComboBox->setProperty("settingsKey", QVariant(QString::fromUtf8("SenderPrefixMode")));

        horizontalLayout_2->addWidget(senderPrefixComboBox);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        customChatViewFont = new QCheckBox(ChatViewSettingsPage);
        customChatViewFont->setObjectName(QString::fromUtf8("customChatViewFont"));
        customChatViewFont->setChecked(false);
        customChatViewFont->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Fonts/UseCustomChatViewFont")));
        customChatViewFont->setProperty("defaultValue", QVariant(false));

        horizontalLayout_3->addWidget(customChatViewFont);

        chatViewFont = new FontSelector(ChatViewSettingsPage);
        chatViewFont->setObjectName(QString::fromUtf8("chatViewFont"));
        chatViewFont->setEnabled(false);
        chatViewFont->setProperty("settingsKey", QVariant(QString::fromUtf8("/QtUiStyle/Fonts/ChatView")));
        QFont font;
        font.setFamily(QString::fromUtf8("Monospace"));
        chatViewFont->setProperty("defaultValue", QVariant(font));

        horizontalLayout_3->addWidget(chatViewFont);


        verticalLayout_2->addLayout(horizontalLayout_3);

        showWebPreview = new QCheckBox(ChatViewSettingsPage);
        showWebPreview->setObjectName(QString::fromUtf8("showWebPreview"));
        showWebPreview->setChecked(false);
        showWebPreview->setProperty("defaultValue", QVariant(false));
        showWebPreview->setProperty("settingsKey", QVariant(QString::fromUtf8("ShowWebPreview")));

        verticalLayout_2->addWidget(showWebPreview);

        autoMarkerLine = new QCheckBox(ChatViewSettingsPage);
        autoMarkerLine->setObjectName(QString::fromUtf8("autoMarkerLine"));
        autoMarkerLine->setChecked(true);
        autoMarkerLine->setProperty("settingsKey", QVariant(QString::fromUtf8("AutoMarkerLine")));
        autoMarkerLine->setProperty("defaultValue", QVariant(true));

        verticalLayout_2->addWidget(autoMarkerLine);

        autoMarkerLineOnLostFocus = new QCheckBox(ChatViewSettingsPage);
        autoMarkerLineOnLostFocus->setObjectName(QString::fromUtf8("autoMarkerLineOnLostFocus"));
        autoMarkerLineOnLostFocus->setChecked(true);
        autoMarkerLineOnLostFocus->setProperty("settingsKey", QVariant(QString::fromUtf8("AutoMarkerLineOnLostFocus")));
        autoMarkerLineOnLostFocus->setProperty("defaultValue", QVariant(true));

        verticalLayout_2->addWidget(autoMarkerLineOnLostFocus);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        label_2 = new QLabel(ChatViewSettingsPage);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout_4->addWidget(label_2);

        webSearchUrlFormat = new QLineEdit(ChatViewSettingsPage);
        webSearchUrlFormat->setObjectName(QString::fromUtf8("webSearchUrlFormat"));
        webSearchUrlFormat->setProperty("settingsKey", QVariant(QString::fromUtf8("WebSearchUrlFormat")));

        horizontalLayout_4->addWidget(webSearchUrlFormat);


        verticalLayout_2->addLayout(horizontalLayout_4);

        verticalSpacer = new QSpacerItem(20, 19, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        QWidget::setTabOrder(customTimestampFormat, timestampFormat);
        QWidget::setTabOrder(timestampFormat, showSenderBrackets);
        QWidget::setTabOrder(showSenderBrackets, senderPrefixComboBox);
        QWidget::setTabOrder(senderPrefixComboBox, customChatViewFont);
        QWidget::setTabOrder(customChatViewFont, showWebPreview);
        QWidget::setTabOrder(showWebPreview, autoMarkerLine);
        QWidget::setTabOrder(autoMarkerLine, autoMarkerLineOnLostFocus);
        QWidget::setTabOrder(autoMarkerLineOnLostFocus, webSearchUrlFormat);

        retranslateUi(ChatViewSettingsPage);
        QObject::connect(customChatViewFont, SIGNAL(toggled(bool)), chatViewFont, SLOT(setEnabled(bool)));
        QObject::connect(customTimestampFormat, SIGNAL(toggled(bool)), timestampFormat, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(ChatViewSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *ChatViewSettingsPage)
    {
        ChatViewSettingsPage->setWindowTitle(QCoreApplication::translate("ChatViewSettingsPage", "Form", nullptr));
#if QT_CONFIG(tooltip)
        customTimestampFormat->setToolTip(QCoreApplication::translate("ChatViewSettingsPage", "Use a custom format for the timestamp", nullptr));
#endif // QT_CONFIG(tooltip)
        customTimestampFormat->setText(QCoreApplication::translate("ChatViewSettingsPage", "Custom timestamp format:", nullptr));
#if QT_CONFIG(tooltip)
        timestampFormat->setToolTip(QCoreApplication::translate("ChatViewSettingsPage", "<html><head/><body>\n"
"         <p>Accepts Qt QDateTime Format.</p>\n"
"         <p>Examples:</p>\n"
"         <table cellpadding=\"2\">\n"
"         <tr><td>dd.MM.yyyy</td><td>21.05.2001</td></tr>\n"
"         <tr><td>ddd MMMM d yy</td><td>Tue May 21 01</td></tr>\n"
"         <tr><td>hh:mm:ss.zzz</td><td>14:13:09.042</td></tr>\n"
"         <tr><td>h:m:s ap</td><td>2:13:9 pm</td></tr>\n"
"         </table>\n"
"         </body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        timestampFormat->setText(QString());
        timestampFormat->setProperty("defaultValue", QVariant(QCoreApplication::translate("ChatViewSettingsPage", " hh:mm:ss", nullptr)));
#if QT_CONFIG(tooltip)
        showSenderBrackets->setToolTip(QCoreApplication::translate("ChatViewSettingsPage", "Shows <brackets> around the names of senders", nullptr));
#endif // QT_CONFIG(tooltip)
        showSenderBrackets->setText(QCoreApplication::translate("ChatViewSettingsPage", "Show brackets around sender names", nullptr));
        label->setText(QCoreApplication::translate("ChatViewSettingsPage", "Show sender modes before nicknames:", nullptr));
#if QT_CONFIG(tooltip)
        senderPrefixComboBox->setToolTip(QCoreApplication::translate("ChatViewSettingsPage", "<qt><style>.bold { font-weight: bold; } .italic { font-style: italic; } .underline { text-decoration: underline; }</style>\n"
"<p><span class=\"bold\">Sender modes:</span></p>\n"
"<p><span class=\"underline\">No modes:</span> Don't show any modes<br/><span class=\"italic\">Example:</span> &lt;nickname&gt;</p>\n"
"<p><span class=\"underline\">Highest mode:</span> Show only the highest active mode<br/><span class=\"italic\">Example:</span> &lt;@nickname&gt;</p>\n"
"<p><span class=\"underline\">All modes:</span> Show all active modes<br/><span class=\"italic\">Example:</span> &lt;@+nickname&gt;</p>\n"
"</qt>", nullptr));
#endif // QT_CONFIG(tooltip)
        customChatViewFont->setText(QCoreApplication::translate("ChatViewSettingsPage", "Custom chat window font:", nullptr));
#if QT_CONFIG(tooltip)
        showWebPreview->setToolTip(QCoreApplication::translate("ChatViewSettingsPage", "Show a website preview window when hovering the mouse over a web address", nullptr));
#endif // QT_CONFIG(tooltip)
        showWebPreview->setText(QCoreApplication::translate("ChatViewSettingsPage", "Show previews of webpages on URL hover", nullptr));
#if QT_CONFIG(tooltip)
        autoMarkerLine->setToolTip(QCoreApplication::translate("ChatViewSettingsPage", "Set the marker line to the bottom of the current chat window when selecting another channel", nullptr));
#endif // QT_CONFIG(tooltip)
        autoMarkerLine->setText(QCoreApplication::translate("ChatViewSettingsPage", "Set marker line automatically when switching chats", nullptr));
#if QT_CONFIG(tooltip)
        autoMarkerLineOnLostFocus->setToolTip(QCoreApplication::translate("ChatViewSettingsPage", "Set the marker line to the bottom of the current chat window when Quassel loses focus.", nullptr));
#endif // QT_CONFIG(tooltip)
        autoMarkerLineOnLostFocus->setText(QCoreApplication::translate("ChatViewSettingsPage", "Set marker line automatically when Quassel loses focus", nullptr));
        label_2->setText(QCoreApplication::translate("ChatViewSettingsPage", "Web Search URL:", nullptr));
#if QT_CONFIG(tooltip)
        webSearchUrlFormat->setToolTip(QCoreApplication::translate("ChatViewSettingsPage", "<html><head/><body><p>The URL to open with the selected text as the parameter. Place <span style=\" font-weight:600;\">%s</span> where selected text should go.</p><p>Eg:</p><p>https://www.google.com/search?q=<span style=\" font-weight:600;\">%s<br/></span>https://duckduckgo.com/?q=<span style=\" font-weight:600;\">%s</span></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        webSearchUrlFormat->setProperty("defaultValue", QVariant(QCoreApplication::translate("ChatViewSettingsPage", "https://www.google.com/search?q=%s", nullptr)));
    } // retranslateUi

};

namespace Ui {
    class ChatViewSettingsPage: public Ui_ChatViewSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CHATVIEWSETTINGSPAGE_H
