/********************************************************************************
** Form generated from reading UI file 'backlogsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BACKLOGSETTINGSPAGE_H
#define UI_BACKLOGSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_BacklogSettingsPage
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QSpinBox *dynamicBacklogAmount;
    QSpacerItem *horizontalSpacer;
    QCheckBox *ensureBacklogOnBufferShow;
    QFrame *line;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_3;
    QComboBox *requesterType;
    QSpacerItem *horizontalSpacer_4;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_9;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    QSpinBox *fixedBacklogAmount;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_4;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_3;
    QLabel *label_10;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_11;
    QSpinBox *perBufferUnreadLimit;
    QLabel *label_12;
    QSpinBox *perBufferUnreadAdditional;
    QSpacerItem *horizontalSpacer_5;
    QSpacerItem *verticalSpacer_3;
    QWidget *page_3;
    QVBoxLayout *verticalLayout_5;
    QLabel *label_16;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_4;
    QSpinBox *asNeededLegacyBacklogAmount;
    QSpacerItem *horizontalSpacer_6;
    QSpacerItem *verticalSpacer_5;
    QWidget *Seite;
    QVBoxLayout *verticalLayout_4;
    QLabel *label_15;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_13;
    QSpinBox *globalUnreadLimit;
    QLabel *label_14;
    QSpinBox *globalUnreadAdditional;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *BacklogSettingsPage)
    {
        if (BacklogSettingsPage->objectName().isEmpty())
            BacklogSettingsPage->setObjectName(QString::fromUtf8("BacklogSettingsPage"));
        BacklogSettingsPage->resize(446, 329);
        verticalLayout = new QVBoxLayout(BacklogSettingsPage);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label_2 = new QLabel(BacklogSettingsPage);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout->addWidget(label_2);

        dynamicBacklogAmount = new QSpinBox(BacklogSettingsPage);
        dynamicBacklogAmount->setObjectName(QString::fromUtf8("dynamicBacklogAmount"));
        dynamicBacklogAmount->setMaximum(99999);
        dynamicBacklogAmount->setSingleStep(10);
        dynamicBacklogAmount->setValue(200);
        dynamicBacklogAmount->setProperty("settingsKey", QVariant(QString::fromUtf8("DynamicBacklogAmount")));
        dynamicBacklogAmount->setProperty("defaultValue", QVariant(200));

        horizontalLayout->addWidget(dynamicBacklogAmount);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout);

        ensureBacklogOnBufferShow = new QCheckBox(BacklogSettingsPage);
        ensureBacklogOnBufferShow->setObjectName(QString::fromUtf8("ensureBacklogOnBufferShow"));
        ensureBacklogOnBufferShow->setProperty("settingsKey", QVariant(QString::fromUtf8("EnsureBacklogOnBufferShow")));
        ensureBacklogOnBufferShow->setProperty("defaultValue", QVariant(true));

        verticalLayout->addWidget(ensureBacklogOnBufferShow);

        line = new QFrame(BacklogSettingsPage);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(line);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        label_3 = new QLabel(BacklogSettingsPage);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        horizontalLayout_5->addWidget(label_3);

        requesterType = new QComboBox(BacklogSettingsPage);
        requesterType->addItem(QString());
        requesterType->addItem(QString());
        requesterType->addItem(QString());
        requesterType->addItem(QString());
        requesterType->setObjectName(QString::fromUtf8("requesterType"));

        horizontalLayout_5->addWidget(requesterType);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_5);

        stackedWidget = new QStackedWidget(BacklogSettingsPage);
        stackedWidget->setObjectName(QString::fromUtf8("stackedWidget"));
        page = new QWidget();
        page->setObjectName(QString::fromUtf8("page"));
        verticalLayout_2 = new QVBoxLayout(page);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        label_9 = new QLabel(page);
        label_9->setObjectName(QString::fromUtf8("label_9"));
        label_9->setTextFormat(Qt::PlainText);
        label_9->setWordWrap(true);

        verticalLayout_2->addWidget(label_9);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label = new QLabel(page);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout_2->addWidget(label);

        fixedBacklogAmount = new QSpinBox(page);
        fixedBacklogAmount->setObjectName(QString::fromUtf8("fixedBacklogAmount"));
        fixedBacklogAmount->setMinimum(0);
        fixedBacklogAmount->setMaximum(99999);
        fixedBacklogAmount->setSingleStep(10);
        fixedBacklogAmount->setValue(500);
        fixedBacklogAmount->setProperty("settingsKey", QVariant(QString::fromUtf8("FixedBacklogAmount")));
        fixedBacklogAmount->setProperty("defaultValue", QVariant(500));

        horizontalLayout_2->addWidget(fixedBacklogAmount);

        horizontalSpacer_2 = new QSpacerItem(263, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout_2);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_4);

        stackedWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName(QString::fromUtf8("page_2"));
        verticalLayout_3 = new QVBoxLayout(page_2);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        label_10 = new QLabel(page_2);
        label_10->setObjectName(QString::fromUtf8("label_10"));
        label_10->setTextFormat(Qt::PlainText);
        label_10->setWordWrap(true);

        verticalLayout_3->addWidget(label_10);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label_11 = new QLabel(page_2);
        label_11->setObjectName(QString::fromUtf8("label_11"));

        horizontalLayout_3->addWidget(label_11);

        perBufferUnreadLimit = new QSpinBox(page_2);
        perBufferUnreadLimit->setObjectName(QString::fromUtf8("perBufferUnreadLimit"));
        perBufferUnreadLimit->setMinimum(-1);
        perBufferUnreadLimit->setMaximum(99999);
        perBufferUnreadLimit->setSingleStep(10);
        perBufferUnreadLimit->setValue(1000);
        perBufferUnreadLimit->setProperty("settingsKey", QVariant(QString::fromUtf8("PerBufferUnreadBacklogLimit")));
        perBufferUnreadLimit->setProperty("defaultValue", QVariant(1000));

        horizontalLayout_3->addWidget(perBufferUnreadLimit);

        label_12 = new QLabel(page_2);
        label_12->setObjectName(QString::fromUtf8("label_12"));

        horizontalLayout_3->addWidget(label_12);

        perBufferUnreadAdditional = new QSpinBox(page_2);
        perBufferUnreadAdditional->setObjectName(QString::fromUtf8("perBufferUnreadAdditional"));
        perBufferUnreadAdditional->setMaximum(1000);
        perBufferUnreadAdditional->setSingleStep(10);
        perBufferUnreadAdditional->setValue(50);
        perBufferUnreadAdditional->setProperty("settingsKey", QVariant(QString::fromUtf8("PerBufferUnreadBacklogAdditional")));
        perBufferUnreadAdditional->setProperty("defaultValue", QVariant(50));

        horizontalLayout_3->addWidget(perBufferUnreadAdditional);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_5);


        verticalLayout_3->addLayout(horizontalLayout_3);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);

        stackedWidget->addWidget(page_2);
        page_3 = new QWidget();
        page_3->setObjectName(QString::fromUtf8("page_3"));
        verticalLayout_5 = new QVBoxLayout(page_3);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        label_16 = new QLabel(page_3);
        label_16->setObjectName(QString::fromUtf8("label_16"));
        label_16->setTextFormat(Qt::RichText);
        label_16->setWordWrap(true);

        verticalLayout_5->addWidget(label_16);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QString::fromUtf8("horizontalLayout_6"));
        label_4 = new QLabel(page_3);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        horizontalLayout_6->addWidget(label_4);

        asNeededLegacyBacklogAmount = new QSpinBox(page_3);
        asNeededLegacyBacklogAmount->setObjectName(QString::fromUtf8("asNeededLegacyBacklogAmount"));
        asNeededLegacyBacklogAmount->setMinimum(0);
        asNeededLegacyBacklogAmount->setMaximum(99999);
        asNeededLegacyBacklogAmount->setSingleStep(10);
        asNeededLegacyBacklogAmount->setValue(500);
        asNeededLegacyBacklogAmount->setProperty("settingsKey", QVariant(QString::fromUtf8("AsNeededLegacyBacklogAmount")));
        asNeededLegacyBacklogAmount->setProperty("defaultValue", QVariant(500));

        horizontalLayout_6->addWidget(asNeededLegacyBacklogAmount);

        horizontalSpacer_6 = new QSpacerItem(263, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_6);


        verticalLayout_5->addLayout(horizontalLayout_6);

        verticalSpacer_5 = new QSpacerItem(20, 47, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_5->addItem(verticalSpacer_5);

        stackedWidget->addWidget(page_3);
        Seite = new QWidget();
        Seite->setObjectName(QString::fromUtf8("Seite"));
        verticalLayout_4 = new QVBoxLayout(Seite);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        label_15 = new QLabel(Seite);
        label_15->setObjectName(QString::fromUtf8("label_15"));
        label_15->setTextFormat(Qt::PlainText);
        label_15->setWordWrap(true);

        verticalLayout_4->addWidget(label_15);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        label_13 = new QLabel(Seite);
        label_13->setObjectName(QString::fromUtf8("label_13"));

        horizontalLayout_4->addWidget(label_13);

        globalUnreadLimit = new QSpinBox(Seite);
        globalUnreadLimit->setObjectName(QString::fromUtf8("globalUnreadLimit"));
        globalUnreadLimit->setMinimum(-1);
        globalUnreadLimit->setMaximum(100000);
        globalUnreadLimit->setSingleStep(10);
        globalUnreadLimit->setValue(200);
        globalUnreadLimit->setProperty("settingsKey", QVariant(QString::fromUtf8("GlobalUnreadBacklogLimit")));
        globalUnreadLimit->setProperty("defaultValue", QVariant(200));

        horizontalLayout_4->addWidget(globalUnreadLimit);

        label_14 = new QLabel(Seite);
        label_14->setObjectName(QString::fromUtf8("label_14"));

        horizontalLayout_4->addWidget(label_14);

        globalUnreadAdditional = new QSpinBox(Seite);
        globalUnreadAdditional->setObjectName(QString::fromUtf8("globalUnreadAdditional"));
        globalUnreadAdditional->setMaximum(1000);
        globalUnreadAdditional->setSingleStep(10);
        globalUnreadAdditional->setValue(50);
        globalUnreadAdditional->setProperty("settingsKey", QVariant(QString::fromUtf8("GlobalUnreadBacklogAdditional")));
        globalUnreadAdditional->setProperty("defaultValue", QVariant(50));

        horizontalLayout_4->addWidget(globalUnreadAdditional);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);


        verticalLayout_4->addLayout(horizontalLayout_4);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        stackedWidget->addWidget(Seite);

        verticalLayout->addWidget(stackedWidget);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        retranslateUi(BacklogSettingsPage);
        QObject::connect(requesterType, SIGNAL(currentIndexChanged(int)), stackedWidget, SLOT(setCurrentIndex(int)));

        requesterType->setCurrentIndex(2);
        stackedWidget->setCurrentIndex(2);


        QMetaObject::connectSlotsByName(BacklogSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *BacklogSettingsPage)
    {
        BacklogSettingsPage->setWindowTitle(QCoreApplication::translate("BacklogSettingsPage", "Form", nullptr));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(QCoreApplication::translate("BacklogSettingsPage", "Number of messages to be requested from the core when using scrolling up in the buffer view.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(QCoreApplication::translate("BacklogSettingsPage", "Dynamic backlog amount:", nullptr));
#if QT_CONFIG(tooltip)
        ensureBacklogOnBufferShow->setToolTip(QCoreApplication::translate("BacklogSettingsPage", "When switching to a chat, more backlog will be fetched if no messages are shown yet or the scrollbar isn't visible.  Useful when not fetching any initial backlog.", nullptr));
#endif // QT_CONFIG(tooltip)
        ensureBacklogOnBufferShow->setText(QCoreApplication::translate("BacklogSettingsPage", "Fetch backlog if needed when switching chats", nullptr));
        label_3->setText(QCoreApplication::translate("BacklogSettingsPage", "Backlog request method:", nullptr));
        requesterType->setItemText(0, QCoreApplication::translate("BacklogSettingsPage", "Fixed amount per chat", nullptr));
        requesterType->setItemText(1, QCoreApplication::translate("BacklogSettingsPage", "Unread messages per chat", nullptr));
        requesterType->setItemText(2, QCoreApplication::translate("BacklogSettingsPage", "Only fetch when needed", nullptr));
        requesterType->setItemText(3, QCoreApplication::translate("BacklogSettingsPage", "Globally unread messages", nullptr));

        label_9->setText(QCoreApplication::translate("BacklogSettingsPage", "The simplest requester. It fetches a fixed amount of lines for each chat window from the backlog.", nullptr));
#if QT_CONFIG(tooltip)
        label->setToolTip(QCoreApplication::translate("BacklogSettingsPage", "Amount of messages per buffer that are requested after the core connection has been established.", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(QCoreApplication::translate("BacklogSettingsPage", "Initial backlog amount:", nullptr));
        fixedBacklogAmount->setSpecialValueText(QString());
        label_10->setText(QCoreApplication::translate("BacklogSettingsPage", "This requester fetches unread messages for each chat window individually. The amount of lines can be limited per chat.\n"
"\n"
"You can also choose to fetch additional older chatlines to provide a better context.", nullptr));
#if QT_CONFIG(tooltip)
        label_11->setToolTip(QCoreApplication::translate("BacklogSettingsPage", "Maximum amount of messages to be fetched per buffer.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_11->setText(QCoreApplication::translate("BacklogSettingsPage", "Limit:", nullptr));
#if QT_CONFIG(tooltip)
        perBufferUnreadLimit->setToolTip(QCoreApplication::translate("BacklogSettingsPage", "Maximum amount of messages to be fetched per buffer.", nullptr));
#endif // QT_CONFIG(tooltip)
        perBufferUnreadLimit->setSpecialValueText(QCoreApplication::translate("BacklogSettingsPage", "Unlimited", nullptr));
#if QT_CONFIG(tooltip)
        label_12->setToolTip(QCoreApplication::translate("BacklogSettingsPage", "Amount of messages to be fetched in addition to the unread messages. The Limit does not apply here.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_12->setText(QCoreApplication::translate("BacklogSettingsPage", "Additional Messages:", nullptr));
#if QT_CONFIG(tooltip)
        perBufferUnreadAdditional->setToolTip(QCoreApplication::translate("BacklogSettingsPage", "Amount of messages to be fetched in addition to the unread messages. The Limit does not apply here.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_16->setText(QCoreApplication::translate("BacklogSettingsPage", "<p>On modern cores (v0.13.0 or newer), no backlog will be fetched.  The core keeps track of chat activity automatically.<br/>\n"
"<i>Note: Chat Monitor won't show past messages.</i>\n"
"</p>\n"
"<p>On older cores, this requester fetches a fixed amount of lines for each chat window from the backlog.</p>", nullptr));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(QCoreApplication::translate("BacklogSettingsPage", "Amount of messages per buffer that are requested after the core connection has been established.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(QCoreApplication::translate("BacklogSettingsPage", "For legacy cores, initial backlog amount:", nullptr));
        asNeededLegacyBacklogAmount->setSpecialValueText(QString());
        label_15->setText(QCoreApplication::translate("BacklogSettingsPage", "This requester fetches all messages newer than the oldest unread message for all chats.\n"
"\n"
"Note: This requester is not recommended if you use hidden chat windows or have inactive chats (i.e.: no stale queries or channels).\n"
"It is useful to limit the total amount of the backlog and is probably the fastest.\n"
"\n"
"You can also chose to fetch additional older chatlines to provide a better context.", nullptr));
#if QT_CONFIG(tooltip)
        label_13->setToolTip(QCoreApplication::translate("BacklogSettingsPage", "Maximum amount of messages to be fetched over all buffers.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_13->setText(QCoreApplication::translate("BacklogSettingsPage", "Limit:", nullptr));
#if QT_CONFIG(tooltip)
        globalUnreadLimit->setToolTip(QCoreApplication::translate("BacklogSettingsPage", "Maximum amount of messages to be fetched per buffer.", nullptr));
#endif // QT_CONFIG(tooltip)
        globalUnreadLimit->setSpecialValueText(QCoreApplication::translate("BacklogSettingsPage", "Unlimited", nullptr));
#if QT_CONFIG(tooltip)
        label_14->setToolTip(QCoreApplication::translate("BacklogSettingsPage", "Amount of messages to be fetched in addition to the unread messages. The Limit does not apply here.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_14->setText(QCoreApplication::translate("BacklogSettingsPage", "Additional Messages:", nullptr));
#if QT_CONFIG(tooltip)
        globalUnreadAdditional->setToolTip(QCoreApplication::translate("BacklogSettingsPage", "Amount of messages to be fetched in addition to the unread messages. The Limit does not apply here.", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class BacklogSettingsPage: public Ui_BacklogSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BACKLOGSETTINGSPAGE_H
