/********************************************************************************
** Form generated from reading UI file 'msgprocessorstatuswidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MSGPROCESSORSTATUSWIDGET_H
#define UI_MSGPROCESSORSTATUSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MsgProcessorStatusWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QProgressBar *progressBar;

    void setupUi(QWidget *MsgProcessorStatusWidget)
    {
        if (MsgProcessorStatusWidget->objectName().isEmpty())
            MsgProcessorStatusWidget->setObjectName(QString::fromUtf8("MsgProcessorStatusWidget"));
        MsgProcessorStatusWidget->resize(251, 26);
        QSizePolicy sizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MsgProcessorStatusWidget->sizePolicy().hasHeightForWidth());
        MsgProcessorStatusWidget->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(MsgProcessorStatusWidget);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalLayout->setContentsMargins(4, 0, -1, 0);
        label = new QLabel(MsgProcessorStatusWidget);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        progressBar = new QProgressBar(MsgProcessorStatusWidget);
        progressBar->setObjectName(QString::fromUtf8("progressBar"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(progressBar->sizePolicy().hasHeightForWidth());
        progressBar->setSizePolicy(sizePolicy1);
        progressBar->setValue(24);

        horizontalLayout->addWidget(progressBar);


        retranslateUi(MsgProcessorStatusWidget);

        QMetaObject::connectSlotsByName(MsgProcessorStatusWidget);
    } // setupUi

    void retranslateUi(QWidget *MsgProcessorStatusWidget)
    {
        MsgProcessorStatusWidget->setWindowTitle(QCoreApplication::translate("MsgProcessorStatusWidget", "Form", nullptr));
        label->setText(QCoreApplication::translate("MsgProcessorStatusWidget", "Receiving Backlog", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MsgProcessorStatusWidget: public Ui_MsgProcessorStatusWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MSGPROCESSORSTATUSWIDGET_H
