/****************************************************************************
** Meta object code from reading C++ file 'systemtray.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/systemtray.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'systemtray.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SystemTray_t {
    QByteArrayData data[55];
    char stringdata0[639];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SystemTray_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SystemTray_t qt_meta_stringdata_SystemTray = {
    {
QT_MOC_LITERAL(0, 0, 10), // "SystemTray"
QT_MOC_LITERAL(1, 11, 11), // "modeChanged"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 4), // "Mode"
QT_MOC_LITERAL(4, 29, 4), // "mode"
QT_MOC_LITERAL(5, 34, 12), // "stateChanged"
QT_MOC_LITERAL(6, 47, 5), // "State"
QT_MOC_LITERAL(7, 53, 5), // "state"
QT_MOC_LITERAL(8, 59, 17), // "visibilityChanged"
QT_MOC_LITERAL(9, 77, 9), // "isVisible"
QT_MOC_LITERAL(10, 87, 12), // "iconsChanged"
QT_MOC_LITERAL(11, 100, 22), // "currentIconNameChanged"
QT_MOC_LITERAL(12, 123, 14), // "toolTipChanged"
QT_MOC_LITERAL(13, 138, 5), // "title"
QT_MOC_LITERAL(14, 144, 8), // "subtitle"
QT_MOC_LITERAL(15, 153, 9), // "activated"
QT_MOC_LITERAL(16, 163, 28), // "SystemTray::ActivationReason"
QT_MOC_LITERAL(17, 192, 14), // "messageClicked"
QT_MOC_LITERAL(18, 207, 14), // "notificationId"
QT_MOC_LITERAL(19, 222, 13), // "messageClosed"
QT_MOC_LITERAL(20, 236, 10), // "setVisible"
QT_MOC_LITERAL(21, 247, 7), // "visible"
QT_MOC_LITERAL(22, 255, 8), // "setState"
QT_MOC_LITERAL(23, 264, 8), // "setAlert"
QT_MOC_LITERAL(24, 273, 7), // "alerted"
QT_MOC_LITERAL(25, 281, 10), // "setToolTip"
QT_MOC_LITERAL(26, 292, 11), // "showMessage"
QT_MOC_LITERAL(27, 304, 7), // "message"
QT_MOC_LITERAL(28, 312, 11), // "MessageIcon"
QT_MOC_LITERAL(29, 324, 4), // "icon"
QT_MOC_LITERAL(30, 329, 9), // "msTimeout"
QT_MOC_LITERAL(31, 339, 12), // "closeMessage"
QT_MOC_LITERAL(32, 352, 8), // "activate"
QT_MOC_LITERAL(33, 361, 15), // "minimizeRestore"
QT_MOC_LITERAL(34, 377, 19), // "trayMenuAboutToShow"
QT_MOC_LITERAL(35, 397, 21), // "invertTrayIconChanged"
QT_MOC_LITERAL(36, 419, 24), // "enableChangeColorChanged"
QT_MOC_LITERAL(37, 444, 18), // "enableBlinkChanged"
QT_MOC_LITERAL(38, 463, 14), // "onBlinkTimeout"
QT_MOC_LITERAL(39, 478, 7), // "Passive"
QT_MOC_LITERAL(40, 486, 6), // "Active"
QT_MOC_LITERAL(41, 493, 14), // "NeedsAttention"
QT_MOC_LITERAL(42, 508, 7), // "Invalid"
QT_MOC_LITERAL(43, 516, 6), // "Legacy"
QT_MOC_LITERAL(44, 523, 14), // "StatusNotifier"
QT_MOC_LITERAL(45, 538, 6), // "NoIcon"
QT_MOC_LITERAL(46, 545, 11), // "Information"
QT_MOC_LITERAL(47, 557, 7), // "Warning"
QT_MOC_LITERAL(48, 565, 8), // "Critical"
QT_MOC_LITERAL(49, 574, 16), // "ActivationReason"
QT_MOC_LITERAL(50, 591, 7), // "Unknown"
QT_MOC_LITERAL(51, 599, 7), // "Context"
QT_MOC_LITERAL(52, 607, 11), // "DoubleClick"
QT_MOC_LITERAL(53, 619, 7), // "Trigger"
QT_MOC_LITERAL(54, 627, 11) // "MiddleClick"

    },
    "SystemTray\0modeChanged\0\0Mode\0mode\0"
    "stateChanged\0State\0state\0visibilityChanged\0"
    "isVisible\0iconsChanged\0currentIconNameChanged\0"
    "toolTipChanged\0title\0subtitle\0activated\0"
    "SystemTray::ActivationReason\0"
    "messageClicked\0notificationId\0"
    "messageClosed\0setVisible\0visible\0"
    "setState\0setAlert\0alerted\0setToolTip\0"
    "showMessage\0message\0MessageIcon\0icon\0"
    "msTimeout\0closeMessage\0activate\0"
    "minimizeRestore\0trayMenuAboutToShow\0"
    "invertTrayIconChanged\0enableChangeColorChanged\0"
    "enableBlinkChanged\0onBlinkTimeout\0"
    "Passive\0Active\0NeedsAttention\0Invalid\0"
    "Legacy\0StatusNotifier\0NoIcon\0Information\0"
    "Warning\0Critical\0ActivationReason\0"
    "Unknown\0Context\0DoubleClick\0Trigger\0"
    "MiddleClick"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SystemTray[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      27,   14, // methods
       0,    0, // properties
       4,  240, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  149,    2, 0x06 /* Public */,
       5,    1,  152,    2, 0x06 /* Public */,
       8,    1,  155,    2, 0x06 /* Public */,
      10,    0,  158,    2, 0x06 /* Public */,
      11,    0,  159,    2, 0x06 /* Public */,
      12,    2,  160,    2, 0x06 /* Public */,
      15,    1,  165,    2, 0x06 /* Public */,
      17,    1,  168,    2, 0x06 /* Public */,
      19,    1,  171,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      20,    1,  174,    2, 0x0a /* Public */,
      20,    0,  177,    2, 0x2a /* Public | MethodCloned */,
      22,    1,  178,    2, 0x0a /* Public */,
      23,    1,  181,    2, 0x0a /* Public */,
      25,    2,  184,    2, 0x0a /* Public */,
      26,    5,  189,    2, 0x0a /* Public */,
      26,    4,  200,    2, 0x2a /* Public | MethodCloned */,
      26,    3,  209,    2, 0x2a /* Public | MethodCloned */,
      26,    2,  216,    2, 0x2a /* Public | MethodCloned */,
      31,    1,  221,    2, 0x0a /* Public */,
      32,    1,  224,    2, 0x09 /* Protected */,
      32,    0,  227,    2, 0x29 /* Protected | MethodCloned */,
      33,    0,  228,    2, 0x08 /* Private */,
      34,    0,  229,    2, 0x08 /* Private */,
      35,    1,  230,    2, 0x08 /* Private */,
      36,    1,  233,    2, 0x08 /* Private */,
      37,    1,  236,    2, 0x08 /* Private */,
      38,    0,  239,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   14,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, QMetaType::UInt,   18,
    QMetaType::Void, QMetaType::UInt,   18,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   21,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void, QMetaType::Bool,   24,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   14,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28, QMetaType::Int, QMetaType::UInt,   13,   27,   29,   30,   18,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28, QMetaType::Int,   13,   27,   29,   30,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 28,   13,   27,   29,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   27,
    QMetaType::Void, QMetaType::UInt,   18,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void,

 // enums: name, alias, flags, count, data
       6,    6, 0x0,    3,  260,
       3,    3, 0x0,    3,  266,
      28,   28, 0x0,    4,  272,
      49,   49, 0x0,    5,  280,

 // enum data: key, value
      39, uint(SystemTray::Passive),
      40, uint(SystemTray::Active),
      41, uint(SystemTray::NeedsAttention),
      42, uint(SystemTray::Invalid),
      43, uint(SystemTray::Legacy),
      44, uint(SystemTray::StatusNotifier),
      45, uint(SystemTray::NoIcon),
      46, uint(SystemTray::Information),
      47, uint(SystemTray::Warning),
      48, uint(SystemTray::Critical),
      50, uint(SystemTray::Unknown),
      51, uint(SystemTray::Context),
      52, uint(SystemTray::DoubleClick),
      53, uint(SystemTray::Trigger),
      54, uint(SystemTray::MiddleClick),

       0        // eod
};

void SystemTray::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SystemTray *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->modeChanged((*reinterpret_cast< Mode(*)>(_a[1]))); break;
        case 1: _t->stateChanged((*reinterpret_cast< State(*)>(_a[1]))); break;
        case 2: _t->visibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->iconsChanged(); break;
        case 4: _t->currentIconNameChanged(); break;
        case 5: _t->toolTipChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: _t->activated((*reinterpret_cast< SystemTray::ActivationReason(*)>(_a[1]))); break;
        case 7: _t->messageClicked((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 8: _t->messageClosed((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 9: _t->setVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->setVisible(); break;
        case 11: _t->setState((*reinterpret_cast< State(*)>(_a[1]))); break;
        case 12: _t->setAlert((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->setToolTip((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 14: _t->showMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< MessageIcon(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5]))); break;
        case 15: _t->showMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< MessageIcon(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 16: _t->showMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< MessageIcon(*)>(_a[3]))); break;
        case 17: _t->showMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 18: _t->closeMessage((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 19: _t->activate((*reinterpret_cast< SystemTray::ActivationReason(*)>(_a[1]))); break;
        case 20: _t->activate(); break;
        case 21: _t->minimizeRestore(); break;
        case 22: _t->trayMenuAboutToShow(); break;
        case 23: _t->invertTrayIconChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 24: _t->enableChangeColorChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 25: _t->enableBlinkChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 26: _t->onBlinkTimeout(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SystemTray::*)(Mode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SystemTray::modeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (SystemTray::*)(State );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SystemTray::stateChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (SystemTray::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SystemTray::visibilityChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (SystemTray::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SystemTray::iconsChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (SystemTray::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SystemTray::currentIconNameChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (SystemTray::*)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SystemTray::toolTipChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (SystemTray::*)(SystemTray::ActivationReason );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SystemTray::activated)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (SystemTray::*)(uint );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SystemTray::messageClicked)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (SystemTray::*)(uint );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SystemTray::messageClosed)) {
                *result = 8;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject SystemTray::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_SystemTray.data,
    qt_meta_data_SystemTray,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SystemTray::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SystemTray::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SystemTray.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SystemTray::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void SystemTray::modeChanged(Mode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void SystemTray::stateChanged(State _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void SystemTray::visibilityChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void SystemTray::iconsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SystemTray::currentIconNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SystemTray::toolTipChanged(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void SystemTray::activated(SystemTray::ActivationReason _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void SystemTray::messageClicked(uint _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void SystemTray::messageClosed(uint _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
