/****************************************************************************
** Meta object code from reading C++ file 'identityeditwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/settingspages/identityeditwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'identityeditwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_IdentityEditWidget_t {
    QByteArrayData data[23];
    char stringdata0[356];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_IdentityEditWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_IdentityEditWidget_t qt_meta_stringdata_IdentityEditWidget = {
    {
QT_MOC_LITERAL(0, 0, 18), // "IdentityEditWidget"
QT_MOC_LITERAL(1, 19, 14), // "requestEditSsl"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 16), // "widgetHasChanged"
QT_MOC_LITERAL(4, 52, 11), // "setSslState"
QT_MOC_LITERAL(5, 64, 8), // "SslState"
QT_MOC_LITERAL(6, 73, 5), // "state"
QT_MOC_LITERAL(7, 79, 12), // "showAdvanced"
QT_MOC_LITERAL(8, 92, 8), // "advanced"
QT_MOC_LITERAL(9, 101, 18), // "on_addNick_clicked"
QT_MOC_LITERAL(10, 120, 21), // "on_deleteNick_clicked"
QT_MOC_LITERAL(11, 142, 21), // "on_renameNick_clicked"
QT_MOC_LITERAL(12, 164, 17), // "on_nickUp_clicked"
QT_MOC_LITERAL(13, 182, 19), // "on_nickDown_clicked"
QT_MOC_LITERAL(14, 202, 31), // "on_clearOrLoadKeyButton_clicked"
QT_MOC_LITERAL(15, 234, 32), // "on_clearOrLoadCertButton_clicked"
QT_MOC_LITERAL(16, 267, 15), // "setWidgetStates"
QT_MOC_LITERAL(17, 283, 17), // "sslDragEnterEvent"
QT_MOC_LITERAL(18, 301, 16), // "QDragEnterEvent*"
QT_MOC_LITERAL(19, 318, 5), // "event"
QT_MOC_LITERAL(20, 324, 12), // "sslDropEvent"
QT_MOC_LITERAL(21, 337, 11), // "QDropEvent*"
QT_MOC_LITERAL(22, 349, 6) // "isCert"

    },
    "IdentityEditWidget\0requestEditSsl\0\0"
    "widgetHasChanged\0setSslState\0SslState\0"
    "state\0showAdvanced\0advanced\0"
    "on_addNick_clicked\0on_deleteNick_clicked\0"
    "on_renameNick_clicked\0on_nickUp_clicked\0"
    "on_nickDown_clicked\0on_clearOrLoadKeyButton_clicked\0"
    "on_clearOrLoadCertButton_clicked\0"
    "setWidgetStates\0sslDragEnterEvent\0"
    "QDragEnterEvent*\0event\0sslDropEvent\0"
    "QDropEvent*\0isCert"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_IdentityEditWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   84,    2, 0x06 /* Public */,
       3,    0,   85,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   86,    2, 0x0a /* Public */,
       7,    1,   89,    2, 0x0a /* Public */,
       9,    0,   92,    2, 0x08 /* Private */,
      10,    0,   93,    2, 0x08 /* Private */,
      11,    0,   94,    2, 0x08 /* Private */,
      12,    0,   95,    2, 0x08 /* Private */,
      13,    0,   96,    2, 0x08 /* Private */,
      14,    0,   97,    2, 0x08 /* Private */,
      15,    0,   98,    2, 0x08 /* Private */,
      16,    0,   99,    2, 0x08 /* Private */,
      17,    1,  100,    2, 0x08 /* Private */,
      20,    2,  103,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, 0x80000000 | 21, QMetaType::Bool,   19,   22,

       0        // eod
};

void IdentityEditWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<IdentityEditWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->requestEditSsl(); break;
        case 1: _t->widgetHasChanged(); break;
        case 2: _t->setSslState((*reinterpret_cast< SslState(*)>(_a[1]))); break;
        case 3: _t->showAdvanced((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->on_addNick_clicked(); break;
        case 5: _t->on_deleteNick_clicked(); break;
        case 6: _t->on_renameNick_clicked(); break;
        case 7: _t->on_nickUp_clicked(); break;
        case 8: _t->on_nickDown_clicked(); break;
        case 9: _t->on_clearOrLoadKeyButton_clicked(); break;
        case 10: _t->on_clearOrLoadCertButton_clicked(); break;
        case 11: _t->setWidgetStates(); break;
        case 12: _t->sslDragEnterEvent((*reinterpret_cast< QDragEnterEvent*(*)>(_a[1]))); break;
        case 13: _t->sslDropEvent((*reinterpret_cast< QDropEvent*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (IdentityEditWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IdentityEditWidget::requestEditSsl)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (IdentityEditWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IdentityEditWidget::widgetHasChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject IdentityEditWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_IdentityEditWidget.data,
    qt_meta_data_IdentityEditWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *IdentityEditWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IdentityEditWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_IdentityEditWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int IdentityEditWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void IdentityEditWidget::requestEditSsl()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IdentityEditWidget::widgetHasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
struct qt_meta_stringdata_NickEditDlg_t {
    QByteArrayData data[3];
    char stringdata0[37];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NickEditDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NickEditDlg_t qt_meta_stringdata_NickEditDlg = {
    {
QT_MOC_LITERAL(0, 0, 11), // "NickEditDlg"
QT_MOC_LITERAL(1, 12, 23), // "on_nickEdit_textChanged"
QT_MOC_LITERAL(2, 36, 0) // ""

    },
    "NickEditDlg\0on_nickEdit_textChanged\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NickEditDlg[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void NickEditDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<NickEditDlg *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_nickEdit_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject NickEditDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_NickEditDlg.data,
    qt_meta_data_NickEditDlg,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *NickEditDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NickEditDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NickEditDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int NickEditDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
