/****************************************************************************
** Meta object code from reading C++ file 'sessionthread.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/sessionthread.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessionthread.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SessionThread_t {
    QByteArrayData data[13];
    char stringdata0[163];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SessionThread_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SessionThread_t qt_meta_stringdata_SessionThread = {
    {
QT_MOC_LITERAL(0, 0, 13), // "SessionThread"
QT_MOC_LITERAL(1, 14, 11), // "initialized"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 15), // "shutdownSession"
QT_MOC_LITERAL(4, 43, 16), // "shutdownComplete"
QT_MOC_LITERAL(5, 60, 14), // "SessionThread*"
QT_MOC_LITERAL(6, 75, 17), // "addClientToWorker"
QT_MOC_LITERAL(7, 93, 5), // "Peer*"
QT_MOC_LITERAL(8, 99, 4), // "peer"
QT_MOC_LITERAL(9, 104, 9), // "addClient"
QT_MOC_LITERAL(10, 114, 8), // "shutdown"
QT_MOC_LITERAL(11, 123, 20), // "onSessionInitialized"
QT_MOC_LITERAL(12, 144, 18) // "onSessionDestroyed"

    },
    "SessionThread\0initialized\0\0shutdownSession\0"
    "shutdownComplete\0SessionThread*\0"
    "addClientToWorker\0Peer*\0peer\0addClient\0"
    "shutdown\0onSessionInitialized\0"
    "onSessionDestroyed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SessionThread[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   54,    2, 0x06 /* Public */,
       3,    0,   55,    2, 0x06 /* Public */,
       4,    1,   56,    2, 0x06 /* Public */,
       6,    1,   59,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,   62,    2, 0x0a /* Public */,
      10,    0,   65,    2, 0x0a /* Public */,
      11,    0,   66,    2, 0x08 /* Private */,
      12,    0,   67,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, 0x80000000 | 7,    8,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void SessionThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SessionThread *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->initialized(); break;
        case 1: _t->shutdownSession(); break;
        case 2: _t->shutdownComplete((*reinterpret_cast< SessionThread*(*)>(_a[1]))); break;
        case 3: _t->addClientToWorker((*reinterpret_cast< Peer*(*)>(_a[1]))); break;
        case 4: _t->addClient((*reinterpret_cast< Peer*(*)>(_a[1]))); break;
        case 5: _t->shutdown(); break;
        case 6: _t->onSessionInitialized(); break;
        case 7: _t->onSessionDestroyed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< SessionThread* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SessionThread::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SessionThread::initialized)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (SessionThread::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SessionThread::shutdownSession)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (SessionThread::*)(SessionThread * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SessionThread::shutdownComplete)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (SessionThread::*)(Peer * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SessionThread::addClientToWorker)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject SessionThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_SessionThread.data,
    qt_meta_data_SessionThread,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SessionThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SessionThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SessionThread.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SessionThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void SessionThread::initialized()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SessionThread::shutdownSession()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void SessionThread::shutdownComplete(SessionThread * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void SessionThread::addClientToWorker(Peer * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
