/****************************************************************************
** Meta object code from reading C++ file 'statusnotifieritemdbus.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/statusnotifieritemdbus.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'statusnotifieritemdbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_StatusNotifierItemDBus_t {
    QByteArrayData data[34];
    char stringdata0[382];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_StatusNotifierItemDBus_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_StatusNotifierItemDBus_t qt_meta_stringdata_StatusNotifierItemDBus = {
    {
QT_MOC_LITERAL(0, 0, 22), // "StatusNotifierItemDBus"
QT_MOC_LITERAL(1, 23, 7), // "NewIcon"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 14), // "NewOverlayIcon"
QT_MOC_LITERAL(4, 47, 16), // "NewAttentionIcon"
QT_MOC_LITERAL(5, 64, 10), // "NewToolTip"
QT_MOC_LITERAL(6, 75, 9), // "NewStatus"
QT_MOC_LITERAL(7, 85, 6), // "status"
QT_MOC_LITERAL(8, 92, 11), // "ContextMenu"
QT_MOC_LITERAL(9, 104, 1), // "x"
QT_MOC_LITERAL(10, 106, 1), // "y"
QT_MOC_LITERAL(11, 108, 8), // "Activate"
QT_MOC_LITERAL(12, 117, 17), // "SecondaryActivate"
QT_MOC_LITERAL(13, 135, 6), // "Scroll"
QT_MOC_LITERAL(14, 142, 5), // "delta"
QT_MOC_LITERAL(15, 148, 11), // "orientation"
QT_MOC_LITERAL(16, 160, 8), // "Category"
QT_MOC_LITERAL(17, 169, 2), // "Id"
QT_MOC_LITERAL(18, 172, 5), // "Title"
QT_MOC_LITERAL(19, 178, 6), // "Status"
QT_MOC_LITERAL(20, 185, 8), // "WindowId"
QT_MOC_LITERAL(21, 194, 8), // "IconName"
QT_MOC_LITERAL(22, 203, 10), // "IconPixmap"
QT_MOC_LITERAL(23, 214, 15), // "DBusImageVector"
QT_MOC_LITERAL(24, 230, 15), // "OverlayIconName"
QT_MOC_LITERAL(25, 246, 17), // "OverlayIconPixmap"
QT_MOC_LITERAL(26, 264, 17), // "AttentionIconName"
QT_MOC_LITERAL(27, 282, 19), // "AttentionIconPixmap"
QT_MOC_LITERAL(28, 302, 18), // "AttentionMovieName"
QT_MOC_LITERAL(29, 321, 7), // "ToolTip"
QT_MOC_LITERAL(30, 329, 17), // "DBusToolTipStruct"
QT_MOC_LITERAL(31, 347, 13), // "IconThemePath"
QT_MOC_LITERAL(32, 361, 4), // "Menu"
QT_MOC_LITERAL(33, 366, 15) // "QDBusObjectPath"

    },
    "StatusNotifierItemDBus\0NewIcon\0\0"
    "NewOverlayIcon\0NewAttentionIcon\0"
    "NewToolTip\0NewStatus\0status\0ContextMenu\0"
    "x\0y\0Activate\0SecondaryActivate\0Scroll\0"
    "delta\0orientation\0Category\0Id\0Title\0"
    "Status\0WindowId\0IconName\0IconPixmap\0"
    "DBusImageVector\0OverlayIconName\0"
    "OverlayIconPixmap\0AttentionIconName\0"
    "AttentionIconPixmap\0AttentionMovieName\0"
    "ToolTip\0DBusToolTipStruct\0IconThemePath\0"
    "Menu\0QDBusObjectPath"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_StatusNotifierItemDBus[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
      15,   86, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    0,   60,    2, 0x06 /* Public */,
       4,    0,   61,    2, 0x06 /* Public */,
       5,    0,   62,    2, 0x06 /* Public */,
       6,    1,   63,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    2,   66,    2, 0x0a /* Public */,
      11,    2,   71,    2, 0x0a /* Public */,
      12,    2,   76,    2, 0x0a /* Public */,
      13,    2,   81,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   10,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   10,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    9,   10,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   14,   15,

 // properties: name, type, flags
      16, QMetaType::QString, 0x00095001,
      17, QMetaType::QString, 0x00095001,
      18, QMetaType::QString, 0x00095001,
      19, QMetaType::QString, 0x00095001,
      20, QMetaType::Int, 0x00095001,
      21, QMetaType::QString, 0x00095001,
      22, 0x80000000 | 23, 0x00095009,
      24, QMetaType::QString, 0x00095001,
      25, 0x80000000 | 23, 0x00095009,
      26, QMetaType::QString, 0x00095001,
      27, 0x80000000 | 23, 0x00095009,
      28, QMetaType::QString, 0x00095001,
      29, 0x80000000 | 30, 0x00095009,
      31, QMetaType::QString, 0x00095001,
      32, 0x80000000 | 33, 0x00095009,

       0        // eod
};

void StatusNotifierItemDBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<StatusNotifierItemDBus *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->NewIcon(); break;
        case 1: _t->NewOverlayIcon(); break;
        case 2: _t->NewAttentionIcon(); break;
        case 3: _t->NewToolTip(); break;
        case 4: _t->NewStatus((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->ContextMenu((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 6: _t->Activate((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->SecondaryActivate((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 8: _t->Scroll((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (StatusNotifierItemDBus::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StatusNotifierItemDBus::NewIcon)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (StatusNotifierItemDBus::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StatusNotifierItemDBus::NewOverlayIcon)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (StatusNotifierItemDBus::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StatusNotifierItemDBus::NewAttentionIcon)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (StatusNotifierItemDBus::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StatusNotifierItemDBus::NewToolTip)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (StatusNotifierItemDBus::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&StatusNotifierItemDBus::NewStatus)) {
                *result = 4;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
        case 8:
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DBusImageVector >(); break;
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DBusToolTipStruct >(); break;
        case 14:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QDBusObjectPath >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<StatusNotifierItemDBus *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->Category(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->Id(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->Title(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->Status(); break;
        case 4: *reinterpret_cast< int*>(_v) = _t->WindowId(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->IconName(); break;
        case 6: *reinterpret_cast< DBusImageVector*>(_v) = _t->IconPixmap(); break;
        case 7: *reinterpret_cast< QString*>(_v) = _t->OverlayIconName(); break;
        case 8: *reinterpret_cast< DBusImageVector*>(_v) = _t->OverlayIconPixmap(); break;
        case 9: *reinterpret_cast< QString*>(_v) = _t->AttentionIconName(); break;
        case 10: *reinterpret_cast< DBusImageVector*>(_v) = _t->AttentionIconPixmap(); break;
        case 11: *reinterpret_cast< QString*>(_v) = _t->AttentionMovieName(); break;
        case 12: *reinterpret_cast< DBusToolTipStruct*>(_v) = _t->ToolTip(); break;
        case 13: *reinterpret_cast< QString*>(_v) = _t->IconThemePath(); break;
        case 14: *reinterpret_cast< QDBusObjectPath*>(_v) = _t->Menu(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject StatusNotifierItemDBus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_StatusNotifierItemDBus.data,
    qt_meta_data_StatusNotifierItemDBus,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *StatusNotifierItemDBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StatusNotifierItemDBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_StatusNotifierItemDBus.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int StatusNotifierItemDBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 15;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 15;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void StatusNotifierItemDBus::NewIcon()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void StatusNotifierItemDBus::NewOverlayIcon()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void StatusNotifierItemDBus::NewAttentionIcon()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void StatusNotifierItemDBus::NewToolTip()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void StatusNotifierItemDBus::NewStatus(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
