/****************************************************************************
** Meta object code from reading C++ file 'qtuimessageprocessor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/qtuimessageprocessor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtuimessageprocessor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtUiMessageProcessor_t {
    QByteArrayData data[15];
    char stringdata0[187];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtUiMessageProcessor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtUiMessageProcessor_t qt_meta_stringdata_QtUiMessageProcessor = {
    {
QT_MOC_LITERAL(0, 0, 20), // "QtUiMessageProcessor"
QT_MOC_LITERAL(1, 21, 7), // "process"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 8), // "Message&"
QT_MOC_LITERAL(4, 39, 3), // "msg"
QT_MOC_LITERAL(5, 43, 15), // "QList<Message>&"
QT_MOC_LITERAL(6, 59, 4), // "msgs"
QT_MOC_LITERAL(7, 64, 14), // "networkRemoved"
QT_MOC_LITERAL(8, 79, 9), // "NetworkId"
QT_MOC_LITERAL(9, 89, 2), // "id"
QT_MOC_LITERAL(10, 92, 18), // "processNextMessage"
QT_MOC_LITERAL(11, 111, 25), // "nicksCaseSensitiveChanged"
QT_MOC_LITERAL(12, 137, 7), // "variant"
QT_MOC_LITERAL(13, 145, 20), // "highlightListChanged"
QT_MOC_LITERAL(14, 166, 20) // "highlightNickChanged"

    },
    "QtUiMessageProcessor\0process\0\0Message&\0"
    "msg\0QList<Message>&\0msgs\0networkRemoved\0"
    "NetworkId\0id\0processNextMessage\0"
    "nicksCaseSensitiveChanged\0variant\0"
    "highlightListChanged\0highlightNickChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtUiMessageProcessor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x0a /* Public */,
       1,    1,   52,    2, 0x0a /* Public */,
       7,    1,   55,    2, 0x0a /* Public */,
      10,    0,   58,    2, 0x08 /* Private */,
      11,    1,   59,    2, 0x08 /* Private */,
      13,    1,   62,    2, 0x08 /* Private */,
      14,    1,   65,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QVariant,   12,
    QMetaType::Void, QMetaType::QVariant,   12,
    QMetaType::Void, QMetaType::QVariant,   12,

       0        // eod
};

void QtUiMessageProcessor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QtUiMessageProcessor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->process((*reinterpret_cast< Message(*)>(_a[1]))); break;
        case 1: _t->process((*reinterpret_cast< QList<Message>(*)>(_a[1]))); break;
        case 2: _t->networkRemoved((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 3: _t->processNextMessage(); break;
        case 4: _t->nicksCaseSensitiveChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 5: _t->highlightListChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 6: _t->highlightNickChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QtUiMessageProcessor::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractMessageProcessor::staticMetaObject>(),
    qt_meta_stringdata_QtUiMessageProcessor.data,
    qt_meta_data_QtUiMessageProcessor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtUiMessageProcessor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtUiMessageProcessor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtUiMessageProcessor.stringdata0))
        return static_cast<void*>(this);
    return AbstractMessageProcessor::qt_metacast(_clname);
}

int QtUiMessageProcessor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractMessageProcessor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
