/****************************************************************************
** Meta object code from reading C++ file 'topicwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/topicwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'topicwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_TopicWidget_t {
    QByteArrayData data[19];
    char stringdata0[263];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TopicWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TopicWidget_t qt_meta_stringdata_TopicWidget = {
    {
QT_MOC_LITERAL(0, 0, 11), // "TopicWidget"
QT_MOC_LITERAL(1, 12, 13), // "switchedPlain"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 14), // "currentChanged"
QT_MOC_LITERAL(4, 42, 11), // "QModelIndex"
QT_MOC_LITERAL(5, 54, 7), // "current"
QT_MOC_LITERAL(6, 62, 8), // "previous"
QT_MOC_LITERAL(7, 71, 11), // "dataChanged"
QT_MOC_LITERAL(8, 83, 7), // "topLeft"
QT_MOC_LITERAL(9, 91, 11), // "bottomRight"
QT_MOC_LITERAL(10, 103, 28), // "on_topicLineEdit_textEntered"
QT_MOC_LITERAL(11, 132, 26), // "on_topicEditButton_clicked"
QT_MOC_LITERAL(12, 159, 14), // "switchEditable"
QT_MOC_LITERAL(13, 174, 11), // "switchPlain"
QT_MOC_LITERAL(14, 186, 18), // "clickableActivated"
QT_MOC_LITERAL(15, 205, 9), // "Clickable"
QT_MOC_LITERAL(16, 215, 16), // "updateResizeMode"
QT_MOC_LITERAL(17, 232, 13), // "setCustomFont"
QT_MOC_LITERAL(18, 246, 16) // "setUseCustomFont"

    },
    "TopicWidget\0switchedPlain\0\0currentChanged\0"
    "QModelIndex\0current\0previous\0dataChanged\0"
    "topLeft\0bottomRight\0on_topicLineEdit_textEntered\0"
    "on_topicEditButton_clicked\0switchEditable\0"
    "switchPlain\0clickableActivated\0Clickable\0"
    "updateResizeMode\0setCustomFont\0"
    "setUseCustomFont"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TopicWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    2,   70,    2, 0x09 /* Protected */,
       7,    2,   75,    2, 0x09 /* Protected */,
      10,    0,   80,    2, 0x08 /* Private */,
      11,    0,   81,    2, 0x08 /* Private */,
      12,    0,   82,    2, 0x08 /* Private */,
      13,    0,   83,    2, 0x08 /* Private */,
      14,    1,   84,    2, 0x08 /* Private */,
      16,    0,   87,    2, 0x08 /* Private */,
      17,    1,   88,    2, 0x08 /* Private */,
      18,    1,   91,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4,    5,    6,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4,    8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void, QMetaType::QVariant,    2,

       0        // eod
};

void TopicWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<TopicWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->switchedPlain(); break;
        case 1: _t->currentChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 2: _t->dataChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 3: _t->on_topicLineEdit_textEntered(); break;
        case 4: _t->on_topicEditButton_clicked(); break;
        case 5: _t->switchEditable(); break;
        case 6: _t->switchPlain(); break;
        case 7: _t->clickableActivated((*reinterpret_cast< const Clickable(*)>(_a[1]))); break;
        case 8: _t->updateResizeMode(); break;
        case 9: _t->setCustomFont((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 10: _t->setUseCustomFont((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (TopicWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TopicWidget::switchedPlain)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject TopicWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractItemView::staticMetaObject>(),
    qt_meta_stringdata_TopicWidget.data,
    qt_meta_data_TopicWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *TopicWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TopicWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TopicWidget.stringdata0))
        return static_cast<void*>(this);
    return AbstractItemView::qt_metacast(_clname);
}

int TopicWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractItemView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void TopicWidget::switchedPlain()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
