/********************************************************************************
** Form generated from reading UI file 'appearancesettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_APPEARANCESETTINGSPAGE_H
#define UI_APPEARANCESETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AppearanceSettingsPage
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_9;
    QComboBox *languageComboBox;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label_2;
    QComboBox *styleComboBox;
    QLabel *iconThemeLabel;
    QComboBox *iconThemeComboBox;
    QCheckBox *overrideSystemIconTheme;
    QHBoxLayout *horizontalLayout;
    QCheckBox *useCustomStyleSheet;
    QLineEdit *customStyleSheetPath;
    QToolButton *chooseStyleSheet;
    QGridLayout *gridLayout_3;
    QSpacerItem *horizontalSpacer;
    QCheckBox *useSystemTrayIcon;
    QCheckBox *invertSystrayColors;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *horizontalSpacer_6;
    QCheckBox *minimizeOnClose;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_2;
    QLabel *label_3;
    QCheckBox *userNoticesInDefaultBuffer;
    QCheckBox *userNoticesInStatusBuffer;
    QCheckBox *userNoticesInCurrentBuffer;
    QLabel *label_4;
    QCheckBox *serverNoticesInDefaultBuffer;
    QLabel *label_5;
    QLabel *label_6;
    QLabel *label_7;
    QLabel *label_8;
    QCheckBox *serverNoticesInStatusBuffer;
    QCheckBox *serverNoticesInCurrentBuffer;
    QCheckBox *errorMsgsInDefaultBuffer;
    QCheckBox *errorMsgsInStatusBuffer;
    QCheckBox *errorMsgsInCurrentBuffer;
    QSpacerItem *horizontalSpacer_5;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *AppearanceSettingsPage)
    {
        if (AppearanceSettingsPage->objectName().isEmpty())
            AppearanceSettingsPage->setObjectName(QString::fromUtf8("AppearanceSettingsPage"));
        AppearanceSettingsPage->resize(755, 463);
        verticalLayout = new QVBoxLayout(AppearanceSettingsPage);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_9 = new QLabel(AppearanceSettingsPage);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        gridLayout->addWidget(label_9, 0, 0, 1, 1);

        languageComboBox = new QComboBox(AppearanceSettingsPage);
        languageComboBox->addItem(QString());
        languageComboBox->addItem(QString());
        languageComboBox->setObjectName(QString::fromUtf8("languageComboBox"));

        gridLayout->addWidget(languageComboBox, 0, 1, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 0, 2, 1, 1);

        label_2 = new QLabel(AppearanceSettingsPage);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        styleComboBox = new QComboBox(AppearanceSettingsPage);
        styleComboBox->setObjectName(QString::fromUtf8("styleComboBox"));

        gridLayout->addWidget(styleComboBox, 1, 1, 1, 1);

        iconThemeLabel = new QLabel(AppearanceSettingsPage);
        iconThemeLabel->setObjectName(QString::fromUtf8("iconThemeLabel"));

        gridLayout->addWidget(iconThemeLabel, 2, 0, 1, 1);

        iconThemeComboBox = new QComboBox(AppearanceSettingsPage);
        iconThemeComboBox->setObjectName(QString::fromUtf8("iconThemeComboBox"));

        gridLayout->addWidget(iconThemeComboBox, 2, 1, 1, 1);

        overrideSystemIconTheme = new QCheckBox(AppearanceSettingsPage);
        overrideSystemIconTheme->setObjectName(QString::fromUtf8("overrideSystemIconTheme"));
        overrideSystemIconTheme->setChecked(true);
        overrideSystemIconTheme->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Icons/OverrideSystemTheme")));
        overrideSystemIconTheme->setProperty("defaultValue", QVariant(true));

        gridLayout->addWidget(overrideSystemIconTheme, 2, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        useCustomStyleSheet = new QCheckBox(AppearanceSettingsPage);
        useCustomStyleSheet->setObjectName(QString::fromUtf8("useCustomStyleSheet"));
        useCustomStyleSheet->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/UseCustomStyleSheet")));
        useCustomStyleSheet->setProperty("defaultValue", QVariant(false));

        horizontalLayout->addWidget(useCustomStyleSheet);

        customStyleSheetPath = new QLineEdit(AppearanceSettingsPage);
        customStyleSheetPath->setObjectName(QString::fromUtf8("customStyleSheetPath"));
        customStyleSheetPath->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(customStyleSheetPath->sizePolicy().hasHeightForWidth());
        customStyleSheetPath->setSizePolicy(sizePolicy);
        customStyleSheetPath->setReadOnly(false);
        customStyleSheetPath->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/CustomStyleSheetPath")));

        horizontalLayout->addWidget(customStyleSheetPath);

        chooseStyleSheet = new QToolButton(AppearanceSettingsPage);
        chooseStyleSheet->setObjectName(QString::fromUtf8("chooseStyleSheet"));
        chooseStyleSheet->setEnabled(false);

        horizontalLayout->addWidget(chooseStyleSheet);


        verticalLayout->addLayout(horizontalLayout);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer, 1, 2, 1, 1);

        useSystemTrayIcon = new QCheckBox(AppearanceSettingsPage);
        useSystemTrayIcon->setObjectName(QString::fromUtf8("useSystemTrayIcon"));
        useSystemTrayIcon->setChecked(true);
        useSystemTrayIcon->setProperty("settingsKey", QVariant(QString::fromUtf8("UseSystemTrayIcon")));
        useSystemTrayIcon->setProperty("defaultValue", QVariant(true));

        gridLayout_3->addWidget(useSystemTrayIcon, 0, 0, 1, 2);

        invertSystrayColors = new QCheckBox(AppearanceSettingsPage);
        invertSystrayColors->setObjectName(QString::fromUtf8("invertSystrayColors"));
        invertSystrayColors->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Icons/InvertTray")));
        invertSystrayColors->setProperty("defaultValue", QVariant(false));

        gridLayout_3->addWidget(invertSystrayColors, 2, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 1, 0, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_6, 2, 0, 1, 1);

        minimizeOnClose = new QCheckBox(AppearanceSettingsPage);
        minimizeOnClose->setObjectName(QString::fromUtf8("minimizeOnClose"));
        minimizeOnClose->setProperty("settingsKey", QVariant(QString::fromUtf8("MinimizeOnClose")));
        minimizeOnClose->setProperty("defaultValue", QVariant(false));

        gridLayout_3->addWidget(minimizeOnClose, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout_3);

        groupBox_3 = new QGroupBox(AppearanceSettingsPage);
        groupBox_3->setObjectName(QString::fromUtf8("groupBox_3"));
        gridLayout_2 = new QGridLayout(groupBox_3);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        gridLayout_2->setHorizontalSpacing(20);
        label_3 = new QLabel(groupBox_3);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout_2->addWidget(label_3, 1, 0, 1, 1);

        userNoticesInDefaultBuffer = new QCheckBox(groupBox_3);
        userNoticesInDefaultBuffer->setObjectName(QString::fromUtf8("userNoticesInDefaultBuffer"));
        userNoticesInDefaultBuffer->setEnabled(true);
        userNoticesInDefaultBuffer->setChecked(true);

        gridLayout_2->addWidget(userNoticesInDefaultBuffer, 1, 1, 1, 1);

        userNoticesInStatusBuffer = new QCheckBox(groupBox_3);
        userNoticesInStatusBuffer->setObjectName(QString::fromUtf8("userNoticesInStatusBuffer"));
        userNoticesInStatusBuffer->setEnabled(true);
        userNoticesInStatusBuffer->setChecked(false);

        gridLayout_2->addWidget(userNoticesInStatusBuffer, 1, 2, 1, 1);

        userNoticesInCurrentBuffer = new QCheckBox(groupBox_3);
        userNoticesInCurrentBuffer->setObjectName(QString::fromUtf8("userNoticesInCurrentBuffer"));
        userNoticesInCurrentBuffer->setEnabled(true);

        gridLayout_2->addWidget(userNoticesInCurrentBuffer, 1, 3, 1, 1);

        label_4 = new QLabel(groupBox_3);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout_2->addWidget(label_4, 2, 0, 1, 1);

        serverNoticesInDefaultBuffer = new QCheckBox(groupBox_3);
        serverNoticesInDefaultBuffer->setObjectName(QString::fromUtf8("serverNoticesInDefaultBuffer"));

        gridLayout_2->addWidget(serverNoticesInDefaultBuffer, 2, 1, 1, 1);

        label_5 = new QLabel(groupBox_3);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout_2->addWidget(label_5, 0, 1, 1, 1);

        label_6 = new QLabel(groupBox_3);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout_2->addWidget(label_6, 0, 2, 1, 1);

        label_7 = new QLabel(groupBox_3);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout_2->addWidget(label_7, 0, 3, 1, 1);

        label_8 = new QLabel(groupBox_3);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        gridLayout_2->addWidget(label_8, 3, 0, 1, 1);

        serverNoticesInStatusBuffer = new QCheckBox(groupBox_3);
        serverNoticesInStatusBuffer->setObjectName(QString::fromUtf8("serverNoticesInStatusBuffer"));
        serverNoticesInStatusBuffer->setChecked(true);

        gridLayout_2->addWidget(serverNoticesInStatusBuffer, 2, 2, 1, 1);

        serverNoticesInCurrentBuffer = new QCheckBox(groupBox_3);
        serverNoticesInCurrentBuffer->setObjectName(QString::fromUtf8("serverNoticesInCurrentBuffer"));

        gridLayout_2->addWidget(serverNoticesInCurrentBuffer, 2, 3, 1, 1);

        errorMsgsInDefaultBuffer = new QCheckBox(groupBox_3);
        errorMsgsInDefaultBuffer->setObjectName(QString::fromUtf8("errorMsgsInDefaultBuffer"));
        errorMsgsInDefaultBuffer->setChecked(true);

        gridLayout_2->addWidget(errorMsgsInDefaultBuffer, 3, 1, 1, 1);

        errorMsgsInStatusBuffer = new QCheckBox(groupBox_3);
        errorMsgsInStatusBuffer->setObjectName(QString::fromUtf8("errorMsgsInStatusBuffer"));

        gridLayout_2->addWidget(errorMsgsInStatusBuffer, 3, 2, 1, 1);

        errorMsgsInCurrentBuffer = new QCheckBox(groupBox_3);
        errorMsgsInCurrentBuffer->setObjectName(QString::fromUtf8("errorMsgsInCurrentBuffer"));

        gridLayout_2->addWidget(errorMsgsInCurrentBuffer, 3, 3, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_5, 0, 4, 1, 1);

        gridLayout_2->setColumnStretch(4, 1);

        verticalLayout->addWidget(groupBox_3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        QWidget::setTabOrder(languageComboBox, styleComboBox);
        QWidget::setTabOrder(styleComboBox, iconThemeComboBox);
        QWidget::setTabOrder(iconThemeComboBox, overrideSystemIconTheme);
        QWidget::setTabOrder(overrideSystemIconTheme, useCustomStyleSheet);
        QWidget::setTabOrder(useCustomStyleSheet, chooseStyleSheet);
        QWidget::setTabOrder(chooseStyleSheet, customStyleSheetPath);
        QWidget::setTabOrder(customStyleSheetPath, useSystemTrayIcon);
        QWidget::setTabOrder(useSystemTrayIcon, minimizeOnClose);
        QWidget::setTabOrder(minimizeOnClose, invertSystrayColors);
        QWidget::setTabOrder(invertSystrayColors, userNoticesInDefaultBuffer);
        QWidget::setTabOrder(userNoticesInDefaultBuffer, userNoticesInStatusBuffer);
        QWidget::setTabOrder(userNoticesInStatusBuffer, userNoticesInCurrentBuffer);
        QWidget::setTabOrder(userNoticesInCurrentBuffer, serverNoticesInDefaultBuffer);
        QWidget::setTabOrder(serverNoticesInDefaultBuffer, serverNoticesInStatusBuffer);
        QWidget::setTabOrder(serverNoticesInStatusBuffer, serverNoticesInCurrentBuffer);
        QWidget::setTabOrder(serverNoticesInCurrentBuffer, errorMsgsInDefaultBuffer);
        QWidget::setTabOrder(errorMsgsInDefaultBuffer, errorMsgsInStatusBuffer);
        QWidget::setTabOrder(errorMsgsInStatusBuffer, errorMsgsInCurrentBuffer);

        retranslateUi(AppearanceSettingsPage);
        QObject::connect(useCustomStyleSheet, SIGNAL(toggled(bool)), customStyleSheetPath, SLOT(setEnabled(bool)));
        QObject::connect(useCustomStyleSheet, SIGNAL(toggled(bool)), chooseStyleSheet, SLOT(setEnabled(bool)));
        QObject::connect(useSystemTrayIcon, SIGNAL(toggled(bool)), minimizeOnClose, SLOT(setEnabled(bool)));
        QObject::connect(useSystemTrayIcon, SIGNAL(toggled(bool)), invertSystrayColors, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(AppearanceSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *AppearanceSettingsPage)
    {
        AppearanceSettingsPage->setWindowTitle(QCoreApplication::translate("AppearanceSettingsPage", "Form", nullptr));
        label_9->setText(QCoreApplication::translate("AppearanceSettingsPage", "Language:", nullptr));
        languageComboBox->setItemText(0, QCoreApplication::translate("AppearanceSettingsPage", "<Untranslated>", nullptr));
        languageComboBox->setItemText(1, QCoreApplication::translate("AppearanceSettingsPage", "<System Default>", nullptr));

#if QT_CONFIG(tooltip)
        languageComboBox->setToolTip(QCoreApplication::translate("AppearanceSettingsPage", "Set the application language. Requires restart!", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(QCoreApplication::translate("AppearanceSettingsPage", "Widget style:", nullptr));
#if QT_CONFIG(tooltip)
        styleComboBox->setToolTip(QCoreApplication::translate("AppearanceSettingsPage", "Set application style", nullptr));
#endif // QT_CONFIG(tooltip)
        iconThemeLabel->setText(QCoreApplication::translate("AppearanceSettingsPage", "Fallback icon theme:", nullptr));
#if QT_CONFIG(tooltip)
        iconThemeComboBox->setToolTip(QCoreApplication::translate("AppearanceSettingsPage", "<html><head/><body><p>Icon theme to use for icons that are not found in the current system theme. Requires the selected theme to be installed either system-wide, or as part of the Quassel installation.</p><p>Supported themes are Breeze, Breeze Dark and Oxygen, all of KDE fame.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        overrideSystemIconTheme->setToolTip(QCoreApplication::translate("AppearanceSettingsPage", "<html><head/><body><p>If enabled, uses the selected fallback icon theme instead of the configured system theme for all icons. Recommended if you want Quassel to have a consistent look-and-feel.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        overrideSystemIconTheme->setText(QCoreApplication::translate("AppearanceSettingsPage", "Override system theme", nullptr));
        useCustomStyleSheet->setText(QCoreApplication::translate("AppearanceSettingsPage", "Use custom stylesheet", nullptr));
        customStyleSheetPath->setProperty("defaultValue", QVariant(QString()));
        chooseStyleSheet->setText(QCoreApplication::translate("AppearanceSettingsPage", "...", nullptr));
        useSystemTrayIcon->setText(QCoreApplication::translate("AppearanceSettingsPage", "Show system tray icon", nullptr));
        invertSystrayColors->setText(QCoreApplication::translate("AppearanceSettingsPage", "Invert brightness", nullptr));
        minimizeOnClose->setText(QCoreApplication::translate("AppearanceSettingsPage", "Hide to tray on close button", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("AppearanceSettingsPage", "Message Redirection", nullptr));
        label_3->setText(QCoreApplication::translate("AppearanceSettingsPage", "User Notices:", nullptr));
        userNoticesInDefaultBuffer->setText(QString());
        userNoticesInStatusBuffer->setText(QString());
        userNoticesInCurrentBuffer->setText(QString());
        label_4->setText(QCoreApplication::translate("AppearanceSettingsPage", "Server Notices:", nullptr));
        serverNoticesInDefaultBuffer->setText(QString());
        label_5->setText(QCoreApplication::translate("AppearanceSettingsPage", "Default Target", nullptr));
        label_6->setText(QCoreApplication::translate("AppearanceSettingsPage", "Status Window", nullptr));
        label_7->setText(QCoreApplication::translate("AppearanceSettingsPage", "Current Chat", nullptr));
        label_8->setText(QCoreApplication::translate("AppearanceSettingsPage", "Errors:", nullptr));
        serverNoticesInStatusBuffer->setText(QString());
        serverNoticesInCurrentBuffer->setText(QString());
        errorMsgsInDefaultBuffer->setText(QString());
        errorMsgsInStatusBuffer->setText(QString());
        errorMsgsInCurrentBuffer->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class AppearanceSettingsPage: public Ui_AppearanceSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_APPEARANCESETTINGSPAGE_H
