/********************************************************************************
** Form generated from reading UI file 'coreaccounteditdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COREACCOUNTEDITDLG_H
#define UI_COREACCOUNTEDITDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_CoreAccountEditDlg
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_3;
    QLabel *label;
    QLineEdit *accountName;
    QLabel *label_2;
    QLineEdit *hostName;
    QLabel *label_3;
    QSpinBox *port;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_4;
    QLineEdit *user;
    QLabel *label_10;
    QLineEdit *password;
    QCheckBox *rememberPassword;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QLabel *label_7;
    QComboBox *proxyType;
    QSpacerItem *horizontalSpacer;
    QLabel *label_6;
    QLineEdit *proxyHostName;
    QLineEdit *proxyUser;
    QSpinBox *proxyPort;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label_8;
    QLabel *label_9;
    QLineEdit *proxyPassword;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *horizontalSpacer_5;
    QLabel *label_5;
    QVBoxLayout *verticalLayoutProxyRadioGroup;
    QRadioButton *radioButtonNoProxy;
    QRadioButton *radioButtonSystemProxy;
    QRadioButton *radioButtonManualProxy;
    QSpacerItem *spacerItem;
    QDialogButtonBox *buttonBox;
    QButtonGroup *buttonGroupProxyType;

    void setupUi(QDialog *CoreAccountEditDlg)
    {
        if (CoreAccountEditDlg->objectName().isEmpty())
            CoreAccountEditDlg->setObjectName(QString::fromUtf8("CoreAccountEditDlg"));
        CoreAccountEditDlg->resize(398, 602);
        verticalLayout = new QVBoxLayout(CoreAccountEditDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        groupBox = new QGroupBox(CoreAccountEditDlg);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        gridLayout_3 = new QGridLayout(groupBox);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        label = new QLabel(groupBox);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout_3->addWidget(label, 0, 0, 1, 1);

        accountName = new QLineEdit(groupBox);
        accountName->setObjectName(QString::fromUtf8("accountName"));

        gridLayout_3->addWidget(accountName, 0, 1, 1, 3);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout_3->addWidget(label_2, 1, 0, 1, 1);

        hostName = new QLineEdit(groupBox);
        hostName->setObjectName(QString::fromUtf8("hostName"));

        gridLayout_3->addWidget(hostName, 1, 1, 1, 3);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout_3->addWidget(label_3, 2, 0, 1, 1);

        port = new QSpinBox(groupBox);
        port->setObjectName(QString::fromUtf8("port"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(port->sizePolicy().hasHeightForWidth());
        port->setSizePolicy(sizePolicy);
        port->setMinimum(1);
        port->setMaximum(65535);
        port->setValue(4242);

        gridLayout_3->addWidget(port, 2, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(63, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_2, 2, 2, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout_3->addWidget(label_4, 3, 0, 1, 1);

        user = new QLineEdit(groupBox);
        user->setObjectName(QString::fromUtf8("user"));

        gridLayout_3->addWidget(user, 3, 1, 1, 2);

        label_10 = new QLabel(groupBox);
        label_10->setObjectName(QString::fromUtf8("label_10"));

        gridLayout_3->addWidget(label_10, 4, 0, 1, 1);

        password = new QLineEdit(groupBox);
        password->setObjectName(QString::fromUtf8("password"));
        password->setEchoMode(QLineEdit::Password);

        gridLayout_3->addWidget(password, 4, 1, 1, 2);

        rememberPassword = new QCheckBox(groupBox);
        rememberPassword->setObjectName(QString::fromUtf8("rememberPassword"));

        gridLayout_3->addWidget(rememberPassword, 4, 3, 1, 1);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(CoreAccountEditDlg);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_7 = new QLabel(groupBox_2);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout->addWidget(label_7, 3, 0, 1, 1);

        proxyType = new QComboBox(groupBox_2);
        proxyType->addItem(QString());
        proxyType->addItem(QString());
        proxyType->setObjectName(QString::fromUtf8("proxyType"));
        proxyType->setEnabled(false);

        gridLayout->addWidget(proxyType, 1, 2, 1, 2);

        horizontalSpacer = new QSpacerItem(89, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 4, 1, 1);

        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout->addWidget(label_6, 2, 0, 1, 1);

        proxyHostName = new QLineEdit(groupBox_2);
        proxyHostName->setObjectName(QString::fromUtf8("proxyHostName"));
        proxyHostName->setEnabled(false);

        gridLayout->addWidget(proxyHostName, 2, 2, 1, 4);

        proxyUser = new QLineEdit(groupBox_2);
        proxyUser->setObjectName(QString::fromUtf8("proxyUser"));
        proxyUser->setEnabled(false);

        gridLayout->addWidget(proxyUser, 4, 2, 1, 3);

        proxyPort = new QSpinBox(groupBox_2);
        proxyPort->setObjectName(QString::fromUtf8("proxyPort"));
        proxyPort->setEnabled(false);
        sizePolicy.setHeightForWidth(proxyPort->sizePolicy().hasHeightForWidth());
        proxyPort->setSizePolicy(sizePolicy);
        proxyPort->setMinimum(1);
        proxyPort->setMaximum(65535);
        proxyPort->setValue(8080);

        gridLayout->addWidget(proxyPort, 3, 2, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(98, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 3, 3, 1, 2);

        label_8 = new QLabel(groupBox_2);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        gridLayout->addWidget(label_8, 4, 0, 1, 1);

        label_9 = new QLabel(groupBox_2);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        gridLayout->addWidget(label_9, 5, 0, 1, 1);

        proxyPassword = new QLineEdit(groupBox_2);
        proxyPassword->setObjectName(QString::fromUtf8("proxyPassword"));
        proxyPassword->setEnabled(false);
        proxyPassword->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(proxyPassword, 5, 2, 1, 3);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 4, 5, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_5, 5, 5, 1, 1);

        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout->addWidget(label_5, 1, 0, 1, 1);

        verticalLayoutProxyRadioGroup = new QVBoxLayout();
        verticalLayoutProxyRadioGroup->setObjectName(QString::fromUtf8("verticalLayoutProxyRadioGroup"));
        radioButtonNoProxy = new QRadioButton(groupBox_2);
        buttonGroupProxyType = new QButtonGroup(CoreAccountEditDlg);
        buttonGroupProxyType->setObjectName(QString::fromUtf8("buttonGroupProxyType"));
        buttonGroupProxyType->addButton(radioButtonNoProxy);
        radioButtonNoProxy->setObjectName(QString::fromUtf8("radioButtonNoProxy"));

        verticalLayoutProxyRadioGroup->addWidget(radioButtonNoProxy);

        radioButtonSystemProxy = new QRadioButton(groupBox_2);
        buttonGroupProxyType->addButton(radioButtonSystemProxy);
        radioButtonSystemProxy->setObjectName(QString::fromUtf8("radioButtonSystemProxy"));
        radioButtonSystemProxy->setChecked(true);

        verticalLayoutProxyRadioGroup->addWidget(radioButtonSystemProxy);

        radioButtonManualProxy = new QRadioButton(groupBox_2);
        buttonGroupProxyType->addButton(radioButtonManualProxy);
        radioButtonManualProxy->setObjectName(QString::fromUtf8("radioButtonManualProxy"));

        verticalLayoutProxyRadioGroup->addWidget(radioButtonManualProxy);


        gridLayout->addLayout(verticalLayoutProxyRadioGroup, 0, 2, 1, 1);


        verticalLayout->addWidget(groupBox_2);

        spacerItem = new QSpacerItem(20, 4, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem);

        buttonBox = new QDialogButtonBox(CoreAccountEditDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(accountName, hostName);
        QWidget::setTabOrder(hostName, port);
        QWidget::setTabOrder(port, user);
        QWidget::setTabOrder(user, password);
        QWidget::setTabOrder(password, rememberPassword);
        QWidget::setTabOrder(rememberPassword, proxyType);
        QWidget::setTabOrder(proxyType, proxyHostName);
        QWidget::setTabOrder(proxyHostName, proxyPort);
        QWidget::setTabOrder(proxyPort, proxyUser);
        QWidget::setTabOrder(proxyUser, proxyPassword);
        QWidget::setTabOrder(proxyPassword, buttonBox);

        retranslateUi(CoreAccountEditDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), CoreAccountEditDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), CoreAccountEditDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(CoreAccountEditDlg);
    } // setupUi

    void retranslateUi(QDialog *CoreAccountEditDlg)
    {
        CoreAccountEditDlg->setWindowTitle(QCoreApplication::translate("CoreAccountEditDlg", "Edit Core Account", nullptr));
        groupBox->setTitle(QCoreApplication::translate("CoreAccountEditDlg", "Account Details", nullptr));
        label->setText(QCoreApplication::translate("CoreAccountEditDlg", "Account Name:", nullptr));
        accountName->setText(QCoreApplication::translate("CoreAccountEditDlg", "Local Core", nullptr));
        label_2->setText(QCoreApplication::translate("CoreAccountEditDlg", "Hostname:", nullptr));
        hostName->setText(QCoreApplication::translate("CoreAccountEditDlg", "localhost", nullptr));
        label_3->setText(QCoreApplication::translate("CoreAccountEditDlg", "Port:", nullptr));
        label_4->setText(QCoreApplication::translate("CoreAccountEditDlg", "User:", nullptr));
        label_10->setText(QCoreApplication::translate("CoreAccountEditDlg", "Password:", nullptr));
        rememberPassword->setText(QCoreApplication::translate("CoreAccountEditDlg", "Remember", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("CoreAccountEditDlg", "Proxy Settings", nullptr));
        label_7->setText(QCoreApplication::translate("CoreAccountEditDlg", "Port:", nullptr));
        proxyType->setItemText(0, QCoreApplication::translate("CoreAccountEditDlg", "SOCKS 5", nullptr));
        proxyType->setItemText(1, QCoreApplication::translate("CoreAccountEditDlg", "HTTP", nullptr));

        label_6->setText(QCoreApplication::translate("CoreAccountEditDlg", "Hostname:", nullptr));
        proxyHostName->setText(QCoreApplication::translate("CoreAccountEditDlg", "localhost", nullptr));
        label_8->setText(QCoreApplication::translate("CoreAccountEditDlg", "User:", nullptr));
        label_9->setText(QCoreApplication::translate("CoreAccountEditDlg", "Password:", nullptr));
        label_5->setText(QCoreApplication::translate("CoreAccountEditDlg", "Proxy Type:", nullptr));
        radioButtonNoProxy->setText(QCoreApplication::translate("CoreAccountEditDlg", "No pro&xy", nullptr));
        radioButtonSystemProxy->setText(QCoreApplication::translate("CoreAccountEditDlg", "S&ystem proxy", nullptr));
        radioButtonManualProxy->setText(QCoreApplication::translate("CoreAccountEditDlg", "&Manual proxy configuration", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CoreAccountEditDlg: public Ui_CoreAccountEditDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_COREACCOUNTEDITDLG_H
