/********************************************************************************
** Form generated from reading UI file 'shortcutssettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SHORTCUTSSETTINGSPAGE_H
#define UI_SHORTCUTSSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "keysequencewidget.h"

QT_BEGIN_NAMESPACE

class Ui_ShortcutsSettingsPage
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QLineEdit *searchEdit;
    QTreeView *shortcutsView;
    QGroupBox *actionBox;
    QGridLayout *gridLayout;
    QRadioButton *useDefault;
    QLabel *defaultShortcut;
    QRadioButton *useCustom;
    KeySequenceWidget *keySequenceWidget;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *ShortcutsSettingsPage)
    {
        if (ShortcutsSettingsPage->objectName().isEmpty())
            ShortcutsSettingsPage->setObjectName(QString::fromUtf8("ShortcutsSettingsPage"));
        ShortcutsSettingsPage->resize(497, 481);
        verticalLayout = new QVBoxLayout(ShortcutsSettingsPage);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label_2 = new QLabel(ShortcutsSettingsPage);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout->addWidget(label_2);

        searchEdit = new QLineEdit(ShortcutsSettingsPage);
        searchEdit->setObjectName(QString::fromUtf8("searchEdit"));

        horizontalLayout->addWidget(searchEdit);


        verticalLayout->addLayout(horizontalLayout);

        shortcutsView = new QTreeView(ShortcutsSettingsPage);
        shortcutsView->setObjectName(QString::fromUtf8("shortcutsView"));
        shortcutsView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        shortcutsView->setProperty("showDropIndicator", QVariant(false));
        shortcutsView->setAlternatingRowColors(true);
        shortcutsView->setSortingEnabled(true);
        shortcutsView->setAnimated(false);
        shortcutsView->setAllColumnsShowFocus(true);
        shortcutsView->header()->setCascadingSectionResizes(true);
        shortcutsView->header()->setStretchLastSection(true);

        verticalLayout->addWidget(shortcutsView);

        actionBox = new QGroupBox(ShortcutsSettingsPage);
        actionBox->setObjectName(QString::fromUtf8("actionBox"));
        gridLayout = new QGridLayout(actionBox);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        useDefault = new QRadioButton(actionBox);
        useDefault->setObjectName(QString::fromUtf8("useDefault"));

        gridLayout->addWidget(useDefault, 0, 0, 1, 1);

        defaultShortcut = new QLabel(actionBox);
        defaultShortcut->setObjectName(QString::fromUtf8("defaultShortcut"));

        gridLayout->addWidget(defaultShortcut, 0, 1, 1, 1);

        useCustom = new QRadioButton(actionBox);
        useCustom->setObjectName(QString::fromUtf8("useCustom"));

        gridLayout->addWidget(useCustom, 1, 0, 1, 1);

        keySequenceWidget = new KeySequenceWidget(actionBox);
        keySequenceWidget->setObjectName(QString::fromUtf8("keySequenceWidget"));

        gridLayout->addWidget(keySequenceWidget, 1, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(346, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 2, 1, 1);


        verticalLayout->addWidget(actionBox);

        QWidget::setTabOrder(searchEdit, shortcutsView);
        QWidget::setTabOrder(shortcutsView, useDefault);
        QWidget::setTabOrder(useDefault, useCustom);

        retranslateUi(ShortcutsSettingsPage);

        QMetaObject::connectSlotsByName(ShortcutsSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *ShortcutsSettingsPage)
    {
        ShortcutsSettingsPage->setWindowTitle(QCoreApplication::translate("ShortcutsSettingsPage", "Form", nullptr));
        label_2->setText(QCoreApplication::translate("ShortcutsSettingsPage", "Search:", nullptr));
        actionBox->setTitle(QCoreApplication::translate("ShortcutsSettingsPage", "Shortcut for Selected Action", nullptr));
        useDefault->setText(QCoreApplication::translate("ShortcutsSettingsPage", "Default:", nullptr));
        defaultShortcut->setText(QCoreApplication::translate("ShortcutsSettingsPage", "None", nullptr));
        useCustom->setText(QCoreApplication::translate("ShortcutsSettingsPage", "Custom:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ShortcutsSettingsPage: public Ui_ShortcutsSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SHORTCUTSSETTINGSPAGE_H
