/****************************************************************************
** Meta object code from reading C++ file 'coresessioneventprocessor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/coresessioneventprocessor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'coresessioneventprocessor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreSessionEventProcessor_t {
    QByteArrayData data[82];
    char stringdata0[1428];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreSessionEventProcessor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreSessionEventProcessor_t qt_meta_stringdata_CoreSessionEventProcessor = {
    {
QT_MOC_LITERAL(0, 0, 25), // "CoreSessionEventProcessor"
QT_MOC_LITERAL(1, 26, 8), // "newEvent"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 6), // "Event*"
QT_MOC_LITERAL(4, 43, 5), // "event"
QT_MOC_LITERAL(5, 49, 18), // "handleNetsplitJoin"
QT_MOC_LITERAL(6, 68, 8), // "Network*"
QT_MOC_LITERAL(7, 77, 3), // "net"
QT_MOC_LITERAL(8, 81, 7), // "channel"
QT_MOC_LITERAL(9, 89, 5), // "users"
QT_MOC_LITERAL(10, 95, 5), // "modes"
QT_MOC_LITERAL(11, 101, 11), // "quitMessage"
QT_MOC_LITERAL(12, 113, 18), // "handleNetsplitQuit"
QT_MOC_LITERAL(13, 132, 22), // "handleNetsplitFinished"
QT_MOC_LITERAL(14, 155, 23), // "handleEarlyNetsplitJoin"
QT_MOC_LITERAL(15, 179, 16), // "destroyNetsplits"
QT_MOC_LITERAL(16, 196, 9), // "NetworkId"
QT_MOC_LITERAL(17, 206, 7), // "network"
QT_MOC_LITERAL(18, 214, 22), // "processIrcEventNumeric"
QT_MOC_LITERAL(19, 237, 16), // "IrcEventNumeric*"
QT_MOC_LITERAL(20, 254, 27), // "processIrcEventAuthenticate"
QT_MOC_LITERAL(21, 282, 9), // "IrcEvent*"
QT_MOC_LITERAL(22, 292, 18), // "processIrcEventCap"
QT_MOC_LITERAL(23, 311, 22), // "processIrcEventAccount"
QT_MOC_LITERAL(24, 334, 19), // "processIrcEventAway"
QT_MOC_LITERAL(25, 354, 22), // "processIrcEventChghost"
QT_MOC_LITERAL(26, 377, 21), // "processIrcEventInvite"
QT_MOC_LITERAL(27, 399, 19), // "processIrcEventJoin"
QT_MOC_LITERAL(28, 419, 23), // "lateProcessIrcEventKick"
QT_MOC_LITERAL(29, 443, 19), // "processIrcEventMode"
QT_MOC_LITERAL(30, 463, 19), // "processIrcEventNick"
QT_MOC_LITERAL(31, 483, 23), // "lateProcessIrcEventNick"
QT_MOC_LITERAL(32, 507, 19), // "processIrcEventPart"
QT_MOC_LITERAL(33, 527, 23), // "lateProcessIrcEventPart"
QT_MOC_LITERAL(34, 551, 19), // "processIrcEventPing"
QT_MOC_LITERAL(35, 571, 19), // "processIrcEventPong"
QT_MOC_LITERAL(36, 591, 19), // "processIrcEventQuit"
QT_MOC_LITERAL(37, 611, 23), // "lateProcessIrcEventQuit"
QT_MOC_LITERAL(38, 635, 20), // "processIrcEventTopic"
QT_MOC_LITERAL(39, 656, 20), // "processIrcEventError"
QT_MOC_LITERAL(40, 677, 22), // "processIrcEventSetname"
QT_MOC_LITERAL(41, 700, 15), // "processKeyEvent"
QT_MOC_LITERAL(42, 716, 9), // "KeyEvent*"
QT_MOC_LITERAL(43, 726, 18), // "processIrcEvent001"
QT_MOC_LITERAL(44, 745, 18), // "processIrcEvent005"
QT_MOC_LITERAL(45, 764, 18), // "processIrcEvent221"
QT_MOC_LITERAL(46, 783, 18), // "processIrcEvent250"
QT_MOC_LITERAL(47, 802, 18), // "processIrcEvent265"
QT_MOC_LITERAL(48, 821, 18), // "processIrcEvent266"
QT_MOC_LITERAL(49, 840, 18), // "processIrcEvent301"
QT_MOC_LITERAL(50, 859, 18), // "processIrcEvent305"
QT_MOC_LITERAL(51, 878, 18), // "processIrcEvent306"
QT_MOC_LITERAL(52, 897, 18), // "processIrcEvent307"
QT_MOC_LITERAL(53, 916, 18), // "processIrcEvent310"
QT_MOC_LITERAL(54, 935, 18), // "processIrcEvent311"
QT_MOC_LITERAL(55, 954, 18), // "processIrcEvent312"
QT_MOC_LITERAL(56, 973, 18), // "processIrcEvent313"
QT_MOC_LITERAL(57, 992, 18), // "processIrcEvent315"
QT_MOC_LITERAL(58, 1011, 18), // "processIrcEvent317"
QT_MOC_LITERAL(59, 1030, 18), // "processIrcEvent322"
QT_MOC_LITERAL(60, 1049, 18), // "processIrcEvent323"
QT_MOC_LITERAL(61, 1068, 18), // "processIrcEvent324"
QT_MOC_LITERAL(62, 1087, 18), // "processIrcEvent330"
QT_MOC_LITERAL(63, 1106, 18), // "processIrcEvent331"
QT_MOC_LITERAL(64, 1125, 18), // "processIrcEvent332"
QT_MOC_LITERAL(65, 1144, 18), // "processIrcEvent352"
QT_MOC_LITERAL(66, 1163, 18), // "processIrcEvent353"
QT_MOC_LITERAL(67, 1182, 18), // "processIrcEvent354"
QT_MOC_LITERAL(68, 1201, 18), // "processIrcEvent403"
QT_MOC_LITERAL(69, 1220, 18), // "processIrcEvent432"
QT_MOC_LITERAL(70, 1239, 18), // "processIrcEvent433"
QT_MOC_LITERAL(71, 1258, 18), // "processIrcEvent437"
QT_MOC_LITERAL(72, 1277, 16), // "processCtcpEvent"
QT_MOC_LITERAL(73, 1294, 10), // "CtcpEvent*"
QT_MOC_LITERAL(74, 1305, 16), // "handleCtcpAction"
QT_MOC_LITERAL(75, 1322, 20), // "handleCtcpClientinfo"
QT_MOC_LITERAL(76, 1343, 13), // "handleCtcpDcc"
QT_MOC_LITERAL(77, 1357, 14), // "handleCtcpPing"
QT_MOC_LITERAL(78, 1372, 14), // "handleCtcpTime"
QT_MOC_LITERAL(79, 1387, 17), // "handleCtcpVersion"
QT_MOC_LITERAL(80, 1405, 14), // "defaultHandler"
QT_MOC_LITERAL(81, 1420, 7) // "ctcpCmd"

    },
    "CoreSessionEventProcessor\0newEvent\0\0"
    "Event*\0event\0handleNetsplitJoin\0"
    "Network*\0net\0channel\0users\0modes\0"
    "quitMessage\0handleNetsplitQuit\0"
    "handleNetsplitFinished\0handleEarlyNetsplitJoin\0"
    "destroyNetsplits\0NetworkId\0network\0"
    "processIrcEventNumeric\0IrcEventNumeric*\0"
    "processIrcEventAuthenticate\0IrcEvent*\0"
    "processIrcEventCap\0processIrcEventAccount\0"
    "processIrcEventAway\0processIrcEventChghost\0"
    "processIrcEventInvite\0processIrcEventJoin\0"
    "lateProcessIrcEventKick\0processIrcEventMode\0"
    "processIrcEventNick\0lateProcessIrcEventNick\0"
    "processIrcEventPart\0lateProcessIrcEventPart\0"
    "processIrcEventPing\0processIrcEventPong\0"
    "processIrcEventQuit\0lateProcessIrcEventQuit\0"
    "processIrcEventTopic\0processIrcEventError\0"
    "processIrcEventSetname\0processKeyEvent\0"
    "KeyEvent*\0processIrcEvent001\0"
    "processIrcEvent005\0processIrcEvent221\0"
    "processIrcEvent250\0processIrcEvent265\0"
    "processIrcEvent266\0processIrcEvent301\0"
    "processIrcEvent305\0processIrcEvent306\0"
    "processIrcEvent307\0processIrcEvent310\0"
    "processIrcEvent311\0processIrcEvent312\0"
    "processIrcEvent313\0processIrcEvent315\0"
    "processIrcEvent317\0processIrcEvent322\0"
    "processIrcEvent323\0processIrcEvent324\0"
    "processIrcEvent330\0processIrcEvent331\0"
    "processIrcEvent332\0processIrcEvent352\0"
    "processIrcEvent353\0processIrcEvent354\0"
    "processIrcEvent403\0processIrcEvent432\0"
    "processIrcEvent433\0processIrcEvent437\0"
    "processCtcpEvent\0CtcpEvent*\0"
    "handleCtcpAction\0handleCtcpClientinfo\0"
    "handleCtcpDcc\0handleCtcpPing\0"
    "handleCtcpTime\0handleCtcpVersion\0"
    "defaultHandler\0ctcpCmd"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreSessionEventProcessor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      65,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  339,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    5,  342,    2, 0x08 /* Private */,
      12,    4,  353,    2, 0x08 /* Private */,
      13,    0,  362,    2, 0x08 /* Private */,
      14,    4,  363,    2, 0x08 /* Private */,
      15,    1,  372,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      18,    1,  375,    2, 0x02 /* Public */,
      20,    1,  378,    2, 0x02 /* Public */,
      22,    1,  381,    2, 0x02 /* Public */,
      23,    1,  384,    2, 0x02 /* Public */,
      24,    1,  387,    2, 0x02 /* Public */,
      25,    1,  390,    2, 0x02 /* Public */,
      26,    1,  393,    2, 0x02 /* Public */,
      27,    1,  396,    2, 0x02 /* Public */,
      28,    1,  399,    2, 0x02 /* Public */,
      29,    1,  402,    2, 0x02 /* Public */,
      30,    1,  405,    2, 0x02 /* Public */,
      31,    1,  408,    2, 0x02 /* Public */,
      32,    1,  411,    2, 0x02 /* Public */,
      33,    1,  414,    2, 0x02 /* Public */,
      34,    1,  417,    2, 0x02 /* Public */,
      35,    1,  420,    2, 0x02 /* Public */,
      36,    1,  423,    2, 0x02 /* Public */,
      37,    1,  426,    2, 0x02 /* Public */,
      38,    1,  429,    2, 0x02 /* Public */,
      39,    1,  432,    2, 0x02 /* Public */,
      40,    1,  435,    2, 0x02 /* Public */,
      41,    1,  438,    2, 0x02 /* Public */,
      43,    1,  441,    2, 0x02 /* Public */,
      44,    1,  444,    2, 0x02 /* Public */,
      45,    1,  447,    2, 0x02 /* Public */,
      46,    1,  450,    2, 0x02 /* Public */,
      47,    1,  453,    2, 0x02 /* Public */,
      48,    1,  456,    2, 0x02 /* Public */,
      49,    1,  459,    2, 0x02 /* Public */,
      50,    1,  462,    2, 0x02 /* Public */,
      51,    1,  465,    2, 0x02 /* Public */,
      52,    1,  468,    2, 0x02 /* Public */,
      53,    1,  471,    2, 0x02 /* Public */,
      54,    1,  474,    2, 0x02 /* Public */,
      55,    1,  477,    2, 0x02 /* Public */,
      56,    1,  480,    2, 0x02 /* Public */,
      57,    1,  483,    2, 0x02 /* Public */,
      58,    1,  486,    2, 0x02 /* Public */,
      59,    1,  489,    2, 0x02 /* Public */,
      60,    1,  492,    2, 0x02 /* Public */,
      61,    1,  495,    2, 0x02 /* Public */,
      62,    1,  498,    2, 0x02 /* Public */,
      63,    1,  501,    2, 0x02 /* Public */,
      64,    1,  504,    2, 0x02 /* Public */,
      65,    1,  507,    2, 0x02 /* Public */,
      66,    1,  510,    2, 0x02 /* Public */,
      67,    1,  513,    2, 0x02 /* Public */,
      68,    1,  516,    2, 0x02 /* Public */,
      69,    1,  519,    2, 0x02 /* Public */,
      70,    1,  522,    2, 0x02 /* Public */,
      71,    1,  525,    2, 0x02 /* Public */,
      72,    1,  528,    2, 0x02 /* Public */,
      74,    1,  531,    2, 0x02 /* Public */,
      75,    1,  534,    2, 0x02 /* Public */,
      76,    1,  537,    2, 0x02 /* Public */,
      77,    1,  540,    2, 0x02 /* Public */,
      78,    1,  543,    2, 0x02 /* Public */,
      79,    1,  546,    2, 0x02 /* Public */,
      80,    2,  549,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::QStringList, QMetaType::QStringList, QMetaType::QString,    7,    8,    9,   10,   11,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::QStringList, QMetaType::QString,    7,    8,    9,   11,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString, QMetaType::QStringList, QMetaType::QStringList,    7,    8,    9,   10,
    QMetaType::Void, 0x80000000 | 16,   17,

 // methods: parameters
    QMetaType::Void, 0x80000000 | 19,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 42,    4,
    QMetaType::Void, 0x80000000 | 19,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 21,    4,
    QMetaType::Void, 0x80000000 | 19,    4,
    QMetaType::Void, 0x80000000 | 19,    4,
    QMetaType::Void, 0x80000000 | 19,    4,
    QMetaType::Void, 0x80000000 | 19,    4,
    QMetaType::Void, 0x80000000 | 73,    4,
    QMetaType::Void, 0x80000000 | 73,    4,
    QMetaType::Void, 0x80000000 | 73,    4,
    QMetaType::Void, 0x80000000 | 73,    4,
    QMetaType::Void, 0x80000000 | 73,    4,
    QMetaType::Void, 0x80000000 | 73,    4,
    QMetaType::Void, 0x80000000 | 73,    4,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 73,   81,    4,

       0        // eod
};

void CoreSessionEventProcessor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreSessionEventProcessor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->newEvent((*reinterpret_cast< Event*(*)>(_a[1]))); break;
        case 1: _t->handleNetsplitJoin((*reinterpret_cast< Network*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QStringList(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5]))); break;
        case 2: _t->handleNetsplitQuit((*reinterpret_cast< Network*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QStringList(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 3: _t->handleNetsplitFinished(); break;
        case 4: _t->handleEarlyNetsplitJoin((*reinterpret_cast< Network*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QStringList(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4]))); break;
        case 5: _t->destroyNetsplits((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 6: _t->processIrcEventNumeric((*reinterpret_cast< IrcEventNumeric*(*)>(_a[1]))); break;
        case 7: _t->processIrcEventAuthenticate((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 8: _t->processIrcEventCap((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 9: _t->processIrcEventAccount((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 10: _t->processIrcEventAway((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 11: _t->processIrcEventChghost((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 12: _t->processIrcEventInvite((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 13: _t->processIrcEventJoin((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 14: _t->lateProcessIrcEventKick((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 15: _t->processIrcEventMode((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 16: _t->processIrcEventNick((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 17: _t->lateProcessIrcEventNick((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 18: _t->processIrcEventPart((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 19: _t->lateProcessIrcEventPart((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 20: _t->processIrcEventPing((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 21: _t->processIrcEventPong((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 22: _t->processIrcEventQuit((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 23: _t->lateProcessIrcEventQuit((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 24: _t->processIrcEventTopic((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 25: _t->processIrcEventError((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 26: _t->processIrcEventSetname((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 27: _t->processKeyEvent((*reinterpret_cast< KeyEvent*(*)>(_a[1]))); break;
        case 28: _t->processIrcEvent001((*reinterpret_cast< IrcEventNumeric*(*)>(_a[1]))); break;
        case 29: _t->processIrcEvent005((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 30: _t->processIrcEvent221((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 31: _t->processIrcEvent250((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 32: _t->processIrcEvent265((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 33: _t->processIrcEvent266((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 34: _t->processIrcEvent301((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 35: _t->processIrcEvent305((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 36: _t->processIrcEvent306((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 37: _t->processIrcEvent307((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 38: _t->processIrcEvent310((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 39: _t->processIrcEvent311((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 40: _t->processIrcEvent312((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 41: _t->processIrcEvent313((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 42: _t->processIrcEvent315((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 43: _t->processIrcEvent317((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 44: _t->processIrcEvent322((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 45: _t->processIrcEvent323((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 46: _t->processIrcEvent324((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 47: _t->processIrcEvent330((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 48: _t->processIrcEvent331((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 49: _t->processIrcEvent332((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 50: _t->processIrcEvent352((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 51: _t->processIrcEvent353((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 52: _t->processIrcEvent354((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 53: _t->processIrcEvent403((*reinterpret_cast< IrcEventNumeric*(*)>(_a[1]))); break;
        case 54: _t->processIrcEvent432((*reinterpret_cast< IrcEventNumeric*(*)>(_a[1]))); break;
        case 55: _t->processIrcEvent433((*reinterpret_cast< IrcEventNumeric*(*)>(_a[1]))); break;
        case 56: _t->processIrcEvent437((*reinterpret_cast< IrcEventNumeric*(*)>(_a[1]))); break;
        case 57: _t->processCtcpEvent((*reinterpret_cast< CtcpEvent*(*)>(_a[1]))); break;
        case 58: _t->handleCtcpAction((*reinterpret_cast< CtcpEvent*(*)>(_a[1]))); break;
        case 59: _t->handleCtcpClientinfo((*reinterpret_cast< CtcpEvent*(*)>(_a[1]))); break;
        case 60: _t->handleCtcpDcc((*reinterpret_cast< CtcpEvent*(*)>(_a[1]))); break;
        case 61: _t->handleCtcpPing((*reinterpret_cast< CtcpEvent*(*)>(_a[1]))); break;
        case 62: _t->handleCtcpTime((*reinterpret_cast< CtcpEvent*(*)>(_a[1]))); break;
        case 63: _t->handleCtcpVersion((*reinterpret_cast< CtcpEvent*(*)>(_a[1]))); break;
        case 64: _t->defaultHandler((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< CtcpEvent*(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Network* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Network* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Network* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CoreSessionEventProcessor::*)(Event * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreSessionEventProcessor::newEvent)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreSessionEventProcessor::staticMetaObject = { {
    QMetaObject::SuperData::link<BasicHandler::staticMetaObject>(),
    qt_meta_stringdata_CoreSessionEventProcessor.data,
    qt_meta_data_CoreSessionEventProcessor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreSessionEventProcessor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreSessionEventProcessor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreSessionEventProcessor.stringdata0))
        return static_cast<void*>(this);
    return BasicHandler::qt_metacast(_clname);
}

int CoreSessionEventProcessor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BasicHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 65)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 65;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 65)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 65;
    }
    return _id;
}

// SIGNAL 0
void CoreSessionEventProcessor::newEvent(Event * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
