/********************************************************************************
** Form generated from reading UI file 'coreconnectionstatuswidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CORECONNECTIONSTATUSWIDGET_H
#define UI_CORECONNECTIONSTATUSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CoreConnectionStatusWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *messageLabel;
    QProgressBar *progressBar;
    QLabel *lagLabel;
    QLabel *sslLabel;

    void setupUi(QWidget *CoreConnectionStatusWidget)
    {
        if (CoreConnectionStatusWidget->objectName().isEmpty())
            CoreConnectionStatusWidget->setObjectName(QString::fromUtf8("CoreConnectionStatusWidget"));
        CoreConnectionStatusWidget->resize(402, 34);
        horizontalLayout = new QHBoxLayout(CoreConnectionStatusWidget);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalLayout->setContentsMargins(4, 0, 4, 0);
        messageLabel = new QLabel(CoreConnectionStatusWidget);
        messageLabel->setObjectName(QString::fromUtf8("messageLabel"));

        horizontalLayout->addWidget(messageLabel);

        progressBar = new QProgressBar(CoreConnectionStatusWidget);
        progressBar->setObjectName(QString::fromUtf8("progressBar"));
        QSizePolicy sizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(progressBar->sizePolicy().hasHeightForWidth());
        progressBar->setSizePolicy(sizePolicy);
        progressBar->setValue(24);

        horizontalLayout->addWidget(progressBar);

        lagLabel = new QLabel(CoreConnectionStatusWidget);
        lagLabel->setObjectName(QString::fromUtf8("lagLabel"));
        lagLabel->setText(QString::fromUtf8("Lag: n/a"));

        horizontalLayout->addWidget(lagLabel);

        sslLabel = new QLabel(CoreConnectionStatusWidget);
        sslLabel->setObjectName(QString::fromUtf8("sslLabel"));

        horizontalLayout->addWidget(sslLabel);


        retranslateUi(CoreConnectionStatusWidget);

        QMetaObject::connectSlotsByName(CoreConnectionStatusWidget);
    } // setupUi

    void retranslateUi(QWidget *CoreConnectionStatusWidget)
    {
        CoreConnectionStatusWidget->setWindowTitle(QCoreApplication::translate("CoreConnectionStatusWidget", "Form", nullptr));
        messageLabel->setText(QCoreApplication::translate("CoreConnectionStatusWidget", "Message", nullptr));
        sslLabel->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class CoreConnectionStatusWidget: public Ui_CoreConnectionStatusWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CORECONNECTIONSTATUSWIDGET_H
