/********************************************************************************
** Form generated from reading UI file 'identitiessettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IDENTITIESSETTINGSPAGE_H
#define UI_IDENTITIESSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <identityeditwidget.h>

QT_BEGIN_NAMESPACE

class Ui_IdentitiesSettingsPage
{
public:
    QVBoxLayout *verticalLayout_13;
    QHBoxLayout *hboxLayout;
    QComboBox *identityList;
    QToolButton *renameIdentity;
    QToolButton *addIdentity;
    QToolButton *deleteIdentity;
    IdentityEditWidget *identityEditor;

    void setupUi(QWidget *IdentitiesSettingsPage)
    {
        if (IdentitiesSettingsPage->objectName().isEmpty())
            IdentitiesSettingsPage->setObjectName(QString::fromUtf8("IdentitiesSettingsPage"));
        IdentitiesSettingsPage->resize(256, 183);
        verticalLayout_13 = new QVBoxLayout(IdentitiesSettingsPage);
        verticalLayout_13->setObjectName(QString::fromUtf8("verticalLayout_13"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        identityList = new QComboBox(IdentitiesSettingsPage);
        identityList->setObjectName(QString::fromUtf8("identityList"));
        identityList->setInsertPolicy(QComboBox::InsertAtBottom);
        identityList->setDuplicatesEnabled(true);

        hboxLayout->addWidget(identityList);

        renameIdentity = new QToolButton(IdentitiesSettingsPage);
        renameIdentity->setObjectName(QString::fromUtf8("renameIdentity"));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/22x22/actions/oxygen/22x22/actions/edit-rename.png"), QSize(), QIcon::Normal, QIcon::Off);
        renameIdentity->setIcon(icon);
        renameIdentity->setIconSize(QSize(22, 22));

        hboxLayout->addWidget(renameIdentity);

        addIdentity = new QToolButton(IdentitiesSettingsPage);
        addIdentity->setObjectName(QString::fromUtf8("addIdentity"));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/22x22/actions/oxygen/22x22/actions/list-add-user.png"), QSize(), QIcon::Normal, QIcon::Off);
        addIdentity->setIcon(icon1);
        addIdentity->setIconSize(QSize(22, 22));
        addIdentity->setToolButtonStyle(Qt::ToolButtonIconOnly);

        hboxLayout->addWidget(addIdentity);

        deleteIdentity = new QToolButton(IdentitiesSettingsPage);
        deleteIdentity->setObjectName(QString::fromUtf8("deleteIdentity"));
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/22x22/actions/oxygen/22x22/actions/list-remove-user.png"), QSize(), QIcon::Normal, QIcon::Off);
        deleteIdentity->setIcon(icon2);
        deleteIdentity->setIconSize(QSize(22, 22));

        hboxLayout->addWidget(deleteIdentity);


        verticalLayout_13->addLayout(hboxLayout);

        identityEditor = new IdentityEditWidget(IdentitiesSettingsPage);
        identityEditor->setObjectName(QString::fromUtf8("identityEditor"));

        verticalLayout_13->addWidget(identityEditor);

        QWidget::setTabOrder(identityList, renameIdentity);
        QWidget::setTabOrder(renameIdentity, addIdentity);
        QWidget::setTabOrder(addIdentity, deleteIdentity);

        retranslateUi(IdentitiesSettingsPage);

        QMetaObject::connectSlotsByName(IdentitiesSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *IdentitiesSettingsPage)
    {
        IdentitiesSettingsPage->setWindowTitle(QString());
#if QT_CONFIG(tooltip)
        renameIdentity->setToolTip(QCoreApplication::translate("IdentitiesSettingsPage", "Rename Identity", nullptr));
#endif // QT_CONFIG(tooltip)
        renameIdentity->setText(QCoreApplication::translate("IdentitiesSettingsPage", "...", nullptr));
#if QT_CONFIG(tooltip)
        addIdentity->setToolTip(QCoreApplication::translate("IdentitiesSettingsPage", "Add Identity", nullptr));
#endif // QT_CONFIG(tooltip)
        addIdentity->setText(QCoreApplication::translate("IdentitiesSettingsPage", "Add...", nullptr));
#if QT_CONFIG(tooltip)
        deleteIdentity->setToolTip(QCoreApplication::translate("IdentitiesSettingsPage", "Remove Identity", nullptr));
#endif // QT_CONFIG(tooltip)
        deleteIdentity->setText(QCoreApplication::translate("IdentitiesSettingsPage", "...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class IdentitiesSettingsPage: public Ui_IdentitiesSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_IDENTITIESSETTINGSPAGE_H
