/********************************************************************************
** Form generated from reading UI file 'servereditdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SERVEREDITDLG_H
#define UI_SERVEREDITDLG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ServerEditDlg
{
public:
    QVBoxLayout *verticalLayout_3;
    QTabWidget *tabWidget;
    QWidget *basic;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QLabel *label_2;
    QLineEdit *host;
    QSpinBox *port;
    QHBoxLayout *hboxLayout;
    QLabel *passwordLabel;
    QLineEdit *password;
    QCheckBox *useSSL;
    QCheckBox *sslVerify;
    QSpacerItem *verticalSpacer_2;
    QWidget *advanced;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *label_3;
    QComboBox *sslVersion;
    QGroupBox *useProxy;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_8;
    QComboBox *proxyType;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_4;
    QLineEdit *proxyHost;
    QLabel *label_5;
    QSpinBox *proxyPort;
    QGridLayout *gridLayout;
    QLabel *label_6;
    QLineEdit *proxyUsername;
    QLabel *label_7;
    QLineEdit *proxyPassword;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ServerEditDlg)
    {
        if (ServerEditDlg->objectName().isEmpty())
            ServerEditDlg->setObjectName(QString::fromUtf8("ServerEditDlg"));
        ServerEditDlg->resize(386, 346);
        verticalLayout_3 = new QVBoxLayout(ServerEditDlg);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        tabWidget = new QTabWidget(ServerEditDlg);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        tabWidget->setUsesScrollButtons(false);
        basic = new QWidget();
        basic->setObjectName(QString::fromUtf8("basic"));
        verticalLayout_4 = new QVBoxLayout(basic);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        label = new QLabel(basic);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        label_2 = new QLabel(basic);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout_2->addWidget(label_2, 0, 1, 1, 1);

        host = new QLineEdit(basic);
        host->setObjectName(QString::fromUtf8("host"));

        gridLayout_2->addWidget(host, 1, 0, 1, 1);

        port = new QSpinBox(basic);
        port->setObjectName(QString::fromUtf8("port"));
        port->setMinimum(1);
        port->setMaximum(65535);
        port->setValue(6667);

        gridLayout_2->addWidget(port, 1, 1, 1, 1);


        verticalLayout_4->addLayout(gridLayout_2);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        passwordLabel = new QLabel(basic);
        passwordLabel->setObjectName(QString::fromUtf8("passwordLabel"));

        hboxLayout->addWidget(passwordLabel);

        password = new QLineEdit(basic);
        password->setObjectName(QString::fromUtf8("password"));
        password->setEnabled(true);
        password->setEchoMode(QLineEdit::Password);

        hboxLayout->addWidget(password);


        verticalLayout_4->addLayout(hboxLayout);

        useSSL = new QCheckBox(basic);
        useSSL->setObjectName(QString::fromUtf8("useSSL"));
        useSSL->setEnabled(true);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/document-encrypt.png"), QSize(), QIcon::Normal, QIcon::Off);
        useSSL->setIcon(icon);

        verticalLayout_4->addWidget(useSSL);

        sslVerify = new QCheckBox(basic);
        sslVerify->setObjectName(QString::fromUtf8("sslVerify"));
        sslVerify->setEnabled(false);
        sslVerify->setChecked(true);

        verticalLayout_4->addWidget(sslVerify);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_2);

        tabWidget->addTab(basic, QString());
        advanced = new QWidget();
        advanced->setObjectName(QString::fromUtf8("advanced"));
        verticalLayout_2 = new QVBoxLayout(advanced);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        label_3 = new QLabel(advanced);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        horizontalLayout->addWidget(label_3);

        sslVersion = new QComboBox(advanced);
        sslVersion->addItem(QString());
        sslVersion->addItem(QString());
        sslVersion->addItem(QString());
        sslVersion->setObjectName(QString::fromUtf8("sslVersion"));

        horizontalLayout->addWidget(sslVersion);


        verticalLayout_2->addLayout(horizontalLayout);

        useProxy = new QGroupBox(advanced);
        useProxy->setObjectName(QString::fromUtf8("useProxy"));
        useProxy->setFlat(false);
        useProxy->setCheckable(true);
        useProxy->setChecked(false);
        verticalLayout = new QVBoxLayout(useProxy);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label_8 = new QLabel(useProxy);
        label_8->setObjectName(QString::fromUtf8("label_8"));

        horizontalLayout_3->addWidget(label_8);

        proxyType = new QComboBox(useProxy);
        proxyType->addItem(QString());
        proxyType->addItem(QString());
        proxyType->setObjectName(QString::fromUtf8("proxyType"));

        horizontalLayout_3->addWidget(proxyType);


        verticalLayout->addLayout(horizontalLayout_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_4 = new QLabel(useProxy);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        horizontalLayout_2->addWidget(label_4);

        proxyHost = new QLineEdit(useProxy);
        proxyHost->setObjectName(QString::fromUtf8("proxyHost"));

        horizontalLayout_2->addWidget(proxyHost);

        label_5 = new QLabel(useProxy);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        horizontalLayout_2->addWidget(label_5);

        proxyPort = new QSpinBox(useProxy);
        proxyPort->setObjectName(QString::fromUtf8("proxyPort"));
        proxyPort->setMinimum(1);
        proxyPort->setMaximum(65535);
        proxyPort->setValue(8080);

        horizontalLayout_2->addWidget(proxyPort);


        verticalLayout->addLayout(horizontalLayout_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_6 = new QLabel(useProxy);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout->addWidget(label_6, 0, 0, 1, 1);

        proxyUsername = new QLineEdit(useProxy);
        proxyUsername->setObjectName(QString::fromUtf8("proxyUsername"));

        gridLayout->addWidget(proxyUsername, 0, 1, 1, 1);

        label_7 = new QLabel(useProxy);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout->addWidget(label_7, 1, 0, 1, 1);

        proxyPassword = new QLineEdit(useProxy);
        proxyPassword->setObjectName(QString::fromUtf8("proxyPassword"));
        proxyPassword->setEchoMode(QLineEdit::Password);

        gridLayout->addWidget(proxyPassword, 1, 1, 1, 1);


        verticalLayout->addLayout(gridLayout);


        verticalLayout_2->addWidget(useProxy);

        tabWidget->addTab(advanced, QString());

        verticalLayout_3->addWidget(tabWidget);

        verticalSpacer = new QSpacerItem(20, 17, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(ServerEditDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(buttonBox);

        QWidget::setTabOrder(tabWidget, host);
        QWidget::setTabOrder(host, port);
        QWidget::setTabOrder(port, password);
        QWidget::setTabOrder(password, useSSL);
        QWidget::setTabOrder(useSSL, sslVerify);
        QWidget::setTabOrder(sslVerify, sslVersion);
        QWidget::setTabOrder(sslVersion, useProxy);
        QWidget::setTabOrder(useProxy, proxyType);
        QWidget::setTabOrder(proxyType, proxyHost);
        QWidget::setTabOrder(proxyHost, proxyPort);
        QWidget::setTabOrder(proxyPort, proxyUsername);
        QWidget::setTabOrder(proxyUsername, proxyPassword);
        QWidget::setTabOrder(proxyPassword, buttonBox);

        retranslateUi(ServerEditDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), ServerEditDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), ServerEditDlg, SLOT(reject()));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ServerEditDlg);
    } // setupUi

    void retranslateUi(QDialog *ServerEditDlg)
    {
        ServerEditDlg->setWindowTitle(QCoreApplication::translate("ServerEditDlg", "Edit Server", nullptr));
#if QT_CONFIG(tooltip)
        tabWidget->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        label->setText(QCoreApplication::translate("ServerEditDlg", "Server address:", nullptr));
        label_2->setText(QCoreApplication::translate("ServerEditDlg", "Port:", nullptr));
        passwordLabel->setText(QCoreApplication::translate("ServerEditDlg", "Password:", nullptr));
#if QT_CONFIG(tooltip)
        useSSL->setToolTip(QCoreApplication::translate("ServerEditDlg", "Try to use an encrypted connection (e.g. SSL/TLS)", nullptr));
#endif // QT_CONFIG(tooltip)
        useSSL->setText(QCoreApplication::translate("ServerEditDlg", "Use encrypted connection", nullptr));
#if QT_CONFIG(tooltip)
        sslVerify->setToolTip(QCoreApplication::translate("ServerEditDlg", "<p>Verify the encrypted connection provides a valid certificate, increasing security.<br/>Uncheck if the IRC server uses a self-signed or invalid certificate.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        sslVerify->setText(QCoreApplication::translate("ServerEditDlg", "Verify connection security", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(basic), QCoreApplication::translate("ServerEditDlg", "Server Info", nullptr));
        label_3->setText(QCoreApplication::translate("ServerEditDlg", "SSL Version:", nullptr));
        sslVersion->setItemText(0, QCoreApplication::translate("ServerEditDlg", "SSLv3 (insecure)", nullptr));
        sslVersion->setItemText(1, QCoreApplication::translate("ServerEditDlg", "SSLv2 (insecure)", nullptr));
        sslVersion->setItemText(2, QCoreApplication::translate("ServerEditDlg", "TLSv1", nullptr));

#if QT_CONFIG(tooltip)
        sslVersion->setToolTip(QCoreApplication::translate("ServerEditDlg", "Use only TLSv1 unless you know what you are doing!", nullptr));
#endif // QT_CONFIG(tooltip)
        useProxy->setTitle(QCoreApplication::translate("ServerEditDlg", "Use a Proxy", nullptr));
        label_8->setText(QCoreApplication::translate("ServerEditDlg", "Proxy Type:", nullptr));
        proxyType->setItemText(0, QCoreApplication::translate("ServerEditDlg", "SOCKS 5", nullptr));
        proxyType->setItemText(1, QCoreApplication::translate("ServerEditDlg", "HTTP", nullptr));

        label_4->setText(QCoreApplication::translate("ServerEditDlg", "Proxy Host:", nullptr));
        proxyHost->setText(QCoreApplication::translate("ServerEditDlg", "localhost", nullptr));
        label_5->setText(QCoreApplication::translate("ServerEditDlg", "Port:", nullptr));
        label_6->setText(QCoreApplication::translate("ServerEditDlg", "Proxy Username:", nullptr));
        label_7->setText(QCoreApplication::translate("ServerEditDlg", "Proxy Password:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(advanced), QCoreApplication::translate("ServerEditDlg", "Advanced", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ServerEditDlg: public Ui_ServerEditDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SERVEREDITDLG_H
