/****************************************************************************
** Meta object code from reading C++ file 'bufferviewsettingspage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/settingspages/bufferviewsettingspage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bufferviewsettingspage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BufferViewSettingsPage_t {
    QByteArrayData data[25];
    char stringdata0[377];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferViewSettingsPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferViewSettingsPage_t qt_meta_stringdata_BufferViewSettingsPage = {
    {
QT_MOC_LITERAL(0, 0, 22), // "BufferViewSettingsPage"
QT_MOC_LITERAL(1, 23, 4), // "save"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 4), // "load"
QT_MOC_LITERAL(4, 34, 5), // "reset"
QT_MOC_LITERAL(5, 40, 26), // "coreConnectionStateChanged"
QT_MOC_LITERAL(6, 67, 5), // "state"
QT_MOC_LITERAL(7, 73, 13), // "addBufferView"
QT_MOC_LITERAL(8, 87, 17), // "BufferViewConfig*"
QT_MOC_LITERAL(9, 105, 6), // "config"
QT_MOC_LITERAL(10, 112, 12), // "bufferViewId"
QT_MOC_LITERAL(11, 125, 17), // "bufferViewDeleted"
QT_MOC_LITERAL(12, 143, 13), // "newBufferView"
QT_MOC_LITERAL(13, 157, 14), // "bufferViewName"
QT_MOC_LITERAL(14, 172, 16), // "updateBufferView"
QT_MOC_LITERAL(15, 189, 19), // "enableStatusBuffers"
QT_MOC_LITERAL(16, 209, 10), // "networkIdx"
QT_MOC_LITERAL(17, 220, 24), // "on_addBufferView_clicked"
QT_MOC_LITERAL(18, 245, 27), // "on_renameBufferView_clicked"
QT_MOC_LITERAL(19, 273, 27), // "on_deleteBufferView_clicked"
QT_MOC_LITERAL(20, 301, 26), // "bufferViewSelectionChanged"
QT_MOC_LITERAL(21, 328, 14), // "QItemSelection"
QT_MOC_LITERAL(22, 343, 7), // "current"
QT_MOC_LITERAL(23, 351, 8), // "previous"
QT_MOC_LITERAL(24, 360, 16) // "widgetHasChanged"

    },
    "BufferViewSettingsPage\0save\0\0load\0"
    "reset\0coreConnectionStateChanged\0state\0"
    "addBufferView\0BufferViewConfig*\0config\0"
    "bufferViewId\0bufferViewDeleted\0"
    "newBufferView\0bufferViewName\0"
    "updateBufferView\0enableStatusBuffers\0"
    "networkIdx\0on_addBufferView_clicked\0"
    "on_renameBufferView_clicked\0"
    "on_deleteBufferView_clicked\0"
    "bufferViewSelectionChanged\0QItemSelection\0"
    "current\0previous\0widgetHasChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferViewSettingsPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   89,    2, 0x0a /* Public */,
       3,    0,   90,    2, 0x0a /* Public */,
       4,    0,   91,    2, 0x0a /* Public */,
       5,    1,   92,    2, 0x08 /* Private */,
       7,    1,   95,    2, 0x08 /* Private */,
       7,    1,   98,    2, 0x08 /* Private */,
      11,    0,  101,    2, 0x08 /* Private */,
      12,    1,  102,    2, 0x08 /* Private */,
      14,    0,  105,    2, 0x08 /* Private */,
      15,    1,  106,    2, 0x08 /* Private */,
      17,    0,  109,    2, 0x08 /* Private */,
      18,    0,  110,    2, 0x08 /* Private */,
      19,    0,  111,    2, 0x08 /* Private */,
      20,    2,  112,    2, 0x08 /* Private */,
      24,    0,  117,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 21, 0x80000000 | 21,   22,   23,
    QMetaType::Void,

       0        // eod
};

void BufferViewSettingsPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferViewSettingsPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->save(); break;
        case 1: _t->load(); break;
        case 2: _t->reset(); break;
        case 3: _t->coreConnectionStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->addBufferView((*reinterpret_cast< BufferViewConfig*(*)>(_a[1]))); break;
        case 5: _t->addBufferView((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->bufferViewDeleted(); break;
        case 7: _t->newBufferView((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->updateBufferView(); break;
        case 9: _t->enableStatusBuffers((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->on_addBufferView_clicked(); break;
        case 11: _t->on_renameBufferView_clicked(); break;
        case 12: _t->on_deleteBufferView_clicked(); break;
        case 13: _t->bufferViewSelectionChanged((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 14: _t->widgetHasChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QItemSelection >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BufferViewSettingsPage::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingsPage::staticMetaObject>(),
    qt_meta_stringdata_BufferViewSettingsPage.data,
    qt_meta_data_BufferViewSettingsPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferViewSettingsPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferViewSettingsPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferViewSettingsPage.stringdata0))
        return static_cast<void*>(this);
    return SettingsPage::qt_metacast(_clname);
}

int BufferViewSettingsPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingsPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
struct qt_meta_stringdata_BufferViewEditDlg_t {
    QByteArrayData data[3];
    char stringdata0[49];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferViewEditDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferViewEditDlg_t qt_meta_stringdata_BufferViewEditDlg = {
    {
QT_MOC_LITERAL(0, 0, 17), // "BufferViewEditDlg"
QT_MOC_LITERAL(1, 18, 29), // "on_bufferViewEdit_textChanged"
QT_MOC_LITERAL(2, 48, 0) // ""

    },
    "BufferViewEditDlg\0on_bufferViewEdit_textChanged\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferViewEditDlg[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void BufferViewEditDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferViewEditDlg *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_bufferViewEdit_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BufferViewEditDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_BufferViewEditDlg.data,
    qt_meta_data_BufferViewEditDlg,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferViewEditDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferViewEditDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferViewEditDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int BufferViewEditDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
