/****************************************************************************
** Meta object code from reading C++ file 'networkssettingspage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/settingspages/networkssettingspage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'networkssettingspage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_NetworksSettingsPage_t {
    QByteArrayData data[44];
    char stringdata0[845];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NetworksSettingsPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NetworksSettingsPage_t qt_meta_stringdata_NetworksSettingsPage = {
    {
QT_MOC_LITERAL(0, 0, 20), // "NetworksSettingsPage"
QT_MOC_LITERAL(1, 21, 4), // "save"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 4), // "load"
QT_MOC_LITERAL(4, 32, 15), // "bufferList_Open"
QT_MOC_LITERAL(5, 48, 9), // "NetworkId"
QT_MOC_LITERAL(6, 58, 16), // "widgetHasChanged"
QT_MOC_LITERAL(7, 75, 15), // "setWidgetStates"
QT_MOC_LITERAL(8, 91, 26), // "coreConnectionStateChanged"
QT_MOC_LITERAL(9, 118, 29), // "networkConnectionStateChanged"
QT_MOC_LITERAL(10, 148, 24), // "Network::ConnectionState"
QT_MOC_LITERAL(11, 173, 5), // "state"
QT_MOC_LITERAL(12, 179, 22), // "networkConnectionError"
QT_MOC_LITERAL(13, 202, 3), // "msg"
QT_MOC_LITERAL(14, 206, 14), // "displayNetwork"
QT_MOC_LITERAL(15, 221, 12), // "setItemState"
QT_MOC_LITERAL(16, 234, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(17, 251, 4), // "item"
QT_MOC_LITERAL(18, 256, 21), // "resetNetworkCapStates"
QT_MOC_LITERAL(19, 278, 19), // "setNetworkCapStates"
QT_MOC_LITERAL(20, 298, 2), // "id"
QT_MOC_LITERAL(21, 301, 18), // "clientNetworkAdded"
QT_MOC_LITERAL(22, 320, 20), // "clientNetworkRemoved"
QT_MOC_LITERAL(23, 341, 20), // "clientNetworkUpdated"
QT_MOC_LITERAL(24, 362, 19), // "clientIdentityAdded"
QT_MOC_LITERAL(25, 382, 10), // "IdentityId"
QT_MOC_LITERAL(26, 393, 21), // "clientIdentityRemoved"
QT_MOC_LITERAL(27, 415, 21), // "clientIdentityUpdated"
QT_MOC_LITERAL(28, 437, 24), // "clientNetworkCapsUpdated"
QT_MOC_LITERAL(29, 462, 10), // "sslUpdated"
QT_MOC_LITERAL(30, 473, 35), // "on_networkList_itemSelectionC..."
QT_MOC_LITERAL(31, 509, 21), // "on_addNetwork_clicked"
QT_MOC_LITERAL(32, 531, 24), // "on_deleteNetwork_clicked"
QT_MOC_LITERAL(33, 556, 24), // "on_renameNetwork_clicked"
QT_MOC_LITERAL(34, 581, 25), // "on_editIdentities_clicked"
QT_MOC_LITERAL(35, 607, 34), // "on_serverList_itemSelectionCh..."
QT_MOC_LITERAL(36, 642, 20), // "on_addServer_clicked"
QT_MOC_LITERAL(37, 663, 23), // "on_deleteServer_clicked"
QT_MOC_LITERAL(38, 687, 21), // "on_editServer_clicked"
QT_MOC_LITERAL(39, 709, 19), // "on_upServer_clicked"
QT_MOC_LITERAL(40, 729, 21), // "on_downServer_clicked"
QT_MOC_LITERAL(41, 751, 28), // "on_saslStatusDetails_clicked"
QT_MOC_LITERAL(42, 780, 34), // "on_enableCapsStatusDetails_cl..."
QT_MOC_LITERAL(43, 815, 29) // "on_enableCapsAdvanced_clicked"

    },
    "NetworksSettingsPage\0save\0\0load\0"
    "bufferList_Open\0NetworkId\0widgetHasChanged\0"
    "setWidgetStates\0coreConnectionStateChanged\0"
    "networkConnectionStateChanged\0"
    "Network::ConnectionState\0state\0"
    "networkConnectionError\0msg\0displayNetwork\0"
    "setItemState\0QListWidgetItem*\0item\0"
    "resetNetworkCapStates\0setNetworkCapStates\0"
    "id\0clientNetworkAdded\0clientNetworkRemoved\0"
    "clientNetworkUpdated\0clientIdentityAdded\0"
    "IdentityId\0clientIdentityRemoved\0"
    "clientIdentityUpdated\0clientNetworkCapsUpdated\0"
    "sslUpdated\0on_networkList_itemSelectionChanged\0"
    "on_addNetwork_clicked\0on_deleteNetwork_clicked\0"
    "on_renameNetwork_clicked\0"
    "on_editIdentities_clicked\0"
    "on_serverList_itemSelectionChanged\0"
    "on_addServer_clicked\0on_deleteServer_clicked\0"
    "on_editServer_clicked\0on_upServer_clicked\0"
    "on_downServer_clicked\0"
    "on_saslStatusDetails_clicked\0"
    "on_enableCapsStatusDetails_clicked\0"
    "on_enableCapsAdvanced_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NetworksSettingsPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      35,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  189,    2, 0x0a /* Public */,
       3,    0,  190,    2, 0x0a /* Public */,
       4,    1,  191,    2, 0x0a /* Public */,
       6,    0,  194,    2, 0x08 /* Private */,
       7,    0,  195,    2, 0x08 /* Private */,
       8,    1,  196,    2, 0x08 /* Private */,
       9,    1,  199,    2, 0x08 /* Private */,
      12,    1,  202,    2, 0x08 /* Private */,
      14,    1,  205,    2, 0x08 /* Private */,
      15,    2,  208,    2, 0x08 /* Private */,
      15,    1,  213,    2, 0x28 /* Private | MethodCloned */,
      18,    0,  216,    2, 0x08 /* Private */,
      19,    1,  217,    2, 0x08 /* Private */,
      21,    1,  220,    2, 0x08 /* Private */,
      22,    1,  223,    2, 0x08 /* Private */,
      23,    0,  226,    2, 0x08 /* Private */,
      24,    1,  227,    2, 0x08 /* Private */,
      26,    1,  230,    2, 0x08 /* Private */,
      27,    0,  233,    2, 0x08 /* Private */,
      28,    0,  234,    2, 0x08 /* Private */,
      29,    0,  235,    2, 0x08 /* Private */,
      30,    0,  236,    2, 0x08 /* Private */,
      31,    0,  237,    2, 0x08 /* Private */,
      32,    0,  238,    2, 0x08 /* Private */,
      33,    0,  239,    2, 0x08 /* Private */,
      34,    0,  240,    2, 0x08 /* Private */,
      35,    0,  241,    2, 0x08 /* Private */,
      36,    0,  242,    2, 0x08 /* Private */,
      37,    0,  243,    2, 0x08 /* Private */,
      38,    0,  244,    2, 0x08 /* Private */,
      39,    0,  245,    2, 0x08 /* Private */,
      40,    0,  246,    2, 0x08 /* Private */,
      41,    0,  247,    2, 0x08 /* Private */,
      42,    0,  248,    2, 0x08 /* Private */,
      43,    0,  249,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 16,    2,   17,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,   20,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void, 0x80000000 | 25,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void NetworksSettingsPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<NetworksSettingsPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->save(); break;
        case 1: _t->load(); break;
        case 2: _t->bufferList_Open((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 3: _t->widgetHasChanged(); break;
        case 4: _t->setWidgetStates(); break;
        case 5: _t->coreConnectionStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->networkConnectionStateChanged((*reinterpret_cast< Network::ConnectionState(*)>(_a[1]))); break;
        case 7: _t->networkConnectionError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->displayNetwork((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 9: _t->setItemState((*reinterpret_cast< NetworkId(*)>(_a[1])),(*reinterpret_cast< QListWidgetItem*(*)>(_a[2]))); break;
        case 10: _t->setItemState((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 11: _t->resetNetworkCapStates(); break;
        case 12: _t->setNetworkCapStates((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 13: _t->clientNetworkAdded((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 14: _t->clientNetworkRemoved((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 15: _t->clientNetworkUpdated(); break;
        case 16: _t->clientIdentityAdded((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 17: _t->clientIdentityRemoved((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 18: _t->clientIdentityUpdated(); break;
        case 19: _t->clientNetworkCapsUpdated(); break;
        case 20: _t->sslUpdated(); break;
        case 21: _t->on_networkList_itemSelectionChanged(); break;
        case 22: _t->on_addNetwork_clicked(); break;
        case 23: _t->on_deleteNetwork_clicked(); break;
        case 24: _t->on_renameNetwork_clicked(); break;
        case 25: _t->on_editIdentities_clicked(); break;
        case 26: _t->on_serverList_itemSelectionChanged(); break;
        case 27: _t->on_addServer_clicked(); break;
        case 28: _t->on_deleteServer_clicked(); break;
        case 29: _t->on_editServer_clicked(); break;
        case 30: _t->on_upServer_clicked(); break;
        case 31: _t->on_downServer_clicked(); break;
        case 32: _t->on_saslStatusDetails_clicked(); break;
        case 33: _t->on_enableCapsStatusDetails_clicked(); break;
        case 34: _t->on_enableCapsAdvanced_clicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject NetworksSettingsPage::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingsPage::staticMetaObject>(),
    qt_meta_stringdata_NetworksSettingsPage.data,
    qt_meta_data_NetworksSettingsPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *NetworksSettingsPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetworksSettingsPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NetworksSettingsPage.stringdata0))
        return static_cast<void*>(this);
    return SettingsPage::qt_metacast(_clname);
}

int NetworksSettingsPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingsPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    return _id;
}
struct qt_meta_stringdata_NetworkAddDlg_t {
    QByteArrayData data[5];
    char stringdata0[55];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NetworkAddDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NetworkAddDlg_t qt_meta_stringdata_NetworkAddDlg = {
    {
QT_MOC_LITERAL(0, 0, 13), // "NetworkAddDlg"
QT_MOC_LITERAL(1, 14, 15), // "setButtonStates"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 13), // "updateSslPort"
QT_MOC_LITERAL(4, 45, 9) // "isChecked"

    },
    "NetworkAddDlg\0setButtonStates\0\0"
    "updateSslPort\0isChecked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NetworkAddDlg[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x08 /* Private */,
       3,    1,   25,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,

       0        // eod
};

void NetworkAddDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<NetworkAddDlg *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setButtonStates(); break;
        case 1: _t->updateSslPort((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject NetworkAddDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_NetworkAddDlg.data,
    qt_meta_data_NetworkAddDlg,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *NetworkAddDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetworkAddDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NetworkAddDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int NetworkAddDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_NetworkEditDlg_t {
    QByteArrayData data[3];
    char stringdata0[43];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NetworkEditDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NetworkEditDlg_t qt_meta_stringdata_NetworkEditDlg = {
    {
QT_MOC_LITERAL(0, 0, 14), // "NetworkEditDlg"
QT_MOC_LITERAL(1, 15, 26), // "on_networkEdit_textChanged"
QT_MOC_LITERAL(2, 42, 0) // ""

    },
    "NetworkEditDlg\0on_networkEdit_textChanged\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NetworkEditDlg[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void NetworkEditDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<NetworkEditDlg *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_networkEdit_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject NetworkEditDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_NetworkEditDlg.data,
    qt_meta_data_NetworkEditDlg,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *NetworkEditDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetworkEditDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NetworkEditDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int NetworkEditDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_ServerEditDlg_t {
    QByteArrayData data[5];
    char stringdata0[59];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ServerEditDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ServerEditDlg_t qt_meta_stringdata_ServerEditDlg = {
    {
QT_MOC_LITERAL(0, 0, 13), // "ServerEditDlg"
QT_MOC_LITERAL(1, 14, 19), // "on_host_textChanged"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 13), // "updateSslPort"
QT_MOC_LITERAL(4, 49, 9) // "isChecked"

    },
    "ServerEditDlg\0on_host_textChanged\0\0"
    "updateSslPort\0isChecked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ServerEditDlg[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x08 /* Private */,
       3,    1,   25,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,

       0        // eod
};

void ServerEditDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ServerEditDlg *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_host_textChanged(); break;
        case 1: _t->updateSslPort((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ServerEditDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_ServerEditDlg.data,
    qt_meta_data_ServerEditDlg,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ServerEditDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ServerEditDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ServerEditDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int ServerEditDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_CapsEditDlg_t {
    QByteArrayData data[4];
    char stringdata0[57];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CapsEditDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CapsEditDlg_t qt_meta_stringdata_CapsEditDlg = {
    {
QT_MOC_LITERAL(0, 0, 11), // "CapsEditDlg"
QT_MOC_LITERAL(1, 12, 15), // "defaultSkipCaps"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 27) // "on_skipCapsEdit_textChanged"

    },
    "CapsEditDlg\0defaultSkipCaps\0\0"
    "on_skipCapsEdit_textChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CapsEditDlg[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x08 /* Private */,
       3,    1,   25,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void CapsEditDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CapsEditDlg *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->defaultSkipCaps(); break;
        case 1: _t->on_skipCapsEdit_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CapsEditDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_CapsEditDlg.data,
    qt_meta_data_CapsEditDlg,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CapsEditDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CapsEditDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CapsEditDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int CapsEditDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_SaveNetworksDlg_t {
    QByteArrayData data[3];
    char stringdata0[29];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SaveNetworksDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SaveNetworksDlg_t qt_meta_stringdata_SaveNetworksDlg = {
    {
QT_MOC_LITERAL(0, 0, 15), // "SaveNetworksDlg"
QT_MOC_LITERAL(1, 16, 11), // "clientEvent"
QT_MOC_LITERAL(2, 28, 0) // ""

    },
    "SaveNetworksDlg\0clientEvent\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SaveNetworksDlg[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void SaveNetworksDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SaveNetworksDlg *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clientEvent(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject SaveNetworksDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_SaveNetworksDlg.data,
    qt_meta_data_SaveNetworksDlg,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SaveNetworksDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SaveNetworksDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SaveNetworksDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int SaveNetworksDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
