/****************************************************************************
** Meta object code from reading C++ file 'coresession.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/coresession.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'coresession.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreSession_t {
    QByteArrayData data[74];
    char stringdata0[964];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreSession_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreSession_t qt_meta_stringdata_CoreSession = {
    {
QT_MOC_LITERAL(0, 0, 11), // "CoreSession"
QT_MOC_LITERAL(1, 12, 11), // "initialized"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 20), // "sessionStateReceived"
QT_MOC_LITERAL(4, 46, 22), // "Protocol::SessionState"
QT_MOC_LITERAL(5, 69, 12), // "sessionState"
QT_MOC_LITERAL(6, 82, 10), // "displayMsg"
QT_MOC_LITERAL(7, 93, 7), // "Message"
QT_MOC_LITERAL(8, 101, 7), // "message"
QT_MOC_LITERAL(9, 109, 16), // "displayStatusMsg"
QT_MOC_LITERAL(10, 126, 15), // "identityCreated"
QT_MOC_LITERAL(11, 142, 8), // "Identity"
QT_MOC_LITERAL(12, 151, 8), // "identity"
QT_MOC_LITERAL(13, 160, 15), // "identityRemoved"
QT_MOC_LITERAL(14, 176, 10), // "IdentityId"
QT_MOC_LITERAL(15, 187, 14), // "networkCreated"
QT_MOC_LITERAL(16, 202, 9), // "NetworkId"
QT_MOC_LITERAL(17, 212, 14), // "networkRemoved"
QT_MOC_LITERAL(18, 227, 19), // "networkDisconnected"
QT_MOC_LITERAL(19, 247, 15), // "passwordChanged"
QT_MOC_LITERAL(20, 263, 7), // "PeerPtr"
QT_MOC_LITERAL(21, 271, 4), // "peer"
QT_MOC_LITERAL(22, 276, 7), // "success"
QT_MOC_LITERAL(23, 284, 18), // "disconnectFromCore"
QT_MOC_LITERAL(24, 303, 9), // "addClient"
QT_MOC_LITERAL(25, 313, 11), // "RemotePeer*"
QT_MOC_LITERAL(26, 325, 13), // "InternalPeer*"
QT_MOC_LITERAL(27, 339, 8), // "shutdown"
QT_MOC_LITERAL(28, 348, 13), // "msgFromClient"
QT_MOC_LITERAL(29, 362, 10), // "BufferInfo"
QT_MOC_LITERAL(30, 373, 14), // "createIdentity"
QT_MOC_LITERAL(31, 388, 10), // "additional"
QT_MOC_LITERAL(32, 399, 12), // "CoreIdentity"
QT_MOC_LITERAL(33, 412, 14), // "removeIdentity"
QT_MOC_LITERAL(34, 427, 13), // "createNetwork"
QT_MOC_LITERAL(35, 441, 11), // "NetworkInfo"
QT_MOC_LITERAL(36, 453, 4), // "info"
QT_MOC_LITERAL(37, 458, 18), // "persistentChannels"
QT_MOC_LITERAL(38, 477, 13), // "removeNetwork"
QT_MOC_LITERAL(39, 491, 7), // "network"
QT_MOC_LITERAL(40, 499, 12), // "renameBuffer"
QT_MOC_LITERAL(41, 512, 9), // "networkId"
QT_MOC_LITERAL(42, 522, 7), // "newName"
QT_MOC_LITERAL(43, 530, 7), // "oldName"
QT_MOC_LITERAL(44, 538, 14), // "changePassword"
QT_MOC_LITERAL(45, 553, 8), // "userName"
QT_MOC_LITERAL(46, 562, 11), // "oldPassword"
QT_MOC_LITERAL(47, 574, 11), // "newPassword"
QT_MOC_LITERAL(48, 586, 10), // "kickClient"
QT_MOC_LITERAL(49, 597, 6), // "peerId"
QT_MOC_LITERAL(50, 604, 22), // "QHash<QString,QString>"
QT_MOC_LITERAL(51, 627, 13), // "bufferCiphers"
QT_MOC_LITERAL(52, 641, 25), // "QHash<QString,QByteArray>"
QT_MOC_LITERAL(53, 667, 2), // "id"
QT_MOC_LITERAL(54, 670, 15), // "setBufferCipher"
QT_MOC_LITERAL(55, 686, 10), // "bufferName"
QT_MOC_LITERAL(56, 697, 6), // "cipher"
QT_MOC_LITERAL(57, 704, 10), // "globalAway"
QT_MOC_LITERAL(58, 715, 3), // "msg"
QT_MOC_LITERAL(59, 719, 14), // "skipFormatting"
QT_MOC_LITERAL(60, 734, 12), // "removeClient"
QT_MOC_LITERAL(61, 747, 5), // "Peer*"
QT_MOC_LITERAL(62, 753, 23), // "recvStatusMsgFromServer"
QT_MOC_LITERAL(63, 777, 21), // "recvMessageFromServer"
QT_MOC_LITERAL(64, 799, 10), // "RawMessage"
QT_MOC_LITERAL(65, 810, 14), // "destroyNetwork"
QT_MOC_LITERAL(66, 825, 16), // "clientsConnected"
QT_MOC_LITERAL(67, 842, 19), // "clientsDisconnected"
QT_MOC_LITERAL(68, 862, 22), // "updateIdentityBySender"
QT_MOC_LITERAL(69, 885, 16), // "saveSessionState"
QT_MOC_LITERAL(70, 902, 21), // "onNetworkDisconnected"
QT_MOC_LITERAL(71, 924, 19), // "processMessageEvent"
QT_MOC_LITERAL(72, 944, 13), // "MessageEvent*"
QT_MOC_LITERAL(73, 958, 5) // "event"

    },
    "CoreSession\0initialized\0\0sessionStateReceived\0"
    "Protocol::SessionState\0sessionState\0"
    "displayMsg\0Message\0message\0displayStatusMsg\0"
    "identityCreated\0Identity\0identity\0"
    "identityRemoved\0IdentityId\0networkCreated\0"
    "NetworkId\0networkRemoved\0networkDisconnected\0"
    "passwordChanged\0PeerPtr\0peer\0success\0"
    "disconnectFromCore\0addClient\0RemotePeer*\0"
    "InternalPeer*\0shutdown\0msgFromClient\0"
    "BufferInfo\0createIdentity\0additional\0"
    "CoreIdentity\0removeIdentity\0createNetwork\0"
    "NetworkInfo\0info\0persistentChannels\0"
    "removeNetwork\0network\0renameBuffer\0"
    "networkId\0newName\0oldName\0changePassword\0"
    "userName\0oldPassword\0newPassword\0"
    "kickClient\0peerId\0QHash<QString,QString>\0"
    "bufferCiphers\0QHash<QString,QByteArray>\0"
    "id\0setBufferCipher\0bufferName\0cipher\0"
    "globalAway\0msg\0skipFormatting\0"
    "removeClient\0Peer*\0recvStatusMsgFromServer\0"
    "recvMessageFromServer\0RawMessage\0"
    "destroyNetwork\0clientsConnected\0"
    "clientsDisconnected\0updateIdentityBySender\0"
    "saveSessionState\0onNetworkDisconnected\0"
    "processMessageEvent\0MessageEvent*\0"
    "event"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreSession[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      40,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  214,    2, 0x06 /* Public */,
       3,    1,  215,    2, 0x06 /* Public */,
       6,    1,  218,    2, 0x06 /* Public */,
       9,    2,  221,    2, 0x06 /* Public */,
      10,    1,  226,    2, 0x06 /* Public */,
      13,    1,  229,    2, 0x06 /* Public */,
      15,    1,  232,    2, 0x06 /* Public */,
      17,    1,  235,    2, 0x06 /* Public */,
      18,    1,  238,    2, 0x06 /* Public */,
      19,    2,  241,    2, 0x06 /* Public */,
      23,    0,  246,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      24,    1,  247,    2, 0x0a /* Public */,
      24,    1,  250,    2, 0x0a /* Public */,
      27,    0,  253,    2, 0x0a /* Public */,
      28,    2,  254,    2, 0x0a /* Public */,
      30,    2,  259,    2, 0x0a /* Public */,
      30,    1,  264,    2, 0x0a /* Public */,
      33,    1,  267,    2, 0x0a /* Public */,
      34,    2,  270,    2, 0x0a /* Public */,
      34,    1,  275,    2, 0x2a /* Public | MethodCloned */,
      38,    1,  278,    2, 0x0a /* Public */,
      40,    3,  281,    2, 0x0a /* Public */,
      44,    4,  288,    2, 0x0a /* Public */,
      48,    1,  297,    2, 0x0a /* Public */,
      37,    1,  300,    2, 0x0a /* Public */,
      51,    1,  303,    2, 0x0a /* Public */,
      54,    3,  306,    2, 0x0a /* Public */,
      57,    2,  313,    2, 0x0a /* Public */,
      57,    1,  318,    2, 0x2a /* Public | MethodCloned */,
      57,    0,  321,    2, 0x2a /* Public | MethodCloned */,
      60,    1,  322,    2, 0x08 /* Private */,
      62,    1,  325,    2, 0x08 /* Private */,
      63,    1,  328,    2, 0x08 /* Private */,
      65,    1,  331,    2, 0x08 /* Private */,
      66,    0,  334,    2, 0x08 /* Private */,
      67,    0,  335,    2, 0x08 /* Private */,
      68,    0,  336,    2, 0x08 /* Private */,
      69,    0,  337,    2, 0x08 /* Private */,
      70,    1,  338,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      71,    1,  341,    2, 0x00 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    2,    2,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, 0x80000000 | 14,   12,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, 0x80000000 | 20, QMetaType::Bool,   21,   22,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 25,   21,
    QMetaType::Void, 0x80000000 | 26,   21,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 29, QMetaType::QString,    2,    8,
    QMetaType::Void, 0x80000000 | 11, QMetaType::QVariantMap,   12,   31,
    QMetaType::Void, 0x80000000 | 32,   12,
    QMetaType::Void, 0x80000000 | 14,   12,
    QMetaType::Void, 0x80000000 | 35, QMetaType::QStringList,   36,   37,
    QMetaType::Void, 0x80000000 | 35,   36,
    QMetaType::Void, 0x80000000 | 16,   39,
    QMetaType::Void, 0x80000000 | 16, QMetaType::QString, QMetaType::QString,   41,   42,   43,
    QMetaType::Void, 0x80000000 | 20, QMetaType::QString, QMetaType::QString, QMetaType::QString,   21,   45,   46,   47,
    QMetaType::Void, QMetaType::Int,   49,
    0x80000000 | 50, 0x80000000 | 16,    2,
    0x80000000 | 52, 0x80000000 | 16,   53,
    QMetaType::Void, 0x80000000 | 16, QMetaType::QString, QMetaType::QByteArray,   53,   55,   56,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   58,   59,
    QMetaType::Void, QMetaType::QString,   58,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 61,   21,
    QMetaType::Void, QMetaType::QString,   58,
    QMetaType::Void, 0x80000000 | 64,   58,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 16,   41,

 // methods: parameters
    QMetaType::Void, 0x80000000 | 72,   73,

       0        // eod
};

void CoreSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreSession *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->initialized(); break;
        case 1: _t->sessionStateReceived((*reinterpret_cast< const Protocol::SessionState(*)>(_a[1]))); break;
        case 2: _t->displayMsg((*reinterpret_cast< Message(*)>(_a[1]))); break;
        case 3: _t->displayStatusMsg((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 4: _t->identityCreated((*reinterpret_cast< const Identity(*)>(_a[1]))); break;
        case 5: _t->identityRemoved((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 6: _t->networkCreated((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 7: _t->networkRemoved((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 8: _t->networkDisconnected((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 9: _t->passwordChanged((*reinterpret_cast< PeerPtr(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 10: _t->disconnectFromCore(); break;
        case 11: _t->addClient((*reinterpret_cast< RemotePeer*(*)>(_a[1]))); break;
        case 12: _t->addClient((*reinterpret_cast< InternalPeer*(*)>(_a[1]))); break;
        case 13: _t->shutdown(); break;
        case 14: _t->msgFromClient((*reinterpret_cast< BufferInfo(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 15: _t->createIdentity((*reinterpret_cast< const Identity(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2]))); break;
        case 16: _t->createIdentity((*reinterpret_cast< const CoreIdentity(*)>(_a[1]))); break;
        case 17: _t->removeIdentity((*reinterpret_cast< IdentityId(*)>(_a[1]))); break;
        case 18: _t->createNetwork((*reinterpret_cast< const NetworkInfo(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 19: _t->createNetwork((*reinterpret_cast< const NetworkInfo(*)>(_a[1]))); break;
        case 20: _t->removeNetwork((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 21: _t->renameBuffer((*reinterpret_cast< const NetworkId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 22: _t->changePassword((*reinterpret_cast< PeerPtr(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 23: _t->kickClient((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: { QHash<QString,QString> _r = _t->persistentChannels((*reinterpret_cast< NetworkId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QHash<QString,QString>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QHash<QString,QByteArray> _r = _t->bufferCiphers((*reinterpret_cast< NetworkId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QHash<QString,QByteArray>*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->setBufferCipher((*reinterpret_cast< NetworkId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3]))); break;
        case 27: _t->globalAway((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 28: _t->globalAway((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 29: _t->globalAway(); break;
        case 30: _t->removeClient((*reinterpret_cast< Peer*(*)>(_a[1]))); break;
        case 31: _t->recvStatusMsgFromServer((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 32: _t->recvMessageFromServer((*reinterpret_cast< RawMessage(*)>(_a[1]))); break;
        case 33: _t->destroyNetwork((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 34: _t->clientsConnected(); break;
        case 35: _t->clientsDisconnected(); break;
        case 36: _t->updateIdentityBySender(); break;
        case 37: _t->saveSessionState(); break;
        case 38: _t->onNetworkDisconnected((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 39: _t->processMessageEvent((*reinterpret_cast< MessageEvent*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Message >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Identity >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PeerPtr >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Identity >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IdentityId >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkInfo >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkInfo >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PeerPtr >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Peer* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CoreSession::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreSession::initialized)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (CoreSession::*)(const Protocol::SessionState & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreSession::sessionStateReceived)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (CoreSession::*)(Message );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreSession::displayMsg)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (CoreSession::*)(QString , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreSession::displayStatusMsg)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (CoreSession::*)(const Identity & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreSession::identityCreated)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (CoreSession::*)(IdentityId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreSession::identityRemoved)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (CoreSession::*)(NetworkId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreSession::networkCreated)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (CoreSession::*)(NetworkId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreSession::networkRemoved)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (CoreSession::*)(NetworkId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreSession::networkDisconnected)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (CoreSession::*)(PeerPtr , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreSession::passwordChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (CoreSession::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreSession::disconnectFromCore)) {
                *result = 10;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreSession::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_CoreSession.data,
    qt_meta_data_CoreSession,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreSession.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CoreSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
    return _id;
}

// SIGNAL 0
void CoreSession::initialized()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CoreSession::sessionStateReceived(const Protocol::SessionState & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void CoreSession::displayMsg(Message _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void CoreSession::displayStatusMsg(QString _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void CoreSession::identityCreated(const Identity & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void CoreSession::identityRemoved(IdentityId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void CoreSession::networkCreated(NetworkId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void CoreSession::networkRemoved(NetworkId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void CoreSession::networkDisconnected(NetworkId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void CoreSession::passwordChanged(PeerPtr _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void CoreSession::disconnectFromCore()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
