/********************************************************************************
** Form generated from reading UI file 'topicwidgetsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TOPICWIDGETSETTINGSPAGE_H
#define UI_TOPICWIDGETSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "fontselector.h"

QT_BEGIN_NAMESPACE

class Ui_TopicWidgetSettingsPage
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QCheckBox *customFont;
    FontSelector *topicWidgetFont;
    QCheckBox *dynamicResize;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QCheckBox *resizeOnHover;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *TopicWidgetSettingsPage)
    {
        if (TopicWidgetSettingsPage->objectName().isEmpty())
            TopicWidgetSettingsPage->setObjectName(QString::fromUtf8("TopicWidgetSettingsPage"));
        TopicWidgetSettingsPage->resize(470, 370);
        verticalLayout = new QVBoxLayout(TopicWidgetSettingsPage);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        customFont = new QCheckBox(TopicWidgetSettingsPage);
        customFont->setObjectName(QString::fromUtf8("customFont"));
        customFont->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Fonts/UseCustomTopicWidgetFont")));
        customFont->setProperty("defaultValue", QVariant(false));

        horizontalLayout->addWidget(customFont);

        topicWidgetFont = new FontSelector(TopicWidgetSettingsPage);
        topicWidgetFont->setObjectName(QString::fromUtf8("topicWidgetFont"));
        topicWidgetFont->setEnabled(false);
        topicWidgetFont->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Fonts/TopicWidget")));
        QFont font;
        topicWidgetFont->setProperty("defaultValue", QVariant(font));

        horizontalLayout->addWidget(topicWidgetFont);


        verticalLayout->addLayout(horizontalLayout);

        dynamicResize = new QCheckBox(TopicWidgetSettingsPage);
        dynamicResize->setObjectName(QString::fromUtf8("dynamicResize"));
        dynamicResize->setChecked(true);
        dynamicResize->setProperty("settingsKey", QVariant(QString::fromUtf8("DynamicResize")));
        dynamicResize->setProperty("defaultValue", QVariant(true));

        verticalLayout->addWidget(dynamicResize);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalSpacer = new QSpacerItem(20, 16, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        resizeOnHover = new QCheckBox(TopicWidgetSettingsPage);
        resizeOnHover->setObjectName(QString::fromUtf8("resizeOnHover"));
        resizeOnHover->setChecked(true);
        resizeOnHover->setProperty("settingsKey", QVariant(QString::fromUtf8("ResizeOnHover")));
        resizeOnHover->setProperty("defaultValue", QVariant(true));

        horizontalLayout_2->addWidget(resizeOnHover);


        verticalLayout->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 274, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        QWidget::setTabOrder(customFont, dynamicResize);
        QWidget::setTabOrder(dynamicResize, resizeOnHover);

        retranslateUi(TopicWidgetSettingsPage);
        QObject::connect(customFont, SIGNAL(toggled(bool)), topicWidgetFont, SLOT(setEnabled(bool)));
        QObject::connect(dynamicResize, SIGNAL(toggled(bool)), resizeOnHover, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(TopicWidgetSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *TopicWidgetSettingsPage)
    {
        TopicWidgetSettingsPage->setWindowTitle(QCoreApplication::translate("TopicWidgetSettingsPage", "Form", nullptr));
        customFont->setText(QCoreApplication::translate("TopicWidgetSettingsPage", "Custom font:", nullptr));
        dynamicResize->setText(QCoreApplication::translate("TopicWidgetSettingsPage", "Resize dynamically to fit contents", nullptr));
        resizeOnHover->setText(QCoreApplication::translate("TopicWidgetSettingsPage", "On hover only", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TopicWidgetSettingsPage: public Ui_TopicWidgetSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TOPICWIDGETSETTINGSPAGE_H
