/****************************************************************************
** Meta object code from reading C++ file 'ircchannel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/ircchannel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ircchannel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_IrcChannel_t {
    QByteArrayData data[43];
    char stringdata0[479];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_IrcChannel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_IrcChannel_t qt_meta_stringdata_IrcChannel = {
    {
QT_MOC_LITERAL(0, 0, 10), // "IrcChannel"
QT_MOC_LITERAL(1, 11, 8), // "topicSet"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 5), // "topic"
QT_MOC_LITERAL(4, 27, 12), // "encryptedSet"
QT_MOC_LITERAL(5, 40, 9), // "encrypted"
QT_MOC_LITERAL(6, 50, 14), // "ircUsersJoined"
QT_MOC_LITERAL(7, 65, 15), // "QList<IrcUser*>"
QT_MOC_LITERAL(8, 81, 8), // "ircusers"
QT_MOC_LITERAL(9, 90, 13), // "ircUserParted"
QT_MOC_LITERAL(10, 104, 8), // "IrcUser*"
QT_MOC_LITERAL(11, 113, 7), // "ircuser"
QT_MOC_LITERAL(12, 121, 14), // "ircUserNickSet"
QT_MOC_LITERAL(13, 136, 4), // "nick"
QT_MOC_LITERAL(14, 141, 16), // "ircUserModeAdded"
QT_MOC_LITERAL(15, 158, 4), // "mode"
QT_MOC_LITERAL(16, 163, 18), // "ircUserModeRemoved"
QT_MOC_LITERAL(17, 182, 15), // "ircUserModesSet"
QT_MOC_LITERAL(18, 198, 5), // "modes"
QT_MOC_LITERAL(19, 204, 6), // "parted"
QT_MOC_LITERAL(20, 211, 8), // "setTopic"
QT_MOC_LITERAL(21, 220, 11), // "setPassword"
QT_MOC_LITERAL(22, 232, 8), // "password"
QT_MOC_LITERAL(23, 241, 12), // "setEncrypted"
QT_MOC_LITERAL(24, 254, 12), // "joinIrcUsers"
QT_MOC_LITERAL(25, 267, 5), // "users"
QT_MOC_LITERAL(26, 273, 5), // "nicks"
QT_MOC_LITERAL(27, 279, 11), // "joinIrcUser"
QT_MOC_LITERAL(28, 291, 4), // "part"
QT_MOC_LITERAL(29, 296, 12), // "setUserModes"
QT_MOC_LITERAL(30, 309, 11), // "addUserMode"
QT_MOC_LITERAL(31, 321, 14), // "removeUserMode"
QT_MOC_LITERAL(32, 336, 14), // "addChannelMode"
QT_MOC_LITERAL(33, 351, 5), // "value"
QT_MOC_LITERAL(34, 357, 17), // "removeChannelMode"
QT_MOC_LITERAL(35, 375, 13), // "initUserModes"
QT_MOC_LITERAL(36, 389, 13), // "initChanModes"
QT_MOC_LITERAL(37, 403, 16), // "initSetUserModes"
QT_MOC_LITERAL(38, 420, 9), // "usermodes"
QT_MOC_LITERAL(39, 430, 16), // "initSetChanModes"
QT_MOC_LITERAL(40, 447, 9), // "chanModes"
QT_MOC_LITERAL(41, 457, 16), // "ircUserDestroyed"
QT_MOC_LITERAL(42, 474, 4) // "name"

    },
    "IrcChannel\0topicSet\0\0topic\0encryptedSet\0"
    "encrypted\0ircUsersJoined\0QList<IrcUser*>\0"
    "ircusers\0ircUserParted\0IrcUser*\0ircuser\0"
    "ircUserNickSet\0nick\0ircUserModeAdded\0"
    "mode\0ircUserModeRemoved\0ircUserModesSet\0"
    "modes\0parted\0setTopic\0setPassword\0"
    "password\0setEncrypted\0joinIrcUsers\0"
    "users\0nicks\0joinIrcUser\0part\0setUserModes\0"
    "addUserMode\0removeUserMode\0addChannelMode\0"
    "value\0removeChannelMode\0initUserModes\0"
    "initChanModes\0initSetUserModes\0usermodes\0"
    "initSetChanModes\0chanModes\0ircUserDestroyed\0"
    "name"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_IrcChannel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      31,   14, // methods
       4,  282, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  169,    2, 0x06 /* Public */,
       4,    1,  172,    2, 0x06 /* Public */,
       6,    1,  175,    2, 0x06 /* Public */,
       9,    1,  178,    2, 0x06 /* Public */,
      12,    2,  181,    2, 0x06 /* Public */,
      14,    2,  186,    2, 0x06 /* Public */,
      16,    2,  191,    2, 0x06 /* Public */,
      17,    2,  196,    2, 0x06 /* Public */,
      19,    0,  201,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      20,    1,  202,    2, 0x0a /* Public */,
      21,    1,  205,    2, 0x0a /* Public */,
      23,    1,  208,    2, 0x0a /* Public */,
      24,    2,  211,    2, 0x0a /* Public */,
      24,    2,  216,    2, 0x0a /* Public */,
      27,    1,  221,    2, 0x0a /* Public */,
      28,    1,  224,    2, 0x0a /* Public */,
      28,    1,  227,    2, 0x0a /* Public */,
      29,    2,  230,    2, 0x0a /* Public */,
      29,    2,  235,    2, 0x0a /* Public */,
      30,    2,  240,    2, 0x0a /* Public */,
      30,    2,  245,    2, 0x0a /* Public */,
      31,    2,  250,    2, 0x0a /* Public */,
      31,    2,  255,    2, 0x0a /* Public */,
      32,    2,  260,    2, 0x0a /* Public */,
      34,    2,  265,    2, 0x0a /* Public */,
      35,    0,  270,    2, 0x0a /* Public */,
      36,    0,  271,    2, 0x0a /* Public */,
      37,    1,  272,    2, 0x0a /* Public */,
      39,    1,  275,    2, 0x0a /* Public */,
      41,    0,  278,    2, 0x08 /* Private */,
      12,    1,  279,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10, QMetaType::QString,   11,   13,
    QMetaType::Void, 0x80000000 | 10, QMetaType::QString,   11,   15,
    QMetaType::Void, 0x80000000 | 10, QMetaType::QString,   11,   15,
    QMetaType::Void, 0x80000000 | 10, QMetaType::QString,   11,   18,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,   22,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, 0x80000000 | 7, QMetaType::QStringList,   25,   18,
    QMetaType::Void, QMetaType::QStringList, QMetaType::QStringList,   26,   18,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void, 0x80000000 | 10, QMetaType::QString,   11,   18,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   18,
    QMetaType::Void, 0x80000000 | 10, QMetaType::QString,   11,   15,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   15,
    QMetaType::Void, 0x80000000 | 10, QMetaType::QString,   11,   15,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   15,
    QMetaType::Void, QMetaType::QChar, QMetaType::QString,   15,   33,
    QMetaType::Void, QMetaType::QChar, QMetaType::QString,   15,   33,
    QMetaType::QVariantMap,
    QMetaType::QVariantMap,
    QMetaType::Void, QMetaType::QVariantMap,   38,
    QMetaType::Void, QMetaType::QVariantMap,   40,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   13,

 // properties: name, type, flags
      42, QMetaType::QString, 0x00095001,
       3, QMetaType::QString, 0x00095103,
      22, QMetaType::QString, 0x00095103,
       5, QMetaType::Bool, 0x00095103,

       0        // eod
};

void IrcChannel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<IrcChannel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->topicSet((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->encryptedSet((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->ircUsersJoined((*reinterpret_cast< const QList<IrcUser*>(*)>(_a[1]))); break;
        case 3: _t->ircUserParted((*reinterpret_cast< IrcUser*(*)>(_a[1]))); break;
        case 4: _t->ircUserNickSet((*reinterpret_cast< IrcUser*(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 5: _t->ircUserModeAdded((*reinterpret_cast< IrcUser*(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 6: _t->ircUserModeRemoved((*reinterpret_cast< IrcUser*(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 7: _t->ircUserModesSet((*reinterpret_cast< IrcUser*(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 8: _t->parted(); break;
        case 9: _t->setTopic((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->setPassword((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->setEncrypted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->joinIrcUsers((*reinterpret_cast< const QList<IrcUser*>(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 13: _t->joinIrcUsers((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 14: _t->joinIrcUser((*reinterpret_cast< IrcUser*(*)>(_a[1]))); break;
        case 15: _t->part((*reinterpret_cast< IrcUser*(*)>(_a[1]))); break;
        case 16: _t->part((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: _t->setUserModes((*reinterpret_cast< IrcUser*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 18: _t->setUserModes((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 19: _t->addUserMode((*reinterpret_cast< IrcUser*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 20: _t->addUserMode((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 21: _t->removeUserMode((*reinterpret_cast< IrcUser*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 22: _t->removeUserMode((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 23: _t->addChannelMode((*reinterpret_cast< const QChar(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 24: _t->removeChannelMode((*reinterpret_cast< const QChar(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 25: { QVariantMap _r = _t->initUserModes();
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 26: { QVariantMap _r = _t->initChanModes();
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->initSetUserModes((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 28: _t->initSetChanModes((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 29: _t->ircUserDestroyed(); break;
        case 30: _t->ircUserNickSet((*reinterpret_cast< QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (IrcChannel::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcChannel::topicSet)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (IrcChannel::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcChannel::encryptedSet)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (IrcChannel::*)(const QList<IrcUser*> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcChannel::ircUsersJoined)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (IrcChannel::*)(IrcUser * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcChannel::ircUserParted)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (IrcChannel::*)(IrcUser * , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcChannel::ircUserNickSet)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (IrcChannel::*)(IrcUser * , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcChannel::ircUserModeAdded)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (IrcChannel::*)(IrcUser * , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcChannel::ircUserModeRemoved)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (IrcChannel::*)(IrcUser * , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcChannel::ircUserModesSet)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (IrcChannel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&IrcChannel::parted)) {
                *result = 8;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<IrcChannel *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->topic(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->password(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->encrypted(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<IrcChannel *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setTopic(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setPassword(*reinterpret_cast< QString*>(_v)); break;
        case 3: _t->setEncrypted(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject IrcChannel::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_IrcChannel.data,
    qt_meta_data_IrcChannel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *IrcChannel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IrcChannel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_IrcChannel.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int IrcChannel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 31;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 4;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 4;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void IrcChannel::topicSet(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void IrcChannel::encryptedSet(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void IrcChannel::ircUsersJoined(const QList<IrcUser*> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void IrcChannel::ircUserParted(IrcUser * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void IrcChannel::ircUserNickSet(IrcUser * _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void IrcChannel::ircUserModeAdded(IrcUser * _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void IrcChannel::ircUserModeRemoved(IrcUser * _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void IrcChannel::ircUserModesSet(IrcUser * _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void IrcChannel::parted()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
