/****************************************************************************
** Meta object code from reading C++ file 'buffermodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/client/buffermodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'buffermodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BufferModel_t {
    QByteArrayData data[31];
    char stringdata0[368];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferModel_t qt_meta_stringdata_BufferModel = {
    {
QT_MOC_LITERAL(0, 0, 11), // "BufferModel"
QT_MOC_LITERAL(1, 12, 15), // "setCurrentIndex"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 11), // "QModelIndex"
QT_MOC_LITERAL(4, 41, 10), // "newCurrent"
QT_MOC_LITERAL(5, 52, 14), // "switchToBuffer"
QT_MOC_LITERAL(6, 67, 8), // "BufferId"
QT_MOC_LITERAL(7, 76, 8), // "bufferId"
QT_MOC_LITERAL(8, 85, 19), // "switchToBufferIndex"
QT_MOC_LITERAL(9, 105, 9), // "bufferIdx"
QT_MOC_LITERAL(10, 115, 20), // "switchToOrJoinBuffer"
QT_MOC_LITERAL(11, 136, 9), // "NetworkId"
QT_MOC_LITERAL(12, 146, 7), // "network"
QT_MOC_LITERAL(13, 154, 10), // "bufferName"
QT_MOC_LITERAL(14, 165, 7), // "isQuery"
QT_MOC_LITERAL(15, 173, 20), // "switchToOrStartQuery"
QT_MOC_LITERAL(16, 194, 4), // "nick"
QT_MOC_LITERAL(17, 199, 27), // "switchToBufferAfterCreation"
QT_MOC_LITERAL(18, 227, 4), // "name"
QT_MOC_LITERAL(19, 232, 20), // "debug_currentChanged"
QT_MOC_LITERAL(20, 253, 7), // "current"
QT_MOC_LITERAL(21, 261, 8), // "previous"
QT_MOC_LITERAL(22, 270, 10), // "newNetwork"
QT_MOC_LITERAL(23, 281, 2), // "id"
QT_MOC_LITERAL(24, 284, 24), // "networkConnectionChanged"
QT_MOC_LITERAL(25, 309, 24), // "Network::ConnectionState"
QT_MOC_LITERAL(26, 334, 5), // "state"
QT_MOC_LITERAL(27, 340, 10), // "newBuffers"
QT_MOC_LITERAL(28, 351, 6), // "parent"
QT_MOC_LITERAL(29, 358, 5), // "start"
QT_MOC_LITERAL(30, 364, 3) // "end"

    },
    "BufferModel\0setCurrentIndex\0\0QModelIndex\0"
    "newCurrent\0switchToBuffer\0BufferId\0"
    "bufferId\0switchToBufferIndex\0bufferIdx\0"
    "switchToOrJoinBuffer\0NetworkId\0network\0"
    "bufferName\0isQuery\0switchToOrStartQuery\0"
    "nick\0switchToBufferAfterCreation\0name\0"
    "debug_currentChanged\0current\0previous\0"
    "newNetwork\0id\0networkConnectionChanged\0"
    "Network::ConnectionState\0state\0"
    "newBuffers\0parent\0start\0end"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x0a /* Public */,
       5,    1,   72,    2, 0x0a /* Public */,
       8,    1,   75,    2, 0x0a /* Public */,
      10,    3,   78,    2, 0x0a /* Public */,
      10,    2,   85,    2, 0x2a /* Public | MethodCloned */,
      15,    2,   90,    2, 0x0a /* Public */,
      17,    2,   95,    2, 0x0a /* Public */,
      19,    2,  100,    2, 0x08 /* Private */,
      22,    1,  105,    2, 0x08 /* Private */,
      24,    1,  108,    2, 0x08 /* Private */,
      27,    3,  111,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 3,    9,
    QMetaType::Void, 0x80000000 | 11, QMetaType::QString, QMetaType::Bool,   12,   13,   14,
    QMetaType::Void, 0x80000000 | 11, QMetaType::QString,   12,   13,
    QMetaType::Void, 0x80000000 | 11, QMetaType::QString,   12,   16,
    QMetaType::Void, 0x80000000 | 11, QMetaType::QString,   12,   18,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,   20,   21,
    QMetaType::Void, 0x80000000 | 11,   23,
    QMetaType::Void, 0x80000000 | 25,   26,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int, QMetaType::Int,   28,   29,   30,

       0        // eod
};

void BufferModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setCurrentIndex((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 1: _t->switchToBuffer((*reinterpret_cast< const BufferId(*)>(_a[1]))); break;
        case 2: _t->switchToBufferIndex((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 3: _t->switchToOrJoinBuffer((*reinterpret_cast< NetworkId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 4: _t->switchToOrJoinBuffer((*reinterpret_cast< NetworkId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->switchToOrStartQuery((*reinterpret_cast< NetworkId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: _t->switchToBufferAfterCreation((*reinterpret_cast< NetworkId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 7: _t->debug_currentChanged((*reinterpret_cast< QModelIndex(*)>(_a[1])),(*reinterpret_cast< QModelIndex(*)>(_a[2]))); break;
        case 8: _t->newNetwork((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        case 9: _t->networkConnectionChanged((*reinterpret_cast< Network::ConnectionState(*)>(_a[1]))); break;
        case 10: _t->newBuffers((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BufferModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_meta_stringdata_BufferModel.data,
    qt_meta_data_BufferModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferModel.stringdata0))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int BufferModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
