/****************************************************************************
** Meta object code from reading C++ file 'coreconfigwizard.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/coreconfigwizard.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'coreconfigwizard.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreConfigWizard_t {
    QByteArrayData data[17];
    char stringdata0[202];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreConfigWizard_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreConfigWizard_t qt_meta_stringdata_CoreConfigWizard = {
    {
QT_MOC_LITERAL(0, 0, 16), // "CoreConfigWizard"
QT_MOC_LITERAL(1, 17, 9), // "setupCore"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 9), // "setupData"
QT_MOC_LITERAL(4, 38, 11), // "loginToCore"
QT_MOC_LITERAL(5, 50, 4), // "user"
QT_MOC_LITERAL(6, 55, 8), // "password"
QT_MOC_LITERAL(7, 64, 16), // "rememberPassword"
QT_MOC_LITERAL(8, 81, 12), // "syncFinished"
QT_MOC_LITERAL(9, 94, 16), // "prepareCoreSetup"
QT_MOC_LITERAL(10, 111, 7), // "backend"
QT_MOC_LITERAL(11, 119, 10), // "properties"
QT_MOC_LITERAL(12, 130, 13), // "authenticator"
QT_MOC_LITERAL(13, 144, 14), // "authProperties"
QT_MOC_LITERAL(14, 159, 16), // "coreSetupSuccess"
QT_MOC_LITERAL(15, 176, 15), // "coreSetupFailed"
QT_MOC_LITERAL(16, 192, 9) // "startOver"

    },
    "CoreConfigWizard\0setupCore\0\0setupData\0"
    "loginToCore\0user\0password\0rememberPassword\0"
    "syncFinished\0prepareCoreSetup\0backend\0"
    "properties\0authenticator\0authProperties\0"
    "coreSetupSuccess\0coreSetupFailed\0"
    "startOver"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreConfigWizard[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,
       4,    3,   52,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,   59,    2, 0x0a /* Public */,
       9,    4,   60,    2, 0x08 /* Private */,
      14,    0,   69,    2, 0x08 /* Private */,
      15,    1,   70,    2, 0x08 /* Private */,
      16,    0,   73,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QVariant,    3,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::Bool,    5,    6,    7,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap, QMetaType::QString, QMetaType::QVariantMap,   10,   11,   12,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,

       0        // eod
};

void CoreConfigWizard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreConfigWizard *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setupCore((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 1: _t->loginToCore((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3]))); break;
        case 2: _t->syncFinished(); break;
        case 3: _t->prepareCoreSetup((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QVariantMap(*)>(_a[4]))); break;
        case 4: _t->coreSetupSuccess(); break;
        case 5: _t->coreSetupFailed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->startOver(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CoreConfigWizard::*)(const QVariant & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConfigWizard::setupCore)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (CoreConfigWizard::*)(const QString & , const QString & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreConfigWizard::loginToCore)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreConfigWizard::staticMetaObject = { {
    QMetaObject::SuperData::link<QWizard::staticMetaObject>(),
    qt_meta_stringdata_CoreConfigWizard.data,
    qt_meta_data_CoreConfigWizard,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreConfigWizard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreConfigWizard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreConfigWizard.stringdata0))
        return static_cast<void*>(this);
    return QWizard::qt_metacast(_clname);
}

int CoreConfigWizard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWizard::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void CoreConfigWizard::setupCore(const QVariant & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void CoreConfigWizard::loginToCore(const QString & _t1, const QString & _t2, bool _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_CoreConfigWizardPages__IntroPage_t {
    QByteArrayData data[1];
    char stringdata0[33];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreConfigWizardPages__IntroPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreConfigWizardPages__IntroPage_t qt_meta_stringdata_CoreConfigWizardPages__IntroPage = {
    {
QT_MOC_LITERAL(0, 0, 32) // "CoreConfigWizardPages::IntroPage"

    },
    "CoreConfigWizardPages::IntroPage"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreConfigWizardPages__IntroPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void CoreConfigWizardPages::IntroPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject CoreConfigWizardPages::IntroPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWizardPage::staticMetaObject>(),
    qt_meta_stringdata_CoreConfigWizardPages__IntroPage.data,
    qt_meta_data_CoreConfigWizardPages__IntroPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreConfigWizardPages::IntroPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreConfigWizardPages::IntroPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreConfigWizardPages__IntroPage.stringdata0))
        return static_cast<void*>(this);
    return QWizardPage::qt_metacast(_clname);
}

int CoreConfigWizardPages::IntroPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWizardPage::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_CoreConfigWizardPages__AdminUserPage_t {
    QByteArrayData data[1];
    char stringdata0[37];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreConfigWizardPages__AdminUserPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreConfigWizardPages__AdminUserPage_t qt_meta_stringdata_CoreConfigWizardPages__AdminUserPage = {
    {
QT_MOC_LITERAL(0, 0, 36) // "CoreConfigWizardPages::AdminU..."

    },
    "CoreConfigWizardPages::AdminUserPage"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreConfigWizardPages__AdminUserPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void CoreConfigWizardPages::AdminUserPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject CoreConfigWizardPages::AdminUserPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWizardPage::staticMetaObject>(),
    qt_meta_stringdata_CoreConfigWizardPages__AdminUserPage.data,
    qt_meta_data_CoreConfigWizardPages__AdminUserPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreConfigWizardPages::AdminUserPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreConfigWizardPages::AdminUserPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreConfigWizardPages__AdminUserPage.stringdata0))
        return static_cast<void*>(this);
    return QWizardPage::qt_metacast(_clname);
}

int CoreConfigWizardPages::AdminUserPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWizardPage::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_CoreConfigWizardPages__AuthenticationSelectionPage_t {
    QByteArrayData data[4];
    char stringdata0[93];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreConfigWizardPages__AuthenticationSelectionPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreConfigWizardPages__AuthenticationSelectionPage_t qt_meta_stringdata_CoreConfigWizardPages__AuthenticationSelectionPage = {
    {
QT_MOC_LITERAL(0, 0, 50), // "CoreConfigWizardPages::Authen..."
QT_MOC_LITERAL(1, 51, 34), // "on_backendList_currentIndexCh..."
QT_MOC_LITERAL(2, 86, 0), // ""
QT_MOC_LITERAL(3, 87, 5) // "index"

    },
    "CoreConfigWizardPages::AuthenticationSelectionPage\0"
    "on_backendList_currentIndexChanged\0\0"
    "index"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreConfigWizardPages__AuthenticationSelectionPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,

       0        // eod
};

void CoreConfigWizardPages::AuthenticationSelectionPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AuthenticationSelectionPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_backendList_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreConfigWizardPages::AuthenticationSelectionPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWizardPage::staticMetaObject>(),
    qt_meta_stringdata_CoreConfigWizardPages__AuthenticationSelectionPage.data,
    qt_meta_data_CoreConfigWizardPages__AuthenticationSelectionPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreConfigWizardPages::AuthenticationSelectionPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreConfigWizardPages::AuthenticationSelectionPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreConfigWizardPages__AuthenticationSelectionPage.stringdata0))
        return static_cast<void*>(this);
    return QWizardPage::qt_metacast(_clname);
}

int CoreConfigWizardPages::AuthenticationSelectionPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWizardPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_CoreConfigWizardPages__StorageSelectionPage_t {
    QByteArrayData data[4];
    char stringdata0[86];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreConfigWizardPages__StorageSelectionPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreConfigWizardPages__StorageSelectionPage_t qt_meta_stringdata_CoreConfigWizardPages__StorageSelectionPage = {
    {
QT_MOC_LITERAL(0, 0, 43), // "CoreConfigWizardPages::Storag..."
QT_MOC_LITERAL(1, 44, 34), // "on_backendList_currentIndexCh..."
QT_MOC_LITERAL(2, 79, 0), // ""
QT_MOC_LITERAL(3, 80, 5) // "index"

    },
    "CoreConfigWizardPages::StorageSelectionPage\0"
    "on_backendList_currentIndexChanged\0\0"
    "index"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreConfigWizardPages__StorageSelectionPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,

       0        // eod
};

void CoreConfigWizardPages::StorageSelectionPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<StorageSelectionPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_backendList_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreConfigWizardPages::StorageSelectionPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWizardPage::staticMetaObject>(),
    qt_meta_stringdata_CoreConfigWizardPages__StorageSelectionPage.data,
    qt_meta_data_CoreConfigWizardPages__StorageSelectionPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreConfigWizardPages::StorageSelectionPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreConfigWizardPages::StorageSelectionPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreConfigWizardPages__StorageSelectionPage.stringdata0))
        return static_cast<void*>(this);
    return QWizardPage::qt_metacast(_clname);
}

int CoreConfigWizardPages::StorageSelectionPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWizardPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_CoreConfigWizardPages__SyncPage_t {
    QByteArrayData data[9];
    char stringdata0[103];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreConfigWizardPages__SyncPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreConfigWizardPages__SyncPage_t qt_meta_stringdata_CoreConfigWizardPages__SyncPage = {
    {
QT_MOC_LITERAL(0, 0, 31), // "CoreConfigWizardPages::SyncPage"
QT_MOC_LITERAL(1, 32, 9), // "setupCore"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 7), // "backend"
QT_MOC_LITERAL(4, 51, 13), // "authenticator"
QT_MOC_LITERAL(5, 65, 9), // "setStatus"
QT_MOC_LITERAL(6, 75, 6), // "status"
QT_MOC_LITERAL(7, 82, 8), // "setError"
QT_MOC_LITERAL(8, 91, 11) // "setComplete"

    },
    "CoreConfigWizardPages::SyncPage\0"
    "setupCore\0\0backend\0authenticator\0"
    "setStatus\0status\0setError\0setComplete"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreConfigWizardPages__SyncPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    4,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   43,    2, 0x0a /* Public */,
       7,    1,   46,    2, 0x0a /* Public */,
       8,    1,   49,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap, QMetaType::QString, QMetaType::QVariantMap,    3,    2,    4,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void CoreConfigWizardPages::SyncPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SyncPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setupCore((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariantMap(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QVariantMap(*)>(_a[4]))); break;
        case 1: _t->setStatus((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->setError((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->setComplete((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SyncPage::*)(const QString & , const QVariantMap & , const QString & , const QVariantMap & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SyncPage::setupCore)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreConfigWizardPages::SyncPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWizardPage::staticMetaObject>(),
    qt_meta_stringdata_CoreConfigWizardPages__SyncPage.data,
    qt_meta_data_CoreConfigWizardPages__SyncPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreConfigWizardPages::SyncPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreConfigWizardPages::SyncPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreConfigWizardPages__SyncPage.stringdata0))
        return static_cast<void*>(this);
    return QWizardPage::qt_metacast(_clname);
}

int CoreConfigWizardPages::SyncPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWizardPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void CoreConfigWizardPages::SyncPage::setupCore(const QString & _t1, const QVariantMap & _t2, const QString & _t3, const QVariantMap & _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_CoreConfigWizardPages__SyncRelayPage_t {
    QByteArrayData data[5];
    char stringdata0[61];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreConfigWizardPages__SyncRelayPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreConfigWizardPages__SyncRelayPage_t qt_meta_stringdata_CoreConfigWizardPages__SyncRelayPage = {
    {
QT_MOC_LITERAL(0, 0, 36), // "CoreConfigWizardPages::SyncRe..."
QT_MOC_LITERAL(1, 37, 9), // "startOver"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 7), // "setMode"
QT_MOC_LITERAL(4, 56, 4) // "Mode"

    },
    "CoreConfigWizardPages::SyncRelayPage\0"
    "startOver\0\0setMode\0Mode"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreConfigWizardPages__SyncRelayPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   25,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    2,

       0        // eod
};

void CoreConfigWizardPages::SyncRelayPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SyncRelayPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->startOver(); break;
        case 1: _t->setMode((*reinterpret_cast< Mode(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SyncRelayPage::*)() const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SyncRelayPage::startOver)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreConfigWizardPages::SyncRelayPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWizardPage::staticMetaObject>(),
    qt_meta_stringdata_CoreConfigWizardPages__SyncRelayPage.data,
    qt_meta_data_CoreConfigWizardPages__SyncRelayPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreConfigWizardPages::SyncRelayPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreConfigWizardPages::SyncRelayPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreConfigWizardPages__SyncRelayPage.stringdata0))
        return static_cast<void*>(this);
    return QWizardPage::qt_metacast(_clname);
}

int CoreConfigWizardPages::SyncRelayPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWizardPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void CoreConfigWizardPages::SyncRelayPage::startOver()const
{
    QMetaObject::activate(const_cast< CoreConfigWizardPages::SyncRelayPage *>(this), &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
