/********************************************************************************
** Form generated from reading UI file 'resourcetreedlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RESOURCETREEDLG_H
#define UI_RESOURCETREEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ResourceTreeDlg
{
public:
    QVBoxLayout *verticalLayout;
    QTreeView *treeView;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ResourceTreeDlg)
    {
        if (ResourceTreeDlg->objectName().isEmpty())
            ResourceTreeDlg->setObjectName(QString::fromUtf8("ResourceTreeDlg"));
        ResourceTreeDlg->resize(474, 399);
        verticalLayout = new QVBoxLayout(ResourceTreeDlg);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        treeView = new QTreeView(ResourceTreeDlg);
        treeView->setObjectName(QString::fromUtf8("treeView"));

        verticalLayout->addWidget(treeView);

        buttonBox = new QDialogButtonBox(ResourceTreeDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(ResourceTreeDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), ResourceTreeDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), ResourceTreeDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(ResourceTreeDlg);
    } // setupUi

    void retranslateUi(QDialog *ResourceTreeDlg)
    {
        ResourceTreeDlg->setWindowTitle(QCoreApplication::translate("ResourceTreeDlg", "Resource Tree", nullptr));
#if QT_CONFIG(tooltip)
        treeView->setToolTip(QCoreApplication::translate("ResourceTreeDlg", "Shows the contents of the compiled-in resource tree.", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class ResourceTreeDlg: public Ui_ResourceTreeDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_RESOURCETREEDLG_H
