/****************************************************************************
** Meta object code from reading C++ file 'bufferview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/uisupport/bufferview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bufferview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BufferView_t {
    QByteArrayData data[32];
    char stringdata0[446];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferView_t qt_meta_stringdata_BufferView = {
    {
QT_MOC_LITERAL(0, 0, 10), // "BufferView"
QT_MOC_LITERAL(1, 11, 12), // "removeBuffer"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 11), // "QModelIndex"
QT_MOC_LITERAL(4, 37, 23), // "removeBufferPermanently"
QT_MOC_LITERAL(5, 61, 24), // "setRootIndexForNetworkId"
QT_MOC_LITERAL(6, 86, 9), // "NetworkId"
QT_MOC_LITERAL(7, 96, 9), // "networkId"
QT_MOC_LITERAL(8, 106, 21), // "removeSelectedBuffers"
QT_MOC_LITERAL(9, 128, 11), // "permanently"
QT_MOC_LITERAL(10, 140, 19), // "menuActionTriggered"
QT_MOC_LITERAL(11, 160, 8), // "QAction*"
QT_MOC_LITERAL(12, 169, 10), // "nextBuffer"
QT_MOC_LITERAL(13, 180, 14), // "previousBuffer"
QT_MOC_LITERAL(14, 195, 17), // "hideCurrentBuffer"
QT_MOC_LITERAL(15, 213, 17), // "filterTextChanged"
QT_MOC_LITERAL(16, 231, 12), // "filterString"
QT_MOC_LITERAL(17, 244, 15), // "changeHighlight"
QT_MOC_LITERAL(18, 260, 9), // "Direction"
QT_MOC_LITERAL(19, 270, 9), // "direction"
QT_MOC_LITERAL(20, 280, 17), // "selectHighlighted"
QT_MOC_LITERAL(21, 298, 14), // "clearHighlight"
QT_MOC_LITERAL(22, 313, 11), // "joinChannel"
QT_MOC_LITERAL(23, 325, 5), // "index"
QT_MOC_LITERAL(24, 331, 12), // "toggleHeader"
QT_MOC_LITERAL(25, 344, 7), // "checked"
QT_MOC_LITERAL(26, 352, 16), // "setExpandedState"
QT_MOC_LITERAL(27, 369, 18), // "storeExpandedState"
QT_MOC_LITERAL(28, 388, 10), // "networkIdx"
QT_MOC_LITERAL(29, 399, 16), // "on_configChanged"
QT_MOC_LITERAL(30, 416, 16), // "on_layoutChanged"
QT_MOC_LITERAL(31, 433, 12) // "changeBuffer"

    },
    "BufferView\0removeBuffer\0\0QModelIndex\0"
    "removeBufferPermanently\0"
    "setRootIndexForNetworkId\0NetworkId\0"
    "networkId\0removeSelectedBuffers\0"
    "permanently\0menuActionTriggered\0"
    "QAction*\0nextBuffer\0previousBuffer\0"
    "hideCurrentBuffer\0filterTextChanged\0"
    "filterString\0changeHighlight\0Direction\0"
    "direction\0selectHighlighted\0clearHighlight\0"
    "joinChannel\0index\0toggleHeader\0checked\0"
    "setExpandedState\0storeExpandedState\0"
    "networkIdx\0on_configChanged\0"
    "on_layoutChanged\0changeBuffer"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  119,    2, 0x06 /* Public */,
       4,    1,  122,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,  125,    2, 0x0a /* Public */,
       8,    1,  128,    2, 0x0a /* Public */,
       8,    0,  131,    2, 0x2a /* Public | MethodCloned */,
      10,    1,  132,    2, 0x0a /* Public */,
      12,    0,  135,    2, 0x0a /* Public */,
      13,    0,  136,    2, 0x0a /* Public */,
      14,    0,  137,    2, 0x0a /* Public */,
      15,    1,  138,    2, 0x0a /* Public */,
      17,    1,  141,    2, 0x0a /* Public */,
      20,    0,  144,    2, 0x0a /* Public */,
      21,    0,  145,    2, 0x0a /* Public */,
      22,    1,  146,    2, 0x08 /* Private */,
      24,    1,  149,    2, 0x08 /* Private */,
      26,    0,  152,    2, 0x08 /* Private */,
      27,    1,  153,    2, 0x08 /* Private */,
      26,    1,  156,    2, 0x08 /* Private */,
      29,    0,  159,    2, 0x08 /* Private */,
      30,    0,  160,    2, 0x08 /* Private */,
      31,    1,  161,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, 0x80000000 | 3,    2,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::Bool,    9,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,   23,
    QMetaType::Void, QMetaType::Bool,   25,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,   28,
    QMetaType::Void, 0x80000000 | 3,   28,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18,   19,

       0        // eod
};

void BufferView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferView *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->removeBuffer((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 1: _t->removeBufferPermanently((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 2: _t->setRootIndexForNetworkId((*reinterpret_cast< const NetworkId(*)>(_a[1]))); break;
        case 3: _t->removeSelectedBuffers((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->removeSelectedBuffers(); break;
        case 5: _t->menuActionTriggered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 6: _t->nextBuffer(); break;
        case 7: _t->previousBuffer(); break;
        case 8: _t->hideCurrentBuffer(); break;
        case 9: _t->filterTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->changeHighlight((*reinterpret_cast< Direction(*)>(_a[1]))); break;
        case 11: _t->selectHighlighted(); break;
        case 12: _t->clearHighlight(); break;
        case 13: _t->joinChannel((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 14: _t->toggleHeader((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->setExpandedState(); break;
        case 16: _t->storeExpandedState((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 17: _t->setExpandedState((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 18: _t->on_configChanged(); break;
        case 19: _t->on_layoutChanged(); break;
        case 20: _t->changeBuffer((*reinterpret_cast< Direction(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BufferView::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferView::removeBuffer)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (BufferView::*)(const QModelIndex & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferView::removeBufferPermanently)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BufferView::staticMetaObject = { {
    QMetaObject::SuperData::link<TreeViewTouch::staticMetaObject>(),
    qt_meta_stringdata_BufferView.data,
    qt_meta_data_BufferView,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferView.stringdata0))
        return static_cast<void*>(this);
    return TreeViewTouch::qt_metacast(_clname);
}

int BufferView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TreeViewTouch::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void BufferView::removeBuffer(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void BufferView::removeBufferPermanently(const QModelIndex & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_BufferViewDelegate_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferViewDelegate_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferViewDelegate_t qt_meta_stringdata_BufferViewDelegate = {
    {
QT_MOC_LITERAL(0, 0, 18) // "BufferViewDelegate"

    },
    "BufferViewDelegate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferViewDelegate[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void BufferViewDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject BufferViewDelegate::staticMetaObject = { {
    QMetaObject::SuperData::link<QStyledItemDelegate::staticMetaObject>(),
    qt_meta_stringdata_BufferViewDelegate.data,
    qt_meta_data_BufferViewDelegate,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferViewDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferViewDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferViewDelegate.stringdata0))
        return static_cast<void*>(this);
    return QStyledItemDelegate::qt_metacast(_clname);
}

int BufferViewDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStyledItemDelegate::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_BufferViewDock_t {
    QByteArrayData data[15];
    char stringdata0[166];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferViewDock_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferViewDock_t qt_meta_stringdata_BufferViewDock = {
    {
QT_MOC_LITERAL(0, 0, 14), // "BufferViewDock"
QT_MOC_LITERAL(1, 15, 9), // "setActive"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 6), // "active"
QT_MOC_LITERAL(4, 33, 11), // "eventFilter"
QT_MOC_LITERAL(5, 45, 6), // "object"
QT_MOC_LITERAL(6, 52, 7), // "QEvent*"
QT_MOC_LITERAL(7, 60, 5), // "event"
QT_MOC_LITERAL(8, 66, 12), // "focusInEvent"
QT_MOC_LITERAL(9, 79, 12), // "QFocusEvent*"
QT_MOC_LITERAL(10, 92, 17), // "bufferViewRenamed"
QT_MOC_LITERAL(11, 110, 7), // "newName"
QT_MOC_LITERAL(12, 118, 11), // "updateTitle"
QT_MOC_LITERAL(13, 130, 13), // "configChanged"
QT_MOC_LITERAL(14, 144, 21) // "onFilterReturnPressed"

    },
    "BufferViewDock\0setActive\0\0active\0"
    "eventFilter\0object\0QEvent*\0event\0"
    "focusInEvent\0QFocusEvent*\0bufferViewRenamed\0"
    "newName\0updateTitle\0configChanged\0"
    "onFilterReturnPressed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferViewDock[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       1,   72, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x0a /* Public */,
       1,    0,   57,    2, 0x2a /* Public | MethodCloned */,
       4,    2,   58,    2, 0x09 /* Protected */,
       8,    1,   63,    2, 0x09 /* Protected */,
      10,    1,   66,    2, 0x08 /* Private */,
      12,    0,   69,    2, 0x08 /* Private */,
      13,    0,   70,    2, 0x08 /* Private */,
      14,    0,   71,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::QObjectStar, 0x80000000 | 6,    5,    7,
    QMetaType::Void, 0x80000000 | 9,    7,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       3, QMetaType::Bool, 0x00095103,

       0        // eod
};

void BufferViewDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferViewDock *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setActive((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->setActive(); break;
        case 2: { bool _r = _t->eventFilter((*reinterpret_cast< QObject*(*)>(_a[1])),(*reinterpret_cast< QEvent*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->focusInEvent((*reinterpret_cast< QFocusEvent*(*)>(_a[1]))); break;
        case 4: _t->bufferViewRenamed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->updateTitle(); break;
        case 6: _t->configChanged(); break;
        case 7: _t->onFilterReturnPressed(); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<BufferViewDock *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isActive(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<BufferViewDock *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setActive(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject BufferViewDock::staticMetaObject = { {
    QMetaObject::SuperData::link<QDockWidget::staticMetaObject>(),
    qt_meta_stringdata_BufferViewDock.data,
    qt_meta_data_BufferViewDock,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferViewDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferViewDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferViewDock.stringdata0))
        return static_cast<void*>(this);
    return QDockWidget::qt_metacast(_clname);
}

int BufferViewDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDockWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
