/****************************************************************************
** Meta object code from reading C++ file 'peer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/peer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'peer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Peer_t {
    QByteArrayData data[24];
    char stringdata0[386];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Peer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Peer_t qt_meta_stringdata_Peer = {
    {
QT_MOC_LITERAL(0, 0, 4), // "Peer"
QT_MOC_LITERAL(1, 5, 12), // "disconnected"
QT_MOC_LITERAL(2, 18, 0), // ""
QT_MOC_LITERAL(3, 19, 18), // "secureStateChanged"
QT_MOC_LITERAL(4, 38, 6), // "secure"
QT_MOC_LITERAL(5, 45, 10), // "lagUpdated"
QT_MOC_LITERAL(6, 56, 5), // "msecs"
QT_MOC_LITERAL(7, 62, 8), // "dispatch"
QT_MOC_LITERAL(8, 71, 24), // "Protocol::RegisterClient"
QT_MOC_LITERAL(9, 96, 22), // "Protocol::ClientDenied"
QT_MOC_LITERAL(10, 119, 26), // "Protocol::ClientRegistered"
QT_MOC_LITERAL(11, 146, 19), // "Protocol::SetupData"
QT_MOC_LITERAL(12, 166, 21), // "Protocol::SetupFailed"
QT_MOC_LITERAL(13, 188, 19), // "Protocol::SetupDone"
QT_MOC_LITERAL(14, 208, 15), // "Protocol::Login"
QT_MOC_LITERAL(15, 224, 21), // "Protocol::LoginFailed"
QT_MOC_LITERAL(16, 246, 22), // "Protocol::LoginSuccess"
QT_MOC_LITERAL(17, 269, 22), // "Protocol::SessionState"
QT_MOC_LITERAL(18, 292, 21), // "Protocol::SyncMessage"
QT_MOC_LITERAL(19, 314, 17), // "Protocol::RpcCall"
QT_MOC_LITERAL(20, 332, 21), // "Protocol::InitRequest"
QT_MOC_LITERAL(21, 354, 18), // "Protocol::InitData"
QT_MOC_LITERAL(22, 373, 5), // "close"
QT_MOC_LITERAL(23, 379, 6) // "reason"

    },
    "Peer\0disconnected\0\0secureStateChanged\0"
    "secure\0lagUpdated\0msecs\0dispatch\0"
    "Protocol::RegisterClient\0"
    "Protocol::ClientDenied\0"
    "Protocol::ClientRegistered\0"
    "Protocol::SetupData\0Protocol::SetupFailed\0"
    "Protocol::SetupDone\0Protocol::Login\0"
    "Protocol::LoginFailed\0Protocol::LoginSuccess\0"
    "Protocol::SessionState\0Protocol::SyncMessage\0"
    "Protocol::RpcCall\0Protocol::InitRequest\0"
    "Protocol::InitData\0close\0reason"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Peer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  114,    2, 0x06 /* Public */,
       3,    1,  115,    2, 0x06 /* Public */,
       3,    0,  118,    2, 0x26 /* Public | MethodCloned */,
       5,    1,  119,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,  122,    2, 0x0a /* Public */,
       7,    1,  125,    2, 0x0a /* Public */,
       7,    1,  128,    2, 0x0a /* Public */,
       7,    1,  131,    2, 0x0a /* Public */,
       7,    1,  134,    2, 0x0a /* Public */,
       7,    1,  137,    2, 0x0a /* Public */,
       7,    1,  140,    2, 0x0a /* Public */,
       7,    1,  143,    2, 0x0a /* Public */,
       7,    1,  146,    2, 0x0a /* Public */,
       7,    1,  149,    2, 0x0a /* Public */,
       7,    1,  152,    2, 0x0a /* Public */,
       7,    1,  155,    2, 0x0a /* Public */,
       7,    1,  158,    2, 0x0a /* Public */,
       7,    1,  161,    2, 0x0a /* Public */,
      22,    1,  164,    2, 0x0a /* Public */,
      22,    0,  167,    2, 0x2a /* Public | MethodCloned */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    6,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void, 0x80000000 | 9,    2,
    QMetaType::Void, 0x80000000 | 10,    2,
    QMetaType::Void, 0x80000000 | 11,    2,
    QMetaType::Void, 0x80000000 | 12,    2,
    QMetaType::Void, 0x80000000 | 13,    2,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void, 0x80000000 | 15,    2,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void, 0x80000000 | 17,    2,
    QMetaType::Void, 0x80000000 | 18,    2,
    QMetaType::Void, 0x80000000 | 19,    2,
    QMetaType::Void, 0x80000000 | 20,    2,
    QMetaType::Void, 0x80000000 | 21,    2,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void,

       0        // eod
};

void Peer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Peer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->disconnected(); break;
        case 1: _t->secureStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->secureStateChanged(); break;
        case 3: _t->lagUpdated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->dispatch((*reinterpret_cast< const Protocol::RegisterClient(*)>(_a[1]))); break;
        case 5: _t->dispatch((*reinterpret_cast< const Protocol::ClientDenied(*)>(_a[1]))); break;
        case 6: _t->dispatch((*reinterpret_cast< const Protocol::ClientRegistered(*)>(_a[1]))); break;
        case 7: _t->dispatch((*reinterpret_cast< const Protocol::SetupData(*)>(_a[1]))); break;
        case 8: _t->dispatch((*reinterpret_cast< const Protocol::SetupFailed(*)>(_a[1]))); break;
        case 9: _t->dispatch((*reinterpret_cast< const Protocol::SetupDone(*)>(_a[1]))); break;
        case 10: _t->dispatch((*reinterpret_cast< const Protocol::Login(*)>(_a[1]))); break;
        case 11: _t->dispatch((*reinterpret_cast< const Protocol::LoginFailed(*)>(_a[1]))); break;
        case 12: _t->dispatch((*reinterpret_cast< const Protocol::LoginSuccess(*)>(_a[1]))); break;
        case 13: _t->dispatch((*reinterpret_cast< const Protocol::SessionState(*)>(_a[1]))); break;
        case 14: _t->dispatch((*reinterpret_cast< const Protocol::SyncMessage(*)>(_a[1]))); break;
        case 15: _t->dispatch((*reinterpret_cast< const Protocol::RpcCall(*)>(_a[1]))); break;
        case 16: _t->dispatch((*reinterpret_cast< const Protocol::InitRequest(*)>(_a[1]))); break;
        case 17: _t->dispatch((*reinterpret_cast< const Protocol::InitData(*)>(_a[1]))); break;
        case 18: _t->close((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->close(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Protocol::SyncMessage >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Protocol::RpcCall >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Protocol::InitRequest >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Protocol::InitData >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Peer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Peer::disconnected)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Peer::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Peer::secureStateChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Peer::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Peer::lagUpdated)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Peer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Peer.data,
    qt_meta_data_Peer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Peer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Peer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Peer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Peer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void Peer::disconnected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Peer::secureStateChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 3
void Peer::lagUpdated(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
