/********************************************************************************
** Form generated from reading UI file 'saveidentitiesdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SAVEIDENTITIESDLG_H
#define UI_SAVEIDENTITIESDLG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SaveIdentitiesDlg
{
public:
    QVBoxLayout *vboxLayout;
    QVBoxLayout *vboxLayout1;
    QLabel *label;
    QSpacerItem *spacerItem;
    QProgressBar *progressBar;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem1;
    QPushButton *abort;
    QSpacerItem *spacerItem2;

    void setupUi(QDialog *SaveIdentitiesDlg)
    {
        if (SaveIdentitiesDlg->objectName().isEmpty())
            SaveIdentitiesDlg->setObjectName(QString::fromUtf8("SaveIdentitiesDlg"));
        SaveIdentitiesDlg->resize(316, 110);
        vboxLayout = new QVBoxLayout(SaveIdentitiesDlg);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        label = new QLabel(SaveIdentitiesDlg);
        label->setObjectName(QString::fromUtf8("label"));
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        label->setWordWrap(true);

        vboxLayout1->addWidget(label);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacerItem);

        progressBar = new QProgressBar(SaveIdentitiesDlg);
        progressBar->setObjectName(QString::fromUtf8("progressBar"));
        progressBar->setMaximum(0);
        progressBar->setValue(32);
        progressBar->setInvertedAppearance(false);

        vboxLayout1->addWidget(progressBar);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem1);

        abort = new QPushButton(SaveIdentitiesDlg);
        abort->setObjectName(QString::fromUtf8("abort"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(abort->sizePolicy().hasHeightForWidth());
        abort->setSizePolicy(sizePolicy);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/22x22/actions/oxygen/22x22/actions/dialog-cancel.png"), QSize(), QIcon::Normal, QIcon::Off);
        abort->setIcon(icon);

        hboxLayout->addWidget(abort);

        spacerItem2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem2);


        vboxLayout1->addLayout(hboxLayout);


        vboxLayout->addLayout(vboxLayout1);


        retranslateUi(SaveIdentitiesDlg);
        QObject::connect(abort, SIGNAL(clicked()), SaveIdentitiesDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(SaveIdentitiesDlg);
    } // setupUi

    void retranslateUi(QDialog *SaveIdentitiesDlg)
    {
        SaveIdentitiesDlg->setWindowTitle(QCoreApplication::translate("SaveIdentitiesDlg", "Sync With Core", nullptr));
        label->setText(QCoreApplication::translate("SaveIdentitiesDlg", "Syncing data with core, please wait...", nullptr));
        abort->setText(QCoreApplication::translate("SaveIdentitiesDlg", "Abort", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SaveIdentitiesDlg: public Ui_SaveIdentitiesDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SAVEIDENTITIESDLG_H
