/********************************************************************************
** Form generated from reading UI file 'passwordchangedlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PASSWORDCHANGEDLG_H
#define UI_PASSWORDCHANGEDLG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_PasswordChangeDlg
{
public:
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QLabel *infoLabel;
    QFormLayout *formLayout;
    QLabel *oldPasswordLabel;
    QLineEdit *oldPasswordEdit;
    QLabel *newPasswordLabel;
    QLineEdit *newPasswordEdit;
    QLabel *confirmPasswordLabel;
    QLineEdit *confirmPasswordEdit;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *PasswordChangeDlg)
    {
        if (PasswordChangeDlg->objectName().isEmpty())
            PasswordChangeDlg->setObjectName(QString::fromUtf8("PasswordChangeDlg"));
        PasswordChangeDlg->resize(455, 173);
        verticalLayout_2 = new QVBoxLayout(PasswordChangeDlg);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        infoLabel = new QLabel(PasswordChangeDlg);
        infoLabel->setObjectName(QString::fromUtf8("infoLabel"));
        infoLabel->setText(QString::fromUtf8("<html><head/><body><p>This changes the password for your username <span style=\" font-weight:600;\">John</span> on the Quassel Core running at <span style=\" font-weight:600;\">example.invalid</span>.</p></body></html>"));
        infoLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        infoLabel->setWordWrap(true);

        verticalLayout->addWidget(infoLabel);

        formLayout = new QFormLayout();
        formLayout->setObjectName(QString::fromUtf8("formLayout"));
        oldPasswordLabel = new QLabel(PasswordChangeDlg);
        oldPasswordLabel->setObjectName(QString::fromUtf8("oldPasswordLabel"));

        formLayout->setWidget(0, QFormLayout::LabelRole, oldPasswordLabel);

        oldPasswordEdit = new QLineEdit(PasswordChangeDlg);
        oldPasswordEdit->setObjectName(QString::fromUtf8("oldPasswordEdit"));
        oldPasswordEdit->setEchoMode(QLineEdit::Password);

        formLayout->setWidget(0, QFormLayout::FieldRole, oldPasswordEdit);

        newPasswordLabel = new QLabel(PasswordChangeDlg);
        newPasswordLabel->setObjectName(QString::fromUtf8("newPasswordLabel"));

        formLayout->setWidget(1, QFormLayout::LabelRole, newPasswordLabel);

        newPasswordEdit = new QLineEdit(PasswordChangeDlg);
        newPasswordEdit->setObjectName(QString::fromUtf8("newPasswordEdit"));
        newPasswordEdit->setEchoMode(QLineEdit::Password);

        formLayout->setWidget(1, QFormLayout::FieldRole, newPasswordEdit);

        confirmPasswordLabel = new QLabel(PasswordChangeDlg);
        confirmPasswordLabel->setObjectName(QString::fromUtf8("confirmPasswordLabel"));

        formLayout->setWidget(2, QFormLayout::LabelRole, confirmPasswordLabel);

        confirmPasswordEdit = new QLineEdit(PasswordChangeDlg);
        confirmPasswordEdit->setObjectName(QString::fromUtf8("confirmPasswordEdit"));
        confirmPasswordEdit->setEchoMode(QLineEdit::Password);

        formLayout->setWidget(2, QFormLayout::FieldRole, confirmPasswordEdit);


        verticalLayout->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(PasswordChangeDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        verticalLayout_2->addLayout(verticalLayout);


        retranslateUi(PasswordChangeDlg);
        QObject::connect(buttonBox, SIGNAL(rejected()), PasswordChangeDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(PasswordChangeDlg);
    } // setupUi

    void retranslateUi(QDialog *PasswordChangeDlg)
    {
        PasswordChangeDlg->setWindowTitle(QCoreApplication::translate("PasswordChangeDlg", "Change Password", nullptr));
        oldPasswordLabel->setText(QCoreApplication::translate("PasswordChangeDlg", "Old password:", nullptr));
        newPasswordLabel->setText(QCoreApplication::translate("PasswordChangeDlg", "New Password:", nullptr));
        confirmPasswordLabel->setText(QCoreApplication::translate("PasswordChangeDlg", "Confirm password:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PasswordChangeDlg: public Ui_PasswordChangeDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PASSWORDCHANGEDLG_H
