/********************************************************************************
** Form generated from reading UI file 'ignorelisteditdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IGNORELISTEDITDLG_H
#define UI_IGNORELISTEDITDLG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_IgnoreListEditDlg
{
public:
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *horizontalLayout_4;
    QGroupBox *strictnessGroupBox;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *dynamicStrictnessButton;
    QRadioButton *permanentStrictnessButton;
    QGroupBox *typeGroupBox;
    QVBoxLayout *verticalLayout_4;
    QRadioButton *senderTypeButton;
    QRadioButton *messageTypeButton;
    QRadioButton *ctcpTypeButton;
    QGroupBox *ignoreRuleGroupBox;
    QVBoxLayout *verticalLayout;
    QLineEdit *ignoreRuleLineEdit;
    QHBoxLayout *horizontalLayout_5;
    QCheckBox *isRegExCheckBox;
    QGroupBox *scopeGroupBox;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_3;
    QRadioButton *globalScopeButton;
    QRadioButton *networkScopeButton;
    QRadioButton *channelScopeButton;
    QPlainTextEdit *scopeRuleTextEdit;
    QHBoxLayout *horizontalLayout_6;
    QSpacerItem *horizontalSpacer;
    QCheckBox *isActiveCheckBox;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *IgnoreListEditDlg)
    {
        if (IgnoreListEditDlg->objectName().isEmpty())
            IgnoreListEditDlg->setObjectName(QString::fromUtf8("IgnoreListEditDlg"));
        IgnoreListEditDlg->resize(389, 368);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/oxygen/16x16/actions/configure.png"), QSize(), QIcon::Normal, QIcon::Off);
        IgnoreListEditDlg->setWindowIcon(icon);
        verticalLayout_5 = new QVBoxLayout(IgnoreListEditDlg);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        strictnessGroupBox = new QGroupBox(IgnoreListEditDlg);
        strictnessGroupBox->setObjectName(QString::fromUtf8("strictnessGroupBox"));
        verticalLayout_2 = new QVBoxLayout(strictnessGroupBox);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        dynamicStrictnessButton = new QRadioButton(strictnessGroupBox);
        dynamicStrictnessButton->setObjectName(QString::fromUtf8("dynamicStrictnessButton"));

        verticalLayout_2->addWidget(dynamicStrictnessButton);

        permanentStrictnessButton = new QRadioButton(strictnessGroupBox);
        permanentStrictnessButton->setObjectName(QString::fromUtf8("permanentStrictnessButton"));

        verticalLayout_2->addWidget(permanentStrictnessButton);


        horizontalLayout_4->addWidget(strictnessGroupBox);

        typeGroupBox = new QGroupBox(IgnoreListEditDlg);
        typeGroupBox->setObjectName(QString::fromUtf8("typeGroupBox"));
        verticalLayout_4 = new QVBoxLayout(typeGroupBox);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        senderTypeButton = new QRadioButton(typeGroupBox);
        senderTypeButton->setObjectName(QString::fromUtf8("senderTypeButton"));

        verticalLayout_4->addWidget(senderTypeButton);

        messageTypeButton = new QRadioButton(typeGroupBox);
        messageTypeButton->setObjectName(QString::fromUtf8("messageTypeButton"));

        verticalLayout_4->addWidget(messageTypeButton);

        ctcpTypeButton = new QRadioButton(typeGroupBox);
        ctcpTypeButton->setObjectName(QString::fromUtf8("ctcpTypeButton"));

        verticalLayout_4->addWidget(ctcpTypeButton);


        horizontalLayout_4->addWidget(typeGroupBox);


        verticalLayout_5->addLayout(horizontalLayout_4);

        ignoreRuleGroupBox = new QGroupBox(IgnoreListEditDlg);
        ignoreRuleGroupBox->setObjectName(QString::fromUtf8("ignoreRuleGroupBox"));
        verticalLayout = new QVBoxLayout(ignoreRuleGroupBox);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        ignoreRuleLineEdit = new QLineEdit(ignoreRuleGroupBox);
        ignoreRuleLineEdit->setObjectName(QString::fromUtf8("ignoreRuleLineEdit"));

        verticalLayout->addWidget(ignoreRuleLineEdit);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        isRegExCheckBox = new QCheckBox(ignoreRuleGroupBox);
        isRegExCheckBox->setObjectName(QString::fromUtf8("isRegExCheckBox"));

        horizontalLayout_5->addWidget(isRegExCheckBox);


        verticalLayout->addLayout(horizontalLayout_5);


        verticalLayout_5->addWidget(ignoreRuleGroupBox);

        scopeGroupBox = new QGroupBox(IgnoreListEditDlg);
        scopeGroupBox->setObjectName(QString::fromUtf8("scopeGroupBox"));
        horizontalLayout = new QHBoxLayout(scopeGroupBox);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        globalScopeButton = new QRadioButton(scopeGroupBox);
        globalScopeButton->setObjectName(QString::fromUtf8("globalScopeButton"));

        verticalLayout_3->addWidget(globalScopeButton);

        networkScopeButton = new QRadioButton(scopeGroupBox);
        networkScopeButton->setObjectName(QString::fromUtf8("networkScopeButton"));

        verticalLayout_3->addWidget(networkScopeButton);

        channelScopeButton = new QRadioButton(scopeGroupBox);
        channelScopeButton->setObjectName(QString::fromUtf8("channelScopeButton"));

        verticalLayout_3->addWidget(channelScopeButton);


        horizontalLayout->addLayout(verticalLayout_3);

        scopeRuleTextEdit = new QPlainTextEdit(scopeGroupBox);
        scopeRuleTextEdit->setObjectName(QString::fromUtf8("scopeRuleTextEdit"));

        horizontalLayout->addWidget(scopeRuleTextEdit);


        verticalLayout_5->addWidget(scopeGroupBox);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName(QString::fromUtf8("horizontalLayout_6"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer);

        isActiveCheckBox = new QCheckBox(IgnoreListEditDlg);
        isActiveCheckBox->setObjectName(QString::fromUtf8("isActiveCheckBox"));

        horizontalLayout_6->addWidget(isActiveCheckBox);

        buttonBox = new QDialogButtonBox(IgnoreListEditDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout_6->addWidget(buttonBox);


        verticalLayout_5->addLayout(horizontalLayout_6);

        QWidget::setTabOrder(dynamicStrictnessButton, permanentStrictnessButton);
        QWidget::setTabOrder(permanentStrictnessButton, senderTypeButton);
        QWidget::setTabOrder(senderTypeButton, messageTypeButton);
        QWidget::setTabOrder(messageTypeButton, ignoreRuleLineEdit);
        QWidget::setTabOrder(ignoreRuleLineEdit, isRegExCheckBox);
        QWidget::setTabOrder(isRegExCheckBox, scopeRuleTextEdit);
        QWidget::setTabOrder(scopeRuleTextEdit, globalScopeButton);
        QWidget::setTabOrder(globalScopeButton, networkScopeButton);
        QWidget::setTabOrder(networkScopeButton, channelScopeButton);
        QWidget::setTabOrder(channelScopeButton, isActiveCheckBox);
        QWidget::setTabOrder(isActiveCheckBox, buttonBox);

        retranslateUi(IgnoreListEditDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), IgnoreListEditDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), IgnoreListEditDlg, SLOT(reject()));

        QMetaObject::connectSlotsByName(IgnoreListEditDlg);
    } // setupUi

    void retranslateUi(QDialog *IgnoreListEditDlg)
    {
        IgnoreListEditDlg->setWindowTitle(QCoreApplication::translate("IgnoreListEditDlg", "Configure Ignore Rule", nullptr));
#if QT_CONFIG(tooltip)
        strictnessGroupBox->setToolTip(QCoreApplication::translate("IgnoreListEditDlg", "<p><b>Strictness:</b></p>\n"
"<p><u>Dynamic:</u></p>\n"
"<p>Messages are filtered \"on the fly\".\n"
"Whenever you disable/delete the ignore rule, the messages are shown again.</p>\n"
"<p><u>Permanent:</u></p>\n"
"<p>Messages are filtered before they get stored in the database.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        strictnessGroupBox->setTitle(QCoreApplication::translate("IgnoreListEditDlg", "Strictness", nullptr));
        dynamicStrictnessButton->setText(QCoreApplication::translate("IgnoreListEditDlg", "Dynamic", nullptr));
        permanentStrictnessButton->setText(QCoreApplication::translate("IgnoreListEditDlg", "Permanent", nullptr));
#if QT_CONFIG(tooltip)
        typeGroupBox->setToolTip(QCoreApplication::translate("IgnoreListEditDlg", "<p><b>Rule Type:</b></p>\n"
"<p><u>Sender:</u></p>\n"
"<p>The rule is matched against the sender string\n"
"<i>nick!ident@host.name<i></p>\n"
"<p><u>Message:</u></p>\n"
"<p>The rule is matched against the actual message content</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        typeGroupBox->setTitle(QCoreApplication::translate("IgnoreListEditDlg", "Rule Type", nullptr));
        senderTypeButton->setText(QCoreApplication::translate("IgnoreListEditDlg", "Sender", nullptr));
        messageTypeButton->setText(QCoreApplication::translate("IgnoreListEditDlg", "Message", nullptr));
        ctcpTypeButton->setText(QCoreApplication::translate("IgnoreListEditDlg", "CTCP", nullptr));
#if QT_CONFIG(tooltip)
        ignoreRuleGroupBox->setToolTip(QCoreApplication::translate("IgnoreListEditDlg", "<p><b>Ignore rule:</b></p>\n"
"<p>Depending on the type of the rule, the text is matched against either:</p>\n"
"<p><u>- the message content:</u></p>\n"
"<p><i>Example:</i>\n"
"<br />\n"
"<i>*foobar*</i> matches any text containing the word <i>foobar</i></p>\n"
"<p><u>- the sender string</u>  <i>(nick!ident@host.name)</i></p>\n"
"<p><i>Examples:</i>\n"
"<br />\n"
"- <i>*@foobar.com</i> matches any sender from host <i>foobar.com</i>\n"
"<br />\n"
"- <i>stupid!.+</i> (RegEx) matches any sender with nickname <i>stupid</i> from any host</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        ignoreRuleGroupBox->setTitle(QCoreApplication::translate("IgnoreListEditDlg", "Ignore Rule", nullptr));
#if QT_CONFIG(tooltip)
        isRegExCheckBox->setToolTip(QCoreApplication::translate("IgnoreListEditDlg", "<p><b>Use regular expressions:</b></p>\n"
"<p>If enabled, rules follow regular expression syntax.</p>\n"
"<p>Otherwise rules allow wildcard matching with the following special characters:</p>\n"
"<p> *: representing \"any amount of any character\"\n"
"<br />\n"
"?: representing \"exactly one character\"</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        isRegExCheckBox->setText(QCoreApplication::translate("IgnoreListEditDlg", "Regular expression", nullptr));
#if QT_CONFIG(tooltip)
        scopeGroupBox->setToolTip(QCoreApplication::translate("IgnoreListEditDlg", "<p><b>Scope:</b></p>\n"
"<p><u>Global:</u></p>\n"
"<p>The rule is active for any channel on any network</p>\n"
"<p><u>Network:</u></p>\n"
"<p>The list below is interpreted as a list of networks for which the rule should match</p>\n"
"<p><u>Channel:</u></p>\n"
"<p>The list below is interpreted as a list of channels for which the rule should match</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        scopeGroupBox->setTitle(QCoreApplication::translate("IgnoreListEditDlg", "Scope", nullptr));
        globalScopeButton->setText(QCoreApplication::translate("IgnoreListEditDlg", "Global", nullptr));
        networkScopeButton->setText(QCoreApplication::translate("IgnoreListEditDlg", "Network", nullptr));
        channelScopeButton->setText(QCoreApplication::translate("IgnoreListEditDlg", "Channel", nullptr));
#if QT_CONFIG(tooltip)
        scopeRuleTextEdit->setToolTip(QCoreApplication::translate("IgnoreListEditDlg", "<p><b>Scope rule:</b></p>\n"
"<p>A scope rule is a semicolon separated list of either <i>network</i> or <i>channel</i> names.</p>\n"
"<p><i>Example:</i>\n"
"<br />\n"
"<i>#quassel*; #foobar; !#quasseldroid</i>\n"
"<br />\n"
"would match on <i>#foobar</i> and any channel starting with <i>#quassel</i> except for <i>#quasseldroid</i>\n"
"<br />\n"
"<p>If only inverted names are specified, it will match anything except for what's specified (implicit wildcard).</p>\n"
"<p><i>Example:</i>\n"
"<br />\n"
"<i>!#quassel*; !#foobar</i>\n"
"<br />\n"
"would match anything except for <i>#foobar</i> or any channel starting with <i>#quassel</i></p>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        isActiveCheckBox->setToolTip(QCoreApplication::translate("IgnoreListEditDlg", "<p><b>Enable / Disable:</b></p>\n"
"<p>Only enabled rules are filtered.\n"
"<br />\n"
"For dynamic rules, disabling actually shows the filtered messages again.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        isActiveCheckBox->setText(QCoreApplication::translate("IgnoreListEditDlg", "Rule is enabled", nullptr));
    } // retranslateUi

};

namespace Ui {
    class IgnoreListEditDlg: public Ui_IgnoreListEditDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_IGNORELISTEDITDLG_H
