/****************************************************************************
** Meta object code from reading C++ file 'legacysystemtray.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/legacysystemtray.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'legacysystemtray.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_LegacySystemTray_t {
    QByteArrayData data[20];
    char stringdata0[241];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_LegacySystemTray_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_LegacySystemTray_t qt_meta_stringdata_LegacySystemTray = {
    {
QT_MOC_LITERAL(0, 0, 16), // "LegacySystemTray"
QT_MOC_LITERAL(1, 17, 11), // "showMessage"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 5), // "title"
QT_MOC_LITERAL(4, 36, 7), // "message"
QT_MOC_LITERAL(5, 44, 11), // "MessageIcon"
QT_MOC_LITERAL(6, 56, 4), // "icon"
QT_MOC_LITERAL(7, 61, 9), // "msTimeout"
QT_MOC_LITERAL(8, 71, 14), // "notificationId"
QT_MOC_LITERAL(9, 86, 12), // "closeMessage"
QT_MOC_LITERAL(10, 99, 13), // "onModeChanged"
QT_MOC_LITERAL(11, 113, 4), // "Mode"
QT_MOC_LITERAL(12, 118, 4), // "mode"
QT_MOC_LITERAL(13, 123, 19), // "onVisibilityChanged"
QT_MOC_LITERAL(14, 143, 9), // "isVisible"
QT_MOC_LITERAL(15, 153, 11), // "onActivated"
QT_MOC_LITERAL(16, 165, 33), // "QSystemTrayIcon::ActivationRe..."
QT_MOC_LITERAL(17, 199, 16), // "onMessageClicked"
QT_MOC_LITERAL(18, 216, 10), // "updateIcon"
QT_MOC_LITERAL(19, 227, 13) // "updateToolTip"

    },
    "LegacySystemTray\0showMessage\0\0title\0"
    "message\0MessageIcon\0icon\0msTimeout\0"
    "notificationId\0closeMessage\0onModeChanged\0"
    "Mode\0mode\0onVisibilityChanged\0isVisible\0"
    "onActivated\0QSystemTrayIcon::ActivationReason\0"
    "onMessageClicked\0updateIcon\0updateToolTip"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_LegacySystemTray[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    5,   69,    2, 0x0a /* Public */,
       1,    4,   80,    2, 0x2a /* Public | MethodCloned */,
       1,    3,   89,    2, 0x2a /* Public | MethodCloned */,
       1,    2,   96,    2, 0x2a /* Public | MethodCloned */,
       9,    1,  101,    2, 0x0a /* Public */,
      10,    1,  104,    2, 0x08 /* Private */,
      13,    1,  107,    2, 0x08 /* Private */,
      15,    1,  110,    2, 0x08 /* Private */,
      17,    0,  113,    2, 0x08 /* Private */,
      18,    0,  114,    2, 0x08 /* Private */,
      19,    0,  115,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 5, QMetaType::Int, QMetaType::UInt,    3,    4,    6,    7,    8,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 5, QMetaType::Int,    3,    4,    6,    7,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 5,    3,    4,    6,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    3,    4,
    QMetaType::Void, QMetaType::UInt,    8,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void LegacySystemTray::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<LegacySystemTray *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->showMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< MessageIcon(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< uint(*)>(_a[5]))); break;
        case 1: _t->showMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< MessageIcon(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 2: _t->showMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< MessageIcon(*)>(_a[3]))); break;
        case 3: _t->showMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->closeMessage((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 5: _t->onModeChanged((*reinterpret_cast< Mode(*)>(_a[1]))); break;
        case 6: _t->onVisibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->onActivated((*reinterpret_cast< QSystemTrayIcon::ActivationReason(*)>(_a[1]))); break;
        case 8: _t->onMessageClicked(); break;
        case 9: _t->updateIcon(); break;
        case 10: _t->updateToolTip(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject LegacySystemTray::staticMetaObject = { {
    QMetaObject::SuperData::link<SystemTray::staticMetaObject>(),
    qt_meta_stringdata_LegacySystemTray.data,
    qt_meta_data_LegacySystemTray,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *LegacySystemTray::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LegacySystemTray::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_LegacySystemTray.stringdata0))
        return static_cast<void*>(this);
    return SystemTray::qt_metacast(_clname);
}

int LegacySystemTray::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SystemTray::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
