/****************************************************************************
** Meta object code from reading C++ file 'chatview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/chatview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'chatview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ChatView_t {
    QByteArrayData data[28];
    char stringdata0[342];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChatView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChatView_t qt_meta_stringdata_ChatView = {
    {
QT_MOC_LITERAL(0, 0, 8), // "ChatView"
QT_MOC_LITERAL(1, 9, 5), // "clear"
QT_MOC_LITERAL(2, 15, 0), // ""
QT_MOC_LITERAL(3, 16, 6), // "zoomIn"
QT_MOC_LITERAL(4, 23, 7), // "zoomOut"
QT_MOC_LITERAL(5, 31, 12), // "zoomOriginal"
QT_MOC_LITERAL(6, 44, 20), // "setMarkerLineVisible"
QT_MOC_LITERAL(7, 65, 7), // "visible"
QT_MOC_LITERAL(8, 73, 13), // "setMarkerLine"
QT_MOC_LITERAL(9, 87, 5), // "MsgId"
QT_MOC_LITERAL(10, 93, 5), // "msgId"
QT_MOC_LITERAL(11, 99, 16), // "jumpToMarkerLine"
QT_MOC_LITERAL(12, 116, 14), // "requestBacklog"
QT_MOC_LITERAL(13, 131, 24), // "verticalScrollbarChanged"
QT_MOC_LITERAL(14, 156, 15), // "lastLineChanged"
QT_MOC_LITERAL(15, 172, 14), // "QGraphicsItem*"
QT_MOC_LITERAL(16, 187, 8), // "chatLine"
QT_MOC_LITERAL(17, 196, 6), // "offset"
QT_MOC_LITERAL(18, 203, 15), // "adjustSceneRect"
QT_MOC_LITERAL(19, 219, 19), // "checkChatLineCaches"
QT_MOC_LITERAL(20, 239, 23), // "mouseMoveWhileSelecting"
QT_MOC_LITERAL(21, 263, 8), // "scenePos"
QT_MOC_LITERAL(22, 272, 18), // "scrollTimerTimeout"
QT_MOC_LITERAL(23, 291, 16), // "invalidateFilter"
QT_MOC_LITERAL(24, 308, 13), // "markerLineSet"
QT_MOC_LITERAL(25, 322, 8), // "BufferId"
QT_MOC_LITERAL(26, 331, 6), // "buffer"
QT_MOC_LITERAL(27, 338, 3) // "msg"

    },
    "ChatView\0clear\0\0zoomIn\0zoomOut\0"
    "zoomOriginal\0setMarkerLineVisible\0"
    "visible\0setMarkerLine\0MsgId\0msgId\0"
    "jumpToMarkerLine\0requestBacklog\0"
    "verticalScrollbarChanged\0lastLineChanged\0"
    "QGraphicsItem*\0chatLine\0offset\0"
    "adjustSceneRect\0checkChatLineCaches\0"
    "mouseMoveWhileSelecting\0scenePos\0"
    "scrollTimerTimeout\0invalidateFilter\0"
    "markerLineSet\0BufferId\0buffer\0msg"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChatView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   94,    2, 0x0a /* Public */,
       3,    0,   95,    2, 0x0a /* Public */,
       4,    0,   96,    2, 0x0a /* Public */,
       5,    0,   97,    2, 0x0a /* Public */,
       6,    1,   98,    2, 0x0a /* Public */,
       6,    0,  101,    2, 0x2a /* Public | MethodCloned */,
       8,    1,  102,    2, 0x0a /* Public */,
      11,    1,  105,    2, 0x0a /* Public */,
      13,    1,  108,    2, 0x09 /* Protected */,
      14,    2,  111,    2, 0x08 /* Private */,
      18,    0,  116,    2, 0x08 /* Private */,
      19,    0,  117,    2, 0x08 /* Private */,
      20,    1,  118,    2, 0x08 /* Private */,
      22,    0,  121,    2, 0x08 /* Private */,
      23,    0,  122,    2, 0x08 /* Private */,
      24,    2,  123,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 15, QMetaType::QReal,   16,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPointF,   21,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 25, 0x80000000 | 9,   26,   27,

       0        // eod
};

void ChatView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ChatView *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clear(); break;
        case 1: _t->zoomIn(); break;
        case 2: _t->zoomOut(); break;
        case 3: _t->zoomOriginal(); break;
        case 4: _t->setMarkerLineVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->setMarkerLineVisible(); break;
        case 6: _t->setMarkerLine((*reinterpret_cast< MsgId(*)>(_a[1]))); break;
        case 7: _t->jumpToMarkerLine((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->verticalScrollbarChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->lastLineChanged((*reinterpret_cast< QGraphicsItem*(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 10: _t->adjustSceneRect(); break;
        case 11: _t->checkChatLineCaches(); break;
        case 12: _t->mouseMoveWhileSelecting((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 13: _t->scrollTimerTimeout(); break;
        case 14: _t->invalidateFilter(); break;
        case 15: _t->markerLineSet((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ChatView::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsView::staticMetaObject>(),
    qt_meta_stringdata_ChatView.data,
    qt_meta_data_ChatView,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ChatView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChatView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ChatView.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "AbstractChatView"))
        return static_cast< AbstractChatView*>(this);
    return QGraphicsView::qt_metacast(_clname);
}

int ChatView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
