/****************************************************************************
** Meta object code from reading C++ file 'corehighlightrulemanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/corehighlightrulemanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'corehighlightrulemanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreHighlightRuleManager_t {
    QByteArrayData data[15];
    char stringdata0[191];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreHighlightRuleManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreHighlightRuleManager_t qt_meta_stringdata_CoreHighlightRuleManager = {
    {
QT_MOC_LITERAL(0, 0, 24), // "CoreHighlightRuleManager"
QT_MOC_LITERAL(1, 25, 26), // "requestToggleHighlightRule"
QT_MOC_LITERAL(2, 52, 0), // ""
QT_MOC_LITERAL(3, 53, 13), // "highlightRule"
QT_MOC_LITERAL(4, 67, 26), // "requestRemoveHighlightRule"
QT_MOC_LITERAL(5, 94, 23), // "requestAddHighlightRule"
QT_MOC_LITERAL(6, 118, 2), // "id"
QT_MOC_LITERAL(7, 121, 4), // "name"
QT_MOC_LITERAL(8, 126, 7), // "isRegEx"
QT_MOC_LITERAL(9, 134, 15), // "isCaseSensitive"
QT_MOC_LITERAL(10, 150, 9), // "isEnabled"
QT_MOC_LITERAL(11, 160, 9), // "isInverse"
QT_MOC_LITERAL(12, 170, 6), // "sender"
QT_MOC_LITERAL(13, 177, 8), // "chanName"
QT_MOC_LITERAL(14, 186, 4) // "save"

    },
    "CoreHighlightRuleManager\0"
    "requestToggleHighlightRule\0\0highlightRule\0"
    "requestRemoveHighlightRule\0"
    "requestAddHighlightRule\0id\0name\0isRegEx\0"
    "isCaseSensitive\0isEnabled\0isInverse\0"
    "sender\0chanName\0save"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreHighlightRuleManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x0a /* Public */,
       4,    1,   37,    2, 0x0a /* Public */,
       5,    8,   40,    2, 0x0a /* Public */,
      14,    0,   57,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool, QMetaType::QString, QMetaType::QString,    6,    7,    8,    9,   10,   11,   12,   13,
    QMetaType::Void,

       0        // eod
};

void CoreHighlightRuleManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreHighlightRuleManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->requestToggleHighlightRule((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->requestRemoveHighlightRule((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->requestAddHighlightRule((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< bool(*)>(_a[6])),(*reinterpret_cast< const QString(*)>(_a[7])),(*reinterpret_cast< const QString(*)>(_a[8]))); break;
        case 3: _t->save(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreHighlightRuleManager::staticMetaObject = { {
    QMetaObject::SuperData::link<HighlightRuleManager::staticMetaObject>(),
    qt_meta_stringdata_CoreHighlightRuleManager.data,
    qt_meta_data_CoreHighlightRuleManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreHighlightRuleManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreHighlightRuleManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreHighlightRuleManager.stringdata0))
        return static_cast<void*>(this);
    return HighlightRuleManager::qt_metacast(_clname);
}

int CoreHighlightRuleManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = HighlightRuleManager::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
