/****************************************************************************
** Meta object code from reading C++ file 'chatmonitorsettingspage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/settingspages/chatmonitorsettingspage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'chatmonitorsettingspage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ChatMonitorSettingsPage_t {
    QByteArrayData data[13];
    char stringdata0[210];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ChatMonitorSettingsPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ChatMonitorSettingsPage_t qt_meta_stringdata_ChatMonitorSettingsPage = {
    {
QT_MOC_LITERAL(0, 0, 23), // "ChatMonitorSettingsPage"
QT_MOC_LITERAL(1, 24, 4), // "save"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 4), // "load"
QT_MOC_LITERAL(4, 35, 12), // "loadSettings"
QT_MOC_LITERAL(5, 48, 8), // "defaults"
QT_MOC_LITERAL(6, 57, 16), // "widgetHasChanged"
QT_MOC_LITERAL(7, 74, 25), // "on_activateBuffer_clicked"
QT_MOC_LITERAL(8, 100, 27), // "on_deactivateBuffer_clicked"
QT_MOC_LITERAL(9, 128, 19), // "switchOperationMode"
QT_MOC_LITERAL(10, 148, 3), // "idx"
QT_MOC_LITERAL(11, 152, 16), // "setRequesterType"
QT_MOC_LITERAL(12, 169, 40) // "on_showBacklogUnavailableDeta..."

    },
    "ChatMonitorSettingsPage\0save\0\0load\0"
    "loadSettings\0defaults\0widgetHasChanged\0"
    "on_activateBuffer_clicked\0"
    "on_deactivateBuffer_clicked\0"
    "switchOperationMode\0idx\0setRequesterType\0"
    "on_showBacklogUnavailableDetails_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ChatMonitorSettingsPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x0a /* Public */,
       3,    0,   65,    2, 0x0a /* Public */,
       4,    0,   66,    2, 0x0a /* Public */,
       5,    0,   67,    2, 0x0a /* Public */,
       6,    0,   68,    2, 0x08 /* Private */,
       7,    0,   69,    2, 0x08 /* Private */,
       8,    0,   70,    2, 0x08 /* Private */,
       9,    1,   71,    2, 0x08 /* Private */,
      11,    1,   74,    2, 0x08 /* Private */,
      12,    0,   77,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::QVariant,    2,
    QMetaType::Void,

       0        // eod
};

void ChatMonitorSettingsPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ChatMonitorSettingsPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->save(); break;
        case 1: _t->load(); break;
        case 2: _t->loadSettings(); break;
        case 3: _t->defaults(); break;
        case 4: _t->widgetHasChanged(); break;
        case 5: _t->on_activateBuffer_clicked(); break;
        case 6: _t->on_deactivateBuffer_clicked(); break;
        case 7: _t->switchOperationMode((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->setRequesterType((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        case 9: _t->on_showBacklogUnavailableDetails_clicked(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ChatMonitorSettingsPage::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingsPage::staticMetaObject>(),
    qt_meta_stringdata_ChatMonitorSettingsPage.data,
    qt_meta_data_ChatMonitorSettingsPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ChatMonitorSettingsPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ChatMonitorSettingsPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ChatMonitorSettingsPage.stringdata0))
        return static_cast<void*>(this);
    return SettingsPage::qt_metacast(_clname);
}

int ChatMonitorSettingsPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingsPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
