/****************************************************************************
** Meta object code from reading C++ file 'selectionmodelsynchronizer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/client/selectionmodelsynchronizer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'selectionmodelsynchronizer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SelectionModelSynchronizer_t {
    QByteArrayData data[18];
    char stringdata0[251];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SelectionModelSynchronizer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SelectionModelSynchronizer_t qt_meta_stringdata_SelectionModelSynchronizer = {
    {
QT_MOC_LITERAL(0, 0, 26), // "SelectionModelSynchronizer"
QT_MOC_LITERAL(1, 27, 20), // "syncedCurrentChanged"
QT_MOC_LITERAL(2, 48, 0), // ""
QT_MOC_LITERAL(3, 49, 11), // "QModelIndex"
QT_MOC_LITERAL(4, 61, 7), // "current"
QT_MOC_LITERAL(5, 69, 8), // "previous"
QT_MOC_LITERAL(6, 78, 22), // "syncedSelectionChanged"
QT_MOC_LITERAL(7, 101, 14), // "QItemSelection"
QT_MOC_LITERAL(8, 116, 8), // "selected"
QT_MOC_LITERAL(9, 125, 15), // "setCurrentIndex"
QT_MOC_LITERAL(10, 141, 5), // "index"
QT_MOC_LITERAL(11, 147, 19), // "setCurrentSelection"
QT_MOC_LITERAL(12, 167, 9), // "selection"
QT_MOC_LITERAL(13, 177, 14), // "currentChanged"
QT_MOC_LITERAL(14, 192, 16), // "selectionChanged"
QT_MOC_LITERAL(15, 209, 10), // "deselected"
QT_MOC_LITERAL(16, 220, 23), // "selectionModelDestroyed"
QT_MOC_LITERAL(17, 244, 6) // "object"

    },
    "SelectionModelSynchronizer\0"
    "syncedCurrentChanged\0\0QModelIndex\0"
    "current\0previous\0syncedSelectionChanged\0"
    "QItemSelection\0selected\0setCurrentIndex\0"
    "index\0setCurrentSelection\0selection\0"
    "currentChanged\0selectionChanged\0"
    "deselected\0selectionModelDestroyed\0"
    "object"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SelectionModelSynchronizer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   49,    2, 0x08 /* Private */,
       6,    2,   54,    2, 0x08 /* Private */,
       9,    1,   59,    2, 0x08 /* Private */,
      11,    1,   62,    2, 0x08 /* Private */,
      13,    2,   65,    2, 0x08 /* Private */,
      14,    2,   70,    2, 0x08 /* Private */,
      16,    1,   75,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    4,    5,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 7,    8,    5,
    QMetaType::Void, 0x80000000 | 3,   10,
    QMetaType::Void, 0x80000000 | 7,   12,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    4,    5,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 7,    8,   15,
    QMetaType::Void, QMetaType::QObjectStar,   17,

       0        // eod
};

void SelectionModelSynchronizer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SelectionModelSynchronizer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->syncedCurrentChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 1: _t->syncedSelectionChanged((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 2: _t->setCurrentIndex((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 3: _t->setCurrentSelection((*reinterpret_cast< const QItemSelection(*)>(_a[1]))); break;
        case 4: _t->currentChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 5: _t->selectionChanged((*reinterpret_cast< const QItemSelection(*)>(_a[1])),(*reinterpret_cast< const QItemSelection(*)>(_a[2]))); break;
        case 6: _t->selectionModelDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QItemSelection >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QItemSelection >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QItemSelection >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject SelectionModelSynchronizer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_SelectionModelSynchronizer.data,
    qt_meta_data_SelectionModelSynchronizer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SelectionModelSynchronizer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SelectionModelSynchronizer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SelectionModelSynchronizer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SelectionModelSynchronizer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
