/****************************************************************************
** Meta object code from reading C++ file 'backlogmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/backlogmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'backlogmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BacklogManager_t {
    QByteArrayData data[23];
    char stringdata0[324];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BacklogManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BacklogManager_t qt_meta_stringdata_BacklogManager = {
    {
QT_MOC_LITERAL(0, 0, 14), // "BacklogManager"
QT_MOC_LITERAL(1, 15, 16), // "backlogRequested"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 8), // "BufferId"
QT_MOC_LITERAL(4, 42, 5), // "MsgId"
QT_MOC_LITERAL(5, 48, 19), // "backlogAllRequested"
QT_MOC_LITERAL(6, 68, 14), // "requestBacklog"
QT_MOC_LITERAL(7, 83, 8), // "bufferId"
QT_MOC_LITERAL(8, 92, 5), // "first"
QT_MOC_LITERAL(9, 98, 4), // "last"
QT_MOC_LITERAL(10, 103, 5), // "limit"
QT_MOC_LITERAL(11, 109, 10), // "additional"
QT_MOC_LITERAL(12, 120, 22), // "requestBacklogFiltered"
QT_MOC_LITERAL(13, 143, 4), // "type"
QT_MOC_LITERAL(14, 148, 5), // "flags"
QT_MOC_LITERAL(15, 154, 21), // "requestBacklogForward"
QT_MOC_LITERAL(16, 176, 14), // "receiveBacklog"
QT_MOC_LITERAL(17, 191, 22), // "receiveBacklogFiltered"
QT_MOC_LITERAL(18, 214, 21), // "receiveBacklogForward"
QT_MOC_LITERAL(19, 236, 17), // "requestBacklogAll"
QT_MOC_LITERAL(20, 254, 25), // "requestBacklogAllFiltered"
QT_MOC_LITERAL(21, 280, 17), // "receiveBacklogAll"
QT_MOC_LITERAL(22, 298, 25) // "receiveBacklogAllFiltered"

    },
    "BacklogManager\0backlogRequested\0\0"
    "BufferId\0MsgId\0backlogAllRequested\0"
    "requestBacklog\0bufferId\0first\0last\0"
    "limit\0additional\0requestBacklogFiltered\0"
    "type\0flags\0requestBacklogForward\0"
    "receiveBacklog\0receiveBacklogFiltered\0"
    "receiveBacklogForward\0requestBacklogAll\0"
    "requestBacklogAllFiltered\0receiveBacklogAll\0"
    "receiveBacklogAllFiltered"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BacklogManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      37,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    5,  199,    2, 0x06 /* Public */,
       5,    4,  210,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    5,  219,    2, 0x0a /* Public */,
       6,    4,  230,    2, 0x2a /* Public | MethodCloned */,
       6,    3,  239,    2, 0x2a /* Public | MethodCloned */,
       6,    2,  246,    2, 0x2a /* Public | MethodCloned */,
       6,    1,  251,    2, 0x2a /* Public | MethodCloned */,
      12,    7,  254,    2, 0x0a /* Public */,
      12,    6,  269,    2, 0x2a /* Public | MethodCloned */,
      12,    5,  282,    2, 0x2a /* Public | MethodCloned */,
      12,    4,  293,    2, 0x2a /* Public | MethodCloned */,
      12,    3,  302,    2, 0x2a /* Public | MethodCloned */,
      12,    2,  309,    2, 0x2a /* Public | MethodCloned */,
      12,    1,  314,    2, 0x2a /* Public | MethodCloned */,
      15,    6,  317,    2, 0x0a /* Public */,
      15,    5,  330,    2, 0x2a /* Public | MethodCloned */,
      15,    4,  341,    2, 0x2a /* Public | MethodCloned */,
      15,    3,  350,    2, 0x2a /* Public | MethodCloned */,
      15,    2,  357,    2, 0x2a /* Public | MethodCloned */,
      15,    1,  362,    2, 0x2a /* Public | MethodCloned */,
      16,    6,  365,    2, 0x0a /* Public */,
      17,    8,  378,    2, 0x0a /* Public */,
      18,    7,  395,    2, 0x0a /* Public */,
      19,    4,  410,    2, 0x0a /* Public */,
      19,    3,  419,    2, 0x2a /* Public | MethodCloned */,
      19,    2,  426,    2, 0x2a /* Public | MethodCloned */,
      19,    1,  431,    2, 0x2a /* Public | MethodCloned */,
      19,    0,  434,    2, 0x2a /* Public | MethodCloned */,
      20,    6,  435,    2, 0x0a /* Public */,
      20,    5,  448,    2, 0x2a /* Public | MethodCloned */,
      20,    4,  459,    2, 0x2a /* Public | MethodCloned */,
      20,    3,  468,    2, 0x2a /* Public | MethodCloned */,
      20,    2,  475,    2, 0x2a /* Public | MethodCloned */,
      20,    1,  480,    2, 0x2a /* Public | MethodCloned */,
      20,    0,  483,    2, 0x2a /* Public | MethodCloned */,
      21,    5,  484,    2, 0x0a /* Public */,
      22,    7,  495,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    2,    2,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    2,    2,    2,    2,

 // slots: parameters
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    7,    8,    9,   10,   11,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int,    7,    8,    9,   10,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4,    7,    8,    9,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4,    7,    8,
    QMetaType::QVariantList, 0x80000000 | 3,    7,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    7,    8,    9,   10,   11,   13,   14,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, QMetaType::Int,    7,    8,    9,   10,   11,   13,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    7,    8,    9,   10,   11,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int,    7,    8,    9,   10,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4,    7,    8,    9,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4,    7,    8,
    QMetaType::QVariantList, 0x80000000 | 3,    7,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, QMetaType::Int,    7,    8,    9,   10,   13,   14,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    7,    8,    9,   10,   13,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int,    7,    8,    9,   10,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4,    7,    8,    9,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 4,    7,    8,
    QMetaType::QVariantList, 0x80000000 | 3,    7,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, QMetaType::QVariantList,    2,    2,    2,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::QVariantList,    2,    2,    2,    2,    2,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::QVariantList,    2,    2,    2,    2,    2,    2,    2,
    QMetaType::QVariantList, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    8,    9,   10,   11,
    QMetaType::QVariantList, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int,    8,    9,   10,
    QMetaType::QVariantList, 0x80000000 | 4, 0x80000000 | 4,    8,    9,
    QMetaType::QVariantList, 0x80000000 | 4,    8,
    QMetaType::QVariantList,
    QMetaType::QVariantList, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    8,    9,   10,   11,   13,   14,
    QMetaType::QVariantList, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, QMetaType::Int,    8,    9,   10,   11,   13,
    QMetaType::QVariantList, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int,    8,    9,   10,   11,
    QMetaType::QVariantList, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int,    8,    9,   10,
    QMetaType::QVariantList, 0x80000000 | 4, 0x80000000 | 4,    8,    9,
    QMetaType::QVariantList, 0x80000000 | 4,    8,
    QMetaType::QVariantList,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, QMetaType::QVariantList,    2,    2,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 4, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::QVariantList,    2,    2,    2,    2,    2,    2,    2,

       0        // eod
};

void BacklogManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BacklogManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->backlogRequested((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 1: _t->backlogAllRequested((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 2: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 3: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 4: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 5: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 7: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 8: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 9: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 10: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 11: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 12: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 13: { QVariantList _r = _t->requestBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 14: { QVariantList _r = _t->requestBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 15: { QVariantList _r = _t->requestBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 16: { QVariantList _r = _t->requestBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 17: { QVariantList _r = _t->requestBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 18: { QVariantList _r = _t->requestBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 19: { QVariantList _r = _t->requestBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->receiveBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< QVariantList(*)>(_a[6]))); break;
        case 21: _t->receiveBacklogFiltered((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< int(*)>(_a[7])),(*reinterpret_cast< QVariantList(*)>(_a[8]))); break;
        case 22: _t->receiveBacklogForward((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< QVariantList(*)>(_a[7]))); break;
        case 23: { QVariantList _r = _t->requestBacklogAll((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 24: { QVariantList _r = _t->requestBacklogAll((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 25: { QVariantList _r = _t->requestBacklogAll((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 26: { QVariantList _r = _t->requestBacklogAll((*reinterpret_cast< MsgId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 27: { QVariantList _r = _t->requestBacklogAll();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 28: { QVariantList _r = _t->requestBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 29: { QVariantList _r = _t->requestBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 30: { QVariantList _r = _t->requestBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 31: { QVariantList _r = _t->requestBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 32: { QVariantList _r = _t->requestBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 33: { QVariantList _r = _t->requestBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 34: { QVariantList _r = _t->requestBacklogAllFiltered();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->receiveBacklogAll((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< QVariantList(*)>(_a[5]))); break;
        case 36: _t->receiveBacklogAllFiltered((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< QVariantList(*)>(_a[7]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BacklogManager::*)(BufferId , MsgId , MsgId , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BacklogManager::backlogRequested)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (BacklogManager::*)(MsgId , MsgId , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BacklogManager::backlogAllRequested)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BacklogManager::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_BacklogManager.data,
    qt_meta_data_BacklogManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BacklogManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BacklogManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BacklogManager.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int BacklogManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 37)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 37;
    }
    return _id;
}

// SIGNAL 0
void BacklogManager::backlogRequested(BufferId _t1, MsgId _t2, MsgId _t3, int _t4, int _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void BacklogManager::backlogAllRequested(MsgId _t1, MsgId _t2, int _t3, int _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
