/****************************************************************************
** Meta object code from reading C++ file 'clientbacklogmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/client/clientbacklogmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'clientbacklogmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ClientBacklogManager_t {
    QByteArrayData data[22];
    char stringdata0[262];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ClientBacklogManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ClientBacklogManager_t qt_meta_stringdata_ClientBacklogManager = {
    {
QT_MOC_LITERAL(0, 0, 20), // "ClientBacklogManager"
QT_MOC_LITERAL(1, 21, 16), // "messagesReceived"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 8), // "BufferId"
QT_MOC_LITERAL(4, 48, 8), // "bufferId"
QT_MOC_LITERAL(5, 57, 5), // "count"
QT_MOC_LITERAL(6, 63, 17), // "messagesRequested"
QT_MOC_LITERAL(7, 81, 17), // "messagesProcessed"
QT_MOC_LITERAL(8, 99, 14), // "updateProgress"
QT_MOC_LITERAL(9, 114, 14), // "requestBacklog"
QT_MOC_LITERAL(10, 129, 5), // "MsgId"
QT_MOC_LITERAL(11, 135, 5), // "first"
QT_MOC_LITERAL(12, 141, 4), // "last"
QT_MOC_LITERAL(13, 146, 5), // "limit"
QT_MOC_LITERAL(14, 152, 10), // "additional"
QT_MOC_LITERAL(15, 163, 14), // "receiveBacklog"
QT_MOC_LITERAL(16, 178, 4), // "msgs"
QT_MOC_LITERAL(17, 183, 17), // "receiveBacklogAll"
QT_MOC_LITERAL(18, 201, 21), // "requestInitialBacklog"
QT_MOC_LITERAL(19, 223, 15), // "checkForBacklog"
QT_MOC_LITERAL(20, 239, 12), // "BufferIdList"
QT_MOC_LITERAL(21, 252, 9) // "bufferIds"

    },
    "ClientBacklogManager\0messagesReceived\0"
    "\0BufferId\0bufferId\0count\0messagesRequested\0"
    "messagesProcessed\0updateProgress\0"
    "requestBacklog\0MsgId\0first\0last\0limit\0"
    "additional\0receiveBacklog\0msgs\0"
    "receiveBacklogAll\0requestInitialBacklog\0"
    "checkForBacklog\0BufferIdList\0bufferIds"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ClientBacklogManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   84,    2, 0x06 /* Public */,
       6,    1,   89,    2, 0x06 /* Public */,
       7,    1,   92,    2, 0x06 /* Public */,
       8,    2,   95,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    5,  100,    2, 0x0a /* Public */,
       9,    4,  111,    2, 0x2a /* Public | MethodCloned */,
       9,    3,  120,    2, 0x2a /* Public | MethodCloned */,
       9,    2,  127,    2, 0x2a /* Public | MethodCloned */,
       9,    1,  132,    2, 0x2a /* Public | MethodCloned */,
      15,    6,  135,    2, 0x0a /* Public */,
      17,    5,  148,    2, 0x0a /* Public */,
      18,    0,  159,    2, 0x0a /* Public */,
      19,    1,  160,    2, 0x0a /* Public */,
      19,    1,  163,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    4,    5,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    2,    2,

 // slots: parameters
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 10, 0x80000000 | 10, QMetaType::Int, QMetaType::Int,    4,   11,   12,   13,   14,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 10, 0x80000000 | 10, QMetaType::Int,    4,   11,   12,   13,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 10, 0x80000000 | 10,    4,   11,   12,
    QMetaType::QVariantList, 0x80000000 | 3, 0x80000000 | 10,    4,   11,
    QMetaType::QVariantList, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 10, 0x80000000 | 10, QMetaType::Int, QMetaType::Int, QMetaType::QVariantList,    4,   11,   12,   13,   14,   16,
    QMetaType::Void, 0x80000000 | 10, 0x80000000 | 10, QMetaType::Int, QMetaType::Int, QMetaType::QVariantList,   11,   12,   13,   14,   16,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 20,   21,

       0        // eod
};

void ClientBacklogManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ClientBacklogManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->messagesReceived((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->messagesRequested((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->messagesProcessed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->updateProgress((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 5: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 7: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 8: { QVariantList _r = _t->requestBacklog((*reinterpret_cast< BufferId(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->receiveBacklog((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< MsgId(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])),(*reinterpret_cast< QVariantList(*)>(_a[6]))); break;
        case 10: _t->receiveBacklogAll((*reinterpret_cast< MsgId(*)>(_a[1])),(*reinterpret_cast< MsgId(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< QVariantList(*)>(_a[5]))); break;
        case 11: _t->requestInitialBacklog(); break;
        case 12: _t->checkForBacklog((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 13: _t->checkForBacklog((*reinterpret_cast< const BufferIdList(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            case 2:
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MsgId >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ClientBacklogManager::*)(BufferId , int ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientBacklogManager::messagesReceived)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ClientBacklogManager::*)(const QString & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientBacklogManager::messagesRequested)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ClientBacklogManager::*)(const QString & ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientBacklogManager::messagesProcessed)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (ClientBacklogManager::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ClientBacklogManager::updateProgress)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ClientBacklogManager::staticMetaObject = { {
    QMetaObject::SuperData::link<BacklogManager::staticMetaObject>(),
    qt_meta_stringdata_ClientBacklogManager.data,
    qt_meta_data_ClientBacklogManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ClientBacklogManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClientBacklogManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ClientBacklogManager.stringdata0))
        return static_cast<void*>(this);
    return BacklogManager::qt_metacast(_clname);
}

int ClientBacklogManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BacklogManager::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void ClientBacklogManager::messagesReceived(BufferId _t1, int _t2)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(const_cast< ClientBacklogManager *>(this), &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ClientBacklogManager::messagesRequested(const QString & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(const_cast< ClientBacklogManager *>(this), &staticMetaObject, 1, _a);
}

// SIGNAL 2
void ClientBacklogManager::messagesProcessed(const QString & _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(const_cast< ClientBacklogManager *>(this), &staticMetaObject, 2, _a);
}

// SIGNAL 3
void ClientBacklogManager::updateProgress(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
