/********************************************************************************
** Form generated from reading UI file 'settingspagedlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSPAGEDLG_H
#define UI_SETTINGSPAGEDLG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QLabel>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SettingsPageDlg
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *pageTitle;
    QFrame *line;
    QScrollArea *settingsFrame;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SettingsPageDlg)
    {
        if (SettingsPageDlg->objectName().isEmpty())
            SettingsPageDlg->setObjectName(QString::fromUtf8("SettingsPageDlg"));
        SettingsPageDlg->resize(547, 546);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/16x16/actions/configure"), QSize(), QIcon::Normal, QIcon::Off);
        SettingsPageDlg->setWindowIcon(icon);
        vboxLayout = new QVBoxLayout(SettingsPageDlg);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        pageTitle = new QLabel(SettingsPageDlg);
        pageTitle->setObjectName(QString::fromUtf8("pageTitle"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        pageTitle->setFont(font);

        vboxLayout->addWidget(pageTitle);

        line = new QFrame(SettingsPageDlg);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        vboxLayout->addWidget(line);

        settingsFrame = new QScrollArea(SettingsPageDlg);
        settingsFrame->setObjectName(QString::fromUtf8("settingsFrame"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(settingsFrame->sizePolicy().hasHeightForWidth());
        settingsFrame->setSizePolicy(sizePolicy);
        settingsFrame->setFrameShape(QFrame::NoFrame);
        settingsFrame->setFrameShadow(QFrame::Plain);

        vboxLayout->addWidget(settingsFrame);

        buttonBox = new QDialogButtonBox(SettingsPageDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset|QDialogButtonBox::RestoreDefaults);

        vboxLayout->addWidget(buttonBox);


        retranslateUi(SettingsPageDlg);

        QMetaObject::connectSlotsByName(SettingsPageDlg);
    } // setupUi

    void retranslateUi(QDialog *SettingsPageDlg)
    {
        SettingsPageDlg->setWindowTitle(QCoreApplication::translate("SettingsPageDlg", "Configure Quassel", nullptr));
        pageTitle->setText(QCoreApplication::translate("SettingsPageDlg", "Settings", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SettingsPageDlg: public Ui_SettingsPageDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SETTINGSPAGEDLG_H
