/****************************************************************************
** Meta object code from reading C++ file 'authenticator.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/authenticator.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'authenticator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Authenticator_t {
    QByteArrayData data[19];
    char stringdata0[201];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Authenticator_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Authenticator_t qt_meta_stringdata_Authenticator = {
    {
QT_MOC_LITERAL(0, 0, 13), // "Authenticator"
QT_MOC_LITERAL(1, 14, 11), // "isAvailable"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 9), // "backendId"
QT_MOC_LITERAL(4, 37, 11), // "displayName"
QT_MOC_LITERAL(5, 49, 11), // "description"
QT_MOC_LITERAL(6, 61, 9), // "setupData"
QT_MOC_LITERAL(7, 71, 17), // "canChangePassword"
QT_MOC_LITERAL(8, 89, 5), // "setup"
QT_MOC_LITERAL(9, 95, 8), // "settings"
QT_MOC_LITERAL(10, 104, 19), // "QProcessEnvironment"
QT_MOC_LITERAL(11, 124, 11), // "environment"
QT_MOC_LITERAL(12, 136, 19), // "loadFromEnvironment"
QT_MOC_LITERAL(13, 156, 4), // "init"
QT_MOC_LITERAL(14, 161, 5), // "State"
QT_MOC_LITERAL(15, 167, 12), // "validateUser"
QT_MOC_LITERAL(16, 180, 6), // "UserId"
QT_MOC_LITERAL(17, 187, 4), // "user"
QT_MOC_LITERAL(18, 192, 8) // "password"

    },
    "Authenticator\0isAvailable\0\0backendId\0"
    "displayName\0description\0setupData\0"
    "canChangePassword\0setup\0settings\0"
    "QProcessEnvironment\0environment\0"
    "loadFromEnvironment\0init\0State\0"
    "validateUser\0UserId\0user\0password"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Authenticator[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   89,    2, 0x0a /* Public */,
       3,    0,   90,    2, 0x0a /* Public */,
       4,    0,   91,    2, 0x0a /* Public */,
       5,    0,   92,    2, 0x0a /* Public */,
       6,    0,   93,    2, 0x0a /* Public */,
       7,    0,   94,    2, 0x0a /* Public */,
       8,    3,   95,    2, 0x0a /* Public */,
       8,    2,  102,    2, 0x2a /* Public | MethodCloned */,
       8,    1,  107,    2, 0x2a /* Public | MethodCloned */,
       8,    0,  110,    2, 0x2a /* Public | MethodCloned */,
      13,    3,  111,    2, 0x0a /* Public */,
      13,    2,  118,    2, 0x2a /* Public | MethodCloned */,
      13,    1,  123,    2, 0x2a /* Public | MethodCloned */,
      13,    0,  126,    2, 0x2a /* Public | MethodCloned */,
      15,    2,  127,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::QString,
    QMetaType::QString,
    QMetaType::QString,
    QMetaType::QVariantList,
    QMetaType::Bool,
    QMetaType::Bool, QMetaType::QVariantMap, 0x80000000 | 10, QMetaType::Bool,    9,   11,   12,
    QMetaType::Bool, QMetaType::QVariantMap, 0x80000000 | 10,    9,   11,
    QMetaType::Bool, QMetaType::QVariantMap,    9,
    QMetaType::Bool,
    0x80000000 | 14, QMetaType::QVariantMap, 0x80000000 | 10, QMetaType::Bool,    9,   11,   12,
    0x80000000 | 14, QMetaType::QVariantMap, 0x80000000 | 10,    9,   11,
    0x80000000 | 14, QMetaType::QVariantMap,    9,
    0x80000000 | 14,
    0x80000000 | 16, QMetaType::QString, QMetaType::QString,   17,   18,

       0        // eod
};

void Authenticator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Authenticator *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { bool _r = _t->isAvailable();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->backendId();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QString _r = _t->displayName();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->description();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { QVariantList _r = _t->setupData();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->canChangePassword();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->setup((*reinterpret_cast< const QVariantMap(*)>(_a[1])),(*reinterpret_cast< const QProcessEnvironment(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->setup((*reinterpret_cast< const QVariantMap(*)>(_a[1])),(*reinterpret_cast< const QProcessEnvironment(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->setup((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->setup();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { State _r = _t->init((*reinterpret_cast< const QVariantMap(*)>(_a[1])),(*reinterpret_cast< const QProcessEnvironment(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< State*>(_a[0]) = std::move(_r); }  break;
        case 11: { State _r = _t->init((*reinterpret_cast< const QVariantMap(*)>(_a[1])),(*reinterpret_cast< const QProcessEnvironment(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< State*>(_a[0]) = std::move(_r); }  break;
        case 12: { State _r = _t->init((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< State*>(_a[0]) = std::move(_r); }  break;
        case 13: { State _r = _t->init();
            if (_a[0]) *reinterpret_cast< State*>(_a[0]) = std::move(_r); }  break;
        case 14: { UserId _r = _t->validateUser((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< UserId*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Authenticator::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Authenticator.data,
    qt_meta_data_Authenticator,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Authenticator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Authenticator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Authenticator.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Authenticator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
