/****************************************************************************
** Meta object code from reading C++ file 'coreaccountsettingspage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/settingspages/coreaccountsettingspage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'coreaccountsettingspage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreAccountSettingsPage_t {
    QByteArrayData data[21];
    char stringdata0[310];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreAccountSettingsPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreAccountSettingsPage_t qt_meta_stringdata_CoreAccountSettingsPage = {
    {
QT_MOC_LITERAL(0, 0, 23), // "CoreAccountSettingsPage"
QT_MOC_LITERAL(1, 24, 13), // "connectToCore"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 9), // "AccountId"
QT_MOC_LITERAL(4, 49, 5), // "accId"
QT_MOC_LITERAL(5, 55, 4), // "save"
QT_MOC_LITERAL(6, 60, 4), // "load"
QT_MOC_LITERAL(7, 65, 18), // "setSelectedAccount"
QT_MOC_LITERAL(8, 84, 13), // "setStandAlone"
QT_MOC_LITERAL(9, 98, 27), // "on_addAccountButton_clicked"
QT_MOC_LITERAL(10, 126, 28), // "on_editAccountButton_clicked"
QT_MOC_LITERAL(11, 155, 30), // "on_deleteAccountButton_clicked"
QT_MOC_LITERAL(12, 186, 28), // "on_accountView_doubleClicked"
QT_MOC_LITERAL(13, 215, 11), // "QModelIndex"
QT_MOC_LITERAL(14, 227, 5), // "index"
QT_MOC_LITERAL(15, 233, 15), // "setWidgetStates"
QT_MOC_LITERAL(16, 249, 16), // "widgetHasChanged"
QT_MOC_LITERAL(17, 266, 20), // "rowsAboutToBeRemoved"
QT_MOC_LITERAL(18, 287, 5), // "start"
QT_MOC_LITERAL(19, 293, 3), // "end"
QT_MOC_LITERAL(20, 297, 12) // "rowsInserted"

    },
    "CoreAccountSettingsPage\0connectToCore\0"
    "\0AccountId\0accId\0save\0load\0"
    "setSelectedAccount\0setStandAlone\0"
    "on_addAccountButton_clicked\0"
    "on_editAccountButton_clicked\0"
    "on_deleteAccountButton_clicked\0"
    "on_accountView_doubleClicked\0QModelIndex\0"
    "index\0setWidgetStates\0widgetHasChanged\0"
    "rowsAboutToBeRemoved\0start\0end\0"
    "rowsInserted"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreAccountSettingsPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   79,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   82,    2, 0x0a /* Public */,
       6,    0,   83,    2, 0x0a /* Public */,
       7,    1,   84,    2, 0x0a /* Public */,
       8,    1,   87,    2, 0x0a /* Public */,
       9,    0,   90,    2, 0x08 /* Private */,
      10,    0,   91,    2, 0x08 /* Private */,
      11,    0,   92,    2, 0x08 /* Private */,
      12,    1,   93,    2, 0x08 /* Private */,
      15,    0,   96,    2, 0x08 /* Private */,
      16,    0,   97,    2, 0x08 /* Private */,
      17,    3,   98,    2, 0x08 /* Private */,
      20,    3,  105,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 13, QMetaType::Int, QMetaType::Int,   14,   18,   19,
    QMetaType::Void, 0x80000000 | 13, QMetaType::Int, QMetaType::Int,   14,   18,   19,

       0        // eod
};

void CoreAccountSettingsPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreAccountSettingsPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->connectToCore((*reinterpret_cast< AccountId(*)>(_a[1]))); break;
        case 1: _t->save(); break;
        case 2: _t->load(); break;
        case 3: _t->setSelectedAccount((*reinterpret_cast< AccountId(*)>(_a[1]))); break;
        case 4: _t->setStandAlone((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->on_addAccountButton_clicked(); break;
        case 6: _t->on_editAccountButton_clicked(); break;
        case 7: _t->on_deleteAccountButton_clicked(); break;
        case 8: _t->on_accountView_doubleClicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 9: _t->setWidgetStates(); break;
        case 10: _t->widgetHasChanged(); break;
        case 11: _t->rowsAboutToBeRemoved((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 12: _t->rowsInserted((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AccountId >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AccountId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CoreAccountSettingsPage::*)(AccountId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreAccountSettingsPage::connectToCore)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreAccountSettingsPage::staticMetaObject = { {
    QMetaObject::SuperData::link<SettingsPage::staticMetaObject>(),
    qt_meta_stringdata_CoreAccountSettingsPage.data,
    qt_meta_data_CoreAccountSettingsPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreAccountSettingsPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreAccountSettingsPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreAccountSettingsPage.stringdata0))
        return static_cast<void*>(this);
    return SettingsPage::qt_metacast(_clname);
}

int CoreAccountSettingsPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SettingsPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void CoreAccountSettingsPage::connectToCore(AccountId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_CoreAccountEditDlg_t {
    QByteArrayData data[8];
    char stringdata0[149];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreAccountEditDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreAccountEditDlg_t qt_meta_stringdata_CoreAccountEditDlg = {
    {
QT_MOC_LITERAL(0, 0, 18), // "CoreAccountEditDlg"
QT_MOC_LITERAL(1, 19, 23), // "on_hostName_textChanged"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 26), // "on_accountName_textChanged"
QT_MOC_LITERAL(4, 71, 19), // "on_user_textChanged"
QT_MOC_LITERAL(5, 91, 33), // "on_radioButtonManualProxy_tog..."
QT_MOC_LITERAL(6, 125, 7), // "checked"
QT_MOC_LITERAL(7, 133, 15) // "setWidgetStates"

    },
    "CoreAccountEditDlg\0on_hostName_textChanged\0"
    "\0on_accountName_textChanged\0"
    "on_user_textChanged\0"
    "on_radioButtonManualProxy_toggled\0"
    "checked\0setWidgetStates"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreAccountEditDlg[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x08 /* Private */,
       3,    1,   42,    2, 0x08 /* Private */,
       4,    1,   45,    2, 0x08 /* Private */,
       5,    1,   48,    2, 0x08 /* Private */,
       7,    0,   51,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Bool,    6,
    QMetaType::Void,

       0        // eod
};

void CoreAccountEditDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreAccountEditDlg *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_hostName_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->on_accountName_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->on_user_textChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->on_radioButtonManualProxy_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->setWidgetStates(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreAccountEditDlg::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_CoreAccountEditDlg.data,
    qt_meta_data_CoreAccountEditDlg,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreAccountEditDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreAccountEditDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreAccountEditDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int CoreAccountEditDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}
struct qt_meta_stringdata_FilteredCoreAccountModel_t {
    QByteArrayData data[1];
    char stringdata0[25];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FilteredCoreAccountModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FilteredCoreAccountModel_t qt_meta_stringdata_FilteredCoreAccountModel = {
    {
QT_MOC_LITERAL(0, 0, 24) // "FilteredCoreAccountModel"

    },
    "FilteredCoreAccountModel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FilteredCoreAccountModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void FilteredCoreAccountModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject FilteredCoreAccountModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_meta_stringdata_FilteredCoreAccountModel.data,
    qt_meta_data_FilteredCoreAccountModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *FilteredCoreAccountModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FilteredCoreAccountModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FilteredCoreAccountModel.stringdata0))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int FilteredCoreAccountModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
