/********************************************************************************
** Form generated from reading UI file 'coreconfigwizardauthenticationselectionpage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CORECONFIGWIZARDAUTHENTICATIONSELECTIONPAGE_H
#define UI_CORECONFIGWIZARDAUTHENTICATIONSELECTIONPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_CoreConfigWizardAuthenticationSelectionPage
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hboxLayout;
    QLabel *label;
    QComboBox *backendList;
    QSpacerItem *spacerItem;
    QStackedWidget *descriptionStack;
    QStackedWidget *authSettingsStack;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *CoreConfigWizardAuthenticationSelectionPage)
    {
        if (CoreConfigWizardAuthenticationSelectionPage->objectName().isEmpty())
            CoreConfigWizardAuthenticationSelectionPage->setObjectName(QString::fromUtf8("CoreConfigWizardAuthenticationSelectionPage"));
        CoreConfigWizardAuthenticationSelectionPage->resize(377, 160);
        verticalLayout = new QVBoxLayout(CoreConfigWizardAuthenticationSelectionPage);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        hboxLayout->setSizeConstraint(QLayout::SetMinAndMaxSize);
        label = new QLabel(CoreConfigWizardAuthenticationSelectionPage);
        label->setObjectName(QString::fromUtf8("label"));

        hboxLayout->addWidget(label);

        backendList = new QComboBox(CoreConfigWizardAuthenticationSelectionPage);
        backendList->setObjectName(QString::fromUtf8("backendList"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(backendList->sizePolicy().hasHeightForWidth());
        backendList->setSizePolicy(sizePolicy);
        backendList->setInsertPolicy(QComboBox::InsertAtBottom);

        hboxLayout->addWidget(backendList);

        spacerItem = new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        verticalLayout->addLayout(hboxLayout);

        descriptionStack = new QStackedWidget(CoreConfigWizardAuthenticationSelectionPage);
        descriptionStack->setObjectName(QString::fromUtf8("descriptionStack"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(descriptionStack->sizePolicy().hasHeightForWidth());
        descriptionStack->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(descriptionStack);

        authSettingsStack = new QStackedWidget(CoreConfigWizardAuthenticationSelectionPage);
        authSettingsStack->setObjectName(QString::fromUtf8("authSettingsStack"));
        sizePolicy1.setHeightForWidth(authSettingsStack->sizePolicy().hasHeightForWidth());
        authSettingsStack->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(authSettingsStack);

        verticalSpacer = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(CoreConfigWizardAuthenticationSelectionPage);

        descriptionStack->setCurrentIndex(-1);
        authSettingsStack->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(CoreConfigWizardAuthenticationSelectionPage);
    } // setupUi

    void retranslateUi(QWidget *CoreConfigWizardAuthenticationSelectionPage)
    {
        CoreConfigWizardAuthenticationSelectionPage->setWindowTitle(QCoreApplication::translate("CoreConfigWizardAuthenticationSelectionPage", "Form", nullptr));
        label->setText(QCoreApplication::translate("CoreConfigWizardAuthenticationSelectionPage", "Authentication Backend:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CoreConfigWizardAuthenticationSelectionPage: public Ui_CoreConfigWizardAuthenticationSelectionPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CORECONFIGWIZARDAUTHENTICATIONSELECTIONPAGE_H
