/****************************************************************************
** Meta object code from reading C++ file 'eventstringifier.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/eventstringifier.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'eventstringifier.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EventStringifier_t {
    QByteArrayData data[64];
    char stringdata0[1072];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EventStringifier_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EventStringifier_t qt_meta_stringdata_EventStringifier = {
    {
QT_MOC_LITERAL(0, 0, 16), // "EventStringifier"
QT_MOC_LITERAL(1, 17, 15), // "newMessageEvent"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 6), // "Event*"
QT_MOC_LITERAL(4, 41, 5), // "event"
QT_MOC_LITERAL(5, 47, 10), // "displayMsg"
QT_MOC_LITERAL(6, 58, 13), // "NetworkEvent*"
QT_MOC_LITERAL(7, 72, 13), // "Message::Type"
QT_MOC_LITERAL(8, 86, 7), // "msgType"
QT_MOC_LITERAL(9, 94, 3), // "msg"
QT_MOC_LITERAL(10, 98, 6), // "sender"
QT_MOC_LITERAL(11, 105, 6), // "target"
QT_MOC_LITERAL(12, 112, 14), // "Message::Flags"
QT_MOC_LITERAL(13, 127, 8), // "msgFlags"
QT_MOC_LITERAL(14, 136, 23), // "processNetworkSplitJoin"
QT_MOC_LITERAL(15, 160, 18), // "NetworkSplitEvent*"
QT_MOC_LITERAL(16, 179, 23), // "processNetworkSplitQuit"
QT_MOC_LITERAL(17, 203, 22), // "processIrcEventNumeric"
QT_MOC_LITERAL(18, 226, 16), // "IrcEventNumeric*"
QT_MOC_LITERAL(19, 243, 21), // "processIrcEventInvite"
QT_MOC_LITERAL(20, 265, 9), // "IrcEvent*"
QT_MOC_LITERAL(21, 275, 19), // "processIrcEventJoin"
QT_MOC_LITERAL(22, 295, 19), // "processIrcEventKick"
QT_MOC_LITERAL(23, 315, 19), // "processIrcEventMode"
QT_MOC_LITERAL(24, 335, 19), // "processIrcEventNick"
QT_MOC_LITERAL(25, 355, 19), // "processIrcEventPart"
QT_MOC_LITERAL(26, 375, 19), // "processIrcEventPong"
QT_MOC_LITERAL(27, 395, 19), // "processIrcEventQuit"
QT_MOC_LITERAL(28, 415, 20), // "processIrcEventTopic"
QT_MOC_LITERAL(29, 436, 20), // "processIrcEventError"
QT_MOC_LITERAL(30, 457, 22), // "processIrcEventWallops"
QT_MOC_LITERAL(31, 480, 18), // "processIrcEvent005"
QT_MOC_LITERAL(32, 499, 18), // "processIrcEvent301"
QT_MOC_LITERAL(33, 518, 18), // "processIrcEvent305"
QT_MOC_LITERAL(34, 537, 18), // "processIrcEvent306"
QT_MOC_LITERAL(35, 556, 18), // "processIrcEvent311"
QT_MOC_LITERAL(36, 575, 18), // "processIrcEvent312"
QT_MOC_LITERAL(37, 594, 18), // "processIrcEvent314"
QT_MOC_LITERAL(38, 613, 18), // "processIrcEvent315"
QT_MOC_LITERAL(39, 632, 18), // "processIrcEvent317"
QT_MOC_LITERAL(40, 651, 18), // "processIrcEvent318"
QT_MOC_LITERAL(41, 670, 18), // "processIrcEvent319"
QT_MOC_LITERAL(42, 689, 18), // "processIrcEvent322"
QT_MOC_LITERAL(43, 708, 18), // "processIrcEvent323"
QT_MOC_LITERAL(44, 727, 18), // "processIrcEvent324"
QT_MOC_LITERAL(45, 746, 18), // "processIrcEvent328"
QT_MOC_LITERAL(46, 765, 18), // "processIrcEvent329"
QT_MOC_LITERAL(47, 784, 18), // "processIrcEvent330"
QT_MOC_LITERAL(48, 803, 18), // "processIrcEvent331"
QT_MOC_LITERAL(49, 822, 18), // "processIrcEvent332"
QT_MOC_LITERAL(50, 841, 18), // "processIrcEvent333"
QT_MOC_LITERAL(51, 860, 18), // "processIrcEvent341"
QT_MOC_LITERAL(52, 879, 18), // "processIrcEvent352"
QT_MOC_LITERAL(53, 898, 18), // "processIrcEvent354"
QT_MOC_LITERAL(54, 917, 18), // "processIrcEvent369"
QT_MOC_LITERAL(55, 936, 18), // "processIrcEvent432"
QT_MOC_LITERAL(56, 955, 18), // "processIrcEvent433"
QT_MOC_LITERAL(57, 974, 18), // "processIrcEvent437"
QT_MOC_LITERAL(58, 993, 16), // "processCtcpEvent"
QT_MOC_LITERAL(59, 1010, 10), // "CtcpEvent*"
QT_MOC_LITERAL(60, 1021, 16), // "handleCtcpAction"
QT_MOC_LITERAL(61, 1038, 14), // "handleCtcpPing"
QT_MOC_LITERAL(62, 1053, 14), // "defaultHandler"
QT_MOC_LITERAL(63, 1068, 3) // "cmd"

    },
    "EventStringifier\0newMessageEvent\0\0"
    "Event*\0event\0displayMsg\0NetworkEvent*\0"
    "Message::Type\0msgType\0msg\0sender\0"
    "target\0Message::Flags\0msgFlags\0"
    "processNetworkSplitJoin\0NetworkSplitEvent*\0"
    "processNetworkSplitQuit\0processIrcEventNumeric\0"
    "IrcEventNumeric*\0processIrcEventInvite\0"
    "IrcEvent*\0processIrcEventJoin\0"
    "processIrcEventKick\0processIrcEventMode\0"
    "processIrcEventNick\0processIrcEventPart\0"
    "processIrcEventPong\0processIrcEventQuit\0"
    "processIrcEventTopic\0processIrcEventError\0"
    "processIrcEventWallops\0processIrcEvent005\0"
    "processIrcEvent301\0processIrcEvent305\0"
    "processIrcEvent306\0processIrcEvent311\0"
    "processIrcEvent312\0processIrcEvent314\0"
    "processIrcEvent315\0processIrcEvent317\0"
    "processIrcEvent318\0processIrcEvent319\0"
    "processIrcEvent322\0processIrcEvent323\0"
    "processIrcEvent324\0processIrcEvent328\0"
    "processIrcEvent329\0processIrcEvent330\0"
    "processIrcEvent331\0processIrcEvent332\0"
    "processIrcEvent333\0processIrcEvent341\0"
    "processIrcEvent352\0processIrcEvent354\0"
    "processIrcEvent369\0processIrcEvent432\0"
    "processIrcEvent433\0processIrcEvent437\0"
    "processCtcpEvent\0CtcpEvent*\0"
    "handleCtcpAction\0handleCtcpPing\0"
    "defaultHandler\0cmd"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EventStringifier[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      50,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  264,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    6,  267,    2, 0x0a /* Public */,
       5,    5,  280,    2, 0x2a /* Public | MethodCloned */,
       5,    4,  291,    2, 0x2a /* Public | MethodCloned */,
       5,    3,  300,    2, 0x2a /* Public | MethodCloned */,

 // methods: name, argc, parameters, tag, flags
      14,    1,  307,    2, 0x02 /* Public */,
      16,    1,  310,    2, 0x02 /* Public */,
      17,    1,  313,    2, 0x02 /* Public */,
      19,    1,  316,    2, 0x02 /* Public */,
      21,    1,  319,    2, 0x02 /* Public */,
      22,    1,  322,    2, 0x02 /* Public */,
      23,    1,  325,    2, 0x02 /* Public */,
      24,    1,  328,    2, 0x02 /* Public */,
      25,    1,  331,    2, 0x02 /* Public */,
      26,    1,  334,    2, 0x02 /* Public */,
      27,    1,  337,    2, 0x02 /* Public */,
      28,    1,  340,    2, 0x02 /* Public */,
      29,    1,  343,    2, 0x02 /* Public */,
      30,    1,  346,    2, 0x02 /* Public */,
      31,    1,  349,    2, 0x02 /* Public */,
      32,    1,  352,    2, 0x02 /* Public */,
      33,    1,  355,    2, 0x02 /* Public */,
      34,    1,  358,    2, 0x02 /* Public */,
      35,    1,  361,    2, 0x02 /* Public */,
      36,    1,  364,    2, 0x02 /* Public */,
      37,    1,  367,    2, 0x02 /* Public */,
      38,    1,  370,    2, 0x02 /* Public */,
      39,    1,  373,    2, 0x02 /* Public */,
      40,    1,  376,    2, 0x02 /* Public */,
      41,    1,  379,    2, 0x02 /* Public */,
      42,    1,  382,    2, 0x02 /* Public */,
      43,    1,  385,    2, 0x02 /* Public */,
      44,    1,  388,    2, 0x02 /* Public */,
      45,    1,  391,    2, 0x02 /* Public */,
      46,    1,  394,    2, 0x02 /* Public */,
      47,    1,  397,    2, 0x02 /* Public */,
      48,    1,  400,    2, 0x02 /* Public */,
      49,    1,  403,    2, 0x02 /* Public */,
      50,    1,  406,    2, 0x02 /* Public */,
      51,    1,  409,    2, 0x02 /* Public */,
      52,    1,  412,    2, 0x02 /* Public */,
      53,    1,  415,    2, 0x02 /* Public */,
      54,    1,  418,    2, 0x02 /* Public */,
      55,    1,  421,    2, 0x02 /* Public */,
      56,    1,  424,    2, 0x02 /* Public */,
      57,    1,  427,    2, 0x02 /* Public */,
      58,    1,  430,    2, 0x02 /* Public */,
      60,    1,  433,    2, 0x02 /* Public */,
      61,    1,  436,    2, 0x02 /* Public */,
      62,    2,  439,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 7, QMetaType::QString, QMetaType::QString, QMetaType::QString, 0x80000000 | 12,    4,    8,    9,   10,   11,   13,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 7, QMetaType::QString, QMetaType::QString, QMetaType::QString,    4,    8,    9,   10,   11,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 7, QMetaType::QString, QMetaType::QString,    4,    8,    9,   10,
    QMetaType::Void, 0x80000000 | 6, 0x80000000 | 7, QMetaType::QString,    4,    8,    9,

 // methods: parameters
    QMetaType::Void, 0x80000000 | 15,    4,
    QMetaType::Void, 0x80000000 | 15,    4,
    QMetaType::Void, 0x80000000 | 18,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 20,    4,
    QMetaType::Void, 0x80000000 | 59,    4,
    QMetaType::Void, 0x80000000 | 59,    4,
    QMetaType::Void, 0x80000000 | 59,    4,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 59,   63,    4,

       0        // eod
};

void EventStringifier::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<EventStringifier *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->newMessageEvent((*reinterpret_cast< Event*(*)>(_a[1]))); break;
        case 1: _t->displayMsg((*reinterpret_cast< NetworkEvent*(*)>(_a[1])),(*reinterpret_cast< Message::Type(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3])),(*reinterpret_cast< QString(*)>(_a[4])),(*reinterpret_cast< QString(*)>(_a[5])),(*reinterpret_cast< Message::Flags(*)>(_a[6]))); break;
        case 2: _t->displayMsg((*reinterpret_cast< NetworkEvent*(*)>(_a[1])),(*reinterpret_cast< Message::Type(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3])),(*reinterpret_cast< QString(*)>(_a[4])),(*reinterpret_cast< QString(*)>(_a[5]))); break;
        case 3: _t->displayMsg((*reinterpret_cast< NetworkEvent*(*)>(_a[1])),(*reinterpret_cast< Message::Type(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3])),(*reinterpret_cast< QString(*)>(_a[4]))); break;
        case 4: _t->displayMsg((*reinterpret_cast< NetworkEvent*(*)>(_a[1])),(*reinterpret_cast< Message::Type(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 5: _t->processNetworkSplitJoin((*reinterpret_cast< NetworkSplitEvent*(*)>(_a[1]))); break;
        case 6: _t->processNetworkSplitQuit((*reinterpret_cast< NetworkSplitEvent*(*)>(_a[1]))); break;
        case 7: _t->processIrcEventNumeric((*reinterpret_cast< IrcEventNumeric*(*)>(_a[1]))); break;
        case 8: _t->processIrcEventInvite((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 9: _t->processIrcEventJoin((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 10: _t->processIrcEventKick((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 11: _t->processIrcEventMode((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 12: _t->processIrcEventNick((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 13: _t->processIrcEventPart((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 14: _t->processIrcEventPong((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 15: _t->processIrcEventQuit((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 16: _t->processIrcEventTopic((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 17: _t->processIrcEventError((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 18: _t->processIrcEventWallops((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 19: _t->processIrcEvent005((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 20: _t->processIrcEvent301((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 21: _t->processIrcEvent305((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 22: _t->processIrcEvent306((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 23: _t->processIrcEvent311((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 24: _t->processIrcEvent312((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 25: _t->processIrcEvent314((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 26: _t->processIrcEvent315((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 27: _t->processIrcEvent317((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 28: _t->processIrcEvent318((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 29: _t->processIrcEvent319((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 30: _t->processIrcEvent322((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 31: _t->processIrcEvent323((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 32: _t->processIrcEvent324((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 33: _t->processIrcEvent328((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 34: _t->processIrcEvent329((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 35: _t->processIrcEvent330((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 36: _t->processIrcEvent331((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 37: _t->processIrcEvent332((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 38: _t->processIrcEvent333((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 39: _t->processIrcEvent341((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 40: _t->processIrcEvent352((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 41: _t->processIrcEvent354((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 42: _t->processIrcEvent369((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 43: _t->processIrcEvent432((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 44: _t->processIrcEvent433((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 45: _t->processIrcEvent437((*reinterpret_cast< IrcEvent*(*)>(_a[1]))); break;
        case 46: _t->processCtcpEvent((*reinterpret_cast< CtcpEvent*(*)>(_a[1]))); break;
        case 47: _t->handleCtcpAction((*reinterpret_cast< CtcpEvent*(*)>(_a[1]))); break;
        case 48: _t->handleCtcpPing((*reinterpret_cast< CtcpEvent*(*)>(_a[1]))); break;
        case 49: _t->defaultHandler((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< CtcpEvent*(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (EventStringifier::*)(Event * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&EventStringifier::newMessageEvent)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject EventStringifier::staticMetaObject = { {
    QMetaObject::SuperData::link<BasicHandler::staticMetaObject>(),
    qt_meta_stringdata_EventStringifier.data,
    qt_meta_data_EventStringifier,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *EventStringifier::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EventStringifier::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EventStringifier.stringdata0))
        return static_cast<void*>(this);
    return BasicHandler::qt_metacast(_clname);
}

int EventStringifier::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BasicHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 50)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 50;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 50)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 50;
    }
    return _id;
}

// SIGNAL 0
void EventStringifier::newMessageEvent(Event * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
