/********************************************************************************
** Form generated from reading UI file 'nicklistwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NICKLISTWIDGET_H
#define UI_NICKLISTWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_NickListWidget
{
public:
    QVBoxLayout *vboxLayout;
    QStackedWidget *stackedWidget;
    QWidget *emptyPage;

    void setupUi(QWidget *NickListWidget)
    {
        if (NickListWidget->objectName().isEmpty())
            NickListWidget->setObjectName(QString::fromUtf8("NickListWidget"));
        NickListWidget->resize(94, 223);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(NickListWidget->sizePolicy().hasHeightForWidth());
        NickListWidget->setSizePolicy(sizePolicy);
        vboxLayout = new QVBoxLayout(NickListWidget);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        stackedWidget = new QStackedWidget(NickListWidget);
        stackedWidget->setObjectName(QString::fromUtf8("stackedWidget"));
        sizePolicy.setHeightForWidth(stackedWidget->sizePolicy().hasHeightForWidth());
        stackedWidget->setSizePolicy(sizePolicy);
        emptyPage = new QWidget();
        emptyPage->setObjectName(QString::fromUtf8("emptyPage"));
        stackedWidget->addWidget(emptyPage);

        vboxLayout->addWidget(stackedWidget);


        retranslateUi(NickListWidget);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(NickListWidget);
    } // setupUi

    void retranslateUi(QWidget *NickListWidget)
    {
        NickListWidget->setWindowTitle(QString());
    } // retranslateUi

};

namespace Ui {
    class NickListWidget: public Ui_NickListWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NICKLISTWIDGET_H
