/****************************************************************************
** Meta object code from reading C++ file 'storage.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/storage.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'storage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Storage_t {
    QByteArrayData data[16];
    char stringdata0[162];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Storage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Storage_t qt_meta_stringdata_Storage = {
    {
QT_MOC_LITERAL(0, 0, 7), // "Storage"
QT_MOC_LITERAL(1, 8, 17), // "bufferInfoUpdated"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 6), // "UserId"
QT_MOC_LITERAL(4, 34, 4), // "user"
QT_MOC_LITERAL(5, 39, 10), // "BufferInfo"
QT_MOC_LITERAL(6, 50, 13), // "bufferRenamed"
QT_MOC_LITERAL(7, 64, 7), // "newName"
QT_MOC_LITERAL(8, 72, 7), // "oldName"
QT_MOC_LITERAL(9, 80, 9), // "userAdded"
QT_MOC_LITERAL(10, 90, 8), // "username"
QT_MOC_LITERAL(11, 99, 11), // "userRenamed"
QT_MOC_LITERAL(12, 111, 7), // "newname"
QT_MOC_LITERAL(13, 119, 11), // "userRemoved"
QT_MOC_LITERAL(14, 131, 19), // "dbUpgradeInProgress"
QT_MOC_LITERAL(15, 151, 10) // "inProgress"

    },
    "Storage\0bufferInfoUpdated\0\0UserId\0"
    "user\0BufferInfo\0bufferRenamed\0newName\0"
    "oldName\0userAdded\0username\0userRenamed\0"
    "newname\0userRemoved\0dbUpgradeInProgress\0"
    "inProgress"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Storage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   44,    2, 0x06 /* Public */,
       6,    2,   49,    2, 0x06 /* Public */,
       9,    2,   54,    2, 0x06 /* Public */,
      11,    2,   59,    2, 0x06 /* Public */,
      13,    1,   64,    2, 0x06 /* Public */,
      14,    1,   67,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    7,    8,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    2,   10,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    2,   12,
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void, QMetaType::Bool,   15,

       0        // eod
};

void Storage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Storage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->bufferInfoUpdated((*reinterpret_cast< UserId(*)>(_a[1])),(*reinterpret_cast< const BufferInfo(*)>(_a[2]))); break;
        case 1: _t->bufferRenamed((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->userAdded((*reinterpret_cast< UserId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->userRenamed((*reinterpret_cast< UserId(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->userRemoved((*reinterpret_cast< UserId(*)>(_a[1]))); break;
        case 5: _t->dbUpgradeInProgress((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferInfo >(); break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UserId >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UserId >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UserId >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UserId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Storage::*)(UserId , const BufferInfo & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Storage::bufferInfoUpdated)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Storage::*)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Storage::bufferRenamed)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Storage::*)(UserId , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Storage::userAdded)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Storage::*)(UserId , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Storage::userRenamed)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Storage::*)(UserId );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Storage::userRemoved)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Storage::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Storage::dbUpgradeInProgress)) {
                *result = 5;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Storage::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Storage.data,
    qt_meta_data_Storage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Storage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Storage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Storage.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Storage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Storage::bufferInfoUpdated(UserId _t1, const BufferInfo & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Storage::bufferRenamed(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Storage::userAdded(UserId _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Storage::userRenamed(UserId _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Storage::userRemoved(UserId _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Storage::dbUpgradeInProgress(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
