/********************************************************************************
** Form generated from reading UI file 'connectionsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONNECTIONSETTINGSPAGE_H
#define UI_CONNECTIONSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ConnectionSettingsPage
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *pingTimeoutEnabled;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpinBox *pingInterval;
    QSpacerItem *horizontalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QSpinBox *maxPingCount;
    QLabel *label_3;
    QSpacerItem *horizontalSpacer;
    QGroupBox *autoWhoEnabled;
    QHBoxLayout *horizontalLayout_3;
    QGridLayout *gridLayout;
    QLabel *label_4;
    QSpinBox *autoWhoInterval;
    QLabel *label_5;
    QSpinBox *autoWhoNickLimit;
    QLabel *label_6;
    QSpinBox *autoWhoDelay;
    QSpacerItem *horizontalSpacer_3;
    QCheckBox *standardCtcp;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ConnectionSettingsPage)
    {
        if (ConnectionSettingsPage->objectName().isEmpty())
            ConnectionSettingsPage->setObjectName(QString::fromUtf8("ConnectionSettingsPage"));
        ConnectionSettingsPage->resize(524, 402);
        verticalLayout_2 = new QVBoxLayout(ConnectionSettingsPage);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        pingTimeoutEnabled = new QGroupBox(ConnectionSettingsPage);
        pingTimeoutEnabled->setObjectName(QString::fromUtf8("pingTimeoutEnabled"));
        pingTimeoutEnabled->setCheckable(true);
        pingTimeoutEnabled->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        pingTimeoutEnabled->setProperty("defaultValue", QVariant(true));
        verticalLayout = new QVBoxLayout(pingTimeoutEnabled);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(pingTimeoutEnabled);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        pingInterval = new QSpinBox(pingTimeoutEnabled);
        pingInterval->setObjectName(QString::fromUtf8("pingInterval"));
        pingInterval->setMinimum(30);
        pingInterval->setMaximum(9999);
        pingInterval->setProperty("defaultValue", QVariant(30u));
        pingInterval->setProperty("settingsKey", QVariant(QString::fromUtf8("")));

        horizontalLayout->addWidget(pingInterval);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label_2 = new QLabel(pingTimeoutEnabled);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        horizontalLayout_2->addWidget(label_2);

        maxPingCount = new QSpinBox(pingTimeoutEnabled);
        maxPingCount->setObjectName(QString::fromUtf8("maxPingCount"));
        maxPingCount->setMinimum(2);
        maxPingCount->setValue(6);
        maxPingCount->setProperty("defaultValue", QVariant(6u));
        maxPingCount->setProperty("settingsKey", QVariant(QString::fromUtf8("")));

        horizontalLayout_2->addWidget(maxPingCount);

        label_3 = new QLabel(pingTimeoutEnabled);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        horizontalLayout_2->addWidget(label_3);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_2);


        verticalLayout_2->addWidget(pingTimeoutEnabled);

        autoWhoEnabled = new QGroupBox(ConnectionSettingsPage);
        autoWhoEnabled->setObjectName(QString::fromUtf8("autoWhoEnabled"));
        autoWhoEnabled->setCheckable(true);
        autoWhoEnabled->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        autoWhoEnabled->setProperty("defaultValue", QVariant(true));
        horizontalLayout_3 = new QHBoxLayout(autoWhoEnabled);
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label_4 = new QLabel(autoWhoEnabled);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout->addWidget(label_4, 0, 0, 1, 1);

        autoWhoInterval = new QSpinBox(autoWhoEnabled);
        autoWhoInterval->setObjectName(QString::fromUtf8("autoWhoInterval"));
        autoWhoInterval->setMinimum(10);
        autoWhoInterval->setMaximum(999);
        autoWhoInterval->setValue(90);
        autoWhoInterval->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        autoWhoInterval->setProperty("defaultValue", QVariant(90u));

        gridLayout->addWidget(autoWhoInterval, 0, 1, 1, 1);

        label_5 = new QLabel(autoWhoEnabled);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout->addWidget(label_5, 1, 0, 1, 1);

        autoWhoNickLimit = new QSpinBox(autoWhoEnabled);
        autoWhoNickLimit->setObjectName(QString::fromUtf8("autoWhoNickLimit"));
        autoWhoNickLimit->setMinimum(100);
        autoWhoNickLimit->setMaximum(9999);
        autoWhoNickLimit->setValue(200);
        autoWhoNickLimit->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        autoWhoNickLimit->setProperty("defaultValue", QVariant(200u));

        gridLayout->addWidget(autoWhoNickLimit, 1, 1, 1, 1);

        label_6 = new QLabel(autoWhoEnabled);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        gridLayout->addWidget(label_6, 2, 0, 1, 1);

        autoWhoDelay = new QSpinBox(autoWhoEnabled);
        autoWhoDelay->setObjectName(QString::fromUtf8("autoWhoDelay"));
        autoWhoDelay->setMinimum(3);
        autoWhoDelay->setValue(5);
        autoWhoDelay->setProperty("settingsKey", QVariant(QString::fromUtf8("")));
        autoWhoDelay->setProperty("defaultValue", QVariant(5u));

        gridLayout->addWidget(autoWhoDelay, 2, 1, 1, 1);


        horizontalLayout_3->addLayout(gridLayout);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        verticalLayout_2->addWidget(autoWhoEnabled);

        standardCtcp = new QCheckBox(ConnectionSettingsPage);
        standardCtcp->setObjectName(QString::fromUtf8("standardCtcp"));
        standardCtcp->setProperty("settingsKey", QVariant(QString::fromUtf8("")));

        verticalLayout_2->addWidget(standardCtcp);

        verticalSpacer = new QSpacerItem(20, 138, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        QWidget::setTabOrder(pingTimeoutEnabled, pingInterval);
        QWidget::setTabOrder(pingInterval, maxPingCount);
        QWidget::setTabOrder(maxPingCount, autoWhoEnabled);
        QWidget::setTabOrder(autoWhoEnabled, autoWhoInterval);
        QWidget::setTabOrder(autoWhoInterval, autoWhoNickLimit);
        QWidget::setTabOrder(autoWhoNickLimit, autoWhoDelay);

        retranslateUi(ConnectionSettingsPage);

        QMetaObject::connectSlotsByName(ConnectionSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *ConnectionSettingsPage)
    {
        ConnectionSettingsPage->setWindowTitle(QCoreApplication::translate("ConnectionSettingsPage", "Configure the IRC Connection", nullptr));
        pingTimeoutEnabled->setTitle(QCoreApplication::translate("ConnectionSettingsPage", "Enable Ping Timeout Detection", nullptr));
        label->setText(QCoreApplication::translate("ConnectionSettingsPage", "Ping interval:", nullptr));
        pingInterval->setSuffix(QCoreApplication::translate("ConnectionSettingsPage", " seconds", nullptr));
        label_2->setText(QCoreApplication::translate("ConnectionSettingsPage", "Disconnect after", nullptr));
        label_3->setText(QCoreApplication::translate("ConnectionSettingsPage", "missed pings", nullptr));
#if QT_CONFIG(tooltip)
        autoWhoEnabled->setToolTip(QCoreApplication::translate("ConnectionSettingsPage", "This enables periodic polling of user information using /WHO. This is mostly interesting for tracking users' away status.", nullptr));
#endif // QT_CONFIG(tooltip)
        autoWhoEnabled->setTitle(QCoreApplication::translate("ConnectionSettingsPage", "Enable Automatic User Information Lookup (/WHO)", nullptr));
        label_4->setText(QCoreApplication::translate("ConnectionSettingsPage", "Update interval:", nullptr));
        autoWhoInterval->setSuffix(QCoreApplication::translate("ConnectionSettingsPage", " seconds", nullptr));
        label_5->setText(QCoreApplication::translate("ConnectionSettingsPage", "Ignore channels with more than:", nullptr));
        autoWhoNickLimit->setSuffix(QCoreApplication::translate("ConnectionSettingsPage", " users", nullptr));
        label_6->setText(QCoreApplication::translate("ConnectionSettingsPage", "Minimum delay between requests:", nullptr));
        autoWhoDelay->setSuffix(QCoreApplication::translate("ConnectionSettingsPage", " seconds", nullptr));
        standardCtcp->setText(QCoreApplication::translate("ConnectionSettingsPage", "Enable standard-compliant CTCP behavior", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ConnectionSettingsPage: public Ui_ConnectionSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONNECTIONSETTINGSPAGE_H
