/********************************************************************************
** Form generated from reading UI file 'aboutdlg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABOUTDLG_H
#define UI_ABOUTDLG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AboutDlg
{
public:
    QVBoxLayout *vboxLayout;
    QFrame *frame;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QLabel *quasselLogo;
    QVBoxLayout *vboxLayout2;
    QLabel *label;
    QLabel *versionLabel;
    QSpacerItem *spacerItem;
    QTabWidget *tabWidget;
    QWidget *aboutTab;
    QVBoxLayout *vboxLayout3;
    QTextBrowser *aboutTextBrowser;
    QWidget *authorsTab;
    QVBoxLayout *vboxLayout4;
    QTextBrowser *authorTextBrowser;
    QWidget *tab_2;
    QVBoxLayout *vboxLayout5;
    QTextBrowser *contributorTextBrowser;
    QWidget *tab;
    QVBoxLayout *vboxLayout6;
    QTextBrowser *thanksToTextBrowser;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AboutDlg)
    {
        if (AboutDlg->objectName().isEmpty())
            AboutDlg->setObjectName(QString::fromUtf8("AboutDlg"));
        AboutDlg->setWindowModality(Qt::ApplicationModal);
        AboutDlg->resize(864, 628);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/quassel/16x16/apps/quassel.png"), QSize(), QIcon::Normal, QIcon::Off);
        AboutDlg->setWindowIcon(icon);
        vboxLayout = new QVBoxLayout(AboutDlg);
        vboxLayout->setObjectName(QString::fromUtf8("vboxLayout"));
        frame = new QFrame(AboutDlg);
        frame->setObjectName(QString::fromUtf8("frame"));
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Sunken);
        vboxLayout1 = new QVBoxLayout(frame);
        vboxLayout1->setObjectName(QString::fromUtf8("vboxLayout1"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QString::fromUtf8("hboxLayout"));
        quasselLogo = new QLabel(frame);
        quasselLogo->setObjectName(QString::fromUtf8("quasselLogo"));
        quasselLogo->setPixmap(QPixmap(QString::fromUtf8(":/quassel/64x64/apps/quassel.png")));
        quasselLogo->setScaledContents(false);

        hboxLayout->addWidget(quasselLogo);

        vboxLayout2 = new QVBoxLayout();
        vboxLayout2->setObjectName(QString::fromUtf8("vboxLayout2"));
        vboxLayout2->setContentsMargins(10, -1, -1, -1);
        label = new QLabel(frame);
        label->setObjectName(QString::fromUtf8("label"));
        QFont font;
        label->setFont(font);
        label->setTextFormat(Qt::AutoText);

        vboxLayout2->addWidget(label);

        versionLabel = new QLabel(frame);
        versionLabel->setObjectName(QString::fromUtf8("versionLabel"));
        versionLabel->setFont(font);
        versionLabel->setText(QString::fromUtf8(""));
        versionLabel->setOpenExternalLinks(true);
        versionLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);

        vboxLayout2->addWidget(versionLabel);


        hboxLayout->addLayout(vboxLayout2);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout1->addLayout(hboxLayout);


        vboxLayout->addWidget(frame);

        tabWidget = new QTabWidget(AboutDlg);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        aboutTab = new QWidget();
        aboutTab->setObjectName(QString::fromUtf8("aboutTab"));
        vboxLayout3 = new QVBoxLayout(aboutTab);
        vboxLayout3->setObjectName(QString::fromUtf8("vboxLayout3"));
        aboutTextBrowser = new QTextBrowser(aboutTab);
        aboutTextBrowser->setObjectName(QString::fromUtf8("aboutTextBrowser"));
        aboutTextBrowser->setStyleSheet(QString::fromUtf8("QTextBrowser { background:transparent;}"));
        aboutTextBrowser->setFrameShape(QFrame::NoFrame);
        aboutTextBrowser->setOpenExternalLinks(true);

        vboxLayout3->addWidget(aboutTextBrowser);

        tabWidget->addTab(aboutTab, QString());
        authorsTab = new QWidget();
        authorsTab->setObjectName(QString::fromUtf8("authorsTab"));
        vboxLayout4 = new QVBoxLayout(authorsTab);
        vboxLayout4->setObjectName(QString::fromUtf8("vboxLayout4"));
        authorTextBrowser = new QTextBrowser(authorsTab);
        authorTextBrowser->setObjectName(QString::fromUtf8("authorTextBrowser"));
        authorTextBrowser->setStyleSheet(QString::fromUtf8("QTextBrowser { background:transparent;}"));
        authorTextBrowser->setFrameShape(QFrame::NoFrame);
        authorTextBrowser->setOpenExternalLinks(true);

        vboxLayout4->addWidget(authorTextBrowser);

        tabWidget->addTab(authorsTab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName(QString::fromUtf8("tab_2"));
        vboxLayout5 = new QVBoxLayout(tab_2);
        vboxLayout5->setObjectName(QString::fromUtf8("vboxLayout5"));
        contributorTextBrowser = new QTextBrowser(tab_2);
        contributorTextBrowser->setObjectName(QString::fromUtf8("contributorTextBrowser"));
        contributorTextBrowser->setStyleSheet(QString::fromUtf8("QTextBrowser { background:transparent;}"));
        contributorTextBrowser->setFrameShape(QFrame::NoFrame);
        contributorTextBrowser->setOpenExternalLinks(true);

        vboxLayout5->addWidget(contributorTextBrowser);

        tabWidget->addTab(tab_2, QString());
        tab = new QWidget();
        tab->setObjectName(QString::fromUtf8("tab"));
        vboxLayout6 = new QVBoxLayout(tab);
        vboxLayout6->setObjectName(QString::fromUtf8("vboxLayout6"));
        thanksToTextBrowser = new QTextBrowser(tab);
        thanksToTextBrowser->setObjectName(QString::fromUtf8("thanksToTextBrowser"));
        thanksToTextBrowser->setStyleSheet(QString::fromUtf8("QTextBrowser { background:transparent;}"));
        thanksToTextBrowser->setFrameShape(QFrame::NoFrame);
        thanksToTextBrowser->setOpenExternalLinks(true);

        vboxLayout6->addWidget(thanksToTextBrowser);

        tabWidget->addTab(tab, QString());

        vboxLayout->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(AboutDlg);
        buttonBox->setObjectName(QString::fromUtf8("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        vboxLayout->addWidget(buttonBox);

        QWidget::setTabOrder(tabWidget, aboutTextBrowser);
        QWidget::setTabOrder(aboutTextBrowser, authorTextBrowser);
        QWidget::setTabOrder(authorTextBrowser, contributorTextBrowser);
        QWidget::setTabOrder(contributorTextBrowser, thanksToTextBrowser);
        QWidget::setTabOrder(thanksToTextBrowser, buttonBox);

        retranslateUi(AboutDlg);
        QObject::connect(buttonBox, SIGNAL(accepted()), AboutDlg, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), AboutDlg, SLOT(reject()));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AboutDlg);
    } // setupUi

    void retranslateUi(QDialog *AboutDlg)
    {
        AboutDlg->setWindowTitle(QCoreApplication::translate("AboutDlg", "About Quassel", nullptr));
        quasselLogo->setText(QString());
        label->setText(QCoreApplication::translate("AboutDlg", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'DejaVu Sans'; font-size:15pt; font-weight:600; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Quassel IRC</p></body></html>", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(aboutTab), QCoreApplication::translate("AboutDlg", "&About", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(authorsTab), QCoreApplication::translate("AboutDlg", "A&uthors", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QCoreApplication::translate("AboutDlg", "&Contributors", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), QCoreApplication::translate("AboutDlg", "&Thanks To", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AboutDlg: public Ui_AboutDlg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ABOUTDLG_H
