/********************************************************************************
** Form generated from reading UI file 'simplenetworkeditor.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SIMPLENETWORKEDITOR_H
#define UI_SIMPLENETWORKEDITOR_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SimpleNetworkEditor
{
public:
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *networkNameEdit;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout_2;
    QListWidget *serverList;
    QVBoxLayout *verticalLayout_2;
    QPushButton *editServer;
    QPushButton *addServer;
    QPushButton *deleteServer;
    QHBoxLayout *_3;
    QSpacerItem *spacerItem;
    QToolButton *upServer;
    QToolButton *downServer;
    QSpacerItem *spacerItem1;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    QTextEdit *channelList;

    void setupUi(QWidget *SimpleNetworkEditor)
    {
        if (SimpleNetworkEditor->objectName().isEmpty())
            SimpleNetworkEditor->setObjectName(QString::fromUtf8("SimpleNetworkEditor"));
        SimpleNetworkEditor->resize(334, 333);
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(SimpleNetworkEditor->sizePolicy().hasHeightForWidth());
        SimpleNetworkEditor->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(SimpleNetworkEditor);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label = new QLabel(SimpleNetworkEditor);
        label->setObjectName(QString::fromUtf8("label"));

        horizontalLayout->addWidget(label);

        networkNameEdit = new QLineEdit(SimpleNetworkEditor);
        networkNameEdit->setObjectName(QString::fromUtf8("networkNameEdit"));

        horizontalLayout->addWidget(networkNameEdit);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_3->addLayout(horizontalLayout);

        groupBox = new QGroupBox(SimpleNetworkEditor);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        horizontalLayout_2 = new QHBoxLayout(groupBox);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        serverList = new QListWidget(groupBox);
        serverList->setObjectName(QString::fromUtf8("serverList"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(serverList->sizePolicy().hasHeightForWidth());
        serverList->setSizePolicy(sizePolicy1);
        serverList->setMaximumSize(QSize(16777215, 16777215));

        horizontalLayout_2->addWidget(serverList);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        editServer = new QPushButton(groupBox);
        editServer->setObjectName(QString::fromUtf8("editServer"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(editServer->sizePolicy().hasHeightForWidth());
        editServer->setSizePolicy(sizePolicy2);
        QIcon icon;
        icon.addFile(QString::fromUtf8("../settingspages"), QSize(), QIcon::Normal, QIcon::Off);
        editServer->setIcon(icon);

        verticalLayout_2->addWidget(editServer);

        addServer = new QPushButton(groupBox);
        addServer->setObjectName(QString::fromUtf8("addServer"));
        sizePolicy2.setHeightForWidth(addServer->sizePolicy().hasHeightForWidth());
        addServer->setSizePolicy(sizePolicy2);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/list-add.png"), QSize(), QIcon::Normal, QIcon::Off);
        addServer->setIcon(icon1);

        verticalLayout_2->addWidget(addServer);

        deleteServer = new QPushButton(groupBox);
        deleteServer->setObjectName(QString::fromUtf8("deleteServer"));
        sizePolicy2.setHeightForWidth(deleteServer->sizePolicy().hasHeightForWidth());
        deleteServer->setSizePolicy(sizePolicy2);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/edit-delete.png"), QSize(), QIcon::Normal, QIcon::Off);
        deleteServer->setIcon(icon2);

        verticalLayout_2->addWidget(deleteServer);

        _3 = new QHBoxLayout();
        _3->setObjectName(QString::fromUtf8("_3"));
        spacerItem = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _3->addItem(spacerItem);

        upServer = new QToolButton(groupBox);
        upServer->setObjectName(QString::fromUtf8("upServer"));
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/go-up.png"), QSize(), QIcon::Normal, QIcon::Off);
        upServer->setIcon(icon3);

        _3->addWidget(upServer);

        downServer = new QToolButton(groupBox);
        downServer->setObjectName(QString::fromUtf8("downServer"));
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/16x16/actions/oxygen/16x16/actions/go-down.png"), QSize(), QIcon::Normal, QIcon::Off);
        downServer->setIcon(icon4);

        _3->addWidget(downServer);

        spacerItem1 = new QSpacerItem(0, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        _3->addItem(spacerItem1);


        verticalLayout_2->addLayout(_3);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);


        horizontalLayout_2->addLayout(verticalLayout_2);


        verticalLayout_3->addWidget(groupBox);

        groupBox_2 = new QGroupBox(SimpleNetworkEditor);
        groupBox_2->setObjectName(QString::fromUtf8("groupBox_2"));
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        channelList = new QTextEdit(groupBox_2);
        channelList->setObjectName(QString::fromUtf8("channelList"));
        sizePolicy.setHeightForWidth(channelList->sizePolicy().hasHeightForWidth());
        channelList->setSizePolicy(sizePolicy);
        channelList->setMinimumSize(QSize(0, 80));
        channelList->setMaximumSize(QSize(16777215, 16777215));

        verticalLayout->addWidget(channelList);


        verticalLayout_3->addWidget(groupBox_2);

        QWidget::setTabOrder(networkNameEdit, serverList);
        QWidget::setTabOrder(serverList, editServer);
        QWidget::setTabOrder(editServer, addServer);
        QWidget::setTabOrder(addServer, deleteServer);
        QWidget::setTabOrder(deleteServer, upServer);
        QWidget::setTabOrder(upServer, downServer);
        QWidget::setTabOrder(downServer, channelList);

        retranslateUi(SimpleNetworkEditor);

        QMetaObject::connectSlotsByName(SimpleNetworkEditor);
    } // setupUi

    void retranslateUi(QWidget *SimpleNetworkEditor)
    {
        SimpleNetworkEditor->setWindowTitle(QString());
        label->setText(QCoreApplication::translate("SimpleNetworkEditor", "Network name:", nullptr));
#if QT_CONFIG(tooltip)
        networkNameEdit->setToolTip(QCoreApplication::translate("SimpleNetworkEditor", "The name of the IRC network you are configuring", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox->setTitle(QCoreApplication::translate("SimpleNetworkEditor", "Servers", nullptr));
#if QT_CONFIG(tooltip)
        serverList->setToolTip(QCoreApplication::translate("SimpleNetworkEditor", "A list of IRC servers belonging to this network", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        editServer->setToolTip(QCoreApplication::translate("SimpleNetworkEditor", "Edit this server entry", nullptr));
#endif // QT_CONFIG(tooltip)
        editServer->setText(QCoreApplication::translate("SimpleNetworkEditor", "&Edit...", nullptr));
#if QT_CONFIG(tooltip)
        addServer->setToolTip(QCoreApplication::translate("SimpleNetworkEditor", "Add another IRC server", nullptr));
#endif // QT_CONFIG(tooltip)
        addServer->setText(QCoreApplication::translate("SimpleNetworkEditor", "&Add...", nullptr));
#if QT_CONFIG(tooltip)
        deleteServer->setToolTip(QCoreApplication::translate("SimpleNetworkEditor", "Remove this server entry from the list", nullptr));
#endif // QT_CONFIG(tooltip)
        deleteServer->setText(QCoreApplication::translate("SimpleNetworkEditor", "De&lete", nullptr));
#if QT_CONFIG(tooltip)
        upServer->setToolTip(QCoreApplication::translate("SimpleNetworkEditor", "Move upwards in list", nullptr));
#endif // QT_CONFIG(tooltip)
        upServer->setText(QCoreApplication::translate("SimpleNetworkEditor", "...", nullptr));
#if QT_CONFIG(tooltip)
        downServer->setToolTip(QCoreApplication::translate("SimpleNetworkEditor", "Move downwards in list", nullptr));
#endif // QT_CONFIG(tooltip)
        downServer->setText(QCoreApplication::translate("SimpleNetworkEditor", "...", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("SimpleNetworkEditor", "Join Channels Automatically", nullptr));
#if QT_CONFIG(tooltip)
        channelList->setToolTip(QCoreApplication::translate("SimpleNetworkEditor", "A list of IRC channels you will join automatically after connecting to the network", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class SimpleNetworkEditor: public Ui_SimpleNetworkEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SIMPLENETWORKEDITOR_H
