/********************************************************************************
** Form generated from reading UI file 'itemviewsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 5.15.17
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ITEMVIEWSETTINGSPAGE_H
#define UI_ITEMVIEWSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "colorbutton.h"
#include "fontselector.h"

QT_BEGIN_NAMESPACE

class Ui_ItemViewSettingsPage
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *useCustomItemViewFont;
    FontSelector *widget;
    QCheckBox *showItemViewIcons;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *displayTopicInTooltip;
    QCheckBox *mouseWheelChangesBuffers;
    QGroupBox *useBufferViewColors;
    QHBoxLayout *horizontalLayout;
    QGridLayout *gridLayout;
    QLabel *label;
    ColorButton *defaultBufferColor;
    QLabel *label_2;
    ColorButton *inactiveBufferColor;
    QLabel *label_3;
    ColorButton *unreadBufferColor;
    QLabel *label_4;
    ColorButton *highlightedBufferColor;
    QLabel *label_5;
    ColorButton *activeBufferColor;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *horizontalSpacer_2;
    QTreeWidget *bufferViewPreview;
    QSpacerItem *horizontalSpacer_4;
    QGroupBox *useNickViewColors;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_6;
    ColorButton *onlineNickColor;
    QSpacerItem *horizontalSpacer;
    QLabel *label_7;
    ColorButton *awayNickColor;
    QSpacerItem *horizontalSpacer_3;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ItemViewSettingsPage)
    {
        if (ItemViewSettingsPage->objectName().isEmpty())
            ItemViewSettingsPage->setObjectName(QString::fromUtf8("ItemViewSettingsPage"));
        ItemViewSettingsPage->resize(374, 508);
        verticalLayout_2 = new QVBoxLayout(ItemViewSettingsPage);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        useCustomItemViewFont = new QCheckBox(ItemViewSettingsPage);
        useCustomItemViewFont->setObjectName(QString::fromUtf8("useCustomItemViewFont"));
        useCustomItemViewFont->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Fonts/UseCustomItemViewFont")));
        useCustomItemViewFont->setProperty("defaultValue", QVariant(false));

        horizontalLayout_2->addWidget(useCustomItemViewFont);

        widget = new FontSelector(ItemViewSettingsPage);
        widget->setObjectName(QString::fromUtf8("widget"));
        widget->setEnabled(false);
        widget->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Fonts/ItemView")));
        QFont font;
        widget->setProperty("defaultValue", QVariant(font));

        horizontalLayout_2->addWidget(widget);


        verticalLayout_2->addLayout(horizontalLayout_2);

        showItemViewIcons = new QCheckBox(ItemViewSettingsPage);
        showItemViewIcons->setObjectName(QString::fromUtf8("showItemViewIcons"));
        showItemViewIcons->setChecked(true);
        showItemViewIcons->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/ShowItemViewIcons")));
        showItemViewIcons->setProperty("defaultValue", QVariant(true));

        verticalLayout_2->addWidget(showItemViewIcons);

        groupBox = new QGroupBox(ItemViewSettingsPage);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        displayTopicInTooltip = new QCheckBox(groupBox);
        displayTopicInTooltip->setObjectName(QString::fromUtf8("displayTopicInTooltip"));
        displayTopicInTooltip->setProperty("settingsKey", QVariant(QString::fromUtf8("DisplayTopicInTooltip")));
        displayTopicInTooltip->setProperty("defaultValue", QVariant(false));

        verticalLayout->addWidget(displayTopicInTooltip);

        mouseWheelChangesBuffers = new QCheckBox(groupBox);
        mouseWheelChangesBuffers->setObjectName(QString::fromUtf8("mouseWheelChangesBuffers"));
        mouseWheelChangesBuffers->setChecked(false);
        mouseWheelChangesBuffers->setProperty("settingsKey", QVariant(QString::fromUtf8("MouseWheelChangesBuffer")));
        mouseWheelChangesBuffers->setProperty("defaultValue", QVariant(false));

        verticalLayout->addWidget(mouseWheelChangesBuffers);

        useBufferViewColors = new QGroupBox(groupBox);
        useBufferViewColors->setObjectName(QString::fromUtf8("useBufferViewColors"));
        useBufferViewColors->setCheckable(true);
        useBufferViewColors->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Colors/UseBufferViewColors")));
        useBufferViewColors->setProperty("defaultValue", QVariant(false));
        horizontalLayout = new QHBoxLayout(useBufferViewColors);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        gridLayout = new QGridLayout();
        gridLayout->setSpacing(12);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        label = new QLabel(useBufferViewColors);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout->addWidget(label, 0, 0, 1, 1);

        defaultBufferColor = new ColorButton(useBufferViewColors);
        defaultBufferColor->setObjectName(QString::fromUtf8("defaultBufferColor"));
        defaultBufferColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Colors/DefaultBuffer")));
        defaultBufferColor->setProperty("defaultValue", QVariant(QColor(0, 0, 0)));

        gridLayout->addWidget(defaultBufferColor, 0, 1, 1, 1);

        label_2 = new QLabel(useBufferViewColors);
        label_2->setObjectName(QString::fromUtf8("label_2"));

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        inactiveBufferColor = new ColorButton(useBufferViewColors);
        inactiveBufferColor->setObjectName(QString::fromUtf8("inactiveBufferColor"));
        inactiveBufferColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Colors/InactiveBuffer")));
        inactiveBufferColor->setProperty("defaultValue", QVariant(QColor(160, 160, 164)));

        gridLayout->addWidget(inactiveBufferColor, 1, 1, 1, 1);

        label_3 = new QLabel(useBufferViewColors);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        unreadBufferColor = new ColorButton(useBufferViewColors);
        unreadBufferColor->setObjectName(QString::fromUtf8("unreadBufferColor"));
        unreadBufferColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Colors/UnreadBuffer")));
        unreadBufferColor->setProperty("defaultValue", QVariant(QColor(0, 0, 245)));

        gridLayout->addWidget(unreadBufferColor, 2, 1, 1, 1);

        label_4 = new QLabel(useBufferViewColors);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout->addWidget(label_4, 3, 0, 1, 1);

        highlightedBufferColor = new ColorButton(useBufferViewColors);
        highlightedBufferColor->setObjectName(QString::fromUtf8("highlightedBufferColor"));
        highlightedBufferColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Colors/HighlightedBuffer")));
        highlightedBufferColor->setProperty("defaultValue", QVariant(QColor(255, 128, 0)));

        gridLayout->addWidget(highlightedBufferColor, 3, 1, 1, 1);

        label_5 = new QLabel(useBufferViewColors);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        gridLayout->addWidget(label_5, 4, 0, 1, 1);

        activeBufferColor = new ColorButton(useBufferViewColors);
        activeBufferColor->setObjectName(QString::fromUtf8("activeBufferColor"));
        activeBufferColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Colors/ActiveBuffer")));
        activeBufferColor->setProperty("defaultValue", QVariant(QColor(0, 128, 0)));

        gridLayout->addWidget(activeBufferColor, 4, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(1, 1, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 5, 0, 1, 1);


        horizontalLayout->addLayout(gridLayout);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Preferred, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        bufferViewPreview = new QTreeWidget(useBufferViewColors);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        bufferViewPreview->setHeaderItem(__qtreewidgetitem);
        bufferViewPreview->setObjectName(QString::fromUtf8("bufferViewPreview"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(bufferViewPreview->sizePolicy().hasHeightForWidth());
        bufferViewPreview->setSizePolicy(sizePolicy);
        bufferViewPreview->setEditTriggers(QAbstractItemView::NoEditTriggers);
        bufferViewPreview->setProperty("showDropIndicator", QVariant(false));
        bufferViewPreview->setItemsExpandable(false);
        bufferViewPreview->header()->setVisible(false);

        horizontalLayout->addWidget(bufferViewPreview);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_4);


        verticalLayout->addWidget(useBufferViewColors);


        verticalLayout_2->addWidget(groupBox);

        useNickViewColors = new QGroupBox(ItemViewSettingsPage);
        useNickViewColors->setObjectName(QString::fromUtf8("useNickViewColors"));
        useNickViewColors->setCheckable(true);
        useNickViewColors->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Colors/UseNickViewColors")));
        useNickViewColors->setProperty("defaultValue", QVariant(false));
        horizontalLayout_3 = new QHBoxLayout(useNickViewColors);
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        label_6 = new QLabel(useNickViewColors);
        label_6->setObjectName(QString::fromUtf8("label_6"));

        horizontalLayout_3->addWidget(label_6);

        onlineNickColor = new ColorButton(useNickViewColors);
        onlineNickColor->setObjectName(QString::fromUtf8("onlineNickColor"));
        onlineNickColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Colors/OnlineNick")));
        onlineNickColor->setProperty("defaultValue", QVariant(QColor(0, 0, 0)));

        horizontalLayout_3->addWidget(onlineNickColor);

        horizontalSpacer = new QSpacerItem(88, 20, QSizePolicy::Preferred, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        label_7 = new QLabel(useNickViewColors);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        horizontalLayout_3->addWidget(label_7);

        awayNickColor = new ColorButton(useNickViewColors);
        awayNickColor->setObjectName(QString::fromUtf8("awayNickColor"));
        awayNickColor->setProperty("settingsKey", QVariant(QString::fromUtf8("/UiStyle/Colors/AwayNick")));
        awayNickColor->setProperty("defaultValue", QVariant(QColor(160, 160, 164)));

        horizontalLayout_3->addWidget(awayNickColor);

        horizontalSpacer_3 = new QSpacerItem(87, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        verticalLayout_2->addWidget(useNickViewColors);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        QWidget::setTabOrder(useCustomItemViewFont, showItemViewIcons);
        QWidget::setTabOrder(showItemViewIcons, displayTopicInTooltip);
        QWidget::setTabOrder(displayTopicInTooltip, mouseWheelChangesBuffers);
        QWidget::setTabOrder(mouseWheelChangesBuffers, useBufferViewColors);
        QWidget::setTabOrder(useBufferViewColors, defaultBufferColor);
        QWidget::setTabOrder(defaultBufferColor, inactiveBufferColor);
        QWidget::setTabOrder(inactiveBufferColor, unreadBufferColor);
        QWidget::setTabOrder(unreadBufferColor, highlightedBufferColor);
        QWidget::setTabOrder(highlightedBufferColor, activeBufferColor);
        QWidget::setTabOrder(activeBufferColor, bufferViewPreview);
        QWidget::setTabOrder(bufferViewPreview, useNickViewColors);
        QWidget::setTabOrder(useNickViewColors, onlineNickColor);
        QWidget::setTabOrder(onlineNickColor, awayNickColor);

        retranslateUi(ItemViewSettingsPage);
        QObject::connect(useCustomItemViewFont, SIGNAL(toggled(bool)), widget, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(ItemViewSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *ItemViewSettingsPage)
    {
        ItemViewSettingsPage->setWindowTitle(QCoreApplication::translate("ItemViewSettingsPage", "Form", nullptr));
        useCustomItemViewFont->setText(QCoreApplication::translate("ItemViewSettingsPage", "Custom font:", nullptr));
        showItemViewIcons->setText(QCoreApplication::translate("ItemViewSettingsPage", "Show icons", nullptr));
        groupBox->setTitle(QCoreApplication::translate("ItemViewSettingsPage", "Chat List", nullptr));
        displayTopicInTooltip->setText(QCoreApplication::translate("ItemViewSettingsPage", "Display topic in tooltip", nullptr));
        mouseWheelChangesBuffers->setText(QCoreApplication::translate("ItemViewSettingsPage", "Mouse wheel changes selected chat", nullptr));
        useBufferViewColors->setTitle(QCoreApplication::translate("ItemViewSettingsPage", "Use Custom Colors", nullptr));
        label->setText(QCoreApplication::translate("ItemViewSettingsPage", "Standard:", nullptr));
        defaultBufferColor->setText(QCoreApplication::translate("ItemViewSettingsPage", "...", nullptr));
        label_2->setText(QCoreApplication::translate("ItemViewSettingsPage", "Inactive:", nullptr));
        inactiveBufferColor->setText(QCoreApplication::translate("ItemViewSettingsPage", "...", nullptr));
        label_3->setText(QCoreApplication::translate("ItemViewSettingsPage", "Unread messages:", nullptr));
        unreadBufferColor->setText(QCoreApplication::translate("ItemViewSettingsPage", "...", nullptr));
        label_4->setText(QCoreApplication::translate("ItemViewSettingsPage", "Highlight:", nullptr));
        highlightedBufferColor->setText(QCoreApplication::translate("ItemViewSettingsPage", "...", nullptr));
        label_5->setText(QCoreApplication::translate("ItemViewSettingsPage", "Other activity:", nullptr));
        activeBufferColor->setText(QCoreApplication::translate("ItemViewSettingsPage", "...", nullptr));
        useNickViewColors->setTitle(QCoreApplication::translate("ItemViewSettingsPage", "Custom Nick List Colors", nullptr));
        label_6->setText(QCoreApplication::translate("ItemViewSettingsPage", "Online:", nullptr));
        onlineNickColor->setText(QCoreApplication::translate("ItemViewSettingsPage", "...", nullptr));
        label_7->setText(QCoreApplication::translate("ItemViewSettingsPage", "Away:", nullptr));
        awayNickColor->setText(QCoreApplication::translate("ItemViewSettingsPage", "...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ItemViewSettingsPage: public Ui_ItemViewSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ITEMVIEWSETTINGSPAGE_H
