/****************************************************************************
** Meta object code from reading C++ file 'qtui.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/qtui/qtui.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtui.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtUi_t {
    QByteArrayData data[21];
    char stringdata0[304];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtUi_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtUi_t qt_meta_stringdata_QtUi = {
    {
QT_MOC_LITERAL(0, 0, 4), // "QtUi"
QT_MOC_LITERAL(1, 5, 18), // "iconThemeRefreshed"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 4), // "init"
QT_MOC_LITERAL(4, 30, 18), // "invokeNotification"
QT_MOC_LITERAL(5, 49, 8), // "BufferId"
QT_MOC_LITERAL(6, 58, 5), // "bufId"
QT_MOC_LITERAL(7, 64, 45), // "AbstractNotificationBackend::..."
QT_MOC_LITERAL(8, 110, 4), // "type"
QT_MOC_LITERAL(9, 115, 6), // "sender"
QT_MOC_LITERAL(10, 122, 4), // "text"
QT_MOC_LITERAL(11, 127, 17), // "closeNotification"
QT_MOC_LITERAL(12, 145, 14), // "notificationId"
QT_MOC_LITERAL(13, 160, 18), // "closeNotifications"
QT_MOC_LITERAL(14, 179, 8), // "bufferId"
QT_MOC_LITERAL(15, 188, 16), // "refreshIconTheme"
QT_MOC_LITERAL(16, 205, 15), // "connectedToCore"
QT_MOC_LITERAL(17, 221, 20), // "disconnectedFromCore"
QT_MOC_LITERAL(18, 242, 21), // "notificationActivated"
QT_MOC_LITERAL(19, 264, 18), // "bufferMarkedAsRead"
QT_MOC_LITERAL(20, 283, 20) // "useSystemTrayChanged"

    },
    "QtUi\0iconThemeRefreshed\0\0init\0"
    "invokeNotification\0BufferId\0bufId\0"
    "AbstractNotificationBackend::NotificationType\0"
    "type\0sender\0text\0closeNotification\0"
    "notificationId\0closeNotifications\0"
    "bufferId\0refreshIconTheme\0connectedToCore\0"
    "disconnectedFromCore\0notificationActivated\0"
    "bufferMarkedAsRead\0useSystemTrayChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtUi[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   75,    2, 0x0a /* Public */,
       4,    4,   76,    2, 0x0a /* Public */,
      11,    1,   85,    2, 0x0a /* Public */,
      13,    1,   88,    2, 0x0a /* Public */,
      13,    0,   91,    2, 0x2a /* Public | MethodCloned */,
      15,    0,   92,    2, 0x0a /* Public */,
      16,    0,   93,    2, 0x09 /* Protected */,
      17,    0,   94,    2, 0x09 /* Protected */,
      18,    1,   95,    2, 0x09 /* Protected */,
      19,    1,   98,    2, 0x09 /* Protected */,
      20,    1,  101,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::UInt, 0x80000000 | 5, 0x80000000 | 7, QMetaType::QString, QMetaType::QString,    6,    8,    9,   10,
    QMetaType::Void, QMetaType::UInt,   12,
    QMetaType::Void, 0x80000000 | 5,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::UInt,   12,
    QMetaType::Void, 0x80000000 | 5,    2,
    QMetaType::Void, QMetaType::QVariant,    2,

       0        // eod
};

void QtUi::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QtUi *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->iconThemeRefreshed(); break;
        case 1: _t->init(); break;
        case 2: { uint _r = _t->invokeNotification((*reinterpret_cast< BufferId(*)>(_a[1])),(*reinterpret_cast< AbstractNotificationBackend::NotificationType(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< uint*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->closeNotification((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 4: _t->closeNotifications((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 5: _t->closeNotifications(); break;
        case 6: _t->refreshIconTheme(); break;
        case 7: _t->connectedToCore(); break;
        case 8: _t->disconnectedFromCore(); break;
        case 9: _t->notificationActivated((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 10: _t->bufferMarkedAsRead((*reinterpret_cast< BufferId(*)>(_a[1]))); break;
        case 11: _t->useSystemTrayChanged((*reinterpret_cast< const QVariant(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BufferId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QtUi::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QtUi::iconThemeRefreshed)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QtUi::staticMetaObject = { {
    QMetaObject::SuperData::link<GraphicalUi::staticMetaObject>(),
    qt_meta_stringdata_QtUi.data,
    qt_meta_data_QtUi,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtUi::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtUi::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtUi.stringdata0))
        return static_cast<void*>(this);
    return GraphicalUi::qt_metacast(_clname);
}

int QtUi::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GraphicalUi::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void QtUi::iconThemeRefreshed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
