/****************************************************************************
** Meta object code from reading C++ file 'quassel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/quassel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'quassel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Quassel_t {
    QByteArrayData data[34];
    char stringdata0[492];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Quassel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Quassel_t qt_meta_stringdata_Quassel = {
    {
QT_MOC_LITERAL(0, 0, 7), // "Quassel"
QT_MOC_LITERAL(1, 8, 13), // "messageLogged"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 9), // "timeStamp"
QT_MOC_LITERAL(4, 33, 3), // "msg"
QT_MOC_LITERAL(5, 37, 4), // "quit"
QT_MOC_LITERAL(6, 42, 12), // "handleSignal"
QT_MOC_LITERAL(7, 55, 29), // "AbstractSignalWatcher::Action"
QT_MOC_LITERAL(8, 85, 6), // "action"
QT_MOC_LITERAL(9, 92, 13), // "LegacyFeature"
QT_MOC_LITERAL(10, 106, 22), // "SynchronizedMarkerLine"
QT_MOC_LITERAL(11, 129, 18), // "SaslAuthentication"
QT_MOC_LITERAL(12, 148, 12), // "SaslExternal"
QT_MOC_LITERAL(13, 161, 20), // "HideInactiveNetworks"
QT_MOC_LITERAL(14, 182, 14), // "PasswordChange"
QT_MOC_LITERAL(15, 197, 14), // "CapNegotiation"
QT_MOC_LITERAL(16, 212, 15), // "VerifyServerSSL"
QT_MOC_LITERAL(17, 228, 16), // "CustomRateLimits"
QT_MOC_LITERAL(18, 245, 19), // "AwayFormatTimestamp"
QT_MOC_LITERAL(19, 265, 14), // "Authenticators"
QT_MOC_LITERAL(20, 280, 18), // "BufferActivitySync"
QT_MOC_LITERAL(21, 299, 18), // "CoreSideHighlights"
QT_MOC_LITERAL(22, 318, 14), // "SenderPrefixes"
QT_MOC_LITERAL(23, 333, 16), // "RemoteDisconnect"
QT_MOC_LITERAL(24, 350, 16), // "ExtendedFeatures"
QT_MOC_LITERAL(25, 367, 7), // "Feature"
QT_MOC_LITERAL(26, 375, 8), // "LongTime"
QT_MOC_LITERAL(27, 384, 12), // "RichMessages"
QT_MOC_LITERAL(28, 397, 17), // "BacklogFilterType"
QT_MOC_LITERAL(29, 415, 15), // "EcdsaCertfpKeys"
QT_MOC_LITERAL(30, 431, 13), // "LongMessageId"
QT_MOC_LITERAL(31, 445, 14), // "SyncedCoreInfo"
QT_MOC_LITERAL(32, 460, 19), // "LoadBacklogForwards"
QT_MOC_LITERAL(33, 480, 11) // "SkipIrcCaps"

    },
    "Quassel\0messageLogged\0\0timeStamp\0msg\0"
    "quit\0handleSignal\0AbstractSignalWatcher::Action\0"
    "action\0LegacyFeature\0SynchronizedMarkerLine\0"
    "SaslAuthentication\0SaslExternal\0"
    "HideInactiveNetworks\0PasswordChange\0"
    "CapNegotiation\0VerifyServerSSL\0"
    "CustomRateLimits\0AwayFormatTimestamp\0"
    "Authenticators\0BufferActivitySync\0"
    "CoreSideHighlights\0SenderPrefixes\0"
    "RemoteDisconnect\0ExtendedFeatures\0"
    "Feature\0LongTime\0RichMessages\0"
    "BacklogFilterType\0EcdsaCertfpKeys\0"
    "LongMessageId\0SyncedCoreInfo\0"
    "LoadBacklogForwards\0SkipIrcCaps"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Quassel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       2,   38, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   34,    2, 0x0a /* Public */,
       6,    1,   35,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QDateTime, QMetaType::QString,    3,    4,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7,    8,

 // enums: name, alias, flags, count, data
       9,    9, 0x3,   15,   48,
      25,   25, 0x2,   23,   78,

 // enum data: key, value
      10, uint(Quassel::LegacyFeature::SynchronizedMarkerLine),
      11, uint(Quassel::LegacyFeature::SaslAuthentication),
      12, uint(Quassel::LegacyFeature::SaslExternal),
      13, uint(Quassel::LegacyFeature::HideInactiveNetworks),
      14, uint(Quassel::LegacyFeature::PasswordChange),
      15, uint(Quassel::LegacyFeature::CapNegotiation),
      16, uint(Quassel::LegacyFeature::VerifyServerSSL),
      17, uint(Quassel::LegacyFeature::CustomRateLimits),
      18, uint(Quassel::LegacyFeature::AwayFormatTimestamp),
      19, uint(Quassel::LegacyFeature::Authenticators),
      20, uint(Quassel::LegacyFeature::BufferActivitySync),
      21, uint(Quassel::LegacyFeature::CoreSideHighlights),
      22, uint(Quassel::LegacyFeature::SenderPrefixes),
      23, uint(Quassel::LegacyFeature::RemoteDisconnect),
      24, uint(Quassel::LegacyFeature::ExtendedFeatures),
      10, uint(Quassel::Feature::SynchronizedMarkerLine),
      11, uint(Quassel::Feature::SaslAuthentication),
      12, uint(Quassel::Feature::SaslExternal),
      13, uint(Quassel::Feature::HideInactiveNetworks),
      14, uint(Quassel::Feature::PasswordChange),
      15, uint(Quassel::Feature::CapNegotiation),
      16, uint(Quassel::Feature::VerifyServerSSL),
      17, uint(Quassel::Feature::CustomRateLimits),
      18, uint(Quassel::Feature::AwayFormatTimestamp),
      19, uint(Quassel::Feature::Authenticators),
      20, uint(Quassel::Feature::BufferActivitySync),
      21, uint(Quassel::Feature::CoreSideHighlights),
      22, uint(Quassel::Feature::SenderPrefixes),
      23, uint(Quassel::Feature::RemoteDisconnect),
      24, uint(Quassel::Feature::ExtendedFeatures),
      26, uint(Quassel::Feature::LongTime),
      27, uint(Quassel::Feature::RichMessages),
      28, uint(Quassel::Feature::BacklogFilterType),
      29, uint(Quassel::Feature::EcdsaCertfpKeys),
      30, uint(Quassel::Feature::LongMessageId),
      31, uint(Quassel::Feature::SyncedCoreInfo),
      32, uint(Quassel::Feature::LoadBacklogForwards),
      33, uint(Quassel::Feature::SkipIrcCaps),

       0        // eod
};

void Quassel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Quassel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->messageLogged((*reinterpret_cast< const QDateTime(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->quit(); break;
        case 2: _t->handleSignal((*reinterpret_cast< AbstractSignalWatcher::Action(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< AbstractSignalWatcher::Action >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Quassel::*)(const QDateTime & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Quassel::messageLogged)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Quassel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Quassel.data,
    qt_meta_data_Quassel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Quassel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Quassel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Quassel.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Singleton<Quassel>"))
        return static_cast< Singleton<Quassel>*>(this);
    return QObject::qt_metacast(_clname);
}

int Quassel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Quassel::messageLogged(const QDateTime & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
