/****************************************************************************
** Meta object code from reading C++ file 'highlightrulemanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/common/highlightrulemanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'highlightrulemanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_HighlightRuleManager_t {
    QByteArrayData data[29];
    char stringdata0[464];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_HighlightRuleManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_HighlightRuleManager_t qt_meta_stringdata_HighlightRuleManager = {
    {
QT_MOC_LITERAL(0, 0, 20), // "HighlightRuleManager"
QT_MOC_LITERAL(1, 21, 9), // "ruleAdded"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 4), // "name"
QT_MOC_LITERAL(4, 37, 7), // "isRegEx"
QT_MOC_LITERAL(5, 45, 15), // "isCaseSensitive"
QT_MOC_LITERAL(6, 61, 9), // "isEnabled"
QT_MOC_LITERAL(7, 71, 9), // "isInverse"
QT_MOC_LITERAL(8, 81, 6), // "sender"
QT_MOC_LITERAL(9, 88, 8), // "chanName"
QT_MOC_LITERAL(10, 97, 21), // "initHighlightRuleList"
QT_MOC_LITERAL(11, 119, 24), // "initSetHighlightRuleList"
QT_MOC_LITERAL(12, 144, 17), // "HighlightRuleList"
QT_MOC_LITERAL(13, 162, 26), // "requestRemoveHighlightRule"
QT_MOC_LITERAL(14, 189, 13), // "highlightRule"
QT_MOC_LITERAL(15, 203, 19), // "removeHighlightRule"
QT_MOC_LITERAL(16, 223, 26), // "requestToggleHighlightRule"
QT_MOC_LITERAL(17, 250, 19), // "toggleHighlightRule"
QT_MOC_LITERAL(18, 270, 23), // "requestAddHighlightRule"
QT_MOC_LITERAL(19, 294, 2), // "id"
QT_MOC_LITERAL(20, 297, 16), // "addHighlightRule"
QT_MOC_LITERAL(21, 314, 23), // "requestSetHighlightNick"
QT_MOC_LITERAL(22, 338, 13), // "highlightNick"
QT_MOC_LITERAL(23, 352, 16), // "setHighlightNick"
QT_MOC_LITERAL(24, 369, 28), // "requestSetNicksCaseSensitive"
QT_MOC_LITERAL(25, 398, 18), // "nicksCaseSensitive"
QT_MOC_LITERAL(26, 417, 21), // "setNicksCaseSensitive"
QT_MOC_LITERAL(27, 439, 14), // "networkRemoved"
QT_MOC_LITERAL(28, 454, 9) // "NetworkId"

    },
    "HighlightRuleManager\0ruleAdded\0\0name\0"
    "isRegEx\0isCaseSensitive\0isEnabled\0"
    "isInverse\0sender\0chanName\0"
    "initHighlightRuleList\0initSetHighlightRuleList\0"
    "HighlightRuleList\0requestRemoveHighlightRule\0"
    "highlightRule\0removeHighlightRule\0"
    "requestToggleHighlightRule\0"
    "toggleHighlightRule\0requestAddHighlightRule\0"
    "id\0addHighlightRule\0requestSetHighlightNick\0"
    "highlightNick\0setHighlightNick\0"
    "requestSetNicksCaseSensitive\0"
    "nicksCaseSensitive\0setNicksCaseSensitive\0"
    "networkRemoved\0NetworkId"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_HighlightRuleManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       2,  164, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    7,   84,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,   99,    2, 0x0a /* Public */,
      11,    1,  100,    2, 0x0a /* Public */,
      13,    1,  103,    2, 0x0a /* Public */,
      15,    1,  106,    2, 0x0a /* Public */,
      16,    1,  109,    2, 0x0a /* Public */,
      17,    1,  112,    2, 0x0a /* Public */,
      18,    8,  115,    2, 0x0a /* Public */,
      20,    8,  132,    2, 0x0a /* Public */,
      21,    1,  149,    2, 0x0a /* Public */,
      23,    1,  152,    2, 0x0a /* Public */,
      24,    1,  155,    2, 0x0a /* Public */,
      26,    1,  158,    2, 0x0a /* Public */,
      27,    1,  161,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool, QMetaType::QString, QMetaType::QString,    3,    4,    5,    6,    7,    8,    9,

 // slots: parameters
    QMetaType::QVariantMap,
    QMetaType::Void, QMetaType::QVariantMap,   12,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool, QMetaType::QString, QMetaType::QString,   19,    3,    4,    5,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int, QMetaType::QString, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool, QMetaType::Bool, QMetaType::QString, QMetaType::QString,   19,    3,    4,    5,    6,    7,    8,    9,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void, QMetaType::Bool,   25,
    QMetaType::Void, QMetaType::Bool,   25,
    QMetaType::Void, 0x80000000 | 28,   19,

 // properties: name, type, flags
      22, QMetaType::Int, 0x00095103,
      25, QMetaType::Bool, 0x00095103,

       0        // eod
};

void HighlightRuleManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<HighlightRuleManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->ruleAdded((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< QString(*)>(_a[6])),(*reinterpret_cast< QString(*)>(_a[7]))); break;
        case 1: { QVariantMap _r = _t->initHighlightRuleList();
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->initSetHighlightRuleList((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 3: _t->requestRemoveHighlightRule((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->removeHighlightRule((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->requestToggleHighlightRule((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->toggleHighlightRule((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->requestAddHighlightRule((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< bool(*)>(_a[6])),(*reinterpret_cast< const QString(*)>(_a[7])),(*reinterpret_cast< const QString(*)>(_a[8]))); break;
        case 8: _t->addHighlightRule((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5])),(*reinterpret_cast< bool(*)>(_a[6])),(*reinterpret_cast< const QString(*)>(_a[7])),(*reinterpret_cast< const QString(*)>(_a[8]))); break;
        case 9: _t->requestSetHighlightNick((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->setHighlightNick((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->requestSetNicksCaseSensitive((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->setNicksCaseSensitive((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->networkRemoved((*reinterpret_cast< NetworkId(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetworkId >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (HighlightRuleManager::*)(QString , bool , bool , bool , bool , QString , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HighlightRuleManager::ruleAdded)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<HighlightRuleManager *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->highlightNick(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->nicksCaseSensitive(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<HighlightRuleManager *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setHighlightNick(*reinterpret_cast< int*>(_v)); break;
        case 1: _t->setNicksCaseSensitive(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject HighlightRuleManager::staticMetaObject = { {
    QMetaObject::SuperData::link<SyncableObject::staticMetaObject>(),
    qt_meta_stringdata_HighlightRuleManager.data,
    qt_meta_data_HighlightRuleManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *HighlightRuleManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HighlightRuleManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_HighlightRuleManager.stringdata0))
        return static_cast<void*>(this);
    return SyncableObject::qt_metacast(_clname);
}

int HighlightRuleManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SyncableObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void HighlightRuleManager::ruleAdded(QString _t1, bool _t2, bool _t3, bool _t4, bool _t5, QString _t6, QString _t7)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t6))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t7))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
