/****************************************************************************
** Meta object code from reading C++ file 'corenetworkconfig.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/corenetworkconfig.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'corenetworkconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreNetworkConfig_t {
    QByteArrayData data[15];
    char stringdata0[257];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreNetworkConfig_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreNetworkConfig_t qt_meta_stringdata_CoreNetworkConfig = {
    {
QT_MOC_LITERAL(0, 0, 17), // "CoreNetworkConfig"
QT_MOC_LITERAL(1, 18, 28), // "requestSetPingTimeoutEnabled"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 7), // "enabled"
QT_MOC_LITERAL(4, 56, 22), // "requestSetPingInterval"
QT_MOC_LITERAL(5, 79, 8), // "interval"
QT_MOC_LITERAL(6, 88, 22), // "requestSetMaxPingCount"
QT_MOC_LITERAL(7, 111, 5), // "count"
QT_MOC_LITERAL(8, 117, 24), // "requestSetAutoWhoEnabled"
QT_MOC_LITERAL(9, 142, 25), // "requestSetAutoWhoInterval"
QT_MOC_LITERAL(10, 168, 26), // "requestSetAutoWhoNickLimit"
QT_MOC_LITERAL(11, 195, 9), // "nickLimit"
QT_MOC_LITERAL(12, 205, 22), // "requestSetAutoWhoDelay"
QT_MOC_LITERAL(13, 228, 5), // "delay"
QT_MOC_LITERAL(14, 234, 22) // "requestSetStandardCtcp"

    },
    "CoreNetworkConfig\0requestSetPingTimeoutEnabled\0"
    "\0enabled\0requestSetPingInterval\0"
    "interval\0requestSetMaxPingCount\0count\0"
    "requestSetAutoWhoEnabled\0"
    "requestSetAutoWhoInterval\0"
    "requestSetAutoWhoNickLimit\0nickLimit\0"
    "requestSetAutoWhoDelay\0delay\0"
    "requestSetStandardCtcp"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreNetworkConfig[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x0a /* Public */,
       4,    1,   57,    2, 0x0a /* Public */,
       6,    1,   60,    2, 0x0a /* Public */,
       8,    1,   63,    2, 0x0a /* Public */,
       9,    1,   66,    2, 0x0a /* Public */,
      10,    1,   69,    2, 0x0a /* Public */,
      12,    1,   72,    2, 0x0a /* Public */,
      14,    1,   75,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Bool,    3,

       0        // eod
};

void CoreNetworkConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreNetworkConfig *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->requestSetPingTimeoutEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->requestSetPingInterval((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->requestSetMaxPingCount((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->requestSetAutoWhoEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->requestSetAutoWhoInterval((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->requestSetAutoWhoNickLimit((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->requestSetAutoWhoDelay((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->requestSetStandardCtcp((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreNetworkConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<NetworkConfig::staticMetaObject>(),
    qt_meta_stringdata_CoreNetworkConfig.data,
    qt_meta_data_CoreNetworkConfig,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreNetworkConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreNetworkConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreNetworkConfig.stringdata0))
        return static_cast<void*>(this);
    return NetworkConfig::qt_metacast(_clname);
}

int CoreNetworkConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetworkConfig::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
