/****************************************************************************
** Meta object code from reading C++ file 'corebasichandler.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/core/corebasichandler.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'corebasichandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CoreBasicHandler_t {
    QByteArrayData data[14];
    char stringdata0[156];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CoreBasicHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CoreBasicHandler_t qt_meta_stringdata_CoreBasicHandler = {
    {
QT_MOC_LITERAL(0, 0, 16), // "CoreBasicHandler"
QT_MOC_LITERAL(1, 17, 10), // "displayMsg"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 22), // "NetworkInternalMessage"
QT_MOC_LITERAL(4, 52, 3), // "msg"
QT_MOC_LITERAL(5, 56, 10), // "putRawLine"
QT_MOC_LITERAL(6, 67, 7), // "prepend"
QT_MOC_LITERAL(7, 75, 6), // "putCmd"
QT_MOC_LITERAL(8, 82, 3), // "cmd"
QT_MOC_LITERAL(9, 86, 6), // "params"
QT_MOC_LITERAL(10, 93, 6), // "prefix"
QT_MOC_LITERAL(11, 100, 24), // "QHash<IrcTagKey,QString>"
QT_MOC_LITERAL(12, 125, 4), // "tags"
QT_MOC_LITERAL(13, 130, 25) // "QList<QList<QByteArray> >"

    },
    "CoreBasicHandler\0displayMsg\0\0"
    "NetworkInternalMessage\0msg\0putRawLine\0"
    "prepend\0putCmd\0cmd\0params\0prefix\0"
    "QHash<IrcTagKey,QString>\0tags\0"
    "QList<QList<QByteArray> >"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CoreBasicHandler[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      11,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x06 /* Public */,
       5,    2,   72,    2, 0x06 /* Public */,
       5,    1,   77,    2, 0x26 /* Public | MethodCloned */,
       7,    5,   80,    2, 0x06 /* Public */,
       7,    4,   91,    2, 0x26 /* Public | MethodCloned */,
       7,    3,  100,    2, 0x26 /* Public | MethodCloned */,
       7,    2,  107,    2, 0x26 /* Public | MethodCloned */,
       7,    5,  112,    2, 0x06 /* Public */,
       7,    4,  123,    2, 0x26 /* Public | MethodCloned */,
       7,    3,  132,    2, 0x26 /* Public | MethodCloned */,
       7,    2,  139,    2, 0x26 /* Public | MethodCloned */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::QByteArray, QMetaType::Bool,    4,    6,
    QMetaType::Void, QMetaType::QByteArray,    4,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArrayList, QMetaType::QByteArray, 0x80000000 | 11, QMetaType::Bool,    8,    9,   10,   12,    6,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArrayList, QMetaType::QByteArray, 0x80000000 | 11,    8,    9,   10,   12,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArrayList, QMetaType::QByteArray,    8,    9,   10,
    QMetaType::Void, QMetaType::QString, QMetaType::QByteArrayList,    8,    9,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 13, QMetaType::QByteArray, 0x80000000 | 11, QMetaType::Bool,    8,    9,   10,   12,    6,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 13, QMetaType::QByteArray, 0x80000000 | 11,    8,    9,   10,   12,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 13, QMetaType::QByteArray,    8,    9,   10,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 13,    8,    9,

       0        // eod
};

void CoreBasicHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<CoreBasicHandler *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->displayMsg((*reinterpret_cast< const NetworkInternalMessage(*)>(_a[1]))); break;
        case 1: _t->putRawLine((*reinterpret_cast< const QByteArray(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 2: _t->putRawLine((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 3: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QByteArray>(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3])),(*reinterpret_cast< const QHash<IrcTagKey,QString>(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        case 4: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QByteArray>(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3])),(*reinterpret_cast< const QHash<IrcTagKey,QString>(*)>(_a[4]))); break;
        case 5: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QByteArray>(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3]))); break;
        case 6: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QByteArray>(*)>(_a[2]))); break;
        case 7: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QList<QByteArray> >(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3])),(*reinterpret_cast< const QHash<IrcTagKey,QString>(*)>(_a[4])),(*reinterpret_cast< bool(*)>(_a[5]))); break;
        case 8: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QList<QByteArray> >(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3])),(*reinterpret_cast< const QHash<IrcTagKey,QString>(*)>(_a[4]))); break;
        case 9: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QList<QByteArray> >(*)>(_a[2])),(*reinterpret_cast< const QByteArray(*)>(_a[3]))); break;
        case 10: _t->putCmd((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QList<QList<QByteArray> >(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QList<QByteArray> > >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QList<QByteArray> > >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QList<QByteArray> > >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QList<QByteArray> > >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (CoreBasicHandler::*)(const NetworkInternalMessage & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreBasicHandler::displayMsg)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (CoreBasicHandler::*)(const QByteArray & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreBasicHandler::putRawLine)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (CoreBasicHandler::*)(const QString & , const QList<QByteArray> & , const QByteArray & , const QHash<IrcTagKey,QString> & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreBasicHandler::putCmd)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (CoreBasicHandler::*)(const QString & , const QList<QList<QByteArray>> & , const QByteArray & , const QHash<IrcTagKey,QString> & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CoreBasicHandler::putCmd)) {
                *result = 7;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject CoreBasicHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<BasicHandler::staticMetaObject>(),
    qt_meta_stringdata_CoreBasicHandler.data,
    qt_meta_data_CoreBasicHandler,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *CoreBasicHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CoreBasicHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CoreBasicHandler.stringdata0))
        return static_cast<void*>(this);
    return BasicHandler::qt_metacast(_clname);
}

int CoreBasicHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BasicHandler::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void CoreBasicHandler::displayMsg(const NetworkInternalMessage & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void CoreBasicHandler::putRawLine(const QByteArray & _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 3
void CoreBasicHandler::putCmd(const QString & _t1, const QList<QByteArray> & _t2, const QByteArray & _t3, const QHash<IrcTagKey,QString> & _t4, bool _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 7
void CoreBasicHandler::putCmd(const QString & _t1, const QList<QList<QByteArray>> & _t2, const QByteArray & _t3, const QHash<IrcTagKey,QString> & _t4, bool _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
