/****************************************************************************
** Meta object code from reading C++ file 'bufferviewoverlay.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../quassel-0.14.0/src/client/bufferviewoverlay.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bufferviewoverlay.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BufferViewOverlay_t {
    QByteArrayData data[14];
    char stringdata0[132];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BufferViewOverlay_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BufferViewOverlay_t qt_meta_stringdata_BufferViewOverlay = {
    {
QT_MOC_LITERAL(0, 0, 17), // "BufferViewOverlay"
QT_MOC_LITERAL(1, 18, 10), // "hasChanged"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 8), // "initDone"
QT_MOC_LITERAL(4, 39, 7), // "addView"
QT_MOC_LITERAL(5, 47, 6), // "viewId"
QT_MOC_LITERAL(6, 54, 10), // "removeView"
QT_MOC_LITERAL(7, 65, 5), // "reset"
QT_MOC_LITERAL(8, 71, 4), // "save"
QT_MOC_LITERAL(9, 76, 7), // "restore"
QT_MOC_LITERAL(10, 84, 6), // "update"
QT_MOC_LITERAL(11, 91, 15), // "viewInitialized"
QT_MOC_LITERAL(12, 107, 17), // "BufferViewConfig*"
QT_MOC_LITERAL(13, 125, 6) // "config"

    },
    "BufferViewOverlay\0hasChanged\0\0initDone\0"
    "addView\0viewId\0removeView\0reset\0save\0"
    "restore\0update\0viewInitialized\0"
    "BufferViewConfig*\0config"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BufferViewOverlay[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x06 /* Public */,
       3,    0,   65,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   66,    2, 0x0a /* Public */,
       6,    1,   69,    2, 0x0a /* Public */,
       7,    0,   72,    2, 0x0a /* Public */,
       8,    0,   73,    2, 0x0a /* Public */,
       9,    0,   74,    2, 0x0a /* Public */,
      10,    0,   75,    2, 0x0a /* Public */,
      11,    0,   76,    2, 0x08 /* Private */,
      11,    1,   77,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 12,   13,

       0        // eod
};

void BufferViewOverlay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BufferViewOverlay *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->hasChanged(); break;
        case 1: _t->initDone(); break;
        case 2: _t->addView((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->removeView((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->reset(); break;
        case 5: _t->save(); break;
        case 6: _t->restore(); break;
        case 7: _t->update(); break;
        case 8: _t->viewInitialized(); break;
        case 9: _t->viewInitialized((*reinterpret_cast< BufferViewConfig*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BufferViewOverlay::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferViewOverlay::hasChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (BufferViewOverlay::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BufferViewOverlay::initDone)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BufferViewOverlay::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_BufferViewOverlay.data,
    qt_meta_data_BufferViewOverlay,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BufferViewOverlay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BufferViewOverlay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BufferViewOverlay.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int BufferViewOverlay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void BufferViewOverlay::hasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BufferViewOverlay::initDone()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
